@@ -43,24 +43,6 @@ CREATE TABLE person (
     notes text
 );
 
-CREATE TABLE bank (
-    id serial NOT NULL PRIMARY KEY,
-    te_created_id bigint UNIQUE REFERENCES transaction_entry(id),
-    te_modified_id bigint UNIQUE REFERENCES transaction_entry(id),
-    name text,
-    short_name text,
-    compensation_code text
-);
-
-CREATE TABLE person_adapt_to_bank_branch (
-    id serial NOT NULL PRIMARY KEY,
-    te_modified_id bigint UNIQUE REFERENCES transaction_entry(id),
-    te_created_id bigint UNIQUE REFERENCES transaction_entry(id),
-    is_active boolean,
-    bank_id bigint REFERENCES bank(id),
-    original_id bigint UNIQUE REFERENCES person(id)
-);
-
 CREATE TABLE client_category (
     id serial NOT NULL PRIMARY KEY,
     te_created_id bigint UNIQUE REFERENCES transaction_entry(id),
@@ -68,7 +50,7 @@ CREATE TABLE client_category (
     name text UNIQUE
 );
 
-CREATE TABLE person_adapt_to_client (
+CREATE TABLE client (
     id serial NOT NULL PRIMARY KEY,
     te_modified_id bigint UNIQUE REFERENCES transaction_entry(id),
     te_created_id bigint UNIQUE REFERENCES transaction_entry(id),
@@ -79,11 +61,11 @@ CREATE TABLE person_adapt_to_client (
     credit_limit numeric(20, 2) CONSTRAINT positive_credit_limit
         CHECK (credit_limit >= 0)
         DEFAULT 0,
-    original_id bigint UNIQUE REFERENCES person(id),
+    person_id bigint UNIQUE REFERENCES person(id),
     category_id bigint REFERENCES client_category(id)
 );
 
-CREATE TABLE person_adapt_to_company (
+CREATE TABLE company (
     id serial NOT NULL PRIMARY KEY,
     te_modified_id bigint UNIQUE REFERENCES transaction_entry(id),
     te_created_id bigint UNIQUE REFERENCES transaction_entry(id),
@@ -92,10 +74,10 @@ CREATE TABLE person_adapt_to_company (
     fancy_name text,
     state_registry text,
     city_registry text,
-    original_id bigint UNIQUE REFERENCES person(id)
+    person_id bigint UNIQUE REFERENCES person(id)
 );
 
-CREATE TABLE person_adapt_to_credit_provider (
+CREATE TABLE credit_provider (
     id serial NOT NULL PRIMARY KEY,
     te_modified_id bigint UNIQUE REFERENCES transaction_entry(id),
     te_created_id bigint UNIQUE REFERENCES transaction_entry(id),
@@ -132,7 +114,7 @@ CREATE TABLE person_adapt_to_credit_provider (
     short_name text,
     provider_id text,
     open_contract_date timestamp,
-    original_id bigint UNIQUE REFERENCES person(id)
+    person_id bigint UNIQUE REFERENCES person(id)
 );
 
 CREATE TABLE city_location (
@@ -145,7 +127,7 @@ CREATE TABLE city_location (
     UNIQUE(country, state, city)
 );
 
-CREATE TABLE person_adapt_to_individual (
+CREATE TABLE individual (
     id serial NOT NULL PRIMARY KEY,
     te_modified_id bigint UNIQUE REFERENCES transaction_entry(id),
     te_created_id bigint UNIQUE REFERENCES transaction_entry(id),
@@ -164,7 +146,7 @@ CREATE TABLE person_adapt_to_individual (
         CHECK (gender >= 0 AND gender < 2),
     spouse_name text,
     birth_location_id bigint REFERENCES city_location(id),
-    original_id bigint UNIQUE REFERENCES person(id)
+    person_id bigint UNIQUE REFERENCES person(id)
 );
 
 CREATE TABLE employee_role (
@@ -207,13 +189,24 @@ CREATE TABLE bank_account (
     id serial NOT NULL PRIMARY KEY,
     te_created_id bigint UNIQUE REFERENCES transaction_entry(id),
     te_modified_id bigint UNIQUE REFERENCES transaction_entry(id),
-    bank_id integer CONSTRAINT positive_bank_id
-        CHECK (bank_id >= 0),
-    branch text,
-    account text
+    -- bank_account bigint UNIQUE REFERENCES account(id),
+    bank_number integer CONSTRAINT positive_bank_number
+        CHECK (bank_number >= 0),
+    bank_branch text,
+    bank_account text,
+    bank_type bigint
 );
 
-CREATE TABLE person_adapt_to_employee (
+CREATE TABLE bill_option (
+    id serial NOT NULL PRIMARY KEY,
+    te_created_id bigint UNIQUE REFERENCES transaction_entry(id),
+    te_modified_id bigint UNIQUE REFERENCES transaction_entry(id),
+    option text,
+    value text,
+    bank_account_id bigint REFERENCES bank_account(id)
+);
+
+CREATE TABLE employee (
     id serial NOT NULL PRIMARY KEY,
     te_modified_id bigint UNIQUE REFERENCES transaction_entry(id),
     te_created_id bigint UNIQUE REFERENCES transaction_entry(id),
@@ -232,20 +225,20 @@ CREATE TABLE person_adapt_to_employee (
     military_data_id bigint REFERENCES military_data(id),
     voter_data_id bigint REFERENCES voter_data(id),
     bank_account_id bigint REFERENCES bank_account(id),
-    original_id bigint UNIQUE REFERENCES person(id)
+    person_id bigint UNIQUE REFERENCES person(id)
 );
 
-CREATE TABLE person_adapt_to_branch (
+CREATE TABLE branch (
     id serial NOT NULL PRIMARY KEY,
     te_modified_id bigint UNIQUE REFERENCES transaction_entry(id),
     te_created_id bigint UNIQUE REFERENCES transaction_entry(id),
-    manager_id bigint REFERENCES person_adapt_to_employee(id),
+    manager_id bigint REFERENCES employee(id),
     is_active boolean,
     crt integer DEFAULT 1,
-    original_id bigint UNIQUE REFERENCES person(id)
+    person_id bigint UNIQUE REFERENCES person(id)
 );
 
-CREATE TABLE person_adapt_to_sales_person (
+CREATE TABLE sales_person (
     id serial NOT NULL PRIMARY KEY,
     te_modified_id bigint UNIQUE REFERENCES transaction_entry(id),
     te_created_id bigint UNIQUE REFERENCES transaction_entry(id),
@@ -254,10 +247,10 @@ CREATE TABLE person_adapt_to_sales_person (
     comission_type integer CONSTRAINT check_valid_comission_type
         CHECK (comission_type >= 0 AND comission_type < 7),
     is_active boolean,
-    original_id bigint UNIQUE REFERENCES person(id)
+    person_id bigint UNIQUE REFERENCES person(id)
 );
 
-CREATE TABLE person_adapt_to_supplier (
+CREATE TABLE supplier (
     id serial NOT NULL PRIMARY KEY,
     te_modified_id bigint UNIQUE REFERENCES transaction_entry(id),
     te_created_id bigint UNIQUE REFERENCES transaction_entry(id),
@@ -265,10 +258,10 @@ CREATE TABLE person_adapt_to_supplier (
     status integer CONSTRAINT valid_status
         CHECK (status >= 0 AND status < 3),
     product_desc text,
-    original_id bigint UNIQUE REFERENCES person(id)
+    person_id bigint UNIQUE REFERENCES person(id)
 );
 
-CREATE TABLE person_adapt_to_transporter (
+CREATE TABLE transporter (
     id serial NOT NULL PRIMARY KEY,
     te_modified_id bigint UNIQUE REFERENCES transaction_entry(id),
     te_created_id bigint UNIQUE REFERENCES transaction_entry(id),
@@ -277,7 +270,7 @@ CREATE TABLE person_adapt_to_transporter (
     freight_percentage numeric(10, 2) NOT NULL
         CONSTRAINT positive_freight_percentage
         CHECK (freight_percentage >= 0),
-    original_id bigint UNIQUE REFERENCES person(id)
+    person_id bigint UNIQUE REFERENCES person(id)
 );
 
 CREATE TABLE user_profile (
@@ -287,7 +280,7 @@ CREATE TABLE user_profile (
     name text
 );
 
-CREATE TABLE person_adapt_to_user (
+CREATE TABLE login_user (
     id serial NOT NULL PRIMARY KEY,
     te_modified_id bigint UNIQUE REFERENCES transaction_entry(id),
     te_created_id bigint UNIQUE REFERENCES transaction_entry(id),
@@ -295,7 +288,7 @@ CREATE TABLE person_adapt_to_user (
     "password" text,
     is_active boolean,
     profile_id bigint REFERENCES user_profile(id),
-    original_id bigint UNIQUE REFERENCES person(id)
+    person_id bigint UNIQUE REFERENCES person(id)
 );
 
 CREATE TABLE product_tax_template (
@@ -306,24 +299,13 @@ CREATE TABLE product_tax_template (
     tax_type integer
 );
 
-CREATE TABLE base_sellable_info (
+CREATE TABLE image (
     id serial NOT NULL PRIMARY KEY,
     te_created_id bigint UNIQUE REFERENCES transaction_entry(id),
     te_modified_id bigint UNIQUE REFERENCES transaction_entry(id),
-    price numeric(20, 2) CONSTRAINT positive_price CHECK (price >= 0),
-    description text,
-    max_discount numeric(10, 2),
-    commission numeric(10, 2)
-);
-
-CREATE TABLE on_sale_info (
-    id serial NOT NULL PRIMARY KEY,
-    te_created_id bigint UNIQUE REFERENCES transaction_entry(id),
-    te_modified_id bigint UNIQUE REFERENCES transaction_entry(id),
-    on_sale_price numeric(20, 2) CONSTRAINT positive_on_sale_price
-       CHECK (on_sale_price >= 0),
-    on_sale_start_date timestamp,
-    on_sale_end_date timestamp
+    image bytea,
+    thumbnail bytea,
+    description text
 );
 
 CREATE TABLE sellable_tax_constant (
@@ -373,12 +355,20 @@ CREATE TABLE sellable (
     code text,
     status integer CONSTRAINT valid_status
         CHECK (status >= 0 AND status < 4),
+    description text,
     cost numeric(20, 8) CONSTRAINT positive_cost
         CHECK (cost >= 0),
+    base_price numeric(20, 2) CONSTRAINT positive_price
+        CHECK (base_price >= 0),
     notes text,
+    max_discount numeric(10, 2),
+    commission numeric(10, 2),
+    on_sale_price numeric(20, 2) CONSTRAINT positive_on_sale_price
+       CHECK (on_sale_price >= 0),
+    on_sale_start_date timestamp,
+    on_sale_end_date timestamp,
+    image_id bigint UNIQUE REFERENCES image(id),
     unit_id bigint REFERENCES sellable_unit(id),
-    base_sellable_info_id bigint REFERENCES base_sellable_info(id),
-    on_sale_info_id bigint REFERENCES on_sale_info(id),
     category_id bigint REFERENCES sellable_category(id),
     tax_constant_id bigint REFERENCES sellable_tax_constant(id),
     default_sale_cfop_id bigint REFERENCES cfop_data(id)
@@ -426,14 +416,14 @@ CREATE TABLE product (
     te_created_id bigint UNIQUE REFERENCES transaction_entry(id),
     te_modified_id bigint UNIQUE REFERENCES transaction_entry(id),
     consignment boolean NOT NULL DEFAULT FALSE,
-    full_image bytea,
-    image bytea,
     location text,
     part_number text,
     manufacturer text,
     ncm text,
     ex_tipi text,
     genero text,
+    production_time integer DEFAULT 0,
+    is_composed boolean DEFAULT FALSE,
     width numeric(10, 2) CONSTRAINT positive_width
         CHECK (width >= 0),
     height numeric(10, 2) CONSTRAINT positive_height
@@ -459,11 +449,11 @@ CREATE TABLE product_component (
         CONSTRAINT different_products CHECK (product_id != component_id)
 );
 
-CREATE TABLE product_adapt_to_storable (
+CREATE TABLE storable (
     id serial NOT NULL PRIMARY KEY,
     te_created_id bigint UNIQUE REFERENCES transaction_entry(id),
     te_modified_id bigint UNIQUE REFERENCES transaction_entry(id),
-    original_id bigint UNIQUE REFERENCES product(id),
+    product_id bigint UNIQUE REFERENCES product(id),
     minimum_quantity numeric(20, 3) DEFAULT 0
         CONSTRAINT positive_minimum_quantity CHECK (minimum_quantity >= 0),
     maximum_quantity numeric(20, 3) DEFAULT 0
@@ -483,7 +473,7 @@ CREATE TABLE product_supplier_info (
     lead_time integer DEFAULT 1 CONSTRAINT positive_lead_time
         CHECK (lead_time > 0),
     minimum_purchase numeric(20, 3) DEFAULT 1,
-    supplier_id bigint NOT NULL REFERENCES person_adapt_to_supplier(id),
+    supplier_id bigint NOT NULL REFERENCES supplier(id),
     product_id bigint NOT NULL REFERENCES product(id)
 );
 
@@ -509,7 +499,7 @@ CREATE TABLE product_history (
     decreased_date timestamp,
     quantity_decreased numeric(20, 3) CONSTRAINT positive_decreased
         CHECK (quantity_decreased > 0),
-    branch_id bigint REFERENCES person_adapt_to_branch(id),
+    branch_id bigint REFERENCES branch(id),
     sellable_id bigint REFERENCES sellable(id)
 );
 
@@ -517,8 +507,7 @@ CREATE TABLE service (
     id serial NOT NULL PRIMARY KEY,
     te_created_id bigint UNIQUE REFERENCES transaction_entry(id),
     te_modified_id bigint UNIQUE REFERENCES transaction_entry(id),
-    sellable_id bigint REFERENCES sellable(id),
-    image bytea
+    sellable_id bigint REFERENCES sellable(id)
 );
 
 CREATE TABLE payment_renegotiation (
@@ -536,9 +525,9 @@ CREATE TABLE payment_renegotiation (
     total numeric(20, 2) CONSTRAINT positive_total
         CHECK (total >= 0),
     notes text,
-    client_id bigint REFERENCES person_adapt_to_client(id),
-    responsible_id bigint REFERENCES person_adapt_to_user(id),
-    branch_id bigint REFERENCES person_adapt_to_branch(id)
+    client_id bigint REFERENCES client(id),
+    responsible_id bigint REFERENCES login_user(id),
+    branch_id bigint REFERENCES branch(id)
     -- group_id bigint REFERENCES payment_group(id)
 );
 
@@ -598,10 +587,10 @@ CREATE TABLE purchase_order (
     discount_value numeric(20, 2) CONSTRAINT positive_discount_value
         CHECK (discount_value >= 0),
     consigned boolean DEFAULT FALSE,
-    supplier_id bigint REFERENCES person_adapt_to_supplier(id),
-    branch_id bigint REFERENCES person_adapt_to_branch(id),
-    transporter_id bigint REFERENCES person_adapt_to_transporter(id),
-    responsible_id bigint REFERENCES person_adapt_to_user(id),
+    supplier_id bigint REFERENCES supplier(id),
+    branch_id bigint REFERENCES branch(id),
+    transporter_id bigint REFERENCES transporter(id),
+    responsible_id bigint REFERENCES login_user(id),
     group_id bigint REFERENCES payment_group(id)
 );
 
@@ -627,6 +616,7 @@ CREATE TABLE purchase_item (
     quantity_returned numeric(20, 3) CONSTRAINT positive_quantity_returned
         CHECK (quantity_returned >= 0 AND
                quantity_returned <= quantity_received - quantity_sold)
+        DEFAULT 0
 );
 
 CREATE TABLE quote_group (
@@ -650,7 +640,7 @@ CREATE TABLE branch_station (
     te_modified_id bigint UNIQUE REFERENCES transaction_entry(id),
     name text UNIQUE,
     is_active boolean,
-    branch_id bigint REFERENCES person_adapt_to_branch(id)
+    branch_id bigint REFERENCES branch(id)
 );
 
 CREATE TABLE till (
@@ -668,6 +658,18 @@ CREATE TABLE till (
     station_id bigint REFERENCES branch_station(id)
 );
 
+CREATE TABLE client_category_price (
+    id serial NOT NULL PRIMARY KEY,
+    te_created_id bigint UNIQUE REFERENCES transaction_entry(id),
+    te_modified_id bigint UNIQUE REFERENCES transaction_entry(id),
+    sellable_id bigint REFERENCES sellable(id),
+    category_id bigint REFERENCES client_category(id),
+    price numeric(10,2) CONSTRAINT positive_price CHECK (price >= 0),
+    max_discount numeric(10,2),
+    commission numeric(10,2),
+    UNIQUE (sellable_id, category_id)
+);
+
 CREATE TABLE sale (
     id serial NOT NULL PRIMARY KEY,
     te_created_id bigint UNIQUE REFERENCES transaction_entry(id),
@@ -693,12 +695,13 @@ CREATE TABLE sale (
     expire_date timestamp,
     operation_nature text,
     notes text,
-    client_id bigint REFERENCES person_adapt_to_client(id),
+    client_id bigint REFERENCES client(id),
+    client_category_id bigint REFERENCES client_category(id),
     cfop_id bigint REFERENCES cfop_data(id),
-    salesperson_id bigint REFERENCES person_adapt_to_sales_person(id),
-    branch_id bigint REFERENCES person_adapt_to_branch(id),
+    salesperson_id bigint REFERENCES sales_person(id),
+    branch_id bigint REFERENCES branch(id),
     group_id bigint REFERENCES payment_group(id),
-    transporter_id bigint REFERENCES person_adapt_to_transporter(id)
+    transporter_id bigint REFERENCES transporter(id)
 );
 
 CREATE TABLE sale_item_icms (
@@ -766,14 +769,24 @@ CREATE TABLE sale_item (
     cfop_id bigint REFERENCES cfop_data(id)
 );
 
-CREATE TABLE sale_item_adapt_to_delivery (
+CREATE TABLE delivery (
     id serial NOT NULL PRIMARY KEY,
     te_created_id bigint UNIQUE REFERENCES transaction_entry(id),
     te_modified_id bigint UNIQUE REFERENCES transaction_entry(id),
-    address text,
-    original_id bigint UNIQUE REFERENCES sale_item(id)
+    status integer CONSTRAINT valid_status
+        CHECK (status >= 0 AND status < 3),
+    open_date timestamp,
+    deliver_date timestamp,
+    receive_date timestamp,
+    tracking_code text,
+    address_id bigint REFERENCES address(id),
+    transporter_id bigint REFERENCES transporter(id),
+    service_item_id bigint REFERENCES sale_item(id)
 );
 
+ALTER TABLE sale_item ADD COLUMN delivery_id bigint
+    REFERENCES delivery(id);
+
 CREATE TABLE product_stock_item (
     id serial NOT NULL PRIMARY KEY,
     te_created_id bigint UNIQUE REFERENCES transaction_entry(id),
@@ -781,10 +794,8 @@ CREATE TABLE product_stock_item (
     stock_cost numeric(20, 8),
     quantity numeric(20, 3) CONSTRAINT positive_quantity
         CHECK (quantity >= 0),
-    logic_quantity numeric(20, 3) CONSTRAINT positive_logic_quantity
-        CHECK (logic_quantity >= 0),
     storable_id bigint REFERENCES product_adapt_to_storable(id),
-    branch_id bigint REFERENCES person_adapt_to_branch(id)
+    branch_id bigint REFERENCES branch(id)
 );
 
 CREATE TABLE address (
@@ -805,7 +816,7 @@ CREATE TABLE address (
 CREATE TABLE branch_synchronization (
     id serial NOT NULL PRIMARY KEY,
     sync_time timestamp  NOT NULL,
-    branch_id bigint REFERENCES person_adapt_to_branch(id),
+    branch_id bigint REFERENCES branch(id),
     policy text NOT NULL
 );
 
@@ -815,8 +826,9 @@ CREATE TABLE calls (
     te_modified_id bigint UNIQUE REFERENCES transaction_entry(id),
     date timestamp,
     message text,
+    description text,
     person_id bigint REFERENCES person(id),
-    attendant_id bigint REFERENCES person_adapt_to_user(id)
+    attendant_id bigint REFERENCES login_user(id)
 );
 
 CREATE TABLE card_installment_settings (
@@ -854,6 +866,9 @@ CREATE TABLE account (
     station_id bigint REFERENCES branch_station(id)
 );
 
+ALTER TABLE bank_account ADD COLUMN account_id bigint
+    UNIQUE REFERENCES account(id);
+
 CREATE TABLE payment_method (
     id serial NOT NULL PRIMARY KEY,
     is_active boolean,
@@ -879,6 +894,8 @@ CREATE TABLE payment_category (
     te_created_id bigint UNIQUE REFERENCES transaction_entry(id),
     te_modified_id bigint UNIQUE REFERENCES transaction_entry(id),
     name text UNIQUE,
+    category_type integer DEFAULT 0 CONSTRAINT valid_category_type
+        CHECK (category_type >= 0 AND category_type <= 1),
     color text
 );
 
@@ -886,6 +903,8 @@ CREATE TABLE payment (
     id serial NOT NULL PRIMARY KEY,
     te_created_id bigint UNIQUE REFERENCES transaction_entry(id),
     te_modified_id bigint UNIQUE REFERENCES transaction_entry(id),
+    payment_type integer CONSTRAINT valid_payment_type
+        CHECK (payment_type >= 0 AND payment_type < 2),
     status integer CONSTRAINT valid_status
         CHECK (status >= 0 AND status < 6),
     open_date timestamp,
@@ -920,7 +939,7 @@ CREATE TABLE payment_comment (
     date timestamp,
     comment text,
     payment_id bigint REFERENCES payment(id),
-    author_id bigint REFERENCES person_adapt_to_user(id)
+    author_id bigint REFERENCES login_user(id)
 );
 
 CREATE TABLE check_data (
@@ -928,7 +947,7 @@ CREATE TABLE check_data (
     te_created_id bigint UNIQUE REFERENCES transaction_entry(id),
     te_modified_id bigint UNIQUE REFERENCES transaction_entry(id),
     payment_id bigint REFERENCES payment(id),
-    bank_data_id bigint REFERENCES bank_account(id)
+    bank_account_id bigint REFERENCES bank_account(id)
 );
 
 CREATE TABLE credit_card_details (
@@ -955,7 +974,7 @@ CREATE TABLE credit_card_data (
     fee numeric(10, 2) NOT NULL DEFAULT 0,
     fee_value numeric(20, 2) DEFAULT 0,
     payment_id bigint UNIQUE REFERENCES payment(id),
-    provider_id bigint REFERENCES person_adapt_to_credit_provider(id)
+    provider_id bigint REFERENCES credit_provider(id)
 );
 
 CREATE TABLE payment_change_history (
@@ -991,10 +1010,10 @@ CREATE TABLE device_settings (
         CHECK (type >= 0 AND type < 4),
     brand text,
     model text,
-    device integer CONSTRAINT valid_device
-        CHECK (device >= 0 AND device < 4),
+    device_name text,
     is_active boolean,
-    station_id bigint REFERENCES branch_station(id)
+    station_id bigint REFERENCES branch_station(id),
+    UNIQUE (device_name, station_id)
 );
 
 
@@ -1014,6 +1033,9 @@ CREATE TABLE device_constant (
                (constant_enum >= 40 AND constant_enum < 46)),
     device_value bytea,
     device_settings_id bigint REFERENCES device_settings(id)
+    -- FIXME: This is needed by the ECF plugin which doesn't have
+    --        infrastructure to deal with schema generations
+    ,is_valid_model bool
 );
 
 CREATE TABLE employee_role_history (
@@ -1024,7 +1046,7 @@ CREATE TABLE employee_role_history (
     ended timestamp,
     salary numeric(20, 2),
     role_id bigint REFERENCES employee_role(id),
-    employee_id bigint REFERENCES person_adapt_to_employee(id),
+    employee_id bigint REFERENCES employee(id),
     is_active boolean
 );
 
@@ -1046,20 +1068,6 @@ CREATE TABLE parameter_data (
     is_editable boolean
 );
 
-CREATE TABLE payment_adapt_to_in_payment (
-    id serial NOT NULL PRIMARY KEY,
-    te_created_id bigint UNIQUE REFERENCES transaction_entry(id),
-    te_modified_id bigint UNIQUE REFERENCES transaction_entry(id),
-    original_id bigint UNIQUE REFERENCES payment(id)
-);
-
-CREATE TABLE payment_adapt_to_out_payment (
-    id serial NOT NULL PRIMARY KEY,
-    te_created_id bigint UNIQUE REFERENCES transaction_entry(id),
-    te_modified_id bigint UNIQUE REFERENCES transaction_entry(id),
-    original_id bigint UNIQUE REFERENCES payment(id)
-);
-
 CREATE TABLE profile_settings (
     id serial NOT NULL PRIMARY KEY,
     te_created_id bigint UNIQUE REFERENCES transaction_entry(id),
@@ -1091,11 +1099,11 @@ CREATE TABLE receiving_order (
        CHECK (invoice_number >= 1 AND invoice_number <= 999999),
     invoice_total numeric(20, 2),
     cfop_id bigint REFERENCES cfop_data(id),
-    responsible_id bigint REFERENCES person_adapt_to_user(id),
-    supplier_id bigint REFERENCES person_adapt_to_supplier(id),
-    branch_id bigint REFERENCES person_adapt_to_branch(id),
+    responsible_id bigint REFERENCES login_user(id),
+    supplier_id bigint REFERENCES supplier(id),
+    branch_id bigint REFERENCES branch(id),
     purchase_id bigint NOT NULL REFERENCES purchase_order(id),
-    transporter_id bigint REFERENCES person_adapt_to_transporter(id),
+    transporter_id bigint REFERENCES transporter(id),
     secure_value numeric(20, 2) CONSTRAINT positive_secure_value
         CHECK (secure_value >= 0),
     expense_value numeric(20, 2) CONSTRAINT positive_expense_value
@@ -1129,16 +1137,6 @@ CREATE TABLE renegotiation_data (
     sale_id bigint UNIQUE REFERENCES sale(id)
 );
 
-CREATE TABLE delivery_item (
-    id serial NOT NULL PRIMARY KEY,
-    te_created_id bigint UNIQUE REFERENCES transaction_entry(id),
-    te_modified_id bigint UNIQUE REFERENCES transaction_entry(id),
-    quantity numeric(20, 3) CONSTRAINT positive_quantity
-        CHECK (quantity >= 0),
-    sellable_id bigint REFERENCES sellable(id),
-    delivery_id bigint REFERENCES sale_item_adapt_to_delivery(id)
-);
-
 CREATE TABLE till_entry (
     id serial NOT NULL PRIMARY KEY,
     te_created_id bigint UNIQUE REFERENCES transaction_entry(id),
@@ -1163,7 +1161,7 @@ CREATE TABLE fiscal_book_entry (
     invoice_number integer CONSTRAINT positive_invoice_number
         CHECK (invoice_number >= 0),
     cfop_id bigint REFERENCES cfop_data(id),
-    branch_id bigint REFERENCES person_adapt_to_branch(id),
+    branch_id bigint REFERENCES branch(id),
     drawee_id bigint REFERENCES person(id),
     payment_group_id bigint REFERENCES payment_group(id)
 );
@@ -1243,7 +1241,7 @@ CREATE TABLE commission (
     te_modified_id bigint UNIQUE REFERENCES transaction_entry(id),
     value numeric(20, 2) NOT NULL,
     commission_type integer NOT NULL,
-    salesperson_id bigint NOT NULL REFERENCES person_adapt_to_sales_person(id),
+    salesperson_id bigint NOT NULL REFERENCES sales_person(id),
     sale_id bigint NOT NULL REFERENCES sale(id),
     payment_id bigint NOT NULL UNIQUE REFERENCES payment(id)
 );
@@ -1256,10 +1254,10 @@ CREATE TABLE transfer_order (
     receival_date timestamp,
     status integer CONSTRAINT valid_status
         CHECK (status >= 0 AND status < 2),
-    source_branch_id bigint NOT NULL REFERENCES person_adapt_to_branch(id),
-    destination_branch_id bigint NOT NULL REFERENCES person_adapt_to_branch(id),
-    source_responsible_id bigint NOT NULL REFERENCES person_adapt_to_employee(id),
-    destination_responsible_id bigint NOT NULL REFERENCES person_adapt_to_employee(id)
+    source_branch_id bigint NOT NULL REFERENCES branch(id),
+    destination_branch_id bigint NOT NULL REFERENCES branch(id),
+    source_responsible_id bigint NOT NULL REFERENCES employee(id),
+    destination_responsible_id bigint NOT NULL REFERENCES employee(id)
 );
 
 CREATE TABLE transfer_order_item (
@@ -1319,7 +1317,7 @@ CREATE TABLE inventory (
     close_date timestamp,
     invoice_number integer CONSTRAINT positive_invoice_number
         CHECK (invoice_number > 0  and invoice_number < 999999),
-    branch_id bigint NOT NULL REFERENCES person_adapt_to_branch(id)
+    branch_id bigint NOT NULL REFERENCES branch(id)
 );
 
 CREATE TABLE inventory_item (
@@ -1343,14 +1341,14 @@ CREATE TABLE production_order (
     te_created_id bigint UNIQUE REFERENCES transaction_entry(id),
     te_modified_id bigint UNIQUE REFERENCES transaction_entry(id),
     status integer CONSTRAINT valid_status
-        CHECK (status >= 0 AND status < 4),
+        CHECK (status >= 0 AND status < 5),
     open_date timestamp,
     close_date timestamp,
     expected_start_date timestamp,
     start_date timestamp,
     description text,
-    responsible_id bigint REFERENCES person_adapt_to_employee(id),
-    branch_id bigint REFERENCES person_adapt_to_branch(id)
+    responsible_id bigint REFERENCES employee(id),
+    branch_id bigint REFERENCES branch(id)
 );
 
 CREATE TABLE production_item (
@@ -1408,9 +1406,9 @@ CREATE TABLE loan (
         CHECK (status >= 0 AND status < 6),
     notes text,
     removed_by text,
-    client_id bigint REFERENCES person_adapt_to_client(id),
-    responsible_id bigint REFERENCES person_adapt_to_user(id),
-    branch_id bigint REFERENCES person_adapt_to_branch(id)
+    client_id bigint REFERENCES client(id),
+    responsible_id bigint REFERENCES login_user(id),
+    branch_id bigint REFERENCES branch(id)
 );
 
 CREATE TABLE loan_item (
@@ -1438,9 +1436,9 @@ CREATE TABLE stock_decrease (
         CHECK (status >= 0 AND status < 8),
     reason text,
     notes text,
-    responsible_id bigint REFERENCES person_adapt_to_user(id),
-    removed_by_id bigint REFERENCES person_adapt_to_employee(id),
-    branch_id bigint REFERENCES person_adapt_to_branch(id),
+    responsible_id bigint REFERENCES login_user(id),
+    removed_by_id bigint REFERENCES employee(id),
+    branch_id bigint REFERENCES branch(id),
     cfop_id bigint REFERENCES cfop_data(id)
 );
 
@@ -1468,6 +1466,74 @@ CREATE TABLE account_transaction (
     payment_id bigint REFERENCES payment(id)
 );
 
+CREATE TABLE ui_form (
+    id serial NOT NULL PRIMARY KEY,
+    te_created_id bigint UNIQUE REFERENCES transaction_entry(id),
+    te_modified_id bigint UNIQUE REFERENCES transaction_entry(id),
+    description text,
+    form_name text UNIQUE
+);
+
+CREATE TABLE ui_field (
+    id serial NOT NULL PRIMARY KEY,
+    te_created_id bigint UNIQUE REFERENCES transaction_entry(id),
+    te_modified_id bigint UNIQUE REFERENCES transaction_entry(id),
+    description text,
+    field_name text,
+    mandatory boolean,
+    visible boolean,
+    ui_form_id bigint REFERENCES ui_form(id)
+);
+
+CREATE TABLE event (
+    id serial NOT NULL PRIMARY KEY,
+    te_created_id bigint UNIQUE REFERENCES transaction_entry(id),
+    te_modified_id bigint UNIQUE REFERENCES transaction_entry(id),
+    date timestamp NOT NULL,
+    event_type integer NOT NULL,
+    description varchar NOT NULL
+);
+
+CREATE TABLE product_quality_test (
+    id serial NOT NULL PRIMARY KEY,
+    te_created_id bigint UNIQUE REFERENCES transaction_entry(id),
+    te_modified_id bigint UNIQUE REFERENCES transaction_entry(id),
+    product_id bigint REFERENCES product(id),
+    test_type integer,
+    description text,
+    notes text,
+    success_value text
+);
+
+CREATE TABLE production_produced_item (
+    id serial NOT NULL PRIMARY KEY,
+    te_created_id bigint UNIQUE REFERENCES transaction_entry(id),
+    te_modified_id bigint UNIQUE REFERENCES transaction_entry(id),
+    order_id bigint REFERENCES production_order(id),
+    product_id bigint REFERENCES product(id),
+    produced_by_id bigint REFERENCES login_user(id),
+    produced_date timestamp,
+    serial_number integer,
+    entered_stock boolean,
+    test_passed boolean,
+    UNIQUE(product_id, serial_number)
+);
+
+CREATE TABLE production_item_quality_result (
+    id serial NOT NULL PRIMARY KEY,
+    te_created_id bigint UNIQUE REFERENCES transaction_entry(id),
+    te_modified_id bigint UNIQUE REFERENCES transaction_entry(id),
+
+    produced_item_id bigint REFERENCES production_produced_item(id),
+    quality_test_id bigint REFERENCES product_quality_test(id),
+    tested_by_id bigint REFERENCES login_user(id),
+    tested_date timestamp,
+
+    result_value text,
+    test_passed boolean
+);
+
+
 -- Add new tables above this line when creating a new schema generation,
 -- unless they are referenced by other tables above.
 
@@ -1475,7 +1541,7 @@ CREATE TABLE account_transaction (
 
 ALTER TABLE transaction_entry
     ADD CONSTRAINT transaction_entry_user_id_fkey FOREIGN KEY
-        (user_id) REFERENCES person_adapt_to_user (id),
+        (user_id) REFERENCES login_user (id),
     ADD CONSTRAINT transaction_entry_station_id_fkey FOREIGN KEY
         (station_id) REFERENCES branch_station (id);
 
