@@ -89,7 +89,7 @@ class CATFile(object):
     def add(self, register):
         """Add register to the file.
         @param register: a register
-        @type register: L{CATRegister}
+        @type register: :class:`CATRegister`
         """
         self._registers.append(register)
 
@@ -131,7 +131,7 @@ class CATFile(object):
         @param initial_crz:
         @param final_crz:
         @param company:
-        @type company: PersonAdaptToCompany
+        @type company: PersonCompany
 
         """
         today = datetime.datetime.today()
