@@ -72,7 +72,7 @@ class CouponPrinter(object):
         log.info("Opening till")
 
         self._register_emitted_document(ECFDocumentHistory.TYPE_SUMMARY)
-        self._driver.summarize()
+        self._driver.open_till()
 
     def has_pending_reduce(self):
         return self._driver.has_pending_reduce()
@@ -284,7 +284,7 @@ class Coupon(object):
 
     def add_item(self, item):
         """
-        @param item: A L{SellableItem} subclass
+        @param item: A :class:`SellableItem` subclass
         @returns: id of the item.:
           0 >= if it was added successfully
           -1 if an error happend
@@ -383,7 +383,7 @@ class Coupon(object):
 
             # When adding a money payment, use base_value so that the payback
             # is show correctly.
-            if payment.method.method_name == 'money':
+            if payment.is_money():
                 self._driver.add_payment(constant.device_value,
                                          payment.base_value)
 
