@@ -27,6 +27,8 @@ import os
 import time
 
 import gtk
+from serial import SerialException
+
 from kiwi.log import Logger
 from kiwi.python import Settable
 from stoqdrivers.exceptions import CouponOpenError, DriverError
@@ -38,16 +40,17 @@ from stoqlib.domain.events import (SaleStatusChangedEvent, TillAddCashEvent,
                                    GerencialReportPrintEvent,
                                    GerencialReportCancelEvent,
                                    CheckECFStateEvent,
-                                   HasPendingReduceZ, ECFIsLastSaleEvent)
-from stoqlib.domain.interfaces import IIndividual, ICompany
-from stoqlib.domain.person import PersonAdaptToIndividual, PersonAdaptToCompany
+                                   HasPendingReduceZ, ECFIsLastSaleEvent,
+                                   HasOpenCouponEvent)
+from stoqlib.domain.person import Individual, Company
 from stoqlib.domain.renegotiation import RenegotiationData
 from stoqlib.domain.sale import Sale
 from stoqlib.domain.till import Till
 from stoqlib.exceptions import DeviceError
 from stoqlib.gui.keybindings import add_bindings, get_accels
 from stoqlib.gui.base.dialogs import run_dialog
-from stoqlib.gui.events import StartApplicationEvent, CouponCreatedEvent
+from stoqlib.gui.events import (StartApplicationEvent, StopApplicationEvent,
+                                CouponCreatedEvent)
 from stoqlib.lib.message import info, warning, yesno
 from stoqlib.lib.parameters import sysparam
 from stoqlib.lib.translation import stoqlib_gettext
@@ -66,9 +69,12 @@ log = Logger("stoq-ecf-plugin")
 
 class ECFUI(object):
     def __init__(self):
+        self._ui = None
         self.conn = get_connection()
         self._printer_verified = False
-        self._printer = self._create_printer()
+        # Delay printer creation until we are accessing pos or till app. Other
+        # applications should still be accessible without a printer
+        self._printer = None
 
         SaleStatusChangedEvent.connect(self._on_SaleStatusChanged)
         ECFIsLastSaleEvent.connect(self._on_ECFIsLastSale)
@@ -78,11 +84,13 @@ class ECFUI(object):
         TillAddTillEntryEvent.connect(self._on_AddTillEntry)
         TillRemoveCashEvent.connect(self._on_TillRemoveCash)
         StartApplicationEvent.connect(self._on_StartApplicationEvent)
+        StopApplicationEvent.connect(self._on_StopApplicationEvent)
         CouponCreatedEvent.connect(self._on_CouponCreatedEvent)
         GerencialReportPrintEvent.connect(self._on_GerencialReportPrintEvent)
         GerencialReportCancelEvent.connect(self._on_GerencialReportCancelEvent)
         CheckECFStateEvent.connect(self._on_CheckECFStateEvent)
         HasPendingReduceZ.connect(self._on_HasPendingReduceZ)
+        HasOpenCouponEvent.connect(self._on_HasOpenCouponEvent)
 
         self._till_summarize_action = gtk.Action(
             'Summary', _('Summary'), None, None)
@@ -90,8 +98,8 @@ class ECFUI(object):
             'activate', self._on_TillSummary__activate)
 
         add_bindings([
-            ('plugin.ecf.read_memory', '<Control>F9'),
-            ('plugin.ecf.summarize', '<Control>F11'),
+            ('plugin.ecf.read_memory', '<Primary>F9'),
+            ('plugin.ecf.summarize', '<Primary>F11'),
             ])
 
     #
@@ -99,11 +107,22 @@ class ECFUI(object):
     #
 
     def _create_printer(self):
+        if self._printer:
+            return self._printer
+
         station = get_current_station(self.conn)
         printer = ECFPrinter.selectOneBy(station=station, is_active=True,
                                          connection=self.conn)
-        if printer:
-            return CouponPrinter(printer)
+        if not printer:
+            return None
+
+        try:
+            self._printer = CouponPrinter(printer)
+        except SerialException, e:
+            warning(_('Error opening serial port'), str(e))
+        except DriverError, e:
+            warning(str(e))
+        return None
 
     def _validate_printer(self):
         if self._printer is None:
@@ -111,6 +130,7 @@ class ECFUI(object):
                 _("This operation requires a connected fiscal printer"))
 
         if not self._printer_verified:
+            log.info('ecfui._validate_printer')
             if not self._printer.check_serial():
                 raise DeviceError(
                     _("Fiscalprinters serial number is different!"))
@@ -119,8 +139,10 @@ class ECFUI(object):
 
     def _add_ui_menus(self, appname, app, uimanager):
         if appname == 'pos':
+            self._create_printer()
             self._add_pos_menus(uimanager)
         elif appname == 'till':
+            self._create_printer()
             self._add_till_menus(uimanager)
         elif appname == 'admin':
             self._add_admin_menus(uimanager)
@@ -128,14 +150,22 @@ class ECFUI(object):
                 _('Fiscal Printers'), 'fiscal-printer', 'printer',
                 self._on_ConfigurePrinter__activate)
 
+    def _remove_ui_menus(self, uimanager):
+        if not self._ui:
+            return
+        uimanager.remove_ui(self._ui)
+        self._ui = None
+
     def _add_admin_menus(self, uimanager):
         ui_string = """<ui>
           <menubar name="menubar">
-            <menu action="ConfigureMenu">
-            <placeholder name="ConfigurePH">
-              <menuitem action="ConfigurePrinter"/>
+            <placeholder action="AppMenubarPH">
+              <menu action="ConfigureMenu">
+              <placeholder name="ConfigurePH">
+                <menuitem action="ConfigurePrinter"/>
+              </placeholder>
+              </menu>
             </placeholder>
-            </menu>
           </menubar>
         </ui>"""
 
@@ -146,7 +176,7 @@ class ECFUI(object):
              None, None, self._on_ConfigurePrinter__activate),
             ])
         uimanager.insert_action_group(ag, 0)
-        uimanager.add_ui_from_string(ui_string)
+        self._ui = uimanager.add_ui_from_string(ui_string)
 
     def _add_pos_menus(self, uimanager):
         if sysparam(self.conn).POS_SEPARATE_CASHIER:
@@ -154,7 +184,7 @@ class ECFUI(object):
 
         ui_string = """<ui>
           <menubar name="menubar">
-            <placeholder name="ExtraMenu">
+            <placeholder name="ExtraMenubarPH">
               <menu action="ECFMenu">
                 <menuitem action="CancelLastDocument" name="CancelLastDocument"/>
                 <menuitem action="Summary" name="Summary"/>
@@ -178,12 +208,12 @@ class ECFUI(object):
                                  group.get('summarize'))
 
         uimanager.insert_action_group(ag, 0)
-        uimanager.add_ui_from_string(ui_string)
+        self._ui = uimanager.add_ui_from_string(ui_string)
 
     def _add_till_menus(self, uimanager):
         ui_string = """<ui>
           <menubar name="menubar">
-            <placeholder name="ExtraMenu">
+            <placeholder name="ExtraMenubarPH">
               <menu action="ECFMenu">
                 <menuitem action="Summary"/>
                 <menuitem action="ReadMemory"/>
@@ -202,19 +232,22 @@ class ECFUI(object):
         ag.add_action_with_accel(self._till_summarize_action,
                                  group.get('summarize'))
         uimanager.insert_action_group(ag, 0)
-        uimanager.add_ui_from_string(ui_string)
+        self._ui = uimanager.add_ui_from_string(ui_string)
 
     def _check_ecf_state(self):
         log.info('ecfui._check_printer')
         try:
             self._validate_printer()
         except (DriverError, DeviceError):
-            warning('Não foi possível comunicar com a impressora.')
+            warning(_("It was not possible to communicate with the printer"))
             raise SystemExit
 
-        has_open = self._printer.has_open_coupon()
-        if has_open:
-            warning('A ECF tem um cupom aberto. Ele será cancelado agora.')
+        self._has_open_coupon()
+
+    def _has_open_coupon(self):
+        self._validate_printer()
+        if self._printer.has_open_coupon():
+            warning(_("The ECF has an open coupon. It will be canceled now."))
             self._printer.cancel()
 
     def _open_till(self, till):
@@ -312,6 +345,8 @@ class ECFUI(object):
             generator = StoqlibCATGenerator(self.conn, day, printer)
             generator.write(dir)
 
+        self._reset_last_doc()
+
         return retval
 
     def _needs_cat52(self, printer):
@@ -340,6 +375,14 @@ class ECFUI(object):
         printer.last_till_entry = till_entry
         printer.last_sale = None
 
+    def _reset_last_doc(self):
+        # Last ecf document is not a sale or a till_entry anymore.
+        trans = new_transaction()
+        printer = trans.get(self._printer._printer)
+        printer.last_till_entry = None
+        printer.last_sale = None
+        trans.commit()
+
     def _add_cash(self, till, value):
         log.info('ECFCouponPrinter.add_cash(%r, %r)' % (till, value, ))
 
@@ -463,7 +506,7 @@ class ECFUI(object):
 
         if last_doc.last_till_entry:
             self._cancel_last_till_entry(last_doc, trans)
-        else:
+        elif last_doc.last_sale:
             # Verify till balance before cancel the last sale.
             till = Till.get_current(trans)
             if last_doc.last_sale.total_amount > till.get_balance():
@@ -487,6 +530,7 @@ class ECFUI(object):
             return
 
         self._printer.summarize()
+        self._reset_last_doc()
 
     def _fiscal_memory_dialog(self):
         try:
@@ -494,7 +538,9 @@ class ECFUI(object):
         except DeviceError, e:
             warning(e)
             return
-        run_dialog(FiscalMemoryDialog, None, self.conn, self._printer)
+        retval = run_dialog(FiscalMemoryDialog, None, self.conn, self._printer)
+        if retval:
+            self._reset_last_doc()
 
     def _get_client_document(self, sale):
         """Returns a Settable with two attributes: document, a string with
@@ -502,10 +548,10 @@ class ECFUI(object):
         (FiscalSaleHistory.TYPE_CPF, FiscalSaleHistory.TYPE_CNPJ )
         """
         client_role = sale.get_client_role()
-        if isinstance(client_role, PersonAdaptToIndividual):
+        if isinstance(client_role, Individual):
             document_type = FiscalSaleHistory.TYPE_CPF
             document = client_role.cpf
-        elif isinstance(client_role, PersonAdaptToCompany):
+        elif isinstance(client_role, Company):
             document_type = FiscalSaleHistory.TYPE_CNPJ
             document = client_role.cnpj
         else:
@@ -516,16 +562,25 @@ class ECFUI(object):
                             document=document)
 
     def _identify_customer(self, coupon, sale=None):
+        if not sysparam(self.conn).ENABLE_PAULISTA_INVOICE:
+            return
+
         model = None
+        initial_client_document = None
         if sale:
             model = self._get_client_document(sale)
 
-        if sysparam(self.conn).ENABLE_PAULISTA_INVOICE and not model:
-            model = run_dialog(PaulistaInvoiceDialog, self, self.conn)
-
+        # Sale may have no client.
         if model:
-            coupon.identify_customer('-', '-', model.document,
-                                     model.document_type)
+            initial_client_document = model.document
+
+        model = run_dialog(PaulistaInvoiceDialog, self, self.conn, model)
+
+        # User cancelled the dialog or the document didn't change.
+        if not model or model.document == initial_client_document:
+            return
+        coupon.identify_customer('-', '-', model.document,
+                                 model.document_type)
 
     #
     # Events
@@ -534,6 +589,9 @@ class ECFUI(object):
     def _on_StartApplicationEvent(self, appname, app):
         self._add_ui_menus(appname, app, app.main_window.uimanager)
 
+    def _on_StopApplicationEvent(self, appname, app):
+        self._remove_ui_menus(app.main_window.uimanager)
+
     def _on_SaleStatusChanged(self, sale, old_status):
         if sale.status == Sale.STATUS_CONFIRMED:
             self._confirm_sale(sale)
@@ -564,6 +622,9 @@ class ECFUI(object):
     def _on_HasPendingReduceZ(self):
         return self._has_pending_reduce()
 
+    def _on_HasOpenCouponEvent(self):
+        self._has_open_coupon()
+
     #
     # Callbacks
     #
@@ -575,18 +636,17 @@ class ECFUI(object):
         coupon.open()
 
     def _on_coupon__identify_customer(self, coupon, person):
-        if IIndividual(person, None):
-            individual = IIndividual(person)
+        if person.individual:
+            individual = person.individual
             document_type = FiscalSaleHistory.TYPE_CPF
             document = individual.cpf
-        elif ICompany(person, None):
-            company = ICompany(person)
+        elif person.company:
+            company = person.company
             document_type = FiscalSaleHistory.TYPE_CNPJ
             document = company.cnpj
         else:
             raise TypeError(
-                "identify_customer needs an object implementing "
-                "IIndividual or ICompany")
+                "identify_customer needs a individual or a company")
         name = person.name
         address = person.get_address_string()
 
