@@ -27,8 +27,7 @@ from twisted.internet.defer import succeed
 
 from stoqlib.database.orm import ForeignKey
 from stoqlib.domain.address import Address, CityLocation
-from stoqlib.domain.interfaces import IClient, IIndividual
-from stoqlib.domain.person import Person
+from stoqlib.domain.person import Client, Individual, Person
 from stoqlib.lib.translation import stoqlib_gettext
 from stoqlib.lib.parameters import sysparam
 from stoqlib.lib.validators import validate_cpf
@@ -53,7 +52,7 @@ class MagentoClient(MagentoBaseSyncDown):
     (GENDER_MALE,
      GENDER_FEMALE) = range(1, 3)
 
-    client = ForeignKey('PersonAdaptToClient', default=None)
+    client = ForeignKey('Client', default=None)
 
     #
     #  MagentoBaseSyncDown hooks
@@ -85,21 +84,25 @@ class MagentoClient(MagentoBaseSyncDown):
 
     def update_local(self, info):
         person = self.client.person
-        individual = IIndividual(person, None)
+        individual = person.individual
         if not individual:
             # Just log if we don't have individual anymore. If we
             # try to fix this here, we will be masking the problem
             # somewhere else.
             log.warning("Unexpected error: Person '%s' is missing "
-                        "IIndividual facet" % person)
+                        "an individual" % person)
             return False
 
         person.email = info['email']
         if info['dob']:
             birth_date = info['dob']
             individual.birth_date = birth_date
-        if info['gender']:
-            individual.gender = self._get_gender(info['gender'])
+        mag_gender = info.get('gender', None)
+        if mag_gender:
+            if mag_gender == self.GENDER_MALE:
+                individual.gender = individual.GENDER_MALE
+            if mag_gender == self.GENDER_FEMALE:
+                individual.gender = individual.GENDER_FEMALE
 
         if not individual.cpf and validate_cpf(info['taxvat']):
             # Just update the cpf if we did not have any before
@@ -136,42 +139,36 @@ class MagentoClient(MagentoBaseSyncDown):
         person = Person.selectOneBy(connection=conn,
                                     email=email)
         if person:
-            if not IClient(person, None):
-                person.addFacet(IClient,
-                                connection=conn)
-            if not IIndividual(person, None):
-                person.addFacet(IIndividual,
-                                connection=conn,
-                                cpf=cpf)
-            return IClient(person)
+            if not person.client:
+                Client(person=person,
+                       connection=conn)
+            if not person.individual:
+                Individual(person=person,
+                           connection=conn,
+                           cpf=cpf)
+            return person.client
 
         # Check for existing person using the given cpf
         if cpf:
-            individual = Person.iselectOneBy(IIndividual, connection=conn,
-                                             cpf=cpf)
+            individual = Individual.selectOneBy(connection=conn,
+                                                cpf=cpf)
             if individual:
-                if not IClient(individual.person, None):
-                    individual.person.addFacet(IClient,
-                                               connection=conn)
-                return IClient(individual.person)
+                if not individual.person.client:
+                    Client(individual.person,
+                           connection=conn)
+                return individual.person.client
 
         # Create a new one
         person = Person(connection=conn,
                         name=name,
                         email=email)
-        person.addFacet(IIndividual, connection=conn,
-                        cpf=cpf)
-        person.addFacet(IClient, connection=conn)
+        Individual(person=person,
+                   connection=conn,
+                   cpf=cpf)
+        Client(person=person,
+               connection=conn)
 
-        return IClient(person)
-
-    def _get_gender(self, mag_gender):
-        if mag_gender == self.GENDER_MALE:
-            return Person.GENDER_MALE
-        if mag_gender == self.GENDER_FEMALE:
-            return Person.GENDER_FEMALE
-
-        return None
+        return person.client
 
 
 class MagentoAddress(MagentoBaseSyncDown):
