@@ -22,7 +22,6 @@
 ## Author(s): Stoq Team <stoq-devel@async.com.br>
 ##
 
-import base64
 import datetime
 import urllib
 
@@ -31,15 +30,15 @@ from kiwi.log import Logger
 from twisted.internet.defer import inlineCallbacks, returnValue
 from twisted.web.xmlrpc import Fault
 
-from stoqlib.database.orm import (IntCol, UnicodeCol, DateTimeCol, BLOBCol,
-                                  BoolCol, ForeignKey, SingleJoin,
-                                  MultipleJoin, IN)
+from stoqlib.database.orm import (IntCol, UnicodeCol, DateTimeCol, BoolCol,
+                                  ForeignKey, SingleJoin, MultipleJoin, IN)
 from stoqlib.database.runtime import get_connection
-from stoqlib.domain.interfaces import IStorable
+from stoqlib.domain.image import Image
 
 from domain.magentobase import MagentoBaseSyncUp
 from magentolib import get_proxy
 
+Image # pyflakes
 log = Logger('plugins.magento.domain.magentoproduct')
 
 
@@ -77,20 +76,32 @@ class MagentoProduct(MagentoBaseSyncUp):
     TAX_SHIPPING = 4
 
     sku = UnicodeCol(default=None)
-    product_type = UnicodeCol(default=TYPE_SIMPLE)
+    product_type = UnicodeCol(default=None)
     product_set = IntCol(default=None)
     visibility = IntCol(default=VISIBILITY_CATALOG_SEARCH)
     url_key = UnicodeCol(default=None)
     news_from_date = DateTimeCol(default=None)
     news_to_date = DateTimeCol(default=None)
     magento_category = ForeignKey('MagentoCategory', default=None)
-    product = ForeignKey('Product')
+    sellable =  ForeignKey('Sellable')
 
     magento_stock = SingleJoin('MagentoStock',
                                joinColumn='magento_product_id')
     magento_images = MultipleJoin('MagentoImage',
                                   joinColumn='magento_product_id')
 
+    #
+    #  Properties
+    #
+
+    @property
+    def product(self):
+        return self.sellable.product
+
+    @property
+    def service(self):
+        return self.sellable.service
+
     #
     #  MagentoBase hooks
     #
@@ -128,10 +139,10 @@ class MagentoProduct(MagentoBaseSyncUp):
     def create_remote(self):
         assert not self.magento_id
 
-        # If no product, that means we need to remove it from magento.
-        # Can happen if one creates a product and deletes it, before we could
+        # If no sellable, that means we need to remove it from magento.
+        # Can happen if one creates a sellable and deletes it, before we could
         # sync self and create it on Magento.
-        if not self.product:
+        if not self.sellable:
             retval = yield self.remove_remote()
             returnValue(retval)
 
@@ -159,10 +170,7 @@ class MagentoProduct(MagentoBaseSyncUp):
                          magento_id=self.magento_id,
                          config=self.config,
                          magento_product=self)
-            image = self.product.full_image
-            if image:
-                self._update_main_image(image)
-            category = self.product.sellable.category
+            category = self.sellable.category
             if category:
                 self._update_category(category)
 
@@ -170,15 +178,12 @@ class MagentoProduct(MagentoBaseSyncUp):
 
     @inlineCallbacks
     def update_remote(self):
-        # If no product, that means we need to remove it from magento
-        if not self.product:
+        # If no sellable, that means we need to remove it from magento
+        if not self.sellable:
             retval = yield self.remove_remote()
             returnValue(retval)
 
-        image = self.product.full_image
-        if image:
-            self._update_main_image(image)
-        category = self.product.sellable.category
+        category = self.sellable.category
         if category:
             self._update_category(category)
 
@@ -237,32 +242,18 @@ class MagentoProduct(MagentoBaseSyncUp):
         self.magento_category = mag_category
         self.magento_category.need_sync = True
 
-    def _update_main_image(self, image):
-        conn = self.get_connection()
-        mag_image = MagentoImage.selectOneBy(connection=conn,
-                                             magento_product=self,
-                                             is_main=True)
-
-        if mag_image and mag_image.image == image:
-            # Nothing changed..return here to skip processing bellow
-            return
-        elif mag_image and mag_image.image != image:
-            # This won't be the main image anymore.
-            mag_image.is_main = False
-
-        label = self.product.sellable.get_description()
-        mag_image = MagentoImage(connection=conn,
-                                 magento_id=self.magento_id,
-                                 config=self.config,
-                                 image=image,
-                                 is_main=True,
-                                 label=label,
-                                 magento_product=self)
-
     def _generate_initial_data(self):
-        sellable = self.product.sellable
+        sellable = self.sellable
         config = self.config
 
+        if not self.product_type:
+            if self.service:
+                # Magento use virtual products for products that doesn't
+                # have a physical counterpart. Exactly the same way we
+                # treat services.
+                self.product_type = self.TYPE_VIRTUAL
+            else:
+                self.product_type = self.TYPE_SIMPLE
         if not self.product_set:
             self.product_set = config.default_product_set
         if not self.sku:
@@ -274,20 +265,23 @@ class MagentoProduct(MagentoBaseSyncUp):
             self.news_to_date = (self.news_from_date +
                                  relativedelta(days=config.qty_days_as_new))
         if not self.url_key:
-            self.url_key = urllib.quote_plus(str(sellable.get_description()))
+            self.url_key = urllib.quote_plus(
+                sellable.get_description().encode('utf-8'))
 
     def _get_data(self):
-        sellable = self.product.sellable
+        sellable = self.sellable
         status = (self.STATUS_DISABLED if sellable.is_closed() else
                   self.STATUS_ENABLED)
         tax_class_id = (self.TAX_TAXABLE_GOODS if sellable.tax_constant else
                         self.TAX_NONE)
 
-        return {
+        name = sellable.get_description()
+
+        data = {
             'status': status,
             'name': sellable.get_description(),
-            'description': sellable.notes,
-            'short_description': sellable.notes.split('\n')[0],
+            'description': sellable.notes or name,
+            'short_description': sellable.notes.split('\n')[0] or name,
             'cost': sellable.cost,
             'price': sellable.price,
             'tax_class_id': tax_class_id,
@@ -295,9 +289,13 @@ class MagentoProduct(MagentoBaseSyncUp):
             'news_from_date': self.news_from_date,
             'news_to_date': self.news_to_date,
             'visibility': self.visibility,
-            'weight': self.product.weight or 1,
             }
 
+        if self.product:
+            data['weight'] = self.product.weight or 1
+
+        return data
+
 
 class MagentoStock(MagentoBaseSyncUp):
     """Class for product stock synchronization between Stoq and Magento"""
@@ -356,22 +354,35 @@ class MagentoStock(MagentoBaseSyncUp):
     #
 
     def _get_data(self):
-        quantity = 0
-        product = self.magento_product.product
-        storable = IStorable(product, None)
+        sellable = self.magento_product.sellable
 
-        if storable:
-            # Get stock items from branch on config
-            branch = self.config.branch
-            stock_item = storable.get_stock_item(branch)
-            if stock_item:
-                quantity = stock_item.quantity + stock_item.logic_quantity
-
-        return {
-            'qty': quantity,
-            'is_in_stock': int(product.sellable.can_be_sold()),
+        data = {
+            'manage_stock': True,
+            'is_in_stock': sellable.can_be_sold(),
             }
 
+        if sellable.product:
+            quantity = 0
+            storable = sellable.product.storable
+
+            if storable:
+                # Get stock items from branch on config
+                branch = self.config.branch
+                stock_item = storable.get_stock_item(branch)
+                if stock_item:
+                    quantity = stock_item.quantity
+
+            data['qty'] = quantity
+        elif sellable.service:
+            # If we set 'manage_stock' to False, magento will allow users to
+            # buy services, even if they are not available.  But if we set it
+            # to True, it will overwrite 'is_in_stock' when 'qty' id 0, and not
+            # let any user buy nothing of the service. So set this to a high
+            # value. This is very ugly but we have no alternative.
+            data['qty'] = 999999
+
+        return data
+
 
 class MagentoImage(MagentoBaseSyncUp):
     """Class for product image synchronization between Stoq and Magento"""
@@ -392,10 +403,9 @@ class MagentoImage(MagentoBaseSyncUp):
     TYPE_SMALL_IMAGE = 'small_image'
     TYPE_THUMBNAIL = 'thumbnail'
 
-    image = BLOBCol()
-    filename = UnicodeCol(default=None)
+    image = ForeignKey('Image')
+    filename = UnicodeCol(default='')
     is_main = BoolCol(default=False)
-    label = UnicodeCol(default=None)
     visible = BoolCol(default=True)
     magento_product = ForeignKey('MagentoProduct')
 
@@ -412,11 +422,17 @@ class MagentoImage(MagentoBaseSyncUp):
 
     @inlineCallbacks
     def create_remote(self):
+        # If no image, that means we need to remove it from magento
+        if not self.image:
+            retval = yield self.remove_remote()
+            returnValue(retval)
+
         image_data = self._get_data()
+        image_description = self.image.get_description()
         image_data.update({
             'file': {
-                'name': urllib.quote('%s%s' % (self.label, self.id)),
-                'content': base64.b64encode(self.image),
+                'name': urllib.quote(image_description.encode('utf-8')),
+                'content': self.image.get_base64_encoded(),
                 # All of our images are stored as png
                 'mime': 'image/png',
                 }
@@ -436,6 +452,11 @@ class MagentoImage(MagentoBaseSyncUp):
 
     @inlineCallbacks
     def update_remote(self):
+        # If no image, that means we need to remove it from magento
+        if not self.image:
+            retval = yield self.remove_remote()
+            returnValue(retval)
+
         image_data = self._get_data()
         data = [self.magento_product.magento_id, self.filename, image_data]
 
@@ -448,6 +469,26 @@ class MagentoImage(MagentoBaseSyncUp):
 
         returnValue(retval)
 
+    @inlineCallbacks
+    def remove_remote(self):
+        data = [self.magento_product.magento_id, self.filename]
+
+        try:
+            retval = yield self.proxy.call('product_media.remove', data)
+        except Fault as err:
+            if err.faultCode in (self.ERROR_IMAGE_PRODUCT_NOT_EXISTS,
+                                 self.ERROR_IMAGE_NOT_EXISTS):
+                # The image was already deleted! That's what we wanted!
+                retval = True
+            else:
+                log.warning("An error occurried when trying to delete a "
+                            "product's image on magento: %s" % err.faultString)
+                returnValue(False)
+
+        self.delete(self.id, self.get_connection())
+
+        returnValue(retval)
+
     #
     #  Private
     #
@@ -460,7 +501,7 @@ class MagentoImage(MagentoBaseSyncUp):
 
         return {
             'types': types,
-            'label': self.label,
+            'label': self.image.get_description(),
             'exclude': not self.visible,
             }
 
