@@ -42,7 +42,12 @@ from stoqlib.database.runtime import get_connection
 from stoqlib.domain.events import (ProductCreateEvent, ProductRemoveEvent,
                                    ProductEditEvent, ProductStockUpdateEvent,
                                    CategoryCreateEvent, CategoryEditEvent,
-                                   SaleStatusChangedEvent)
+                                   ImageCreateEvent, ImageEditEvent,
+                                   ImageRemoveEvent, SaleStatusChangedEvent,
+                                   ServiceCreateEvent, ServiceEditEvent,
+                                   ServiceRemoveEvent,
+                                   DeliveryStatusChangedEvent)
+from stoqlib.domain.sellable import Sellable
 from stoqlib.lib.interfaces import IPlugin
 from stoqlib.lib.translation import stoqlib_gettext
 from stoqlib.lib.pluginmanager import register_plugin
@@ -66,7 +71,6 @@ class MagentoPlugin(object):
     implements(IPlugin)
 
     name = 'magento'
-    has_product_slave = False
 
     def __init__(self):
         self._lock = DeferredLock()
@@ -115,12 +119,23 @@ class MagentoPlugin(object):
         ProductEditEvent.connect(self._on_product_update)
         ProductStockUpdateEvent.connect(self._on_product_stock_update)
 
+        # Connect service events
+        ServiceCreateEvent.connect(self._on_service_create)
+        ServiceRemoveEvent.connect(self._on_service_delete)
+        ServiceEditEvent.connect(self._on_service_update)
+
+        # Connect image events
+        ImageCreateEvent.connect(self._on_image_create)
+        ImageEditEvent.connect(self._on_image_update)
+        ImageRemoveEvent.connect(self._on_image_delete)
+
         # Connect category events
         CategoryCreateEvent.connect(self._on_category_create)
         CategoryEditEvent.connect(self._on_category_update)
 
         # Connect sale events
         SaleStatusChangedEvent.connect(self._on_sale_status_change)
+        DeliveryStatusChangedEvent.connect(self._on_delivery_status_change)
 
     def get_tables(self):
         return [
@@ -139,7 +154,8 @@ class MagentoPlugin(object):
 
     def get_migration(self):
         environ.add_resource('magentosql', os.path.join(plugin_root, 'sql'))
-        return PluginSchemaMigration(self.name, 'magentosql', ['*.sql'])
+        return PluginSchemaMigration(self.name, 'magentosql',
+                                     ['*.sql', '*.py'])
 
     def get_dbadmin_commands(self):
         return ['sync']
@@ -164,17 +180,23 @@ class MagentoPlugin(object):
 
         log.info("Start synchronizing %s on server %s" % (mag_table, url))
         retval = yield mag_table.synchronize(config)
-        log.info("Start synchronizing %s on server %s with retval %s" %
+        log.info("Finished synchronizing %s on server %s with retval %s" %
                  (mag_table, url, retval))
 
         returnValue(retval)
 
-    def _get_magento_products_by_product(self, product):
-        conn = product.get_connection()
+    def _get_magento_products_by_sellable(self, sellable):
+        conn = sellable.get_connection()
         mag_products = MagentoProduct.selectBy(connection=conn,
-                                               product=product)
+                                               sellable=sellable)
         return mag_products
 
+    def _get_magento_products_by_product(self, product):
+        return self._get_magento_products_by_sellable(product.sellable)
+
+    def _get_magento_products_by_service(self, service):
+        return self._get_magento_products_by_sellable(service.sellable)
+
     def _get_magento_categories_by_category(self, category):
         conn = category.get_connection()
         mag_categories = MagentoCategory.selectBy(connection=conn,
@@ -188,10 +210,13 @@ class MagentoPlugin(object):
     def _on_product_create(self, product, **kwargs):
         conn = product.get_connection()
         for config in MagentoConfig.select(connection=conn):
-            # Just create the registry and it will be synchronized later.
-            MagentoProduct(connection=conn,
-                           product=product,
-                           config=config)
+            if not MagentoProduct.selectOneBy(connection=conn,
+                                              sellable=product.sellable,
+                                              config=config):
+                # Just create the registry and it will be synchronized later.
+                MagentoProduct(connection=conn,
+                               sellable=product.sellable,
+                               config=config)
 
     def _on_product_update(self, product, **kwargs):
         for mag_product in self._get_magento_products_by_product(product):
@@ -202,7 +227,7 @@ class MagentoPlugin(object):
             # Remove the foreign key reference, so the product can be
             # deleted on stoq without problems. This deletion will happen
             # later when synchronizing products.
-            mag_product.product = None
+            mag_product.sellable = None
             mag_product.need_sync = True
 
     def _on_product_stock_update(self, product, branch, old_quantity,
@@ -213,13 +238,77 @@ class MagentoPlugin(object):
                                                    magento_product=mag_product):
                 mag_stock.need_sync = True
 
+    def _on_service_create(self, service, **kwargs):
+        conn = service.get_connection()
+        for config in MagentoConfig.select(connection=conn):
+            if not MagentoProduct.selectOneBy(connection=conn,
+                                              sellable=service.sellable,
+                                              config=config):
+                # Just create the registry and it will be synchronized later.
+                MagentoProduct(connection=conn,
+                               sellable=service.sellable,
+                               config=config)
+
+    def _on_service_update(self, service, **kwargs):
+        for mag_product in self._get_magento_products_by_service(service):
+            mag_product.need_sync = True
+            if mag_product.magento_stock:
+                # Services does not have stock, so mark them
+                # as need_sync in here too
+                mag_product.magento_stock.need_sync = True
+
+    def _on_service_delete(self, service, **kwargs):
+        for mag_product in self._get_magento_products_by_service(service):
+            # Remove the foreign key reference, so the service can be
+            # deleted on stoq without problems. This deletion will happen
+            # later when synchronizing products.
+            mag_product.sellable = None
+            mag_product.need_sync = True
+
+    def _on_image_create(self, image, **kwargs):
+        conn = image.get_connection()
+        sellable = Sellable.selectOneBy(connection=conn,
+                                        image=image)
+        if sellable:
+            for mag_product in self._get_magento_products_by_sellable(sellable):
+                for mag_image in mag_product.magento_images:
+                    if mag_image.is_main:
+                        # If it already have a main image, just update it.
+                        mag_image.image = image
+                        mag_image.need_sync = True
+                else:
+                    MagentoImage(connection=conn,
+                                 config=mag_product.config,
+                                 image=image,
+                                 magento_product=mag_product,
+                                 is_main=True)
+
+    def _on_image_update(self, image, **kwargs):
+        conn = image.get_connection()
+        for mag_image in MagentoImage.selectBy(connection=conn,
+                                               image=image):
+            mag_image.need_sync = True
+
+    def _on_image_delete(self, image, **kwargs):
+        conn = image.get_connection()
+        for mag_image in MagentoImage.selectBy(connection=conn,
+                                               image=image):
+            # Remove the foreign key reference, so the image can be
+            # deleted on stoq without problems. This deletion will happen
+            # later when synchronizing images.
+            mag_image.image = None
+            mag_image.need_sync = True
+
     def _on_category_create(self, category, **kwargs):
         conn = category.get_connection()
         for config in MagentoConfig.select(connection=conn):
-            # Just create the registry and it will be synchronized later.
-            MagentoCategory(connection=conn,
-                            category=category,
-                            config=config)
+            if not MagentoCategory.selectOneBy(connection=conn,
+                                               category=category,
+                                               config=config):
+                # Just create the registry and it will be synchronized later.
+                MagentoCategory(connection=conn,
+                                category=category,
+                                config=config)
 
     def _on_category_update(self, category, **kwargs):
         for mag_category in self._get_magento_categories_by_category(category):
@@ -231,6 +320,14 @@ class MagentoPlugin(object):
         if mag_sale:
             mag_sale.need_sync = True
 
+    def _on_delivery_status_change(self, delivery, old_status, **kwargs):
+        mag_delivery = MagentoShipment.selectOneBy(
+            connection=delivery.get_connection(),
+            delivery=delivery,
+            )
+        if mag_delivery:
+            mag_delivery.need_sync = True
+
 
 register_plugin(MagentoPlugin)
 
@@ -285,3 +382,4 @@ class _MagentoCmd(object):
         print _("Magento synchronization finished:")
         print _("    Status: %s") % (status,)
         print _("    Time took: %s") % (t_delta,)
+        print
