@@ -30,7 +30,6 @@ import random
 from xml.etree.ElementTree import Element
 from xml.sax.saxutils import escape
 
-from stoqlib.domain.interfaces import ICompany, IIndividual
 from stoqlib.exceptions import ModelDataError
 from stoqlib.lib.parameters import sysparam
 from stoqlib.lib.translation import stoqlib_gettext as _
@@ -142,15 +141,15 @@ class NFeGenerator(object):
     def _get_today_date(self):
         return datetime.date.today()
 
-    def _get_cnpj(self, person):
-        company = ICompany(person, None)
+    def _get_cnpj(self, branch):
+        company = branch.person.company
         assert company is not None
 
         #FIXME: fix get_cnpj_number method (fails if start with zero).
         cnpj = ''.join([c for c in company.cnpj if c in '1234567890'])
         if not validate_cnpj(cnpj):
             raise ModelDataError(_("The CNPJ of %s is not valid.")
-                                   % person.person.name)
+                                   % branch.person.name)
 
         return cnpj
 
@@ -177,7 +176,7 @@ class NFeGenerator(object):
         nnf = self._sale.invoice_number
         assert nnf
 
-        payments = self._sale.group.get_items()
+        payments = self._sale.payments
         series = sysparam(self.conn).NFE_SERIAL_NUMBER
         orientation = sysparam(self.conn).NFE_DANFE_ORIENTATION
         ecf_info = self._sale.get_nfe_coupon_info()
@@ -208,11 +207,11 @@ class NFeGenerator(object):
         self._nfe_data.append(nfe_identification)
         self.root.append(self._nfe_data.element)
 
-    def _add_issuer(self, issuer):
-        cnpj = self._get_cnpj(issuer)
-        person = issuer.person
-        name = person.name
-        company = ICompany(issuer, None)
+    def _add_issuer(self, branch):
+        cnpj = self._get_cnpj(branch)
+        name = branch.person.name
+        person = branch.person
+        company = person.company
         state_registry = company.state_registry
         crt = self._sale.branch.crt
         self._nfe_issuer = NFeIssuer(name, cnpj=cnpj,
@@ -223,16 +222,18 @@ class NFeGenerator(object):
     def _add_recipient(self, recipient):
         person = recipient.person
         name = person.name
-        individual = IIndividual(person, None)
+        individual = person.individual
+        email = person.email
         if individual is not None:
             cpf = ''.join([c for c in individual.cpf if c in '1234567890'])
-            self._nfe_recipient = NFeRecipient(name, cpf=cpf)
+            self._nfe_recipient = NFeRecipient(name, cpf=cpf, email=email)
         else:
             cnpj = self._get_cnpj(recipient)
-            company = ICompany(person, None)
+            company = person.company
             state_registry = company.state_registry
             self._nfe_recipient = NFeRecipient(name, cnpj=cnpj,
-                                               state_registry=state_registry)
+                                               state_registry=state_registry,
+                                               email=email)
 
         self._nfe_recipient.set_address(*self._get_address_data(person))
         self._nfe_data.append(self._nfe_recipient)
@@ -309,7 +310,7 @@ class NFeGenerator(object):
                          self._sale.discount_value, sale_total)
         self._nfe_data.append(fat)
 
-        payments = self._sale.group.get_items()
+        payments = self._sale.payments
         for p in payments:
             dup = NFeDuplicata(p.id, p.due_date, p.value)
             self._nfe_data.append(dup)
@@ -707,12 +708,20 @@ class NFeRecipient(NFeIssuer):
     doc_cnpj_tag = 'E02'
     doc_cpf_tag = 'E03'
 
+    def __init__(self, name, cpf=None, cnpj=None, state_registry=None,
+                 email=None):
+        NFeIssuer.__init__(self, name=name, cpf=cpf, cnpj=cnpj,
+                           state_registry=state_registry)
+        if email is not None:
+            self.set_attr('email', email)
+
     def as_txt(self):
         if self.get_attr('CNPJ'):
             ie = self._ie or 'ISENTO'
         else:
             ie = ''
-        base = '%s|%s|%s||\n' % (self.txttag, self.get_attr('xNome'), ie)
+        base = '%s|%s|%s||%s\n' % (self.txttag, self.get_attr('xNome'), ie,
+                                   self.get_attr('email'))
         return base + self.get_doc_txt() + self._address.as_txt()
 
 # Pg. 102
@@ -906,40 +915,43 @@ class NFeICMS(BaseNFeXMLGroup):
 
 
 class BaseNFeICMS(BaseNFeXMLGroup):
+    # (name, precision)
     INFO_NAME_MAP = {
-        'orig': 'orig',
-        'CST': 'cst',
-        'modBC': 'mod_bc',
-        'modBCST': 'mod_bc_st',
+        'orig': ('orig', None),
+        'CST': ('cst', None),
+        'modBC': ('mod_bc', None),
+        'modBCST': ('mod_bc_st', None),
 
-        'vBC': 'v_bc',
-        'vBCST': 'v_bc_st',
-        'vICMS': 'v_icms',
-        'vICMSST': 'v_icms_st',
+        'vBC': ('v_bc', 2),
+        'vBCST': ('v_bc_st', 2),
+        'vICMS': ('v_icms', 2),
+        'vICMSST': ('v_icms_st', 2),
 
-        'pICMS': 'p_icms',
-        'pMVAST': 'p_mva_st',
-        'pRedBC': 'p_red_bc',
-        'pRedBCST': 'p_red_bc_st',
-        'pICMSST': 'p_icms_st',
+        'pICMS': ('p_icms', 2),
+        'pMVAST': ('p_mva_st', 2),
+        'pRedBC': ('p_red_bc', 2),
+        'pRedBCST': ('p_red_bc_st', 2),
+        'pICMSST': ('p_icms_st', 2),
 
         # Simples Nacional
-        'CSOSN': 'csosn',
-        'pCredSN': 'p_cred_sn',
-        'vCredICMSSN': 'v_cred_icms_sn',
-        'vBCSTRet': 'v_bc_st_ret',
-        'vICMSSTRet': 'v_icms_st_ret',
+        'CSOSN': ('csosn', 0),
+        'pCredSN': ('p_cred_sn', 2),
+        'vCredICMSSN': ('v_cred_icms_sn', 2),
+        'vBCSTRet': ('v_bc_st_ret', 2),
+        'vICMSSTRet': ('v_icms_st_ret', 2),
     }
 
     def __init__(self, sale_icms_info):
         BaseNFeXMLGroup.__init__(self)
 
         for (name, default) in self.attributes:
-            info_name = self.INFO_NAME_MAP.get(name)
+            info_name, precision = self.INFO_NAME_MAP.get(name)
             if not info_name:
                 continue
 
             value = getattr(sale_icms_info, info_name, '')
+            if precision is not None:
+                value = self.format_value(value, precision)
             if value is None:
                 value = ''
             self.set_attr(name, value)
@@ -1576,12 +1588,12 @@ class NFeTransporter(BaseNFeXMLGroup):
         name = person.name
         self.set_attr('xNome', name)
 
-        individual = IIndividual(person, None)
+        individual = person.individual
         if individual is not None:
             cpf = ''.join([c for c in individual.cpf if c in '1234567890'])
             self.set_attr('CPF', cpf)
         else:
-            company = ICompany(person)
+            company = person.company
             cnpj = ''.join([c for c in company.cnpj if c in '1234567890'])
             self.set_attr('CNPJ', cnpj)
             self.set_attr('IE', company.state_registry)
