@@ -1,5 +1,5 @@
 #!/usr/bin/env python
-# -*- Mode: Python; coding: iso-8859-1 -*-
+# -*- Mode: Python; coding: utf-8 -*-
 # vi:si:et:sw=4:sts=4:ts=4
 
 ##
@@ -93,13 +93,27 @@ class StoqCommandHandler:
         return func(options, *args)
 
     def cmd_help(self, options):
-        cmds = [attr[4:] for attr in dir(self) if attr.startswith('cmd_')]
-        cmds.sort()
-        cmds.remove('help')
+        """Show available commands help"""
+        cmds = []
+        max_len = 0
 
+        for attr in dir(self):
+            if not attr.startswith('cmd_'):
+                continue
+
+            name = attr[4:]
+            doc = getattr(self, attr).__doc__ or ''
+            max_len = max(max_len, len(name))
+            cmds.append((name, doc.split(r'\n')[0]))
+
+        max_len = max_len + 2
+
+        print 'Usage: stoqdbadmin [plugin] <command> [<args>]'
+        print
         print 'Available commands:'
-        for name in cmds:
-            print '  ', name
+
+        for name, doc in cmds:
+            print '  %s%s' % (name.ljust(max_len), doc)
 
         self._read_config(options, load_plugins=False,
                           register_station=False)
@@ -114,8 +128,7 @@ class StoqCommandHandler:
         return 0
 
     def cmd_init(self, options):
-        from stoq.lib.startup import clean_database
-
+        """Creates and initializes a database"""
         # Create a database user before trying to connect
         if options.create_dbuser:
             if not options.username:
@@ -127,7 +140,10 @@ class StoqCommandHandler:
         config = self._read_config(options, register_station=False,
                                    check_schema=False,
                                    load_plugins=False)
-        clean_database(config, options)
+
+        from stoqlib.database.admin import initialize_system
+        initialize_system(password=options.password or config.get_password(),
+                          force=options.force)
 
         if options.create_examples or options.demo:
             from stoqlib.importers.stoqlibexamples import create
@@ -161,8 +177,12 @@ class StoqCommandHandler:
         group.add_option('', '--create-dbuser',
                          action='store_true',
                          dest='create_dbuser')
+        group.add_option('', '--force',
+                         action='store_true',
+                         dest='force')
 
     def cmd_configure(self, options):
+        """Save initial configuration"""
         if not options.dbname:
             print 'dbname missing'
             return 1
@@ -174,6 +194,7 @@ class StoqCommandHandler:
         config.flush()
 
     def cmd_register(self, options):
+        """Register a station computer"""
         self._read_config(options, register_station=False)
 
         self._register_station()
@@ -203,13 +224,12 @@ class StoqCommandHandler:
         # Register the current computer as a branch station
         import socket
         from stoqlib.database.runtime import new_transaction
-        from stoqlib.domain.interfaces import IBranch
-        from stoqlib.domain.person import Person
+        from stoqlib.domain.person import Branch
         from stoqlib.domain.station import BranchStation
         from stoqlib.exceptions import StoqlibError
         trans = new_transaction()
 
-        branches = Person.iselect(IBranch, connection=trans)
+        branches = Branch.select(connection=trans)
         if branches:
             branch = branches[0]
         else:
@@ -257,6 +277,7 @@ class StoqCommandHandler:
                          dest='disable_backup')
 
     def cmd_updateschema(self, options):
+        """Update the database schema"""
         from stoqlib.database.migration import StoqlibSchemaMigration
 
         self._read_config(options, check_schema=False, load_plugins=False,
@@ -269,6 +290,7 @@ class StoqCommandHandler:
             return 1
 
     def cmd_serve(self, options):
+        """Start a synchronization server"""
         from stoqlib.database.synchronization import SynchronizationService
         self._read_config(options, check_schema=False, register_station=False)
         service = SynchronizationService("", 9000)
@@ -295,6 +317,7 @@ class StoqCommandHandler:
                          dest='dry')
 
     def cmd_update(self, options, hostname, station):
+        """Update the database from a synchronization server"""
         from stoqlib.database.synchronization import SynchronizationClient
         self._read_config(options)
 
@@ -314,14 +337,27 @@ class StoqCommandHandler:
                          dest='dry')
 
     def cmd_dump(self, options, output):
+        """Create a database dump"""
         from stoqlib.database.database import dump_database
         self._read_config(options)
 
         if output == '-':
             output = None
-        dump_database(output)
+        dump_database(output, gzip=options.gzip,
+                      format=options.format)
+
+    def opt_dump(self, parser, group):
+        group.add_option('-z', '--gzip',
+                         action='store_true',
+                         dest='gzip')
+        group.add_option('-F', '--format',
+                         action='store',
+                         default='custom',
+                         help="dump format see man pg_dump for more information",
+                         dest='format')
 
     def cmd_restore(self, options, schema):
+        """Restore a database dump"""
         from stoqlib.database.database import execute_sql
 
         self._read_config(options, register_station=False,
@@ -329,6 +365,7 @@ class StoqCommandHandler:
         execute_sql(schema)
 
     def cmd_enable_plugin(self, options, plugin_name):
+        """Enable a plugin on Stoq"""
         self._read_config(options, register_station=False,
                           check_schema=False,
                           load_plugins=False)
@@ -336,6 +373,7 @@ class StoqCommandHandler:
         self._enable_plugins([plugin_name])
 
     def cmd_generate_sintegra(self, options, filename, month):
+        """Generate a sintegra file"""
         import datetime
         self._read_config(options)
 
@@ -351,6 +389,7 @@ class StoqCommandHandler:
         generate(filename, start, end)
 
     def cmd_shell(self, options):
+        """Drop to a shell for executing SQL queries"""
         from stoqlib.database.database import start_shell
         self._read_config(options, register_station=False,
                           check_schema=False)
@@ -363,6 +402,7 @@ class StoqCommandHandler:
                          dest='command')
 
     def cmd_import(self, options):
+        """Import data into Stoq"""
         self._read_config(options, register_station=False)
         from stoqlib.importers import importer
         importer = importer.get_by_type(options.type)
@@ -380,6 +420,7 @@ class StoqCommandHandler:
                          dest="filename")
 
     def cmd_console(self, options):
+        """Drop to a Stoq python console"""
         from stoqlib.lib.console import Console
         self._read_config(options, register_station=False)
         console = Console()
@@ -408,15 +449,18 @@ class StoqCommandHandler:
 
 
 def main(args):
-    pname = args[0]
     args = args[1:]
     if not args:
-        print "Type '%s help' for usage." % pname
-        return 1
+        # defaults to help
+        args.append('help')
 
     cmd = args[0]
     args = args[1:]
 
+    # import library or else externals won't be on sys.path
+    from stoqlib.lib.kiwilibrary import library
+    library # pyflakes
+
     from stoq.lib.options import get_option_parser
     parser = get_option_parser()
 
