@@ -1,4 +1,4 @@
-# -*- Mode: Python; coding: iso-8859-1 -*-
+# -*- Mode: Python; coding: utf-8 -*-
 # vi:si:et:sw=4:sts=4:ts=4
 
 ##
@@ -24,6 +24,7 @@
 """ Main gui definition for admin application.  """
 
 import gettext
+import operator
 
 import glib
 import gtk
@@ -42,7 +43,6 @@ from stoqlib.gui.editors.invoiceeditor import (InvoiceLayoutDialog,
                                                InvoicePrinterDialog)
 from stoqlib.gui.editors.personeditor import UserEditor
 from stoqlib.gui.editors.sellableeditor import SellableTaxConstantsDialog
-from stoqlib.gui.editors.shortcutseditor import ShortcutsEditor
 from stoqlib.gui.keybindings import get_accels
 from stoqlib.gui.search.eventsearch import EventSearch
 from stoqlib.gui.search.fiscalsearch import CfopSearch, FiscalBookEntrySearch
@@ -59,11 +59,12 @@ from stoqlib.gui.search.stationsearch import StationSearch
 from stoqlib.gui.search.taxclasssearch import TaxTemplatesSearch
 from stoqlib.gui.stockicons import (
     STOQ_CALC, STOQ_ADMIN_APP, STOQ_CLIENTS, STOQ_DEVICES, STOQ_DELIVERY,
-    STOQ_DOCUMENTS, STOQ_EDIT, STOQ_FORMS, STOQ_KEYBOARD, STOQ_HR, STOQ_MONEY,
-    STOQ_PAYABLE_APP, STOQ_SUPPLIERS, STOQ_SYSTEM, STOQ_TAXES,
+    STOQ_DOCUMENTS, STOQ_EDIT, STOQ_FORMS, STOQ_HR, STOQ_MONEY,
+    STOQ_PAYABLE_APP, STOQ_PLUGIN, STOQ_SUPPLIERS, STOQ_SYSTEM, STOQ_TAXES,
     STOQ_USER_PROFILES, STOQ_USERS)
 from stoqlib.gui.wizards.personwizard import run_person_role_dialog
 from stoqlib.lib.message import info
+from stoqlib.lib.translation import locale_sorted
 
 from stoq.gui.application import AppWindow
 
@@ -89,31 +90,31 @@ class Tasks(object):
     def add_defaults(self):
         items = [
             (_('Branches'), 'branches', gtk.STOCK_HOME),
+            (_('C.F.O.P.'), 'cfop', STOQ_CALC),
             (_('Client Categories'), 'client_categories', STOQ_CLIENTS),
             (_('Clients'), 'clients', STOQ_CLIENTS),
-            (_('C.F.O.P.'), 'cfop', STOQ_CALC),
             (_('Computers'), 'stations', STOQ_SYSTEM),
             (_('Devices'), 'devices', STOQ_DEVICES),
             (_('Employees'), 'employees', STOQ_ADMIN_APP),
             (_('Events'), 'events', gtk.STOCK_DIALOG_WARNING),
-            (_('Roles'), 'employee_roles', STOQ_USERS),
             (_('Fiscal Books'), 'fiscal_books', STOQ_EDIT),
-            (_('Invoice Printers'), 'invoice_printers', gtk.STOCK_PRINT),
-            (_('Keyboard shortcuts'), 'keyboard_shortcuts', STOQ_KEYBOARD),
             (_('Forms'), 'forms', STOQ_FORMS),
+            (_('Invoice Printers'), 'invoice_printers', gtk.STOCK_PRINT),
+            (_('Parameters'), 'parameters', gtk.STOCK_PREFERENCES),
             (_('Payment Categories'), 'payment_categories', STOQ_PAYABLE_APP),
             (_('Payment Methods'), 'payment_methods', STOQ_MONEY),
-            (_('Parameters'), 'parameters', gtk.STOCK_PREFERENCES),
-            (_('Plugins'), 'plugins', gtk.STOCK_PROPERTIES),
+            (_('Plugins'), 'plugins', STOQ_PLUGIN),
+            (_('Roles'), 'employee_roles', STOQ_USERS),
             (_('Taxes'), 'taxes', STOQ_TAXES),
-            (_('Tax Classes'), 'tax_templates', STOQ_DOCUMENTS),
             (_('Suppliers'), 'suppliers', STOQ_SUPPLIERS),
+            (_('Tax Classes'), 'tax_templates', STOQ_DOCUMENTS),
             (_('Transporters'), 'transporters', STOQ_DELIVERY),
-            (_('Users'), 'users', STOQ_HR),
             (_('User Profiles'), 'user_profiles', STOQ_USER_PROFILES),
+            (_('Users'), 'users', STOQ_HR),
             ]
 
-        for label, name, pixbuf in items:
+        for label, name, pixbuf in locale_sorted(
+            items, key=operator.itemgetter(0)):
             self.add_item(label, name, pixbuf)
 
     def add_item(self, label, name, pixbuf=None, cb=None):
@@ -177,14 +178,20 @@ class Tasks(object):
                             hide_toolbar=True)
 
     def _open_forms(self):
-        self.app.run_dialog(FormFieldEditor, self.app.conn)
+        trans = api.new_transaction()
+        model = self.app.run_dialog(FormFieldEditor, trans)
+        api.finish_transaction(trans, model)
+        trans.close()
 
     def _open_fiscal_books(self):
         self.app.run_dialog(FiscalBookEntrySearch, self.app.conn,
                             hide_footer=True)
 
     def _open_invoice_layouts(self):
-        self.app.run_dialog(InvoiceLayoutDialog, self.app.conn)
+        trans = api.new_transaction()
+        model = self.app.run_dialog(InvoiceLayoutDialog, trans)
+        api.finish_transaction(trans, model)
+        trans.close()
 
     def _open_invoice_printers(self):
         if not InvoiceLayout.select(connection=self.app.conn):
@@ -192,7 +199,10 @@ class Tasks(object):
                    "before adding an invoice printer"))
             return
 
-        self.app.run_dialog(InvoicePrinterDialog, self.app.conn)
+        trans = api.new_transaction()
+        model = self.app.run_dialog(InvoicePrinterDialog, trans)
+        api.finish_transaction(trans, model)
+        trans.close()
 
     def _open_payment_categories(self):
         trans = api.new_transaction()
@@ -201,20 +211,26 @@ class Tasks(object):
         trans.close()
 
     def _open_payment_methods(self):
-        self.app.run_dialog(PaymentMethodsDialog, self.app.conn)
+        trans = api.new_transaction()
+        model = self.app.run_dialog(PaymentMethodsDialog, trans)
+        api.finish_transaction(trans, model)
+        trans.close()
 
     def _open_parameters(self):
-        self.app.run_dialog(ParameterSearch, self.app.conn)
+        trans = api.new_transaction()
+        model = self.app.run_dialog(ParameterSearch, trans)
+        api.finish_transaction(trans, model)
+        trans.close()
 
     def _open_plugins(self):
-        self.app.run_dialog(PluginManagerDialog, self.app.conn)
+        trans = api.new_transaction()
+        model = self.app.run_dialog(PluginManagerDialog, trans)
+        api.finish_transaction(trans, model)
+        trans.close()
 
     def _open_cfop(self):
         self.app.run_dialog(CfopSearch, self.app.conn, hide_footer=True)
 
-    def _open_keyboard_shortcuts(self):
-        self.app.run_dialog(ShortcutsEditor, self.app.conn)
-
     def _open_sintegra(self):
         branch = api.get_current_branch(self.app.conn)
         if branch.manager is None:
@@ -318,7 +334,8 @@ class AdminApp(AppWindow):
 
     def activate(self, params):
         # Admin app doesn't have anything to print/export
-        for widget in (self.app.launcher.Print, self.app.launcher.ExportCSV):
+        for widget in [self.app.launcher.Print,
+                       self.app.launcher.ExportSpreadSheet]:
             widget.set_visible(False)
 
         self.app.launcher.add_new_items([self.NewUser])
