@@ -1,4 +1,4 @@
-# -*- Mode: Python; coding: iso-8859-1 -*-
+# -*- Mode: Python; coding: utf-8 -*-
 # vi:si:et:sw=4:sts=4:ts=4
 
 ##
@@ -36,7 +36,7 @@ from dateutil.tz import tzlocal, tzutc
 import gtk
 
 from stoqlib.api import api
-from stoqlib.domain.interfaces import IClient
+from stoqlib.domain.person import Client
 from stoqlib.gui.editors.callseditor import CallsEditor
 from stoqlib.gui.editors.paymenteditor import (InPaymentEditor,
                                                OutPaymentEditor)
@@ -408,7 +408,7 @@ class CalendarApp(AppWindow):
 
     def _new_client_call(self):
         with api.trans() as trans:
-            self.run_dialog(CallsEditor, trans, None, None, IClient)
+            self.run_dialog(CallsEditor, trans, None, None, Client)
 
         if trans.committed:
             self._update_events()
@@ -434,7 +434,7 @@ class CalendarApp(AppWindow):
     def print_activate(self):
         self._calendar.print_()
 
-    def export_csv_activate(self):
+    def export_spreadsheet_activate(self):
         pass
 
     def on_NewClientCall__activate(self, action):
