@@ -54,41 +54,40 @@ import gtk
 import gobject
 from kiwi.component import provide_utility
 from kiwi.datatypes import ValidationError
-from kiwi.environ import environ
 from kiwi.log import Logger
 from kiwi.python import Settable
 from kiwi.ui.dialogs import info
 from kiwi.ui.delegates import GladeSlaveDelegate
-from kiwi.ui.wizard import WizardStep
 
 from stoqlib.api import api
 from stoqlib.exceptions import DatabaseInconsistency
-from stoqlib.database.admin import USER_ADMIN_DEFAULT_NAME, ensure_admin_user
+from stoqlib.database.admin import (USER_ADMIN_DEFAULT_NAME, ensure_admin_user,
+                                    create_default_profile_settings)
 from stoqlib.database.database import test_local_database
 from stoqlib.database.interfaces import (ICurrentBranchStation,
                                          ICurrentBranch)
 from stoqlib.database.settings import DatabaseSettings
-from stoqlib.domain.person import Person
+from stoqlib.domain.person import LoginUser
 from stoqlib.domain.station import BranchStation
-from stoqlib.domain.interfaces import IUser
 from stoqlib.domain.system import SystemTable
 from stoqlib.exceptions import DatabaseError
-from stoqlib.gui.base.wizards import BaseWizard, WizardEditorStep
+from stoqlib.gui.base.wizards import (BaseWizard, WizardEditorStep,
+                                      WizardStep)
+from stoqlib.gui.logo import render_logo_pixbuf
 from stoqlib.gui.slaves.userslave import PasswordEditorSlave
 from stoqlib.gui.processview import ProcessView
 from stoqlib.lib.configparser import StoqConfig
+from stoqlib.lib.formatters import raw_phone_number
+from stoqlib.lib.kiwilibrary import library
 from stoqlib.lib.message import warning, yesno
 from stoqlib.lib.osutils import read_registry_key
 from stoqlib.lib.validators import validate_email
-from stoqlib.lib.formatters import raw_phone_number
 from stoqlib.lib.webservice import WebService
 from twisted.internet import reactor
 
-from stoq import library
 from stoq.gui.shell import PRIVACY_STRING
 from stoq.lib.options import get_option_parser
-from stoq.lib.startup import setup, set_default_profile_settings
-from stoq.main import run_app
+from stoq.lib.startup import setup
 
 _ = gettext.gettext
 
@@ -125,38 +124,11 @@ class WelcomeStep(BaseWizardStep):
         self._update_widgets()
 
     def _update_widgets(self):
-        logo_file = environ.find_resource('pixmaps', 'stoq_logo.svg')
-        logo = gtk.gdk.pixbuf_new_from_file_at_size(logo_file, LOGO_WIDTH,
-                                                    LOGO_HEIGHT)
-        self.image1.set_from_pixbuf(logo)
+        self.image1.set_from_pixbuf(render_logo_pixbuf('config'))
         self.title_label.set_bold(True)
 
-    def _postgres_from_stoq_installer(self):
-        if read_registry_key(
-            'HKCC', r'Software\Stoq',
-            'InstalledPostgres') != 1:
-            return False
-        # Make sure PostgreSQL is still installed
-        basedir = read_registry_key(
-            'HKLM', r'Software\PostgreSQL\Installations\postgresql-8.4',
-            'Base Directory')
-        return basedir is not None
-
-    def _get_postgres_port(self):
-        return read_registry_key(
-            'HKLM', r'Software\PostgreSQL\Services\postgresql-8.4',
-            'Port')
-
     def next_step(self):
-        if self._postgres_from_stoq_installer():
-            settings = self.wizard.settings
-            settings.address = "localhost"
-            settings.dbname = "stoq"
-            settings.username = "postgres"
-            settings.port = self._get_postgres_port()
-            return PostgresAdminPasswordStep(self.wizard, self)
-        else:
-            return DatabaseLocationStep(self.wizard, self)
+        return DatabaseLocationStep(self.wizard, self)
 
 
 class DatabaseLocationStep(BaseWizardStep):
@@ -173,10 +145,16 @@ class DatabaseLocationStep(BaseWizardStep):
             return DatabaseSettingsStep(self.wizard, self)
 
         settings = self.wizard.settings
-        settings.address = "" # Unix socket really
         # FIXME: Allow developers to specify another database
         #        is_developer_mode() or STOQ_DATABASE_NAME
         settings.dbname = "stoq"
+        if platform.system() == 'Windows':
+            settings.address = "localhost"
+            settings.username = "postgres"
+            settings.port = self.wizard.get_win32_postgres_port()
+            return PostgresAdminPasswordStep(self.wizard, self)
+        else:
+            settings.address = "" # Unix socket really
 
         return self.wizard.connect_for_settings(self)
 
@@ -234,6 +212,7 @@ class DatabaseSettingsStep(WizardEditorStep):
                 self.force_validation()
             return False
 
+        self.wizard.write_pgpass()
         settings = self.wizard.settings
 
         # If we configured setting to localhost, try connecting
@@ -493,6 +472,8 @@ class PostgresAdminPasswordStep(PasswordStep):
 
     def next_step(self):
         self.wizard.settings.password = str(self.password_slave.model.new_password)
+        self.wizard.auth_type = PASSWORD_AUTHENTICATION
+        self.wizard.write_pgpass()
         return self.wizard.connect_for_settings(self)
 
 
@@ -648,9 +629,7 @@ class CreateDatabaseStep(BaseWizardStep):
             self._launch_stoqdbadmin()
             return
 
-        # Save password if using password authentication
-        if self.wizard.auth_type == PASSWORD_AUTHENTICATION:
-            self._setup_pgpass()
+        self.wizard.write_pgpass()
         settings = self.wizard.settings
         self.wizard.config.load_settings(settings)
 
@@ -673,43 +652,6 @@ class CreateDatabaseStep(BaseWizardStep):
             self.process_view.feed("** Not creating database\r\n")
             self.wizard.disable_next()
 
-    def _setup_pgpass(self):
-        logger.info('_setup_pgpass')
-        # There's no way to pass in the password to psql, so we need
-        # to setup a ~/.pgpass where we store the password entered here
-        if platform.system() == 'Windows':
-            directory = os.path.join(os.environ['APPDATA'],
-                                     'postgresql')
-            passfile = os.path.join(directory, 'pgpass.conf')
-        else:
-            directory = os.environ.get('HOME', '/')
-            passfile = os.path.join(directory, '.pgpass')
-        pgpass = os.environ.get('PGPASSFILE', passfile)
-
-        if os.path.exists(pgpass):
-            lines = []
-            for line in open(pgpass):
-                if line[-1] == '\n':
-                    line = line[:-1]
-                lines.append(line)
-        else:
-            lines = []
-
-        settings = self.wizard.settings
-        line = '%s:%s:%s:%s:%s' % (settings.address, settings.port,
-                                   settings.dbname,
-                                   settings.username, settings.password)
-        if line in lines:
-            return
-
-        lines.append(line)
-        if not os.path.exists(directory):
-            os.makedirs(directory)
-        fd = open(pgpass, 'w')
-        fd.write('\n'.join(lines))
-        fd.write('\n')
-        os.chmod(pgpass, 0600)
-
     def _launch_stoqdbadmin(self):
         logger.info('_launch_stoqdbadmin')
         self.wizard.disable_back()
@@ -805,7 +747,7 @@ class CreateDatabaseStep(BaseWizardStep):
             return
         self.label.set_text("")
         self.wizard.load_config_and_call_setup()
-        set_default_profile_settings()
+        create_default_profile_settings()
         ensure_admin_user(self.wizard.config.get_password())
         self.progressbar.set_text(_("Done."))
         self.progressbar.set_fraction(1.0)
@@ -924,20 +866,26 @@ class FirstTimeConfigWizard(BaseWizard):
 
     def _set_admin_password(self, trans):
         logger.info('_set_admin_password')
-        adminuser = Person.iselectOneBy(IUser,
-                                        username=USER_ADMIN_DEFAULT_NAME,
-                                        connection=trans)
+        adminuser = LoginUser.selectOneBy(username=USER_ADMIN_DEFAULT_NAME,
+                                          connection=trans)
         if adminuser is None:
             raise DatabaseInconsistency(
                 ("You should have a user with username: %s"
                  % USER_ADMIN_DEFAULT_NAME))
-        adminuser.password = self.login_password
+        adminuser.set_password(self.login_password)
 
     def _set_online_services(self, trans):
         logger.info('_set_online_services (%s)' %
                             self.enable_online_services)
         api.sysparam(trans).ONLINE_SERVICES = int(self.enable_online_services)
 
+    # Public API
+
+    def get_win32_postgres_port(self):
+        return read_registry_key(
+            'HKLM', r'Software\PostgreSQL\Services\postgresql-8.4',
+            'Port')
+
     def try_connect(self, settings, warn=True):
         logger.info('try_connect (warn=%s)' % (warn))
         logger.info('settings: address=%s username=%s, dbname=%s' % (
@@ -1017,7 +965,7 @@ class FirstTimeConfigWizard(BaseWizard):
               options=self.options,
               check_schema=True,
               register_station=False,
-              load_plugins=True)
+              load_plugins=False)
 
     def connect_for_settings(self, step):
         # Try to connect, we don't care if we can connect,
@@ -1033,10 +981,57 @@ class FirstTimeConfigWizard(BaseWizard):
             return FinishInstallationStep(self)
 
         return InstallationModeStep(self, step)
+
+    def write_pgpass(self):
+        # Only save password if using password authentication
+        if self.auth_type != PASSWORD_AUTHENTICATION:
+            return
+
+        logger.info('write_pgpass')
+        # There's no way to pass in the password to psql via the command line,
+        # so we need to setup a pgpass where we store the password entered here
+        if platform.system() == 'Windows':
+            directory = os.path.join(os.environ['APPDATA'],
+                                     'postgresql')
+            passfile = os.path.join(directory, 'pgpass.conf')
+        else:
+            directory = os.environ.get('HOME', '/')
+            passfile = os.path.join(directory, '.pgpass')
+        pgpass = os.environ.get('PGPASSFILE', passfile)
+
+        # FIXME: remove duplicates when trying several different passwords
+        if os.path.exists(pgpass):
+            lines = []
+            for line in open(pgpass):
+                if line[-1] == '\n':
+                    line = line[:-1]
+                lines.append(line)
+        else:
+            lines = []
+
+        line = '%s:%s:%s:%s:%s' % (self.settings.address,
+                                   self.settings.port,
+                                   self.settings.dbname,
+                                   self.settings.username,
+                                   self.settings.password)
+        if line in lines:
+            return
+
+        lines.append(line)
+        if not os.path.exists(directory):
+            os.makedirs(directory)
+        fd = open(pgpass, 'w')
+        fd.write('\n'.join(lines))
+        fd.write('\n')
+        os.chmod(pgpass, 0600)
+
     #
     # WizardStep hooks
     #
 
+    def cancel(self, *args):
+        raise SystemExit
+
     def finish(self, run=True):
         if self.has_installed_db:
             self.load_config_and_call_setup()
@@ -1054,5 +1049,9 @@ class FirstTimeConfigWizard(BaseWizard):
         self.config.flush()
 
         self.close()
-        if run:
-            run_app(self.options, 'admin')
+
+        # This wizard is shown with run_dialog, that creates a new main loop,
+        # but we may have created another main loop when calling reactor.run()
+        # above. Make sure to leave only one main loop running after the wizard.
+        if reactor.running:
+            reactor.prepare_restart()
