@@ -1,4 +1,4 @@
-# -*- Mode: Python; coding: iso-8859-1 -*-
+# -*- Mode: Python; coding: utf-8 -*-
 # vi:si:et:sw=4:sts=4:ts=4
 
 ##
@@ -36,7 +36,6 @@ import gobject
 import gtk
 from kiwi.currency import currency
 from kiwi.db.query import DateQueryState, DateIntervalQueryState
-from kiwi.db.sqlobj import SQLObjectQueryExecuter
 from kiwi.python import Settable
 from kiwi.ui.dialogs import open as open_dialog
 from kiwi.ui.objectlist import ColoredColumn, Column, ObjectList
@@ -44,12 +43,14 @@ from kiwi.ui.search import Any, DateSearchFilter, DateSearchOption, SearchContai
 from stoqlib.api import api
 from stoqlib.database.orm import const, OR, AND
 from stoqlib.domain.account import Account, AccountTransaction, AccountTransactionView
+from stoqlib.domain.payment.method import PaymentMethod
 from stoqlib.domain.payment.views import InPaymentView, OutPaymentView
+from stoqlib.database.orm import ORMObjectQueryExecuter
 from stoqlib.gui.accounttree import AccountTree
 from stoqlib.gui.base.dialogs import run_dialog
 from stoqlib.gui.editors.accounteditor import AccountEditor
 from stoqlib.gui.editors.accounttransactioneditor import AccountTransactionEditor
-from stoqlib.gui.dialogs.csvexporterdialog import CSVExporterDialog
+from stoqlib.gui.dialogs.spreadsheetexporterdialog import SpreadSheetExporterDialog
 from stoqlib.gui.dialogs.importerdialog import ImporterDialog
 from stoqlib.gui.keybindings import get_accels
 from stoqlib.gui.printing import print_report
@@ -121,7 +122,7 @@ class TransactionPage(object):
     def _create_search(self):
         self.search = TransactionSearchContainer(
             self, columns=self._get_columns(self.model.kind))
-        self.query = SQLObjectQueryExecuter()
+        self.query = ORMObjectQueryExecuter()
         self.search.set_query_executer(self.query)
         self.search.results.connect('row-activated', self._on_row__activated)
         self.results = self.search.results
@@ -213,11 +214,11 @@ class TransactionPage(object):
     def _get_account_columns(self):
         def format_withdrawal(value):
             if value < 0:
-                return '%.2f' % (abs(value), )
+                return currency(abs(value)).format(symbol=True, precision=2)
 
         def format_deposit(value):
             if value > 0:
-                return '%.2f' % (value, )
+                return currency(value).format(symbol=True, precision=2)
 
         if self.model.account_type == Account.TYPE_INCOME:
             color_func = lambda x: False
@@ -285,7 +286,7 @@ class TransactionPage(object):
             account_transaction = trans.get(item.transaction)
         model = getattr(self.model, 'account', self.model)
 
-        transaction = run_dialog(AccountTransactionEditor, self,
+        transaction = run_dialog(AccountTransactionEditor, self.app,
                                  trans, account_transaction, model)
 
         if transaction:
@@ -309,7 +310,7 @@ class TransactionPage(object):
         model = getattr(self.model, 'account', self.model)
         model = trans.get(model)
 
-        transaction = run_dialog(AccountTransactionEditor, self,
+        transaction = run_dialog(AccountTransactionEditor, self.app,
                                  trans, None, model)
         if transaction:
             transaction.sync()
@@ -339,6 +340,7 @@ class FinancialApp(AppWindow):
         self.accounts = AccountTree()
         AppWindow.__init__(self, app)
         self._tills_account = api.sysparam(self.conn).TILLS_ACCOUNT
+        self._imbalance_account = api.sysparam(self.conn).IMBALANCE_ACCOUNT
         self._banks_account = api.sysparam(self.conn).BANKS_ACCOUNT
 
     #
@@ -352,6 +354,10 @@ class FinancialApp(AppWindow):
             ('AccountMenu', None, _('Account')),
             ('Import', gtk.STOCK_ADD, _('Import...'),
              group.get('import'), _('Import a GnuCash or OFX file')),
+            ('ConfigurePaymentMethods', None,
+             _('Payment methods'),
+             group.get('configure_payment_methods'),
+             _('Select accounts for the payment methods on the system')),
             ('DeleteAccount', gtk.STOCK_DELETE, _('Delete...'),
              group.get('delete_account'),
              _('Delete the selected account')),
@@ -374,6 +380,10 @@ class FinancialApp(AppWindow):
         self.DeleteAccount.set_short_label(_('Delete'))
         self.DeleteTransaction.set_short_label(_('Delete'))
 
+        user = api.get_current_user(self.conn)
+        if not user.profile.check_app_permission('admin'):
+            self.ConfigurePaymentMethods.set_sensitive(False)
+
     def create_ui(self):
         self.trans_popup = self.uimanager.get_widget('/TransactionSelection')
         self.acc_popup = self.uimanager.get_widget('/AccountSelection')
@@ -400,8 +410,8 @@ class FinancialApp(AppWindow):
     def print_activate(self):
         self._print_transaction_report()
 
-    def export_csv_activate(self):
-        self._export_csv()
+    def export_spreadsheet_activate(self):
+        self._export_spreadsheet()
 
     #
     # Private
@@ -413,7 +423,7 @@ class FinancialApp(AppWindow):
         self.TransactionMenu.set_visible(not is_accounts_tab)
         self.DeleteAccount.set_visible(is_accounts_tab)
         self.DeleteTransaction.set_visible(not is_accounts_tab)
-        self.app.launcher.ExportCSV.set_sensitive(not is_accounts_tab)
+        self.app.launcher.ExportSpreadSheet.set_sensitive(not is_accounts_tab)
         self.app.launcher.Print.set_sensitive(not is_accounts_tab)
 
         self.NewAccount.set_sensitive(self._can_add_account())
@@ -580,7 +590,7 @@ class FinancialApp(AppWindow):
         gnucash_filter.add_mime_type('application/x-gzip')
         ffilters.append(gnucash_filter)
 
-        filename, file_chooser = open_dialog("Import", parent=self.financial,
+        filename, file_chooser = open_dialog("Import", parent=self.get_toplevel(),
                                              filter=ffilters, with_file_chooser=True)
         if filename is None:
             file_chooser.destroy()
@@ -600,21 +610,22 @@ class FinancialApp(AppWindow):
 
         file_chooser.destroy()
 
-        run_dialog(ImporterDialog, self.financial, format, filename)
+        run_dialog(ImporterDialog, self, format, filename)
 
         # Refresh everthing after an import
         self.accounts.refresh_accounts(self.conn)
         for page in self._pages.values():
             page.refresh()
 
-    def _export_csv(self):
+    def _export_spreadsheet(self):
         """Runs a dialog to export the current search results to a CSV file.
         """
         assert not self._is_accounts_tab()
 
         page = self._get_current_page_widget()
-        self.run_dialog(CSVExporterDialog, self, AccountTransactionView,
-                        page.results)
+        self.run_dialog(SpreadSheetExporterDialog, object_list=page.results,
+                        name=self.app_name,
+                        filename_prefix=self.app.name)
 
     def _can_add_account(self):
         if self._is_accounts_tab():
@@ -634,8 +645,10 @@ class FinancialApp(AppWindow):
         if account_view.kind != 'account':
             return False
 
-        if account_view.id == self._banks_account.id:
-            return
+        if account_view.id in [self._banks_account.id,
+                               self._imbalance_account.id,
+                               self._tills_account.id]:
+            return False
         return True
 
     def _can_delete_account(self):
@@ -685,10 +698,25 @@ class FinancialApp(AppWindow):
         self._refresh_accounts()
 
     def _delete_account(self, account_view):
-        msg = _('Are you sure you want to remove account "%s" ?' %
-                (account_view.description, ))
-        if yesno(msg, gtk.RESPONSE_YES,
-                 _("Keep account"), _("Remove account")):
+        trans = api.new_transaction()
+        account = trans.get(account_view.account)
+        methods = PaymentMethod.selectBy(
+            destination_account=account,
+            connection=trans)
+        if methods.count() > 0:
+            if yesno(
+                _('This account is used in at least one payment method.\n'
+                  'To be able to delete it the payment methods needs to be'
+                  're-configured first'), gtk.RESPONSE_YES,
+                _("Keep account"), _("Configure payment methods")):
+                trans.close()
+                return
+
+        elif yesno(
+            _('Are you sure you want to remove account "%s" ?' %
+              (account_view.description, )), gtk.RESPONSE_YES,
+            _("Keep account"), _("Remove account")):
+            trans.close()
             return
 
         if account_view.id in self._pages:
@@ -698,8 +726,10 @@ class FinancialApp(AppWindow):
         self.accounts.remove(account_view)
         self.accounts.flush()
 
-        trans = api.new_transaction()
-        account = trans.get(account_view.account)
+        imbalance = api.sysparam(trans).IMBALANCE_ACCOUNT
+        for method in methods:
+            method.destination_account = imbalance
+
         account.remove(trans)
         trans.commit(close=True)
 
@@ -795,3 +825,11 @@ class FinancialApp(AppWindow):
 
     def on_Import__activate(self, action):
         self._import()
+
+    # Edit
+    def on_ConfigurePaymentMethods__activate(self, action):
+        from stoqlib.gui.dialogs.paymentmethod import PaymentMethodsDialog
+        trans = api.new_transaction()
+        model = self.run_dialog(PaymentMethodsDialog, trans)
+        api.finish_transaction(trans, model)
+        trans.close()
