@@ -1,4 +1,4 @@
-# -*- Mode: Python; coding: iso-8859-1 -*-
+# -*- Mode: Python; coding: utf-8 -*-
 # vi:si:et:sw=4:sts=4:ts=4
 
 ##
@@ -32,9 +32,8 @@ from kiwi.ui.search import ComboSearchFilter
 from kiwi.ui.objectlist import Column, SearchColumn
 
 from stoqlib.api import api
-from stoqlib.domain.interfaces import IBranch
 from stoqlib.domain.inventory import Inventory
-from stoqlib.domain.person import Person
+from stoqlib.domain.person import Branch
 from stoqlib.domain.product import ProductStockItem
 from stoqlib.exceptions import DatabaseInconsistency
 from stoqlib.gui.dialogs.openinventorydialog import OpenInventoryDialog
@@ -167,7 +166,7 @@ class InventoryApp(SearchableAppWindow):
         return values
 
     def _get_branches(self):
-        return Person.iselect(IBranch, connection=self.conn)
+        return Branch.select(connection=self.conn)
 
     def _get_branches_for_filter(self):
         items = [(b.person.name, b.id) for b in self._get_branches()]
@@ -188,6 +187,7 @@ class InventoryApp(SearchableAppWindow):
             has_open = selected.is_open()
             has_adjusted = selected.has_adjusted_items()
 
+        self.set_sensitive([self.PrintProductListing], bool(selected))
         self.set_sensitive([self.Cancel], has_open and not has_adjusted)
         self.set_sensitive([self.NewInventory], self._can_open())
         self.set_sensitive([self.CountingAction], has_open)
