@@ -1,4 +1,4 @@
-# -*- Mode: Python; coding: iso-8859-1 -*-
+# -*- Mode: Python; coding: utf-8 -*-
 # vi:si:et:sw=4:sts=4:ts=4
 
 ##
@@ -33,13 +33,12 @@ import gettext
 import pango
 import gtk
 from kiwi.datatypes import currency
-from kiwi.enums import SearchFilterPosition
 from kiwi.python import all
-from kiwi.ui.search import ComboSearchFilter, DateSearchFilter
+from kiwi.ui.search import DateSearchFilter
 from kiwi.ui.objectlist import Column, SearchColumn
 from kiwi.ui.gadgets import render_pixbuf
 from stoqlib.api import api
-from stoqlib.domain.payment.operation import register_payment_operations
+from stoqlib.domain.payment.category import PaymentCategory
 from stoqlib.domain.payment.payment import Payment
 from stoqlib.domain.payment.views import OutPaymentView
 from stoqlib.domain.purchase import PurchaseOrder
@@ -47,23 +46,22 @@ from stoqlib.gui.base.dialogs import run_dialog
 from stoqlib.gui.dialogs.paymentchangedialog import (PaymentDueDateChangeDialog,
                                                      PaymentStatusChangeDialog)
 from stoqlib.gui.dialogs.paymentcommentsdialog import PaymentCommentsDialog
-from stoqlib.gui.dialogs.paymentflowhistorydialog import PaymentFlowHistoryDialog
 from stoqlib.gui.editors.paymenteditor import OutPaymentEditor
-from stoqlib.gui.editors.paymentseditor import PaymentsEditor
+from stoqlib.gui.editors.paymentseditor import PurchasePaymentsEditor
 from stoqlib.gui.keybindings import get_accels
 from stoqlib.gui.printing import print_report
 from stoqlib.gui.search.paymentsearch import OutPaymentBillCheckSearch
+from stoqlib.gui.slaves.installmentslave import PurchaseInstallmentConfirmationSlave
 from stoqlib.lib.message import warning
 from stoqlib.reporting.payment import PayablePaymentReport
 from stoqlib.reporting.payments_receipt import OutPaymentReceipt
 
-from stoq.gui.application import SearchableAppWindow
-from stoqlib.gui.slaves.installmentslave import PurchaseInstallmentConfirmationSlave
+from stoq.gui.accounts import BaseAccountWindow, FilterItem
 
 _ = gettext.gettext
 
 
-class PayableApp(SearchableAppWindow):
+class PayableApp(BaseAccountWindow):
 
     # TODO: Change all widget.set_sensitive to self.set_sensitive([widget])
 
@@ -72,7 +70,8 @@ class PayableApp(SearchableAppWindow):
     search_table = OutPaymentView
     search_label = _('matching:')
     report_table = PayablePaymentReport
-    embedded = True
+
+    payment_category_type = PaymentCategory.TYPE_PAYABLE
 
     #
     # Application
@@ -98,9 +97,9 @@ class PayableApp(SearchableAppWindow):
             ('Pay', gtk.STOCK_APPLY, _('Pay...'),
              group.get('payment_pay'),
              _('Pay the order associated with the selected payment')),
-            ('Edit', gtk.STOCK_EDIT, _('Edit...'),
+            ('Edit', gtk.STOCK_EDIT, _('Edit installments...'),
              group.get('payment_edit'),
-             _('Edit the selected payment details')),
+             _('Edit the selected payment installments')),
             ('CancelPayment', gtk.STOCK_REMOVE, _('Cancel...'),
              group.get('payment_cancel'),
              _('Cancel the selected payment')),
@@ -118,6 +117,9 @@ class PayableApp(SearchableAppWindow):
              _('Print a receipt for the selected payment')),
 
             # Search
+            ('PaymentCategories', None, _("Payment categories..."),
+            group.get('search_payment_categories'),
+            _('Search for payment categories')),
             ('BillCheckSearch', None, _('Bills and checks...'),
              group.get('search_bills'),
              _('Search for bills and checks')),
@@ -130,9 +132,9 @@ class PayableApp(SearchableAppWindow):
         self.Edit.set_short_label(_('Edit'))
         self.Details.set_short_label(_('Details'))
         self.Pay.props.is_important = True
+        self.Pay.set_sensitive(False)
+        self.PrintReceipt.set_sensitive(False)
         self.popup = self.uimanager.get_widget('/PayableSelection')
-
-    def create_ui(self):
         self.app.launcher.add_new_items([self.AddPayment])
         self.app.launcher.NewToolItem.set_tooltip(self.AddPayment.get_tooltip())
         self.app.launcher.add_search_items([self.BillCheckSearch])
@@ -140,11 +142,6 @@ class PayableApp(SearchableAppWindow):
             self.BillCheckSearch.get_tooltip())
         self.app.launcher.Print.set_tooltip(
             _("Print a report of these payments"))
-        self.Pay.set_sensitive(False)
-        self.PrintReceipt.set_sensitive(False)
-        self._setup_widgets()
-        self.search.search.results.set_cell_data_func(
-            self._on_results__cell_data_func)
 
     def activate(self, params):
         # FIXME: double negation is weird here
@@ -152,11 +149,17 @@ class PayableApp(SearchableAppWindow):
             self.search.refresh()
         self._update_widgets()
 
+        # FIXME: Move this to a better place when done
+        if self.app.options.debug:
+            from stoqlib.gui.dialogs.chartdialog import ChartDialog
+            c = ChartDialog()
+            c.show_all()
+
     def deactivate(self):
         self.uimanager.remove_ui(self.payable_ui)
 
     def new_activate(self):
-        self._add_payment()
+        self.add_payment()
 
     def search_activate(self):
         run_dialog(OutPaymentBillCheckSearch, self, self.conn)
@@ -167,22 +170,20 @@ class PayableApp(SearchableAppWindow):
 
     def create_filters(self):
         self.set_text_field_columns(['description', 'supplier_name'])
-        self.status_filter = ComboSearchFilter(_('Show payments'),
-                                               self._get_status_values())
-        self.add_filter(self.status_filter,
-                        SearchFilterPosition.TOP, ['status'])
+        self.create_main_filter()
 
     def get_columns(self):
         return [SearchColumn('id', title=_('#'), long_title=_('Payment ID'),
                              width=60, data_type=int,
                              format='%04d'),
-                Column('color', title=_('Description'), width=20,
-                       data_type=gtk.gdk.Pixbuf, format_func=render_pixbuf),
-                Column('comments_number', title=_(u'Comments'),
-                        visible=False),
                 SearchColumn('description', title=_('Description'),
                               data_type=str, ellipsize=pango.ELLIPSIZE_END,
-                              expand=True, column='color'),
+                              expand=True, pack_end=True),
+                Column('color', title=_('Description'), width=20,
+                       data_type=gtk.gdk.Pixbuf, format_func=render_pixbuf,
+                       column='description'),
+                Column('comments_number', title=_(u'Comments'),
+                        visible=False),
                 SearchColumn('supplier_name', title=_('Supplier'),
                              data_type=str, width=140,
                              ellipsize=pango.ELLIPSIZE_END),
@@ -204,12 +205,25 @@ class PayableApp(SearchableAppWindow):
                              visible=False),
                 ]
 
+    #
+    # BaseAccountWindow
+    #
+
+    def add_payment(self, category=None):
+        with api.trans() as trans:
+            self.run_dialog(OutPaymentEditor, trans, category=category)
+
+        self.search.refresh()
+        if trans.committed:
+            self._update_filter_items()
+            self.select_result(OutPaymentView.get(trans.retval.id))
+
     #
     # Public API
     #
 
     def search_for_date(self, date):
-        self.status_filter.select(None)
+        self.main_filter.select(None)
         dfilter = DateSearchFilter(_("Paid or due date"))
         dfilter.set_removable()
         dfilter.mode.select_item_by_position(5)
@@ -306,6 +320,10 @@ class PayableApp(SearchableAppWindow):
         if len(payable_views) != 1:
             return False
 
+        if not any(view.operation.can_cancel(view.payment)
+                   for view in payable_views):
+            return False
+
         return payable_views[0].can_cancel_payment()
 
     def _can_change_due_date(self, payable_views):
@@ -317,12 +335,19 @@ class PayableApp(SearchableAppWindow):
         if len(payable_views) != 1:
             return False
 
+        if not any(view.operation.can_change_due_date(view.payment)
+                   for view in payable_views):
+            return False
+
         return payable_views[0].can_change_due_date()
 
     def _edit(self, payable_views):
         with api.trans() as trans:
             order = trans.get(payable_views[0].purchase)
-            run_dialog(PaymentsEditor, self, trans, order)
+            run_dialog(PurchasePaymentsEditor, self, trans, order)
+
+        if trans.committed:
+            self.refresh()
 
     def _pay(self, payable_views):
         """
@@ -366,6 +391,10 @@ class PayableApp(SearchableAppWindow):
         if not payable_views:
             return False
 
+        if not any(view.operation.can_pay(view.payment)
+                   for view in payable_views):
+            return False
+
         if len(payable_views) == 1:
             return payable_views[0].status == Payment.STATUS_PENDING
 
@@ -414,13 +443,6 @@ class PayableApp(SearchableAppWindow):
             return False
         return all(view.sale == sale for view in payable_views)
 
-    def _setup_widgets(self):
-        self.results.set_selection_mode(gtk.SELECTION_MULTIPLE)
-        self.search.set_summary_label(column='value',
-                                      label='<b>Total:</b>',
-                                      format='<b>%s</b>',
-                                      parent=self.get_statusbar_message_area())
-
     def _update_widgets(self):
         selected = self.results.get_selected_rows()
         self.Details.set_sensitive(self._can_show_details(selected))
@@ -438,37 +460,22 @@ class PayableApp(SearchableAppWindow):
         items.insert(0, (_('Any'), None))
         return items
 
-    def _add_payment(self):
-        with api.trans() as trans:
-            self.run_dialog(OutPaymentEditor, trans)
-
-        self.search.refresh()
-        if trans.committed:
-            self.select_result(OutPaymentView.get(trans.retval.id))
-
     def _run_bill_check_search(self):
         run_dialog(OutPaymentBillCheckSearch, self, self.conn)
 
+    def _update_filter_items(self):
+        options = [
+            FilterItem(_('Paid payments'), 'status:paid'),
+            FilterItem(_('To pay'), 'status:not-paid'),
+            FilterItem(_('Late payments'), 'status:late'),
+            ]
+
+        self.add_filter_items(PaymentCategory.TYPE_PAYABLE, options)
+
     #
     # Kiwi callbacks
     #
 
-    def _on_results__cell_data_func(self, column, renderer, pv, text):
-        if not isinstance(renderer, gtk.CellRendererText):
-            return text
-
-        if pv.paid_date and self.status_filter.get_state().value is None:
-            renderer.set_property('strikethrough', True)
-            renderer.set_property('strikethrough-set', True)
-        else:
-            renderer.set_property('strikethrough-set', False)
-        if not pv.paid_date and pv.due_date < datetime.datetime.now():
-            renderer.set_property('weight', pango.WEIGHT_BOLD)
-            renderer.set_property('weight-set', True)
-        else:
-            renderer.set_property('weight-set', False)
-        return text
-
     def on_results__row_activated(self, klist, payable_view):
         if self._can_show_details([payable_view]):
             self._show_details(payable_view)
@@ -476,6 +483,9 @@ class PayableApp(SearchableAppWindow):
     def on_results__right_click(self, results, result, event):
         self.popup.popup(None, None, None, event.button, event.time)
 
+    def on_results__selection_changed(self, results, selected):
+        self._update_widgets()
+
     def on_Comments__activate(self, action):
         payable_view = self.results.get_selected_rows()[0]
         self._show_comments(payable_view)
@@ -490,22 +500,15 @@ class PayableApp(SearchableAppWindow):
     def on_Edit__activate(self, action):
         self._edit(self.results.get_selected_rows())
 
-    def on_results__selection_changed(self, results, selected):
-        self._update_widgets()
-
     def on_PrintReceipt__activate(self, action):
-        register_payment_operations()
         payment_views = self.results.get_selected_rows()
         payments = [v.payment for v in payment_views]
         date = datetime.date.today()
         print_report(OutPaymentReceipt, payment=payments[0],
                      order=payment_views[0].purchase, date=date)
 
-    def on_PaymentFlowHistory__activate(self, action):
-        self.run_dialog(PaymentFlowHistoryDialog, self.conn)
-
     def on_AddPayment__activate(self, action):
-        self._add_payment()
+        self.add_payment()
 
     def on_CancelPayment__activate(self, action):
         payable_view = self.results.get_selected_rows()[0]
