@@ -1,4 +1,4 @@
-# -*- Mode: Python; coding: iso-8859-1 -*-
+# -*- Mode: Python; coding: utf-8 -*-
 # vi:si:et:sw=4:sts=4:ts=4
 
 ##
@@ -31,18 +31,15 @@ import gtk
 from kiwi.datatypes import currency, converter
 from kiwi.argcheck import argcheck
 from kiwi.datatypes import ValidationError
-from kiwi.environ import environ
 from kiwi.log import Logger
 from kiwi.python import Settable
 from kiwi.ui.widgets.list import Column
 from kiwi.ui.widgets.contextmenu import ContextMenu, ContextMenuItem
 from stoqdrivers.enum import UnitType
 from stoqlib.api import api
-from stoqlib.domain.interfaces import IDelivery, ISalesPerson
 from stoqlib.domain.devices import DeviceSettings
 from stoqlib.domain.payment.group import PaymentGroup
-from stoqlib.domain.product import IStorable
-from stoqlib.domain.sale import Sale, DeliveryItem
+from stoqlib.domain.sale import Sale, Delivery
 from stoqlib.domain.sellable import Sellable
 from stoqlib.drivers.scale import read_scale_info
 from stoqlib.exceptions import StoqlibError, TaxError
@@ -52,14 +49,15 @@ from stoqlib.lib.message import warning, info, yesno, marker
 from stoqlib.lib.pluginmanager import get_plugin_manager
 from stoqlib.gui.base.dialogs import push_fullscreen, pop_fullscreen
 from stoqlib.gui.base.gtkadds import button_set_image_with_label
-from stoqlib.gui.editors.deliveryeditor import DeliveryEditor
+from stoqlib.gui.editors.deliveryeditor import CreateDeliveryEditor
 from stoqlib.gui.editors.serviceeditor import ServiceItemEditor
 from stoqlib.gui.fiscalprinter import FiscalPrinterHelper
 from stoqlib.gui.keybindings import get_accels
+from stoqlib.gui.logo import render_logo_pixbuf
+from stoqlib.gui.search.deliverysearch import DeliverySearch
 from stoqlib.gui.search.personsearch import ClientSearch
 from stoqlib.gui.search.productsearch import ProductSearch
-from stoqlib.gui.search.salesearch import (SaleSearch, DeliverySearch,
-                                           SoldItemsByBranchSearch)
+from stoqlib.gui.search.salesearch import SaleSearch, SoldItemsByBranchSearch
 from stoqlib.gui.search.sellablesearch import SellableSearch
 from stoqlib.gui.search.servicesearch import ServiceSearch
 
@@ -102,10 +100,6 @@ class _SaleItem(object):
         return '%s %s' % (qtd_string, self.unit)
 
 
-LOGO_WIDTH = 91
-LOGO_HEIGHT = 32
-
-
 class PosApp(AppWindow):
 
     app_name = _('Point of Sales')
@@ -116,7 +110,6 @@ class PosApp(AppWindow):
         AppWindow.__init__(self, app)
         self._delivery = None
         self.param = api.sysparam(self.conn)
-        self.max_results = self.param.MAX_SEARCH_RESULTS
         self._coupon = None
         # Cant use self._coupon to verify if there is a sale, since
         # CONFIRM_SALES_ON_TILL doesnt create a coupon
@@ -192,7 +185,7 @@ class PosApp(AppWindow):
 
     def activate(self, params):
         # Admin app doesn't have anything to print/export
-        for widget in (self.app.launcher.Print, self.app.launcher.ExportCSV):
+        for widget in (self.app.launcher.Print, self.app.launcher.ExportSpreadSheet):
             widget.set_visible(False)
 
         # Hide toolbar specially for pos
@@ -205,7 +198,7 @@ class PosApp(AppWindow):
         # This is important to do after the other calls, since
         # it emits signals that disable UI which might otherwise
         # be enabled.
-        self._printer.check_till()
+        self._printer.run_initial_checks()
 
     def deactivate(self):
         self.uimanager.remove_ui(self.pos_ui)
@@ -309,13 +302,7 @@ class PosApp(AppWindow):
         self.register_sensitive_group(self._inventory_widgets,
                                       lambda: not self.has_open_inventory())
 
-        logo_file = environ.find_resource('pixmaps', 'stoq_logo.svg')
-        logo = gtk.gdk.pixbuf_new_from_file_at_size(logo_file, LOGO_WIDTH,
-                                                    LOGO_HEIGHT)
-        self.stoq_logo.set_from_pixbuf(logo)
-
-        self.till_status_label.set_size('xx-large')
-        self.till_status_label.set_bold(True)
+        self.stoq_logo.set_from_pixbuf(render_logo_pixbuf('pos'))
 
         self.order_total_label.set_size('xx-large')
         self.order_total_label.set_bold(True)
@@ -381,7 +368,8 @@ class PosApp(AppWindow):
         sale_item = _SaleItem(sellable=sellable,
                               quantity=quantity)
         if is_service:
-            rv = self.run_dialog(ServiceItemEditor, self.conn, sale_item)
+            with api.trans() as trans:
+                rv = self.run_dialog(ServiceItemEditor, trans, sale_item)
             if not rv:
                 return
         self._update_added_item(sale_item)
@@ -403,6 +391,12 @@ class PosApp(AppWindow):
                                         status=Sellable.STATUS_AVAILABLE,
                                         connection=self.conn)
 
+        # If the barcode didnt match, maybe the user typed the product code
+        if not sellable:
+            sellable = Sellable.selectOneBy(code=barcode,
+                                        status=Sellable.STATUS_AVAILABLE,
+                                        connection=self.conn)
+
         # If the barcode has the price information, we need to calculate the
         # corresponding weight.
         if info and sellable and info.mode == BarcodeInfo.MODE_PRICE:
@@ -441,13 +435,21 @@ class PosApp(AppWindow):
         self.till_status_label.set_text(text)
 
     def _till_status_changed(self, closed, blocked):
+        def large(s):
+            return '<span weight="bold" size="xx-large">%s</span>' % (s, )
+
         if closed:
-            text = _(u"Till closed")
+            text = large(_("Till closed"))
+            if not blocked:
+                text += '\n\n<span size="large"><a href="open-till">%s</a></span>' % (
+                    _('Open till'))
         elif blocked:
-            text = _(u"Till blocked")
+            text = large(_("Till blocked"))
         else:
-            text = _(u"Till open")
-        self.till_status_label.set_text(text)
+            text = large(_("Till open"))
+        self.till_status_label.set_use_markup(True)
+        self.till_status_label.set_justify(gtk.JUSTIFY_CENTER)
+        self.till_status_label.set_markup(text)
 
         self.set_sensitive([self.TillOpen], closed)
         self.set_sensitive([self.TillClose], not closed or blocked)
@@ -573,7 +575,7 @@ class PosApp(AppWindow):
                 self._scale_settings):
                 self._read_scale(sellable)
 
-        storable = IStorable(sellable.product, None)
+        storable = sellable.product_storable
         if storable is not None:
             if not self._check_available_stock(storable, sellable):
                 info(_("You cannot sell more items of product %s. "
@@ -588,7 +590,7 @@ class PosApp(AppWindow):
 
     def _check_available_stock(self, storable, sellable):
         branch = api.get_current_branch(self.conn)
-        available = storable.get_full_balance(branch)
+        available = storable.get_balance_for_branch(branch)
         added = sum([sale_item.quantity
                      for sale_item in self.sale_items
                          if sale_item.sellable == sellable])
@@ -615,7 +617,8 @@ class PosApp(AppWindow):
             if sale_item.sellable.service == delivery_service:
                 self._edit_delivery()
                 return
-            model = self.run_dialog(ServiceItemEditor, self.conn, sale_item)
+            with api.trans() as trans:
+                model = self.run_dialog(ServiceItemEditor, trans, sale_item)
             if model:
                 self.sale_items.update(sale_item)
         else:
@@ -658,33 +661,36 @@ class PosApp(AppWindow):
         @returns: The delivery
         """
         #FIXME: Canceling the editor still saves the changes.
-        return self.run_dialog(DeliveryEditor, self.conn,
+        return self.run_dialog(CreateDeliveryEditor, self.conn,
                                self._delivery,
                                sale_items=self._get_deliverable_items())
 
-    def _add_delivery_item(self, delivery, delivery_service):
+    def _add_delivery_item(self, delivery, delivery_sellable):
         for sale_item in self.sale_items:
-            if sale_item.sellable == delivery_service:
+            if sale_item.sellable == delivery_sellable:
                 sale_item.price = delivery.price
                 sale_item.notes = delivery.notes
-                delivery_item = sale_item
+                sale_item.estimated_fix_date = delivery.estimated_fix_date
+                self._delivery_item = sale_item
                 new_item = False
                 break
         else:
-            delivery_item = _SaleItem(sellable=delivery_service,
-                                      quantity=1,
-                                      notes=delivery.notes,
-                                      price=delivery.price)
-            delivery_item.estimated_fix_date = delivery.estimated_fix_date
+            self._delivery_item = _SaleItem(
+                sellable=delivery_sellable,
+                quantity=1,
+                notes=delivery.notes,
+                price=delivery.price,
+                )
+            self._delivery_item.estimated_fix_date = delivery.estimated_fix_date
             new_item = True
 
-        self._update_added_item(delivery_item,
+        self._update_added_item(self._delivery_item,
                                 new_item=new_item)
 
     def _create_sale(self, trans):
         user = api.get_current_user(trans)
         branch = api.get_current_branch(trans)
-        salesperson = ISalesPerson(user.person)
+        salesperson = user.person.salesperson
         cfop = api.sysparam(trans).DEFAULT_SALES_CFOP
         group = PaymentGroup(connection=trans)
         sale = Sale(connection=trans,
@@ -696,8 +702,15 @@ class PosApp(AppWindow):
                     operation_nature=api.sysparam(trans).DEFAULT_OPERATION_NATURE)
 
         if self._delivery:
-            address_string = self._delivery.address.get_address_string()
             sale.client = self._delivery.client
+            sale.transporter = self._delivery.transporter
+            delivery = Delivery(
+                connection=trans,
+                address=self._delivery.address,
+                transporter=self._delivery.transporter,
+                )
+        else:
+            delivery = None
 
         for fake_sale_item in self.sale_items:
             sale_item = sale.add_sellable(fake_sale_item.sellable,
@@ -706,14 +719,11 @@ class PosApp(AppWindow):
             sale_item.notes = fake_sale_item.notes
             sale_item.estimated_fix_date = fake_sale_item.estimated_fix_date
 
-            if self._delivery and fake_sale_item.deliver:
-                item = sale_item.addFacet(IDelivery,
-                                          connection=trans)
-                item.address = address_string
-                DeliveryItem(sellable=fake_sale_item.sellable,
-                             quantity=fake_sale_item.quantity,
-                             delivery=item,
-                             connection=trans)
+            if delivery and fake_sale_item.deliver:
+                delivery.add_item(sale_item)
+            elif delivery and fake_sale_item == self._delivery_item:
+                delivery.service_item = sale_item
+
         return sale
 
     def _checkout(self):
@@ -739,9 +749,6 @@ class PosApp(AppWindow):
             log.info("Checking out")
             trans.close()
 
-            # self.conn is infact a transaction, do a commit to bring
-            # the objects from trans into self.conn
-            self.conn.commit()
         self._coupon = None
         self._clear_order()
 
@@ -775,7 +782,7 @@ class PosApp(AppWindow):
                     _("It is not possible to start a new sale if the "
                       "fiscal coupon cannot be opened."),
                     gtk.RESPONSE_YES, _("Try again"), _("Cancel sale")):
-                    self.app.shutdown()
+                    #self.app.shutdown()
                     break
 
         return coupon
@@ -786,7 +793,7 @@ class PosApp(AppWindow):
         Should return -1 if the coupon was not added, but will return None if
         CONFIRM_SALES_ON_TILL is true
 
-        See L{stoqlib.gui.fiscalprinter.FiscalCoupon} for more information
+        See :class:`stoqlib.gui.fiscalprinter.FiscalCoupon` for more information
         """
         self._sale_started = True
         if self.param.CONFIRM_SALES_ON_TILL:
@@ -827,7 +834,8 @@ class PosApp(AppWindow):
         self.run_dialog(ClientSearch, self.conn, hide_footer=True)
 
     def on_Sales__activate(self, action):
-        self.run_dialog(SaleSearch, self.conn)
+        with api.trans() as trans:
+            self.run_dialog(SaleSearch, trans)
 
     def on_SoldItemsByBranchSearch__activate(self, action):
         self.run_dialog(SoldItemsByBranchSearch, self.conn)
@@ -872,6 +880,11 @@ class PosApp(AppWindow):
 
         return True
 
+    def on_till_status_label__activate_link(self, button, link):
+        if link == 'open-till':
+            self._printer.open_till()
+        return True
+
     def on_advanced_search__clicked(self, button):
         self._run_advanced_search()
 
