@@ -35,15 +35,13 @@ from kiwi.python import all
 from kiwi.ui.objectlist import Column, SearchColumn
 from kiwi.ui.search import ComboSearchFilter, DateSearchFilter
 from stoqlib.api import api
-from stoqlib.domain.payment.operation import register_payment_operations
 from stoqlib.domain.purchase import PurchaseOrder, PurchaseOrderView
 from stoqlib.gui.dialogs.purchasedetails import PurchaseDetailsDialog
 from stoqlib.gui.dialogs.sellablepricedialog import SellablePriceDialog
 from stoqlib.gui.dialogs.stockcostdialog import StockCostDialog
 from stoqlib.gui.editors.producteditor import ProductEditor
 from stoqlib.gui.keybindings import get_accels
-from stoqlib.gui.search.categorysearch import (SellableCategorySearch,
-                                               BaseSellableCatSearch)
+from stoqlib.gui.search.categorysearch import SellableCategorySearch
 from stoqlib.gui.search.consignmentsearch import ConsignmentItemSearch
 from stoqlib.gui.search.personsearch import SupplierSearch, TransporterSearch
 from stoqlib.gui.search.productsearch import (ProductSearch,
@@ -107,8 +105,6 @@ class PurchaseApp(SearchableAppWindow):
             ("StockCost", None, _("_Stock cost...")),
 
             # Search
-            ("BaseCategories", None, _("Base categories..."),
-             group.get("search_base_categories")),
             ("Categories", None, _("Categories..."),
              group.get("search_categories")),
             ("Products", STOQ_PRODUCTS, _("Products..."),
@@ -351,8 +347,6 @@ class PurchaseApp(SearchableAppWindow):
                         model=order_views[0].purchase)
 
     def _send_selected_items_to_supplier(self):
-        api.rollback_and_begin(self.conn)
-
         orders = self.results.get_selected_rows()
         valid_order_views = [
             order for order in orders
@@ -395,7 +389,6 @@ class PurchaseApp(SearchableAppWindow):
         self.select_result(order_views)
 
     def _cancel_order(self):
-        register_payment_operations()
         order_views = self.results.get_selected_rows()
         assert all(ov.purchase.can_cancel() for ov in order_views)
         cancel_label = gettext.ngettext(_("Cancel order"),
@@ -497,7 +490,8 @@ class PurchaseApp(SearchableAppWindow):
         self.run_dialog(SellableCategorySearch, self.conn)
 
     def on_SearchQuotes__activate(self, action):
-        self.run_dialog(ReceiveQuoteWizard, self.conn)
+        with api.trans() as trans:
+            self.run_dialog(ReceiveQuoteWizard, trans)
         self.refresh()
 
     def on_SearchPurchasedItems__activate(self, action):
@@ -518,9 +512,6 @@ class PurchaseApp(SearchableAppWindow):
     def on_ProductUnits__activate(self, action):
         self.run_dialog(SellableUnitSearch, self.conn)
 
-    def on_BaseCategories__activate(self, action):
-        self.run_dialog(BaseSellableCatSearch, self.conn)
-
     def on_Services__activate(self, action):
         self.run_dialog(ServiceSearch, self.conn, hide_price_column=True)
 
