@@ -1,4 +1,4 @@
-# -*- Mode: Python; coding: iso-8859-1 -*-
+# -*- Mode: Python; coding: utf-8 -*-
 # vi:si:et:sw=4:sts=4:ts=4
 
 ##
@@ -33,13 +33,12 @@ import gettext
 import pango
 import gtk
 from kiwi.datatypes import currency
-from kiwi.enums import SearchFilterPosition
 from kiwi.python import all
 from kiwi.ui.gadgets import render_pixbuf
 from kiwi.ui.objectlist import SearchColumn, Column
-from kiwi.ui.search import ComboSearchFilter, DateSearchFilter
+from kiwi.ui.search import DateSearchFilter
 from stoqlib.api import api
-from stoqlib.domain.payment.operation import register_payment_operations
+from stoqlib.domain.payment.category import PaymentCategory
 from stoqlib.domain.payment.payment import Payment
 from stoqlib.domain.payment.views import InPaymentView
 from stoqlib.domain.till import Till
@@ -49,24 +48,23 @@ from stoqlib.gui.base.dialogs import run_dialog
 from stoqlib.gui.dialogs.paymentchangedialog import (PaymentDueDateChangeDialog,
                                                      PaymentStatusChangeDialog)
 from stoqlib.gui.dialogs.paymentcommentsdialog import PaymentCommentsDialog
-from stoqlib.gui.dialogs.paymentflowhistorydialog import PaymentFlowHistoryDialog
 from stoqlib.gui.editors.paymenteditor import InPaymentEditor
+from stoqlib.gui.editors.paymentseditor import SalePaymentsEditor
 from stoqlib.gui.keybindings import get_accels
 from stoqlib.gui.search.paymentsearch import InPaymentBillCheckSearch
 from stoqlib.gui.search.paymentsearch import CardPaymentSearch
 from stoqlib.gui.slaves.installmentslave import SaleInstallmentConfirmationSlave
 from stoqlib.gui.wizards.renegotiationwizard import PaymentRenegotiationWizard
 from stoqlib.lib.message import warning
-from stoqlib.reporting.boleto import BillReport
 from stoqlib.reporting.payment import ReceivablePaymentReport
 from stoqlib.reporting.payments_receipt import InPaymentReceipt
 
-from stoq.gui.application import SearchableAppWindow
+from stoq.gui.accounts import BaseAccountWindow, FilterItem
 
 _ = gettext.gettext
 
 
-class ReceivableApp(SearchableAppWindow):
+class ReceivableApp(BaseAccountWindow):
 
     # TODO: Change all widget.set_sensitive to self.set_sensitive([widget])
 
@@ -75,7 +73,8 @@ class ReceivableApp(SearchableAppWindow):
     search_table = InPaymentView
     search_label = _('matching:')
     report_table = ReceivablePaymentReport
-    embedded = True
+
+    payment_category_type = PaymentCategory.TYPE_RECEIVABLE
 
     #
     # Application
@@ -112,6 +111,9 @@ class ReceivableApp(SearchableAppWindow):
             ('Renegotiate', None, _('Renegotiate...'),
              group.get('payment_renegotiate'),
              _('Renegotiate the selected payments')),
+            ('Edit', None, _('Edit installments...'),
+             group.get('payment_edit_installments'),
+             _('Edit the selected payment installments')),
             ('Comments', None, _('Comments...'),
              group.get('payment_comments'),
              _('Add comments to the selected payment')),
@@ -123,6 +125,9 @@ class ReceivableApp(SearchableAppWindow):
              _('Print a receipt for the selected payment')),
 
             # Search
+            ('PaymentCategories', None, _("Payment categories..."),
+            group.get('search_payment_categories'),
+            _('Search for payment categories')),
             ('BillCheckSearch', None, _('Bills and checks...'),
              group.get('search_bills'),
              _('Search for bills and checks')),
@@ -137,21 +142,12 @@ class ReceivableApp(SearchableAppWindow):
         self.Receive.set_short_label(_('Receive'))
         self.Details.set_short_label(_('Details'))
         self.Receive.props.is_important = True
-        self.popup = self.uimanager.get_widget('/ReceivableSelection')
-
-    def create_ui(self):
         self.app.launcher.add_new_items([self.AddReceiving])
         self.app.launcher.add_search_items([self.BillCheckSearch,
                                             self.CardPaymentSearch])
         self.app.launcher.Print.set_tooltip(
             _("Print a report of this payments"))
-        self.results.set_selection_mode(gtk.SELECTION_MULTIPLE)
-        self.search.set_summary_label(column='value',
-            label='<b>%s</b>' % (_("Total")),
-            format='<b>%s</b>',
-            parent=self.get_statusbar_message_area())
-        self.search.search.results.set_cell_data_func(
-            self._on_results__cell_data_func)
+        self.popup = self.uimanager.get_widget('/ReceivableSelection')
 
     def activate(self, params):
         self._update_widgets()
@@ -164,7 +160,7 @@ class ReceivableApp(SearchableAppWindow):
         self.uimanager.remove_ui(self.receivable_ui)
 
     def new_activate(self):
-        self._add_receiving()
+        self.add_payment()
 
     def search_activate(self):
         self._run_bill_check_search()
@@ -175,22 +171,20 @@ class ReceivableApp(SearchableAppWindow):
 
     def create_filters(self):
         self.set_text_field_columns(['description', 'drawee'])
-        self.status_filter = ComboSearchFilter(_('Show payments'),
-                                               self._get_status_values())
-        self.add_filter(self.status_filter,
-            SearchFilterPosition.TOP, ['status'])
+        self.create_main_filter()
 
     def get_columns(self):
         return [SearchColumn('id', title=_('#'), long_title=_("Payment ID"),
                              width=60, data_type=int,
                              format='%04d'),
+                SearchColumn('description', title=_('Description'),
+                             data_type=str, ellipsize=pango.ELLIPSIZE_END,
+                             expand=True, pack_end=True),
                 Column('color', title=_('Description'), width=20,
-                       data_type=gtk.gdk.Pixbuf, format_func=render_pixbuf),
+                       data_type=gtk.gdk.Pixbuf, format_func=render_pixbuf,
+                       column='description'),
                 Column('comments_number', title=_(u'Comments'),
                         visible=False),
-                SearchColumn('description', title=_('Description'),
-                              data_type=str, ellipsize=pango.ELLIPSIZE_END,
-                             column='color', expand=True),
                 SearchColumn('drawee', title=_('Drawee'), data_type=str,
                              ellipsize=pango.ELLIPSIZE_END, width=140),
                 SearchColumn('due_date', title=_('Due date'),
@@ -210,12 +204,23 @@ class ReceivableApp(SearchableAppWindow):
                              long_title=_('Payment category'), width=110,
                              visible=False)]
 
+    #
+    # BaseAccountWindow
+    #
+
+    def add_payment(self, category=None):
+        trans = api.new_transaction()
+        retval = self.run_dialog(InPaymentEditor, trans, category=category)
+        if api.finish_transaction(trans, retval):
+            self._update_filter_items()
+            self.search.refresh()
+
     #
     # Public API
     #
 
     def search_for_date(self, date):
-        self.status_filter.select(None)
+        self.main_filter.select(None)
         dfilter = DateSearchFilter(_("Paid or due date"))
         dfilter.set_removable()
         dfilter.mode.select_item_by_position(5)
@@ -243,7 +248,8 @@ class ReceivableApp(SearchableAppWindow):
             one_item and self._is_paid(selected))
         self.SetNotPaid.set_sensitive(
             one_item and self._is_paid(selected))
-        self.PrintBill.set_sensitive(self._can_print_bill(selected))
+        self.Edit.set_sensitive(self._can_edit(selected))
+        self.PrintBill.set_sensitive(self._can_print(selected))
 
     def _get_status_values(self):
         values = [(v, k) for k, v in Payment.statuses.items()]
@@ -288,12 +294,6 @@ class ReceivableApp(SearchableAppWindow):
         trans.close()
         self._update_widgets()
 
-    def _add_receiving(self):
-        trans = api.new_transaction()
-        retval = self.run_dialog(InPaymentEditor, trans)
-        if api.finish_transaction(trans, retval):
-            self.search.refresh()
-
     def _change_due_date(self, receivable_view):
         """ Receives a receivable_view and change the payment due date
         related to the view.
@@ -351,9 +351,8 @@ class ReceivableApp(SearchableAppWindow):
         if not receivable_views:
             return False
 
-        # Until we fix bug 3703, don't allow receiving store credit payments
-        if any(view.method_name == 'store_credit'
-               for view in receivable_views):
+        if not any(view.operation.can_pay(view.payment)
+                   for view in receivable_views):
             return False
 
         if len(receivable_views) == 1:
@@ -392,12 +391,25 @@ class ReceivableApp(SearchableAppWindow):
                    view.get_parent().can_set_renegotiated()
                    for view in receivable_views)
 
+    def _can_edit(self, views):
+        """Determines if we can edit the selected payments
+        """
+        if not views:
+            return False
+        sale_id = views[0].sale_id
+        can_edit = all(rv.sale_id == sale_id for rv in views)
+        return can_edit
+
     def _can_cancel_payment(self, receivable_views):
         """whether or not we can cancel the receiving.
         """
         if len(receivable_views) != 1:
             return False
 
+        if not any(view.operation.can_cancel(view.payment)
+                   for view in receivable_views):
+            return False
+
         return receivable_views[0].can_cancel_payment()
 
     def _can_change_due_date(self, receivable_views):
@@ -410,6 +422,10 @@ class ReceivableApp(SearchableAppWindow):
         if len(receivable_views) != 1:
             return False
 
+        if not any(view.operation.can_change_due_date(view.payment)
+                   for view in receivable_views):
+            return False
+
         return receivable_views[0].can_change_due_date()
 
     def _can_show_details(self, receivable_views):
@@ -434,10 +450,11 @@ class ReceivableApp(SearchableAppWindow):
     def _can_show_comments(self, receivable_views):
         return len(receivable_views) == 1
 
-    def _can_print_bill(self, receivable_views):
-        return (len(receivable_views) == 1 and
-                receivable_views[0].method_name == 'bill' and
-                receivable_views[0].status == Payment.STATUS_PENDING)
+    def _can_print(self, receivable_views):
+        if len(receivable_views) == 1:
+            view = receivable_views[0]
+            return view.operation.can_print(view.payment)
+        return False
 
     def _run_card_payment_search(self):
         run_dialog(CardPaymentSearch, self, self.conn)
@@ -445,26 +462,18 @@ class ReceivableApp(SearchableAppWindow):
     def _run_bill_check_search(self):
         run_dialog(InPaymentBillCheckSearch, self, self.conn)
 
+    def _update_filter_items(self):
+        options = [
+            FilterItem(_('Received payments'), 'status:paid'),
+            FilterItem(_('To receive'), 'status:not-paid'),
+            FilterItem(_('Late payments'), 'status:late'),
+            ]
+        self.add_filter_items(PaymentCategory.TYPE_RECEIVABLE, options)
+
     #
     # Kiwi callbacks
     #
 
-    def _on_results__cell_data_func(self, column, renderer, pv, text):
-        if not isinstance(renderer, gtk.CellRendererText):
-            return text
-
-        if pv.paid_date and self.status_filter.get_state().value is None:
-            renderer.set_property('strikethrough', True)
-            renderer.set_property('strikethrough-set', True)
-        else:
-            renderer.set_property('strikethrough-set', False)
-        if not pv.paid_date and pv.due_date < datetime.datetime.now():
-            renderer.set_property('weight', pango.WEIGHT_BOLD)
-            renderer.set_property('weight-set', True)
-        else:
-            renderer.set_property('weight-set', False)
-        return text
-
     def on_results__row_activated(self, klist, receivable_view):
         self._show_details(receivable_view)
 
@@ -486,18 +495,14 @@ class ReceivableApp(SearchableAppWindow):
         self._show_comments(receivable_view)
 
     def on_PrintReceipt__activate(self, action):
-        register_payment_operations()
         receivable_view = self.results.get_selected_rows()[0]
         payment = receivable_view.payment
         date = datetime.date.today()
         print_report(InPaymentReceipt, payment=payment,
                      order=receivable_view.sale, date=date)
 
-    def on_PaymentFlowHistory__activate(self, action):
-        self.run_dialog(PaymentFlowHistoryDialog, self.conn)
-
     def on_AddReceiving__activate(self, action):
-        self._add_receiving()
+        self.add_payment()
 
     def on_CancelPayment__activate(self, action):
         receivable_view = self.results.get_selected_rows()[0]
@@ -528,15 +533,32 @@ class ReceivableApp(SearchableAppWindow):
             warning(_('Cannot renegotiate selected payments'))
             return
         trans = api.new_transaction()
+
         groups = list(set([trans.get(v.group) for v in receivable_views]))
         retval = run_dialog(PaymentRenegotiationWizard, self, trans,
                             groups)
+
+        if api.finish_transaction(trans, retval):
+            self.search.refresh()
+
+    def on_Edit__activate(self, action):
+        try:
+            Till.get_current(self.conn)
+        except TillError, e:
+            warning(str(e))
+            return
+
+        trans = api.new_transaction()
+        views = self.results.get_selected_rows()
+        sale = trans.get(views[0].sale)
+        retval = run_dialog(SalePaymentsEditor, self, trans, sale)
+
         if api.finish_transaction(trans, retval):
             self.search.refresh()
 
     def on_PrintBill__activate(self, action):
-        items = self.results.get_selected_rows()
-        payments = [item.payment for item in items]
-        if not BillReport.check_printable(payments):
-            return False
-        print_report(BillReport, payments)
+        view = self.results.get_selected_rows()[0]
+        payments = [view.payment]
+        report = view.operation.print_(payments)
+        if report is not None:
+            print_report(report, payments)
