@@ -1,4 +1,4 @@
-# -*- Mode: Python; coding: iso-8859-1 -*-
+# -*- Mode: Python; coding: utf-8 -*-
 # vi:si:et:sw=4:sts=4:ts=4
 
 ##
@@ -40,7 +40,6 @@ from stoqlib.api import api
 from stoqlib.exceptions import (StoqlibError, TillError, SellError,
                                 ModelDataError)
 from stoqlib.database.orm import AND, OR, const
-from stoqlib.domain.interfaces import IStorable
 from stoqlib.domain.sale import Sale, SaleView
 from stoqlib.domain.till import Till
 from stoqlib.lib.formatters import format_quantity
@@ -154,7 +153,7 @@ class TillApp(SearchableAppWindow):
                                             self.SearchSale])
         self.app.launcher.Print.set_tooltip(_("Print a report of these sales"))
         self.refresh()
-        self._printer.check_till()
+        self._printer.run_initial_checks()
         self.check_open_inventory()
 
     def deactivate(self):
@@ -244,9 +243,9 @@ class TillApp(SearchableAppWindow):
         if self.check_open_inventory():
             return
 
-        api.rollback_and_begin(self.conn)
+        trans = api.new_transaction()
         selected = self.results.get_selected()
-        sale = Sale.get(selected.id, connection=self.conn)
+        sale = trans.get(selected.sale)
         expire_date = sale.expire_date
 
         if (sale.status == Sale.STATUS_QUOTE and
@@ -254,6 +253,7 @@ class TillApp(SearchableAppWindow):
             not yesno(_("This quote has expired. Confirm it anyway?"),
                       gtk.RESPONSE_YES,
                       _("Confirm quote"), _("Don't confirm"))):
+            trans.close()
             return
 
         # Lets confirm that we can create the sale, before opening the coupon
@@ -263,7 +263,7 @@ class TillApp(SearchableAppWindow):
             # Skip services, since we don't need stock to sell.
             if sale_item.is_service():
                 continue
-            storable = IStorable(sale_item.sellable.product, None)
+            storable = sale_item.sellable.product_storable
             prod_sold.setdefault(storable, 0)
             prod_sold[storable] += sale_item.quantity
             prod_desc[storable] = sale_item.sellable.get_description()
@@ -271,7 +271,7 @@ class TillApp(SearchableAppWindow):
         branch = self.current_branch
         missing = []
         for storable in prod_sold.keys():
-            stock = storable.get_full_balance(branch)
+            stock = storable.get_balance_for_branch(branch)
             if stock < prod_sold[storable]:
                 missing.append(Settable(storable=storable,
                                         description=prod_desc[storable],
@@ -282,21 +282,27 @@ class TillApp(SearchableAppWindow):
             retval = run_dialog(ConfirmSaleMissingDialog, self, sale, missing)
             if retval:
                 self.refresh()
+            trans.close()
             return
 
         coupon = self._open_coupon()
         if not coupon:
+            trans.close()
             return
         self._add_sale_items(sale, coupon)
         try:
-            if coupon.confirm(sale, self.conn):
-                self.conn.commit()
+            if coupon.confirm(sale, trans):
+                trans.commit()
                 self.refresh()
+            else:
+                coupon.cancel()
         except SellError as err:
             warning(err)
         except ModelDataError as err:
             warning(err)
 
+        trans.close()
+
     def _open_coupon(self):
         coupon = self._printer.create_coupon()
 
@@ -376,14 +382,15 @@ class TillApp(SearchableAppWindow):
         run_dialog(SaleDetailsDialog, self, self.conn, sale_view)
 
     def _run_add_cash_dialog(self):
-        try:
-            model = run_dialog(CashInEditor, self, self.conn)
-        except TillError as err:
-            # Inform the error to the user instead of crashing
-            warning(err)
-            return
+        with api.trans() as trans:
+            try:
+                run_dialog(CashInEditor, self, trans)
+            except TillError as err:
+                # Inform the error to the user instead of crashing
+                warning(err)
+                return
 
-        if api.finish_transaction(self.conn, model):
+        if trans.committed:
             self._update_total()
 
     def _return_sale(self):
@@ -391,8 +398,11 @@ class TillApp(SearchableAppWindow):
             return
 
         sale_view = self._check_selected()
-        retval = return_sale(self.get_toplevel(), sale_view, self.conn)
-        if api.finish_transaction(self.conn, retval):
+
+        with api.trans() as trans:
+            return_sale(self.get_toplevel(), sale_view, trans)
+
+        if trans.committed:
             self._update_total()
             self.refresh()
 
@@ -403,7 +413,8 @@ class TillApp(SearchableAppWindow):
 
         # We dont have an ecf. Disable till related operations
         widgets = [self.TillOpen, self.TillClose, self.TillAddCash,
-                   self.TillRemoveCash, self.SearchTillHistory, self.app_vbox]
+                   self.TillRemoveCash, self.SearchTillHistory, self.app_vbox,
+                   self.Confirm, self.Return, self.Details]
         self.set_sensitive(widgets, has_ecf)
         text = _(u"Till operations requires a connected fiscal printer")
         self.till_status_label.set_text(text)
@@ -481,8 +492,9 @@ class TillApp(SearchableAppWindow):
         self._run_add_cash_dialog()
 
     def on_TillRemoveCash__activate(self, action):
-        model = run_dialog(CashOutEditor, self, self.conn)
-        if api.finish_transaction(self.conn, model):
+        with api.trans() as trans:
+            run_dialog(CashOutEditor, self, trans)
+        if trans.committed:
             self._update_total()
 
     # Search
