@@ -35,21 +35,24 @@ import sys
 _ = gettext.gettext
 
 DATEUTIL_REQUIRED = (1, 4, 1)
-GTK_REQUIRED = (2, 17, 0)
+GTK_REQUIRED = (2, 20, 0)
 GUDEV_REQUIRED = (147, )
-KIWI_REQUIRED = (1, 9, 32)
+KIWI_REQUIRED = (1, 9, 34)
 MAKO_REQUIRED = (0, 2, 5)
 PIL_REQUIRED = (1, 1, 5)
 PYCAIRO_REQUIRED = (1, 8, 2)
 PYPOPPLER_REQUIRED = (0, 12, 1)
 PSQL_REQUIRED = (8, 4)
 PSYCOPG_REQUIRED = (2, 0, 5)
-PYGTK_REQUIRED = (2, 16, 0)
+PYGTK_REQUIRED = (2, 20, 0)
 PYGTKWEBKIT_REQUIRED = (1, 1, 7)
+PYOBJC_REQUIRED = (2, 3)
 PYSERIAL_REQUIRED = (2, 1)
 REPORTLAB_REQUIRED = (2, 4)
-STOQDRIVERS_REQUIRED = (0, 9, 15)
-TWISTED_REQUIRED = (10, 0)
+STOQDRIVERS_REQUIRED = (0, 9, 16)
+TWISTED_CORE_REQUIRED = (10, 0)
+TWISTED_WEB_REQUIRED = (10, 0)
+XLWT_REQUIRED = (0, 7, 2)
 ZOPE_INTERFACE_REQUIRED = (3, 0)
 
 
@@ -70,11 +73,15 @@ class DependencyChecker(object):
         self._check_pygtk(PYGTK_REQUIRED, GTK_REQUIRED)
         self._check_kiwi(KIWI_REQUIRED)
         self._check_pycairo(PYCAIRO_REQUIRED)
-        if platform.system() == 'Linux':
+        if platform.system() != 'Windows':
             self._check_pygtkwebkit(PYGTKWEBKIT_REQUIRED)
+        if platform.system() == 'Darwin':
+            self._check_pyobjc(PYOBJC_REQUIRED)
         self._check_zope_interface(ZOPE_INTERFACE_REQUIRED)
         self._check_dateutil(DATEUTIL_REQUIRED)
-        self._check_twisted(TWISTED_REQUIRED)
+        self._check_twisted_core(TWISTED_CORE_REQUIRED)
+        self._check_twisted_web(TWISTED_WEB_REQUIRED)
+        self._check_xlwt(XLWT_REQUIRED)
 
         # Postgres
         self._check_psql(PSQL_REQUIRED)
@@ -87,14 +94,14 @@ class DependencyChecker(object):
         self._check_pil(PIL_REQUIRED)
         self._check_reportlab(REPORTLAB_REQUIRED)
         self._check_mako(MAKO_REQUIRED)
-        if platform.system() != 'Windows':
+        if platform.system() not in ['Darwin', 'Windows']:
             self._check_pypoppler(PYPOPPLER_REQUIRED)
 
         # ECF
         # FIXME: makes sense to allow Stoq to run with all of these disabled.
         self._check_pyserial(PYSERIAL_REQUIRED)
         self._check_stoqdrivers(STOQDRIVERS_REQUIRED)
-        if platform.system() != 'Windows':
+        if platform.system() == 'Linux':
             self._check_gudev(GUDEV_REQUIRED)
 
     def _error(self, title, msg):
@@ -354,21 +361,73 @@ You can find an older version of %s on it's homepage at\n%s""") % (
                           url='http://pyserial.sourceforge.net/',
                           version=version)
 
-    def _check_twisted(self, version):
+    def _check_twisted_core(self, version):
         try:
             import twisted
             twisted # pyflakes
         except ImportError:
-            self._missing(project='twisted',
+            self._missing(project='TwistedCore',
                           url='http://twistedmatrix.com/',
                           version=version)
 
         if map(int, twisted.version.base().split('.')) < list(version):
-            self._too_old(project="twisted",
+            self._too_old(project="TwistedCore",
                           url='http://www.twistedmatrix.com/',
                           required=version,
                           found=twisted.version.base())
 
+    def _check_twisted_web(self, version):
+        try:
+            import twisted.web
+        except ImportError:
+            self._missing(project='TwistedWeb',
+                          url='http://twistedmatrix.com/',
+                          version=version)
+
+        if map(int, twisted.web.version.base().split('.')) < list(version):
+            self._too_old(project="TwistedWeb",
+                          url='http://www.twistedmatrix.com/',
+                          required=version,
+                          found=twisted.web.version.base())
+
+    def _check_xlwt(self, version):
+        try:
+            import xlwt
+            xlwt # pyflakes
+        except ImportError:
+            self._missing(project='xlwt',
+                          url='http://www.python-excel.org/',
+                          version=version)
+
+        if map(int, xlwt.__VERSION__.split('.')) < list(version):
+            self._too_old(project="xlwt",
+                          url='http://www.python-excel.org/',
+                          required=version,
+                          found=xlwt.__VERSION__)
+
+    def _check_pyobjc(self, version):
+        try:
+            import objc
+            objc # pyflakes
+        except ImportError:
+            self._missing(project='pyobjc',
+                          url='http://pyobjc.sf.net/',
+                          version=version)
+
+        if map(int, objc.__version__.split('.')) < list(version):
+            self._too_old(project="pyobjc",
+                          url='http://pyobjc.sf.net/',
+                          required=version,
+                          found=objc.__version__)
+
+        try:
+            import AppKit
+            AppKit # pyflakes
+        except ImportError:
+            self._missing(project='pyobjc with cocoa support',
+                          url='http://pyobjc.sf.net/',
+                          version=version)
+
 
 def check_dependencies(text_mode=False):
     dp = DependencyChecker()
