@@ -53,17 +53,17 @@ _tables = [
                  "MilitaryData",
                  "VoterData",
                  "Liaison",
-                 "PersonAdaptToUser",
+                 "LoginUser",
                  "Calls",
-                 "PersonAdaptToIndividual",
-                 "PersonAdaptToCompany",
-                 "PersonAdaptToClient",
-                 "PersonAdaptToSupplier",
-                 "PersonAdaptToEmployee",
-                 "PersonAdaptToBranch",
-                 "PersonAdaptToSalesPerson",
-                 "PersonAdaptToCreditProvider",
-                 "PersonAdaptToTransporter",
+                 "Individual",
+                 "Company",
+                 "Client",
+                 "Supplier",
+                 "Employee",
+                 "Branch",
+                 "SalesPerson",
+                 "CreditProvider",
+                 "Transporter",
                  "EmployeeRoleHistory"]),
      ('synchronization', ["BranchSynchronization"]),
      ('station', ["BranchStation"]),
@@ -71,13 +71,10 @@ _tables = [
      ('payment.category', ["PaymentCategory"]),
      ('payment.group', ["PaymentGroup"]),
      ('payment.method', ["PaymentMethod", "CheckData"]),
-     ('payment.payment', ["Payment",
-                          "PaymentAdaptToInPayment",
-                          "PaymentAdaptToOutPayment"]),
+     ('payment.payment', ["Payment"]),
      ('fiscal', ["CfopData", "FiscalBookEntry"]),
      ('sale', ["SaleItem",
-               "DeliveryItem",
-               "SaleItemAdaptToDelivery",
+               "Delivery",
                "Sale"]),
      ('renegotiation', ["RenegotiationData"]),
      ('sellable', ["SellableUnit",
@@ -87,8 +84,8 @@ _tables = [
      ('service', ["Service"]),
      ('product', ["Product",
                   "ProductSupplierInfo",
-                  "ProductAdaptToStorable",
-                  "ProductStockItem"]),
+                  "ProductStockItem",
+                  "Storable"]),
      ('purchase', ["PurchaseOrder",
                    "Quotation",
                    "PurchaseItem",
@@ -124,7 +121,7 @@ def _import():
 def get_table_type_by_name(table_name):
     """Gets a table by name.
 
-    @param table_name: name of the table
+    :param table_name: name of the table
     """
 
     if not _table_cache:
