@@ -23,6 +23,11 @@
 ##
 """Database routines which are used by the testsuite"""
 
+# This needs to before the other commits, so the externals/
+# path is properly setup.
+from stoqlib.lib.kiwilibrary import library
+library  # pyflakes
+
 import os
 import pwd
 import socket
@@ -36,17 +41,13 @@ from stoqlib.database.interfaces import (
 from stoqlib.database.orm import AND
 from stoqlib.database.runtime import new_transaction, get_connection
 from stoqlib.database.settings import DatabaseSettings
-from stoqlib.domain.person import Person, PersonAdaptToBranch
-from stoqlib.domain.interfaces import IBranch, IUser
+from stoqlib.domain.person import Branch, LoginUser, Person
 from stoqlib.domain.station import BranchStation
 from stoqlib.importers.stoqlibexamples import create
-from stoqlib.lib.interfaces import (IApplicationDescriptions,
-                                    IPaymentOperationManager,
-                                    ISystemNotifier)
+from stoqlib.lib.interfaces import (IApplicationDescriptions, ISystemNotifier)
 from stoqlib.lib.message import DefaultSystemNotifier
 from stoqlib.lib.osutils import get_username
 from stoqlib.lib.parameters import sysparam
-from stoqlib.lib.payment import PaymentOperationManager
 
 log = Logger('stoqlib.database.testsuite')
 
@@ -90,8 +91,8 @@ def _provide_database_settings():
 
 
 def _provide_current_user():
-    user = Person.iselectOneBy(IUser, username='admin',
-                               connection=get_connection())
+    user = LoginUser.selectOneBy(username='admin',
+                                 connection=get_connection())
     provide_utility(ICurrentUser, user, replace=True)
 
 
@@ -102,14 +103,16 @@ def _provide_current_station(station_name=None, branch_name=None):
     if branch_name:
         branch = Person.selectOne(
             AND(Person.q.name == branch_name,
-                PersonAdaptToBranch.q.originalID == Person.q.id),
+                Branch.q.personID == Person.q.id),
             connection=trans)
     else:
-        branches = Person.iselect(IBranch, connection=trans)
-        assert branches
-        branch = branches[0]
+        branches = Branch.select(connection=trans)
+        if branches.count() == 0:
+            person = Person(name="test", connection=trans)
+            branch = Branch(person=person, connection=trans)
+        else:
+            branch = branches[0]
 
-    branch = IBranch(branch)
     provide_utility(ICurrentBranch, branch)
 
     station = BranchStation.get_station(trans, branch, station_name)
@@ -140,12 +143,12 @@ def provide_database_settings(dbname=None, address=None, port=None, username=Non
                               password=None, create=True):
     """
     Provide database settings.
-    @param dbname:
-    @param address:
-    @param port:
-    @param username:
-    @param password:
-    @param create: Create a new empty database if one is missing
+    :param dbname:
+    :param address:
+    :param port:
+    :param username:
+    :param password:
+    :param create: Create a new empty database if one is missing
     """
     if not username:
         username = pwd.getpwuid(os.getuid())[0]
@@ -176,29 +179,29 @@ def provide_database_settings(dbname=None, address=None, port=None, username=Non
         conn = db_settings.get_default_connection()
         if not conn.databaseExists(dbname):
             log.warning('Database %s missing, creating it' % dbname)
-            conn.createDatabase(dbname, ifNotExists=True)
+            conn.createEmptyDatabase(dbname)
             rv = True
         conn.close()
 
     return rv
 
 
-def _provide_payment_operation_manager():
-    from stoqlib.domain.payment.operation import register_payment_operations
-
-    provide_utility(IPaymentOperationManager, PaymentOperationManager())
-    register_payment_operations()
+def _provide_domain_slave_mapper():
+    from stoqlib.gui.interfaces import IDomainSlaveMapper
+    from stoqlib.gui.domainslavemapper import DefaultDomainSlaveMapper
+    provide_utility(IDomainSlaveMapper, DefaultDomainSlaveMapper(),
+                    replace=True)
 
 
 def provide_utilities(station_name, branch_name=None):
     """
     Provide utilities like current user and current station.
-    @param station_name:
-    @param branch_name:
+    :param station_name:
+    :param branch_name:
     """
     _provide_current_user()
     _provide_current_station(station_name, branch_name)
-    _provide_payment_operation_manager()
+    _provide_domain_slave_mapper()
 
 
 def bootstrap_testsuite(address=None, dbname=None, port=5432, username=None,
@@ -206,13 +209,13 @@ def bootstrap_testsuite(address=None, dbname=None, port=5432, username=None,
 
     """
     Test.
-    @param address:
-    @param dbname:
-    @param port:
-    @param username:
-    @param password:
-    @param station_name:
-    @param quick:
+    :param address:
+    :param dbname:
+    :param port:
+    :param username:
+    :param password:
+    :param station_name:
+    :param quick:
     """
     # XXX: Rewrite docstring
     try:
@@ -225,7 +228,7 @@ def bootstrap_testsuite(address=None, dbname=None, port=5432, username=None,
             # XXX: Why clearing_cache if initialize_system will drop the
             # database?!
             sysparam(get_connection()).clear_cache()
-            initialize_system()
+            initialize_system(testsuite=True, force=True)
             ensure_admin_user("")
             create(utilities=True)
     except Exception:
