@@ -31,11 +31,6 @@ from stoqlib.database.orm import const
 from stoqlib.database.runtime import (get_current_station,
                                       get_current_branch,
                                       get_current_user)
-from stoqlib.domain.interfaces import (IBranch, ICompany, IEmployee,
-                                       IIndividual, ISupplier,
-                                       IStorable, ISalesPerson,
-                                       IClient, IUser, ITransporter,
-                                       ICreditProvider)
 from stoqlib.lib.parameters import sysparam
 
 # Do not remove, these are used by doctests
@@ -46,35 +41,35 @@ def create_person(trans):
 
 
 def create_branch(trans):
-    return ExampleCreator.create(trans, 'IBranch')
+    return ExampleCreator.create(trans, 'Branch')
 
 
 def create_supplier(trans):
-    return ExampleCreator.create(trans, 'ISupplier')
+    return ExampleCreator.create(trans, 'Supplier')
 
 
 def create_employee(trans):
-    return ExampleCreator.create(trans, 'IEmployee')
+    return ExampleCreator.create(trans, 'Employee')
 
 
 def create_salesperson(trans):
-    return ExampleCreator.create(trans, 'ISalesPerson')
+    return ExampleCreator.create(trans, 'SalesPerson')
 
 
 def create_client(trans):
-    return ExampleCreator.create(trans, 'IClient')
+    return ExampleCreator.create(trans, 'Client')
 
 
 def create_individual(trans):
-    return ExampleCreator.create(trans, 'IIndividual')
+    return ExampleCreator.create(trans, 'Individual')
 
 
 def create_user(trans):
-    return ExampleCreator.create(trans, 'IUser')
+    return ExampleCreator.create(trans, 'LoginUser')
 
 
 def create_storable(trans):
-    return ExampleCreator.create(trans, 'ProductAdaptToStorable')
+    return ExampleCreator.create(trans, 'Storable')
 
 
 def create_product(trans):
@@ -110,7 +105,7 @@ def create_parameter_data(trans):
 
 
 def create_company(trans):
-    return ExampleCreator.create(trans, 'ICompany')
+    return ExampleCreator.create(trans, 'Company')
 
 
 def create_till(trans):
@@ -205,32 +200,32 @@ class ExampleCreator(object):
             'ClientCategoryPrice': self.create_client_category_price,
             'EmployeeRole': self.create_employee_role,
             'FiscalBookEntry': self.create_fiscal_book_entry,
-            'IClient': self.create_client,
-            'ICompany': self.create_company,
-            'IBranch': self.create_branch,
-            'IEmployee': self.create_employee,
-            'IIndividual': self.create_individual,
+            'Client': self.create_client,
+            'Company': self.create_company,
+            'Branch': self.create_branch,
+            'Employee': self.create_employee,
+            'Individual': self.create_individual,
             'Inventory': self.create_inventory,
             'InventoryItem': self.create_inventory_item,
-            'ISalesPerson': self.create_sales_person,
-            'ISupplier': self.create_supplier,
-            'ITransporter': self.create_transporter,
-            'IUser': self.create_user,
+            'SalesPerson': self.create_sales_person,
+            'Supplier': self.create_supplier,
+            'Transporter': self.create_transporter,
+            'LoginUser': self.create_user,
             'Payment': self.create_payment,
             'ParameterData': self.create_parameter_data,
             'Person': self.create_person,
-            'PersonAdaptToBranch': self.create_branch,
-            'PersonAdaptToCompany': self.create_company,
-            'PersonAdaptToClient': self.create_client,
-            'PersonAdaptToCreditProvider': self.create_credit_provider,
-            'PersonAdaptToEmployee': self.create_employee,
-            'PersonAdaptToIndividual': self.create_individual,
-            'PersonAdaptToSalesPerson': self.create_sales_person,
-            'PersonAdaptToSupplier': self.create_supplier,
-            'PersonAdaptToTransporter': self.create_transporter,
-            'PersonAdaptToUser': self.create_user,
+            'Branch': self.create_branch,
+            'Company': self.create_company,
+            'Client': self.create_client,
+            'CreditProvider': self.create_credit_provider,
+            'Employee': self.create_employee,
+            'Individual': self.create_individual,
+            'SalesPerson': self.create_sales_person,
+            'Supplier': self.create_supplier,
+            'Transporter': self.create_transporter,
+            'LoginUser': self.create_user,
             'Product': self.create_product,
-            'ProductAdaptToStorable': self.create_storable,
+            'Storable': self.create_storable,
             'PurchaseOrder': self.create_purchase_order,
             'PurchaseItem': self.create_purchase_order_item,
             'ReceivingOrder': self.create_receiving_order,
@@ -275,20 +270,20 @@ class ExampleCreator(object):
         return Person(name='John', connection=self.trans)
 
     def create_branch(self, name='Dummy'):
-        from stoqlib.domain.person import Person
+        from stoqlib.domain.person import Branch, Company, Person
         person = Person(name=name, connection=self.trans)
         fancy_name = name + ' shop'
-        person.addFacet(ICompany, fancy_name=fancy_name,
-                        connection=self.trans)
-        return person.addFacet(IBranch, connection=self.trans)
+        Company(person=person, fancy_name=fancy_name,
+                connection=self.trans)
+        return Branch(person=person, connection=self.trans)
 
     def create_supplier(self):
-        from stoqlib.domain.person import Person
+        from stoqlib.domain.person import Company, Person, Supplier
         person = Person(name='Supplier', connection=self.trans)
-        person.addFacet(ICompany, fancy_name='Company Name',
-                        cnpj='90.117.749/7654-80',
-                        connection=self.trans)
-        return person.addFacet(ISupplier, connection=self.trans)
+        Company(person=person, fancy_name='Company Name',
+                cnpj='90.117.749/7654-80',
+                connection=self.trans)
+        return Supplier(person=person, connection=self.trans)
 
     def create_employee_role(self):
         if not self._role:
@@ -297,45 +292,48 @@ class ExampleCreator(object):
         return self._role
 
     def create_employee(self, name="SalesPerson"):
-        from stoqlib.domain.person import Person
+        from stoqlib.domain.person import Employee, Individual, Person
         person = Person(name=name, connection=self.trans)
-        person.addFacet(IIndividual, connection=self.trans)
-        return person.addFacet(IEmployee,
-                               role=self.create_employee_role(),
-                               connection=self.trans)
+        Individual(person=person, connection=self.trans)
+        return Employee(person=person,
+                        role=self.create_employee_role(),
+                        connection=self.trans)
 
     def create_sales_person(self):
+        from stoqlib.domain.person import SalesPerson
         employee = self.create_employee()
-        return employee.person.addFacet(ISalesPerson, connection=self.trans)
+        return SalesPerson(person=employee.person, connection=self.trans)
 
     def create_client(self):
-        from stoqlib.domain.person import Person
+        from stoqlib.domain.person import Client, Individual, Person
         person = Person(name='Client', connection=self.trans)
-        person.addFacet(IIndividual, connection=self.trans)
-        return person.addFacet(IClient, connection=self.trans)
+        Individual(person=person, connection=self.trans)
+        return Client(person=person, connection=self.trans)
 
     def create_individual(self):
-        from stoqlib.domain.person import Person
+        from stoqlib.domain.person import Individual, Person
         person = Person(name='individual', connection=self.trans)
-        return person.addFacet(IIndividual, connection=self.trans)
+        return Individual(person=person, connection=self.trans)
 
     def create_user(self):
+        from stoqlib.domain.person import LoginUser
         individual = self.create_individual()
         profile = self.create_user_profile()
-        return individual.person.addFacet(IUser, username='username',
-                                          password='password',
-                                          profile=profile,
-                                          connection=self.trans)
+        return LoginUser(person=individual.person,
+                         username='username',
+                         password='password',
+                         profile=profile,
+                         connection=self.trans)
 
     def create_storable(self):
-        from stoqlib.domain.product import Product
+        from stoqlib.domain.product import Product, Storable
         sellable = self.create_sellable()
         product = Product(sellable=sellable, connection=self.trans)
-        return product.addFacet(IStorable, connection=self.trans)
+        return Storable(product=product, connection=self.trans)
 
     def create_product(self, price=None, create_supplier=True,
                        branch=None, stock=None):
-        from stoqlib.domain.product import ProductSupplierInfo
+        from stoqlib.domain.product import ProductSupplierInfo, Storable
         sellable = self.create_sellable(price=price)
         if create_supplier:
             ProductSupplierInfo(connection=self.trans,
@@ -347,7 +345,7 @@ class ExampleCreator(object):
             branch = get_current_branch(self.trans)
 
         if stock:
-            storable = product.addFacet(IStorable, connection=self.trans)
+            storable = Storable(product=product, connection=self.trans)
             storable.increase_stock(stock, branch, unit_cost=10)
 
         return product
@@ -475,10 +473,10 @@ class ExampleCreator(object):
         return ParameterData.select(connection=self.trans)[0]
 
     def create_company(self):
-        from stoqlib.domain.person import Person
+        from stoqlib.domain.person import Company, Person
         person = Person(name='Dummy', connection=self.trans)
-        return person.addFacet(ICompany, fancy_name='Dummy shop',
-                               connection=self.trans)
+        return Company(person=person, fancy_name='Dummy shop',
+                       connection=self.trans)
 
     def create_till(self):
         from stoqlib.domain.till import Till
@@ -526,13 +524,13 @@ class ExampleCreator(object):
                                connection=self.trans)
 
     def create_production_item(self, quantity=1, order=None):
-        from stoqlib.domain.product import ProductComponent
+        from stoqlib.domain.product import ProductComponent, Storable
         from stoqlib.domain.production import (ProductionItem,
                                                ProductionMaterial)
         product = self.create_product(10)
-        product.addFacet(IStorable, connection=self.trans)
+        Storable(product=product, connection=self.trans)
         component = self.create_product(5)
-        component.addFacet(IStorable, connection=self.trans)
+        Storable(product=component, connection=self.trans)
         ProductComponent(product=product,
                          component=component,
                          connection=self.trans)
@@ -588,12 +586,13 @@ class ExampleCreator(object):
     def create_receiving_order_item(self, receiving_order=None, sellable=None,
                                     purchase_item=None, quantity=8):
         from stoqlib.domain.receiving import ReceivingOrderItem
+        from stoqlib.domain.product import Storable
         if receiving_order is None:
             receiving_order = self.create_receiving_order()
         if sellable is None:
             sellable = self.create_sellable()
             product = sellable.product
-            product.addFacet(IStorable, connection=self.trans)
+            Storable(product=product, connection=self.trans)
         if purchase_item is None:
             purchase_item = receiving_order.purchase.add_item(
                 sellable, quantity)
@@ -653,9 +652,11 @@ class ExampleCreator(object):
                                  responsible=person)
 
     def create_transporter(self):
+        from stoqlib.domain.person import Company, Transporter
         person = self.create_person()
-        person.addFacet(ICompany, connection=self.trans)
-        return person.addFacet(ITransporter, connection=self.trans)
+        Company(person=person, connection=self.trans)
+        return Transporter(person=person,
+                           connection=self.trans)
 
     def create_bank_account(self, account=None):
         from stoqlib.domain.account import BankAccount
@@ -666,17 +667,20 @@ class ExampleCreator(object):
                            account=account or self.create_account())
 
     def create_credit_provider(self):
+        from stoqlib.domain.person import Company, CreditProvider
         person = self.create_person()
-        person.addFacet(ICompany, connection=self.trans)
-        return person.addFacet(ICreditProvider,
-                               connection=self.trans,
-                               short_name='Velec',
-                               open_contract_date=datetime.date(2006, 01, 01))
+        Company(person=person, connection=self.trans)
+        return CreditProvider(person=person,
+                              connection=self.trans,
+                              short_name='Velec',
+                              open_contract_date=datetime.date(2006, 01, 01))
 
-    def create_payment(self, date=None):
+    def create_payment(self, payment_type=None, date=None):
+        from stoqlib.domain.payment.payment import Payment
+        if payment_type is None:
+            payment_type = Payment.TYPE_OUT
         if not date:
             date = datetime.date.today()
-        from stoqlib.domain.payment.payment import Payment
         return Payment(group=None,
                        open_date=date,
                        due_date=date,
@@ -684,7 +688,8 @@ class ExampleCreator(object):
                        till=None,
                        method=self.get_payment_method(),
                        category=None,
-                       connection=self.trans)
+                       connection=self.trans,
+                       payment_type=payment_type)
 
     def create_payment_group(self):
         from stoqlib.domain.payment.group import PaymentGroup
@@ -717,7 +722,7 @@ class ExampleCreator(object):
                              connection=self.trans)
 
     def create_transfer_order_item(self, order=None, quantity=5):
-        from stoqlib.domain.product import Product
+        from stoqlib.domain.product import Product, Storable
         from stoqlib.domain.sellable import Sellable
         from stoqlib.domain.transfer import TransferOrderItem
         if not order:
@@ -725,7 +730,7 @@ class ExampleCreator(object):
         sellable = self.create_sellable()
         sellable.status = Sellable.STATUS_AVAILABLE
         product = Product.selectOneBy(sellable=sellable, connection=self.trans)
-        storable = product.addFacet(IStorable, connection=self.trans)
+        storable = Storable(product=product, connection=self.trans)
         storable.increase_stock(quantity, order.source_branch)
         return TransferOrderItem(sellable=sellable,
                                  transfer_order=order,
@@ -739,11 +744,12 @@ class ExampleCreator(object):
 
     def create_inventory_item(self, inventory=None, quantity=5):
         from stoqlib.domain.inventory import InventoryItem
+        from stoqlib.domain.product import Storable
         if not inventory:
             inventory = self.create_inventory()
         sellable = self.create_sellable()
         product = sellable.product
-        storable = product.addFacet(IStorable, connection=self.trans)
+        storable = Storable(product=product, connection=self.trans)
         storable.increase_stock(quantity, inventory.branch)
         return InventoryItem(product=product,
                              product_cost=product.sellable.cost,
@@ -775,11 +781,12 @@ class ExampleCreator(object):
         return CityLocation.get_default(self.trans)
 
     def add_product(self, sale, price=None, quantity=1):
+        from stoqlib.domain.product import Storable
         product = self.create_product(price=price)
         sellable = product.sellable
         sellable.tax_constant = self.create_sellable_tax_constant()
         sale.add_sellable(sellable, quantity=quantity)
-        storable = product.addFacet(IStorable, connection=self.trans)
+        storable = Storable(product=product, connection=self.trans)
         storable.increase_stock(100, get_current_branch(self.trans))
         return sellable
 
@@ -797,8 +804,8 @@ class ExampleCreator(object):
             raise ValueError(obj)
 
         if date:
-            payment.payment.due_date = date
-            payment.payment.open_date = date
+            payment.due_date = date
+            payment.open_date = date
 
         return payment
 
@@ -808,13 +815,13 @@ class ExampleCreator(object):
                        account_type=Account.TYPE_CASH,
                        connection=self.trans)
 
-    def create_account_transaction(self, account):
+    def create_account_transaction(self, account, value=1):
         from stoqlib.domain.account import AccountTransaction
         return AccountTransaction(
             description="Test Account Transaction",
             code="Code",
             date=datetime.datetime.now(),
-            value=1,
+            value=value,
             account=account,
             source_account=sysparam(self.trans).IMBALANCE_ACCOUNT,
             connection=self.trans)
