@@ -103,6 +103,10 @@ class PaymentGroup(Domain):
 
     @property
     def payments(self):
+        """Returns all payments of this group
+
+        :returns: a list of :class:`stoqlib.domain.payment.payment.Payment`
+        """
         return self.get_items()
 
     @property
@@ -127,19 +131,19 @@ class PaymentGroup(Domain):
 
     def can_cancel(self):
         """Everything can be called
-        @returns: True if the payment group can be cancelled, otherwise False
+        :returns: True if the payment group can be cancelled, otherwise False
         """
         return self.status != PaymentGroup.STATUS_CANCELLED
 
     def can_confirm(self):
         """Newly created payment groups can be confirmed
-        @returns: True if the payment group can be confirmed, otherwise False
+        :returns: True if the payment group can be confirmed, otherwise False
         """
         return self.status == PaymentGroup.STATUS_INITIAL
 
     def can_pay(self):
         """Confirmed payment groups can be paid
-        @returns: True if the payment group can be paid, otherwise False
+        :returns: True if the payment group can be paid, otherwise False
         """
         return self.status == PaymentGroup.STATUS_CONFIRMED
 
@@ -172,7 +176,7 @@ class PaymentGroup(Domain):
         assert self.can_pay(), self.get_status_string()
 
         for payment in self.get_valid_payments():
-            if payment.method.method_name == 'money':
+            if payment.is_money():
                 payment.pay()
 
     def cancel(self):
@@ -190,7 +194,7 @@ class PaymentGroup(Domain):
 
     def get_total_value(self):
         """Returns the sum of all payment values.
-        @returns: the total payment value or zero.
+        :returns: the total payment value or zero.
         """
         return currency(self.get_valid_payments().sum('value') or 0)
 
@@ -251,7 +255,7 @@ class PaymentGroup(Domain):
 
     def get_total_discount(self):
         """Returns the sum of all payment discounts.
-        @returns: the total payment discount or zero.
+        :returns: the total payment discount or zero.
         """
         discount = Payment.selectBy(
             group=self, connection=self.get_connection()).sum('discount')
@@ -260,7 +264,7 @@ class PaymentGroup(Domain):
 
     def get_total_interest(self):
         """Returns the sum of all payment interests.
-        @returns: the total payment interest or zero.
+        :returns: the total payment interest or zero.
         """
         interest = Payment.selectBy(
             group=self, connection=self.get_connection()).sum('interest')
@@ -269,7 +273,7 @@ class PaymentGroup(Domain):
 
     def get_total_penalty(self):
         """Returns the sum of all payment penalties.
-        @returns: the total payment penalty or zero.
+        :returns: the total payment penalty or zero.
         """
         penalty = Payment.selectBy(
             group=self, connection=self.get_connection()).sum('penalty')
