@@ -2,7 +2,7 @@
 # vi:si:et:sw=4:sts=4:ts=4
 
 ##
-## Copyright (C) 2005-2008 Async Open Source <http://www.async.com.br>
+## Copyright (C) 2005-2012 Async Open Source <http://www.async.com.br>
 ## All rights reserved
 ##
 ## This program is free software; you can redistribute it and/or modify
@@ -25,24 +25,23 @@
 
 from decimal import Decimal
 import datetime
+import operator
 
+from kiwi import ValueUnset
 from kiwi.argcheck import argcheck
-from kiwi.component import get_utility
 from zope.interface import implements
 
 from stoqlib.database.orm import PercentCol, PriceCol
 from stoqlib.database.orm import IntCol, ForeignKey, BoolCol, StringCol, UnicodeCol
 from stoqlib.database.orm import const, AND
 from stoqlib.domain.base import Domain
-from stoqlib.domain.interfaces import (IInPayment, IActive, IOutPayment,
-                                       IDescribable)
+from stoqlib.domain.interfaces import IActive, IDescribable
 from stoqlib.domain.payment.group import PaymentGroup
-from stoqlib.domain.payment.payment import Payment, PaymentAdaptToInPayment
+from stoqlib.domain.payment.payment import Payment
 from stoqlib.domain.till import Till
 from stoqlib.exceptions import DatabaseInconsistency, PaymentMethodError
 from stoqlib.lib.defaults import quantize
-from stoqlib.lib.interfaces import IPaymentOperationManager
-from stoqlib.lib.translation import stoqlib_gettext
+from stoqlib.lib.translation import locale_sorted, stoqlib_gettext
 
 _ = stoqlib_gettext
 
@@ -55,8 +54,8 @@ class CheckData(Domain):
     """Stores check informations and also a history of possible
     devolutions.
 
-    @ivar bank_data: information about the bank account of this check.
-    @ivar payment: the payment object.
+    :attribute bank_data: information about the bank account of this check.
+    :attribute payment: the payment object.
     """
     payment = ForeignKey('Payment')
     bank_account = ForeignKey('BankAccount')
@@ -65,17 +64,17 @@ class CheckData(Domain):
 class CreditCardData(Domain):
     """Stores CreditCard specific state related to a payment
 
-    @ivar payment: the payment
-    @type payment: L{Payment}
-    @ivar card_type:
-    @type card_type: int, > 0, < 3
-    @ivar provider:
-    @type provider: L{PersonAdaptToCreditProvider}
-    @ivar installments: the installments number
-    @type installments: int, >= 1
-    @ivar entrance_value: the value of the first installment
+    :attribute payment: the payment
+    :type payment: :class:`Payment`
+    :attribute card_type:
+    :type card_type: int, > 0, < 3
+    :attribute provider:
+    :type provider: :class:`CreditProvider`
+    :attribute installments: the installments number
+    :type installments: int, >= 1
+    :attribute entrance_value: the value of the first installment
                           (when installments > 1)
-    @type entrance_value: currency
+    :type entrance_value: currency
     """
     (TYPE_CREDIT,
      TYPE_DEBIT,
@@ -94,7 +93,7 @@ class CreditCardData(Domain):
 
     payment = ForeignKey('Payment')
     card_type = IntCol(default=TYPE_CREDIT)
-    provider = ForeignKey('PersonAdaptToCreditProvider', default=None)
+    provider = ForeignKey('CreditProvider', default=None)
     fee = PercentCol(default=0)
     fee_value = PriceCol(default=0)
     nsu = IntCol(default=None)
@@ -110,19 +109,19 @@ class PaymentMethod(Domain):
     The logic itself for the various different methods are in the
     PaymentMethodOperation classes. Each PaymentMethod has a PaymentMethodOperation
     associated.
-    @ivar name:
-    @ivar description:
-    @ivar is_active:
-    @ivar daily_penalty:
-    @ivar interest: a value for the interest. It must always be in the format:
+    :attribute name:
+    :attribute description:
+    :attribute is_active:
+    :attribute daily_penalty:
+    :attribute interest: a value for the interest. It must always be in the format:
        0 <= interest <= 100
-    @ivar payment_day: which day in the month is the credit provider going
+    :attribute payment_day: which day in the month is the credit provider going
       to pay the store? Usually they pay in the same day
       every month.
-    @ivar closing_day: which day the credit provider stoq counting sales
+    :attribute closing_day: which day the credit provider stoq counting sales
       to pay in the payment_day? Sales after this day
       will be paid only in the next month.
-    @ivar account_destination: destination account for payment
+    :attribute account_destination: destination account for payment
       methods which creates transactions
     """
 
@@ -171,10 +170,11 @@ class PaymentMethod(Domain):
         """Get the operation for this method.
         The operation contains method specific logic when
         creating/deleting a payment.
-        @return: the operation associated with the method
-        @rtype: object implementing IPaymentOperation
+        :return: the operation associated with the method
+        :rtype: object implementing IPaymentOperation
         """
-        return get_utility(IPaymentOperationManager).get(self.method_name)
+        from stoqlib.domain.payment.operation import get_payment_operation
+        return get_payment_operation(self.method_name)
 
     #
     # Private API
@@ -200,12 +200,11 @@ class PaymentMethod(Domain):
                              % interest)
 
     def _calculate_payment_value(self, total_value, installments_number,
-                                iface, interest=None):
+                                 payment_type, interest=None):
         if not installments_number:
             raise ValueError(_('The payment_qty argument must be greater '
                                'than zero'))
-
-        if iface is IInPayment:
+        if payment_type == Payment.TYPE_IN:
             self._check_installments_number(installments_number)
 
         self._check_interest_value(interest)
@@ -224,33 +223,32 @@ class PaymentMethod(Domain):
     #       they don't really belong to the method itself.
     #       They should either go into the group or to a separate payment
     #       factory singleton.
-    @argcheck(object, PaymentGroup, Decimal, datetime.datetime,
-              basestring, basestring, Till, basestring)
-    def create_payment(self, iface, payment_group, value, due_date=None,
-                       description=None, base_value=None, till=None,
+    @argcheck(int, PaymentGroup, Decimal, datetime.datetime,
+              basestring, basestring, object, basestring)
+    def create_payment(self, payment_type, payment_group, value, due_date=None,
+                       description=None, base_value=None, till=ValueUnset,
                        payment_number=None):
         """Creates a new payment according to a payment method interface
-        @param iface: a payment method interface eg L{IOutPayment} or
-        L{IInPayment}
-        @param payment_group: a L{PaymentGroup} subclass
-        @param value: value of payment
-        @param due_date: optional, due date of payment
-        @param details: optional
-        @param description: optional, description of the payment
-        @param base_value: optional
-        @param till: optional
-        @param payment_number: optional
-        @returns: a L{PaymentAdaptToOutPayment} or L{PaymentAdaptToInPayment}
+        :param payment_type: the kind of payment, in or out
+        :param payment_group: a :class:`PaymentGroup` subclass
+        :param value: value of payment
+        :param due_date: optional, due date of payment
+        :param details: optional
+        :param description: optional, description of the payment
+        :param base_value: optional
+        :param till: optional
+        :param payment_number: optional
+        :returns: a :class:`Payment`
         """
         conn = self.get_connection()
 
         if due_date is None:
             due_date = const.NOW()
 
-        if iface is IInPayment:
+        if payment_type == Payment.TYPE_IN:
             query = AND(Payment.q.groupID == payment_group.id,
                         Payment.q.methodID == self.id,
-                        Payment.q.id == PaymentAdaptToInPayment.q.originalID)
+                        Payment.q.payment_type == Payment.TYPE_IN)
             payment_count = Payment.select(query,
                                 connection=self.get_connection()).count()
             if payment_count == self.max_installments:
@@ -267,16 +265,17 @@ class PaymentMethod(Domain):
             description = self.describe_payment(payment_group)
 
         # If till is unset, do some clever guessing
-        if till is None:
+        if till is ValueUnset:
             # We only need a till for inpayments
-            if iface is IInPayment:
+            if payment_type == Payment.TYPE_IN:
                 till = Till.get_current(conn)
-            elif iface is IOutPayment:
+            elif payment_type == Payment.TYPE_OUT:
                 till = None
             else:
-                raise AssertionError(iface)
+                raise AssertionError(payment_type)
 
         payment = Payment(connection=conn,
+                          payment_type=payment_type,
                           due_date=due_date,
                           value=value,
                           base_value=base_value,
@@ -286,30 +285,27 @@ class PaymentMethod(Domain):
                           till=till,
                           description=description,
                           payment_number=payment_number)
-        facet = payment.addFacet(iface, connection=conn)
         self.operation.payment_create(payment)
-        return facet
+        return payment
 
-    @argcheck(object, PaymentGroup, Decimal, object)
-    def create_payments(self, iface, group, value, due_dates):
-        """Creates new payments according to a payment method interface.
+    @argcheck(int, PaymentGroup, Decimal, object)
+    def create_payments(self, payment_type, group, value, due_dates):
+        """Creates new payments
         The values of the individual payments are calculated by taking
         the value and dividing it by the number of payments.
         The number of payments is determined by the length of the due_dates
         sequence.
-        @param iface: a payment method interface eg L{IOutPayment} or
-        L{IInPayment}
-        @param payment_group: a L{PaymentGroup} subclass
-        @param value: value of payment
-        @param due_dates: a list of datetime objects
-        @returns: a list of L{PaymentAdaptToOutPayment} or
-        L{PaymentAdaptToInPayment}
+        :param payment_type: the kind of payment, in or out
+        :param payment_group: a :class:`PaymentGroup` subclass
+        :param value: value of payment
+        :param due_dates: a list of datetime objects
+        :returns: a list of :class:`Payment`
         """
         installments = len(due_dates)
         interest = Decimal(0)
 
         normalized_value = self._calculate_payment_value(
-            value, installments, iface, interest)
+            value, installments, payment_type, interest)
 
         normalized_value = quantize(normalized_value)
         if interest:
@@ -320,7 +316,7 @@ class PaymentMethod(Domain):
         payments = []
         payments_total = Decimal(0)
         for i, due_date in enumerate(due_dates):
-            payment = self.create_payment(iface,
+            payment = self.create_payment(payment_type,
                 group, normalized_value, due_date,
                 description=self.describe_payment(group, i + 1, installments))
             payments.append(payment)
@@ -329,8 +325,7 @@ class PaymentMethod(Domain):
         # Adjust the last payment so it the total will sum up nicely.
         difference = -(payments_total - interest_total - value)
         if difference:
-            adapted = payment.get_adapted()
-            adapted.value += difference
+            payment.value += difference
         return payments
 
     def describe_payment(self, payment_group, installment=1, installments=1):
@@ -338,10 +333,10 @@ class PaymentMethod(Domain):
         format: current_installment/total_of_installments payment_description
         for payment_group_description
 
-        @param payment_group: a L{PaymentGroup}
-        @param installment: current installment
-        @param installments: total installments
-        @returns: a payment description
+        :param payment_group: a :class:`PaymentGroup`
+        :param installment: current installment
+        :param installments: total installments
+        :returns: a payment description
         """
         assert installment > 0
         assert installments > 0
@@ -351,36 +346,36 @@ class PaymentMethod(Domain):
                                         payment_group.get_description())
 
     @argcheck(PaymentGroup, Decimal, datetime.datetime,
-              basestring, Decimal, Till)
+              basestring, Decimal, object)
     def create_inpayment(self, payment_group, value, due_date=None,
-                         description=None, base_value=None, till=None):
+                         description=None, base_value=None, till=ValueUnset):
         """Creates a new inpayment
-        @param payment_group: a L{PaymentGroup} subclass
-        @param value: value of payment
-        @param due_date: optional, due date of payment
-        @param description: optional, description of the payment
-        @param base_value: optional
-        @param till: optional
-        @returns: a L{PaymentAdaptToInPayment}
+        :param payment_group: a :class:`PaymentGroup` subclass
+        :param value: value of payment
+        :param due_date: optional, due date of payment
+        :param description: optional, description of the payment
+        :param base_value: optional
+        :param till: optional
+        :returns: a :class:`Payment`
         """
-        return self.create_payment(IInPayment, payment_group,
+        return self.create_payment(Payment.TYPE_IN, payment_group,
                                    value, due_date,
                                    description, base_value, till)
 
     @argcheck(PaymentGroup, Decimal, datetime.datetime,
-              basestring, Decimal, Till)
+              basestring, Decimal, object)
     def create_outpayment(self, payment_group, value, due_date=None,
-                          description=None, base_value=None, till=None):
+                          description=None, base_value=None, till=ValueUnset):
         """Creates a new outpayment
-        @param payment_group: a L{PaymentGroup} subclass
-        @param value: value of payment
-        @param due_date: optional, due date of payment
-        @param description: optional, description of the payment
-        @param base_value: optional
-        @param till: optional
-        @returns: a L{PaymentAdaptToOutPayment}
+        :param payment_group: a :class:`PaymentGroup` subclass
+        :param value: value of payment
+        :param due_date: optional, due date of payment
+        :param description: optional, description of the payment
+        :param base_value: optional
+        :param till: optional
+        :returns: a :class:`Payment`
         """
-        return self.create_payment(IOutPayment, payment_group,
+        return self.create_payment(Payment.TYPE_OUT, payment_group,
                                    value, due_date,
                                    description, base_value, till)
 
@@ -391,12 +386,12 @@ class PaymentMethod(Domain):
         the number of payments.
         The number of payments is determined by the length of the due_dates
         sequence.
-        @param payment_group: a L{PaymentGroup} subclass
-        @param value: total value of all payments
-        @param due_dates: a list of datetime objects
-        @returns: a list of L{PaymentAdaptToInPayment}
+        :param payment_group: a :class:`PaymentGroup` subclass
+        :param value: total value of all payments
+        :param due_dates: a list of datetime objects
+        :returns: a list of :class:`Payment`
         """
-        return self.create_payments(IInPayment, payment_group,
+        return self.create_payments(Payment.TYPE_IN, payment_group,
                                     value, due_dates)
 
     @argcheck(PaymentGroup, Decimal, object)
@@ -406,18 +401,17 @@ class PaymentMethod(Domain):
         the number of payments.
         The number of payments is determined by the length of the due_dates
         sequence.
-        @param payment_group: a L{PaymentGroup} subclass
-        @param value: total value of all payments
-        @param due_dates: a list of datetime objects
-        @returns: a list of L{PaymentAdaptToOutPayment}
+        :param payment_group: a :class:`PaymentGroup` subclass
+        :param value: total value of all payments
+        :param due_dates: a list of datetime objects
+        :returns: a list of :class:`Payment`
         """
-        return self.create_payments(IOutPayment, payment_group,
+        return self.create_payments(Payment.TYPE_OUT, payment_group,
                                     value, due_dates)
 
     @classmethod
     def get_active_methods(cls, conn):
-        """Returns a list of payment method interfaces tied with the
-        active payment methods
+        """Returns a list of active payment methods
         """
         return PaymentMethod.selectBy(is_active=True,
                                       connection=conn).orderBy('description')
@@ -425,16 +419,31 @@ class PaymentMethod(Domain):
     @classmethod
     def get_by_name(cls, conn, name):
         """Returns the Payment method associated by the nmae
-        @param name: name of a payment method
-        @returns: the payment method class
-        @rtype: L{PaymentMethod} instance
+        :param name: name of a payment method
+        :returns: the payment method class
+        :rtype: :class:`PaymentMethod` instance
         """
         return PaymentMethod.selectOneBy(connection=conn,
                                          method_name=name)
 
+    @classmethod
+    def get_creatable_methods(cls, conn, payment_type, separate):
+        """Gets a list of methods that are creatable.
+        Eg, you can use them to create new payments.
+        :returns: a list of :class:`PaymentMethod` instances
+        """
+        methods = []
+        for method in cls.get_active_methods(conn):
+            if not method.operation.creatable(method, payment_type,
+                                              separate):
+                continue
+            methods.append(method)
+        return locale_sorted(methods,
+                             key=operator.attrgetter('description'))
+
     def selectable(self):
         """Finds out if the method is selectable, eg
         if the user can select it when doing a sale.
-        @returns: True if selectable, otherwise False
+        :returns: True if selectable, otherwise False
         """
         return self.operation.selectable(self)
