@@ -28,16 +28,14 @@ from decimal import Decimal
 
 from kiwi.datatypes import currency
 from kiwi.log import Logger
-from zope.interface import implements
 
 from stoqlib.database.orm import (IntCol, DateTimeCol, UnicodeCol, ForeignKey,
                                   PriceCol)
 from stoqlib.database.orm import (const, DESC, AND, OR, MultipleJoin,
                                   SingleJoin)
-from stoqlib.domain.base import Domain, ModelAdapter
+from stoqlib.domain.base import Domain
 from stoqlib.domain.event import Event
 from stoqlib.domain.account import AccountTransaction
-from stoqlib.domain.interfaces import IInPayment, IOutPayment
 from stoqlib.exceptions import DatabaseInconsistency, StoqlibError
 from stoqlib.lib.translation import stoqlib_gettext
 
@@ -57,6 +55,13 @@ class Payment(Domain):
                        this payment.
     """
 
+    # Payment type
+    # IN = incoming to the company, accounts receivable
+    # OUT = outgoing from the company, accounts payable
+
+    (TYPE_IN,
+     TYPE_OUT) = range(2)
+
     # Status description
     # Sale: (PENDING, PAID, CANCELLED)
     # A payment is created in STATUS_PREVIEW
@@ -82,6 +87,7 @@ class Payment(Domain):
                 STATUS_CONFIRMED: _(u'Confirmed'),
                 STATUS_CANCELLED: _(u'Cancelled')}
 
+    payment_type = IntCol()
     status = IntCol(default=STATUS_PREVIEW)
     open_date = DateTimeCol(default=datetime.datetime.now)
     due_date = DateTimeCol()
@@ -126,17 +132,6 @@ class Payment(Domain):
         payment = cls.get(obj_id, connection)
         payment.method.operation.payment_delete(payment)
 
-        # Remove from the In/Out tables, ideally this would
-        # be stored so we don't have to do trial and error
-        out_payment = IOutPayment(payment, None)
-        in_payment = IInPayment(payment, None)
-        if out_payment is not None:
-            PaymentAdaptToOutPayment.delete(
-                out_payment.id, connection)
-        elif in_payment is not None:
-            PaymentAdaptToInPayment.delete(
-                in_payment.id, connection)
-
         super(cls, Payment).delete(obj_id, connection)
 
     #
@@ -187,7 +182,7 @@ class Payment(Domain):
         """Set a STATUS_PAID payment as STATUS_PENDING. This requires clearing
         paid_date and paid_value
 
-        @param change_entry: an PaymentChangeHistory object, that will hold the changes
+        :param change_entry: an PaymentChangeHistory object, that will hold the changes
         information
         """
         self._check_status(self.STATUS_PAID, 'set_not_paid')
@@ -204,6 +199,8 @@ class Payment(Domain):
 
     def pay(self, paid_date=None, paid_value=None, account=None):
         """Pay the current payment set its status as STATUS_PAID"""
+        if self.status != Payment.STATUS_PENDING:
+            raise ValueError(_("This payment is already paid."))
         self._check_status(self.STATUS_PENDING, 'pay')
 
         paid_value = paid_value or (self.value - self.discount +
@@ -214,9 +211,6 @@ class Payment(Domain):
 
         PaymentFlowHistory.add_paid_payment(self.get_connection(), self)
 
-        from stoqlib.domain.payment.operation import register_payment_operations
-        register_payment_operations()
-
         if (self.is_separate_payment() or
             self.method.operation.create_transaction()):
             AccountTransaction.create_from_payment(self, account)
@@ -263,8 +257,8 @@ class Payment(Domain):
 
     def change_due_date(self, new_due_date):
         """Changes the payment due date.
-        @param new_due_date: The new due date for the payment.
-        @rtype: datetime.date
+        :param new_due_date: The new due date for the payment.
+        :rtype: datetime.date
         """
         if self.status in [Payment.STATUS_PAID, Payment.STATUS_CANCELLED]:
             raise StoqlibError(_("Invalid status for change_due_date operation, "
@@ -295,9 +289,9 @@ class Payment(Domain):
 
     def get_penalty(self, date=None):
         """Calculate the penalty in an absolute value
-        @param date: date of payment
-        @returns: penalty
-        @rtype: currency
+        :param date: date of payment
+        :returns: penalty
+        :rtype: currency
         """
         if not date:
             date = datetime.date.today()
@@ -317,9 +311,9 @@ class Payment(Domain):
 
     def get_interest(self, date=None):
         """Calculate the interest in an absolute value
-        @param date: date of payment
-        @returns: interest
-        @rtype: currency
+        :param date: date of payment
+        :returns: interest
+        :rtype: currency
         """
         if not date:
             date = datetime.date.today()
@@ -338,31 +332,31 @@ class Payment(Domain):
 
     def is_paid(self):
         """Check if the payment is paid.
-        @returns: True if the payment is paid, otherwise False
+        :returns: True if the payment is paid, otherwise False
         """
         return self.status == Payment.STATUS_PAID
 
     def is_pending(self):
         """Check if the payment is pending.
-        @returns: True if the payment is pending, otherwise False
+        :returns: True if the payment is pending, otherwise False
         """
         return self.status == Payment.STATUS_PENDING
 
     def is_preview(self):
         """Check if the payment is in preview state
-        @returns: True if the payment is paid, otherwise False
+        :returns: True if the payment is paid, otherwise False
         """
         return self.status == Payment.STATUS_PREVIEW
 
     def is_cancelled(self):
         """Check if the payment was cancelled.
-        @returns: True if the payment was cancelled, otherwise False.
+        :returns: True if the payment was cancelled, otherwise False.
         """
         return self.status == Payment.STATUS_CANCELLED
 
     def get_paid_date_string(self):
         """Get a paid date string
-        @returns: the paid date string or PAID DATE if the payment isn't
+        :returns: the paid date string or PAID DATE if the payment isn't
         paid
         """
         if self.paid_date:
@@ -371,7 +365,7 @@ class Payment(Domain):
 
     def get_open_date_string(self):
         """Get a open date string
-        @returns: the open date string or empty string
+        :returns: the open date string or empty string
         """
         if self.open_date:
             return self.open_date.date().strftime('%x')
@@ -382,13 +376,13 @@ class Payment(Domain):
 
     def is_inpayment(self):
         """Find out if a payment is incoming
-        @returns: True if it's incoming"""
-        return IInPayment(self, None) is not None
+        :returns: True if it's incoming"""
+        return self.payment_type == self.TYPE_IN
 
     def is_outpayment(self):
         """Find out if a payment is outgoing
-        @returns: True if it's outgoing"""
-        return IOutPayment(self, None) is not None
+        :returns: True if it's outgoing"""
+        return self.payment_type == self.TYPE_OUT
 
     def is_separate_payment(self):
         # FIXME: This is a hack, we should rather store a flag
@@ -408,6 +402,12 @@ class Payment(Domain):
 
         return True
 
+    def is_money(self):
+        """Find out if the payment was made with money
+        :returns: True if it's a money payment
+        """
+        return self.method.method_name == 'money'
+
 
 class PaymentChangeHistory(Domain):
     """ A class to hold information about changes to a payment.
@@ -415,12 +415,12 @@ class PaymentChangeHistory(Domain):
     Only one tuple (last_due_date, new_due_date) or (last_status, new_status)
     should be non-null at a time.
 
-    @param payment: the payment changed
-    @param change_reason: the reason of the due date change
-    @param last_due_date: the due date that was set before the changed
-    @param new_due_date: the due date that was set after changed
-    @param last_status: status before the change
-    @param new_status: status after change
+    :param payment: the payment changed
+    :param change_reason: the reason of the due date change
+    :param last_due_date: the due date that was set before the changed
+    :param new_due_date: the due date that was set after changed
+    :param last_status: status before the change
+    :param new_status: status after change
     """
     payment = ForeignKey('Payment')
     change_reason = UnicodeCol(default=None)
@@ -434,15 +434,15 @@ class PaymentChangeHistory(Domain):
 class PaymentFlowHistory(Domain):
     """A class to hold information about the financial flow.
 
-    @param history_date: the date when payments were registered.
-    @param to_receive: the amount scheduled to be received in the
+    :param history_date: the date when payments were registered.
+    :param to_receive: the amount scheduled to be received in the
                        history_date.
-    @param received: the amount received in the history_date.
-    @param to_pay: the amount scheduled to be paid in the history_date.
-    @param paid: the amount paid in the history_date.
-    @param balance_expected: the balance of the last day plus the amount to be
+    :param received: the amount received in the history_date.
+    :param to_pay: the amount scheduled to be paid in the history_date.
+    :param paid: the amount paid in the history_date.
+    :param balance_expected: the balance of the last day plus the amount to be
                              received minus the amount to be paid.
-    @param balance_real: the balance of the last day plus the amount received
+    :param balance_real: the balance of the last day plus the amount received
                          minus the amount paid.
     """
 
@@ -476,7 +476,7 @@ class PaymentFlowHistory(Domain):
         return Decimal(0)
 
     def get_divergent_payments(self):
-        """Returns a L{Payment} sequence that meet to following requirements:
+        """Returns a :class:`Payment` sequence that meet to following requirements:
             - The payment due date, paid date or cancel date is the current
               PaymentFlowHistory date.
             - The payment was paid/received with different values (eg with
@@ -519,21 +519,17 @@ class PaymentFlowHistory(Domain):
                 next_day._update_balance()
 
     def _update_registers(self, payment, value, accomplished=True):
-        """Updates the L{PaymentFlowHistory} attributes according to the
+        """Updates the :class:`PaymentFlowHistory` attributes according to the
         payment facet, value and if the payment was accomplished or not.
 
-        @param payment: the payment that will be registered.
-        @param value: the value that will be used to update history
+        :param payment: the payment that will be registered.
+        :param value: the value that will be used to update history
                       attributes.
-        @param accomplished: indicates if we should update the attributes that
+        :param accomplished: indicates if we should update the attributes that
                              holds information about the accomplished payments
                              or attributes related to payments that will be
                              accomplished later.
         """
-        if not payment.getFacets():
-            log.info('Payment %r will not be registered in %r: missing '
-                     'payment facets.' % (payment, self))
-
         if value > 0:
             payment_qty = 1
         else:
@@ -571,13 +567,13 @@ class PaymentFlowHistory(Domain):
 
     @classmethod
     def get_last_day(cls, conn, reference_date=None):
-        """Returns the L{PaymentFlowHistory} instance of the last day
+        """Returns the :class:`PaymentFlowHistory` instance of the last day
         registered or None if there is no registry. If reference_date was not
         specified, the referente date will be the current date.
 
-        @param reference_date: the reference date to use when querying the
+        :param reference_date: the reference date to use when querying the
                                last day.
-        @param conn: a database connection.
+        :param conn: a database connection.
         """
         if reference_date is None:
             reference_date = datetime.date.today()
@@ -590,13 +586,13 @@ class PaymentFlowHistory(Domain):
 
     @classmethod
     def get_next_day(cls, conn, reference_date=None):
-        """Returns the L{PaymentFlowHistory} instance of the next day
+        """Returns the :class:`PaymentFlowHistory` instance of the next day
         registered or None if there is no registry. If reference_date was not
         specified, the referente date will be the current date.
 
-        @param reference_date: the reference date to use when querying the
+        :param reference_date: the reference date to use when querying the
                                next day.
-        @param conn: a database connection.
+        :param conn: a database connection.
         """
         if reference_date is None:
             reference_date = datetime.date.today()
@@ -609,10 +605,10 @@ class PaymentFlowHistory(Domain):
 
     @classmethod
     def get_or_create_flow_history(cls, conn, date):
-        """Returns a L{PaymentFlowHistory} instance.
+        """Returns a :class:`PaymentFlowHistory` instance.
 
-        @param conn: a database connection.
-        @param date: the date of the L{PaymentFlowHistory} we want to
+        :param conn: a database connection.
+        :param date: the date of the :class:`PaymentFlowHistory` we want to
                      retrieve or create.
         """
         if isinstance(date, datetime.datetime):
@@ -625,12 +621,12 @@ class PaymentFlowHistory(Domain):
 
     @classmethod
     def add_payment(cls, conn, payment, reference_date=None):
-        """Adds a payment in the L{PaymentFlowHistory} registry according to
+        """Adds a payment in the :class:`PaymentFlowHistory` registry according to
         the payment due date.
 
-        @param conn: a database connection.
-        @param payment: the payment to be added in the registry.
-        @param reference_date: the reference date to use when add the payment,
+        :param conn: a database connection.
+        :param payment: the payment to be added in the registry.
+        :param reference_date: the reference date to use when add the payment,
                                if not specified, the reference will be the
                                payment due date.
         """
@@ -642,12 +638,12 @@ class PaymentFlowHistory(Domain):
 
     @classmethod
     def add_paid_payment(cls, conn, payment, reference_date=None):
-        """Adds a paid payment in the L{PaymentFlowHistory} registry. The paid
+        """Adds a paid payment in the :class:`PaymentFlowHistory` registry. The paid
         payment will be added in the current day registry.
 
-        @param conn: a database connection.
-        @param payment: the paid payment to be added in the registry.
-        @param reference_date: the reference date to use when add the paid
+        :param conn: a database connection.
+        :param payment: the paid payment to be added in the registry.
+        :param reference_date: the reference date to use when add the paid
                                payment, if not specified, the reference will
                                be the current date.
         """
@@ -659,12 +655,12 @@ class PaymentFlowHistory(Domain):
 
     @classmethod
     def remove_payment(cls, conn, payment, reference_date=None):
-        """Removes a payment in the L{PaymentFlowHistory} registry. The
+        """Removes a payment in the :class:`PaymentFlowHistory` registry. The
         payment will be deducted from registry according to its due date.
 
-        @param conn: a database connection.
-        @param payment: the payment to be removed in the registry.
-        @param reference_date: the reference date to use when remove the
+        :param conn: a database connection.
+        :param payment: the payment to be removed in the registry.
+        :param reference_date: the reference date to use when remove the
                                payment, if not specified, the reference will
                                be the payment due date.
         """
@@ -677,12 +673,12 @@ class PaymentFlowHistory(Domain):
 
     @classmethod
     def remove_paid_payment(cls, conn, payment, reference_date=None):
-        """Removes a paid payment in the L{PaymentFlowHistory} registry. The paid
+        """Removes a paid payment in the :class:`PaymentFlowHistory` registry. The paid
         payment will be removed in the current day registry.
 
-        @param conn: a database connection.
-        @param payment: the paid payment to be removed in the registry.
-        @param reference_date: the reference date to use when remove the paid
+        :param conn: a database connection.
+        :param payment: the paid payment to be removed in the registry.
+        :param reference_date: the reference date to use when remove the paid
                                payment, if not specified, the reference will
                                be the current date.
         """
@@ -691,34 +687,3 @@ class PaymentFlowHistory(Domain):
         day_history = cls.get_or_create_flow_history(conn, reference_date)
         day_history._update_registers(payment, -payment.paid_value,
                                       accomplished=True)
-
-#
-# Payment adapters
-#
-
-
-class PaymentAdaptToInPayment(ModelAdapter):
-
-    implements(IInPayment)
-
-    @property
-    def payment(self):
-        return self.get_adapted()
-
-Payment.registerFacet(PaymentAdaptToInPayment, IInPayment)
-
-
-class PaymentAdaptToOutPayment(ModelAdapter):
-
-    implements(IOutPayment)
-
-    @property
-    def payment(self):
-        return self.get_adapted()
-
-    def pay(self):
-        if not self.payment.status == Payment.STATUS_PENDING:
-            raise ValueError(_("This payment is already paid."))
-        self.payment.pay()
-
-Payment.registerFacet(PaymentAdaptToOutPayment, IOutPayment)
