@@ -1,4 +1,4 @@
-# -*- Mode: Python; coding: iso-8859-1 -*-
+# -*- Mode: Python; coding: utf-8 -*-
 # vi:si:et:sw=4:sts=4:ts=4
 
 ##
@@ -35,11 +35,9 @@ from stoqlib.domain.payment.comment import PaymentComment
 from stoqlib.domain.payment.group import PaymentGroup
 from stoqlib.domain.payment.method import (CheckData, PaymentMethod,
                                            CreditCardData)
-from stoqlib.domain.payment.payment import (Payment, PaymentAdaptToInPayment,
-                                            PaymentAdaptToOutPayment,
-                                            PaymentChangeHistory)
+from stoqlib.domain.payment.payment import Payment, PaymentChangeHistory
 from stoqlib.domain.payment.renegotiation import PaymentRenegotiation
-from stoqlib.domain.person import Person, PersonAdaptToCreditProvider
+from stoqlib.domain.person import Person, CreditProvider
 from stoqlib.domain.purchase import PurchaseOrder
 from stoqlib.domain.sale import Sale
 from stoqlib.lib.translation import stoqlib_gettext
@@ -66,6 +64,7 @@ class BasePaymentView(Viewable):
 
         # PaymentMethod
         method_name=PaymentMethod.q.method_name,
+        method_id=PaymentMethod.q.id,
 
         # PaymentCategory
         color=PaymentCategory.q.color,
@@ -123,8 +122,14 @@ class BasePaymentView(Viewable):
     def get_status_str(self):
         return Payment.statuses[self.status]
 
-    def get_days_late(self):
+    def is_late(self):
         if self.status in [Payment.STATUS_PAID, Payment.STATUS_CANCELLED]:
+            return False
+
+        return (datetime.date.today() - self.due_date.date()).days > 0
+
+    def get_days_late(self):
+        if not self.is_late():
             return 0
 
         days_late = datetime.date.today() - self.due_date.date()
@@ -149,6 +154,12 @@ class BasePaymentView(Viewable):
         if self.purchase_id:
             return PurchaseOrder.get(self.purchase_id)
 
+    @property
+    def operation(self):
+        method = PaymentMethod.get(self.method_id,
+                                   connection=self.get_connection())
+        return method.operation
+
     @property
     def sale(self):
         if self.sale_id:
@@ -181,14 +192,14 @@ class InPaymentView(BasePaymentView):
 
     joins = BasePaymentView.joins[:]
     joins.extend([
-        INNERJOINOn(None, PaymentAdaptToInPayment,
-                    PaymentAdaptToInPayment.q.originalID == Payment.q.id),
         LEFTJOINOn(None, Person,
                     PaymentGroup.q.payerID == Person.q.id),
         LEFTJOINOn(None, PaymentRenegotiation,
                    PaymentRenegotiation.q.groupID == PaymentGroup.q.id),
     ])
 
+    clause = (Payment.q.payment_type == Payment.TYPE_IN)
+
     @property
     def renegotiation(self):
         if self.renegotiation_id:
@@ -213,12 +224,12 @@ class OutPaymentView(BasePaymentView):
 
     joins = BasePaymentView.joins[:]
     joins.extend([
-        INNERJOINOn(None, PaymentAdaptToOutPayment,
-                    PaymentAdaptToOutPayment.q.originalID == Payment.q.id),
         LEFTJOINOn(None, Person,
                    Person.q.id == BasePaymentView.PaymentGroup_Sale.q.recipientID),
     ])
 
+    clause = (Payment.q.payment_type == Payment.TYPE_OUT)
+
 
 class CardPaymentView(Viewable):
     """A view for credit providers."""
@@ -244,10 +255,10 @@ class CardPaymentView(Viewable):
                     PaymentMethod.q.id == Payment.q.methodID),
         INNERJOINOn(None, CreditCardData,
                     CreditCardData.q.paymentID == Payment.q.id),
-        INNERJOINOn(None, PersonAdaptToCreditProvider,
-              PersonAdaptToCreditProvider.q.id == CreditCardData.q.providerID),
+        INNERJOINOn(None, CreditProvider,
+              CreditProvider.q.id == CreditCardData.q.providerID),
         INNERJOINOn(None, _ProviderPerson,
-            _ProviderPerson.q.id == PersonAdaptToCreditProvider.q.originalID),
+            _ProviderPerson.q.id == CreditProvider.q.personID),
         LEFTJOINOn(None, PaymentGroup,
                     PaymentGroup.q.id == Payment.q.groupID),
         LEFTJOINOn(None, _DraweePerson,
@@ -319,7 +330,7 @@ class InCheckPaymentView(_BillandCheckPaymentView):
     columns = _BillandCheckPaymentView.columns
     joins = _BillandCheckPaymentView.joins
     clause = AND(_BillandCheckPaymentView.clause,
-                 PaymentAdaptToInPayment.q.originalID == Payment.q.id)
+                 Payment.q.payment_type == Payment.TYPE_IN)
 
 
 class OutCheckPaymentView(_BillandCheckPaymentView):
@@ -328,7 +339,7 @@ class OutCheckPaymentView(_BillandCheckPaymentView):
     columns = _BillandCheckPaymentView.columns
     joins = _BillandCheckPaymentView.joins
     clause = AND(_BillandCheckPaymentView.clause,
-                 PaymentAdaptToOutPayment.q.originalID == Payment.q.id)
+                 Payment.q.payment_type == Payment.TYPE_OUT)
 
 
 class PaymentChangeHistoryView(Viewable):
@@ -388,8 +399,6 @@ class PaymentMethodView(Viewable):
         is_active=PaymentMethod.q.is_active
     )
 
-    joins = []
-
     @classmethod
     def get_by_name(cls, conn, name):
         results = cls.select(PaymentMethod.q.method_name == name,
