@@ -2,7 +2,7 @@
 # vi:si:et:sw=4:sts=4:ts=4
 
 ##
-## Copyright (C) 2005-2011 Async Open Source <http://www.async.com.br>
+## Copyright (C) 2005-2012 Async Open Source <http://www.async.com.br>
 ## All rights reserved
 ##
 ## This program is free software; you can redistribute it and/or modify
@@ -26,22 +26,19 @@
 import datetime
 from decimal import Decimal
 
-from kiwi.datatypes import currency
-from kiwi.argcheck import argcheck
 from zope.interface import implements
 
 from stoqlib.database.orm import PriceCol, DecimalCol, QuantityCol
 from stoqlib.database.orm import (UnicodeCol, ForeignKey, MultipleJoin, DateTimeCol,
-                                  BoolCol, BLOBCol, IntCol, PercentCol)
+                                  BoolCol, IntCol, PercentCol)
 from stoqlib.database.orm import const, AND, LEFTJOINOn
-from stoqlib.domain.base import Domain, ModelAdapter
+from stoqlib.domain.base import Domain
 from stoqlib.domain.events import (ProductCreateEvent, ProductEditEvent,
                                    ProductRemoveEvent, ProductStockUpdateEvent)
 from stoqlib.domain.person import Person
-from stoqlib.domain.interfaces import (IStorable, IBranch, IDescribable)
-from stoqlib.exceptions import StockError, DatabaseInconsistency
+from stoqlib.domain.interfaces import IDescribable
+from stoqlib.exceptions import StockError
 from stoqlib.lib.translation import stoqlib_gettext
-from stoqlib.lib.parameters import sysparam
 
 _ = stoqlib_gettext
 
@@ -60,24 +57,24 @@ class ProductSupplierInfo(Domain):
 
     Each product can has more than one supplier.
 
-    @ivar base_cost: the cost which helps the purchaser to define the
+    :attribute base_cost: the cost which helps the purchaser to define the
       main cost of a certain product. Each product can
       have multiple suppliers and for each supplier a
       base_cost is available. The purchaser in this case
       must decide how to define the main cost based in
       the base cost avarage of all suppliers.
-    @ivar notes:
-    @ivar is_main_supplier: defines if this object stores information
+    :attribute notes:
+    :attribute is_main_supplier: defines if this object stores information
         for the main supplier.
-    @ivar icms: a Brazil-specific attribute that means
+    :attribute icms: a Brazil-specific attribute that means
        'Imposto sobre circulacao de mercadorias e prestacao '
        'de servicos'
-    @ivar lead_time}: the number of days needed to deliver the product to
+    :attribute lead_time}: the number of days needed to deliver the product to
        purchaser.
-    @ivar minimum_purchase: the minimum amount that we can buy from this
+    :attribute minimum_purchase: the minimum amount that we can buy from this
        supplier.
-    @ivar supplier: the supplier of this relation
-    @ivar product: the product of this relation
+    :attribute supplier: the supplier of this relation
+    :attribute product: the product of this relation
     """
 
     base_cost = PriceCol(default=0)
@@ -87,7 +84,7 @@ class ProductSupplierInfo(Domain):
     minimum_purchase = QuantityCol(default=Decimal(1))
     # This is Brazil-specific information
     icms = PercentCol(default=0)
-    supplier = ForeignKey('PersonAdaptToSupplier')
+    supplier = ForeignKey('Supplier')
     product = ForeignKey('Product')
 
     #
@@ -130,32 +127,28 @@ class ProductSupplierInfo(Domain):
 class Product(Domain):
     """Class responsible to store basic products informations.
 
-    @ivar sellable: sellable of this product
-    @ivar suppliers: list of suppliers that sells this product
-    @ivar image: a thumbnail of this product
-    @ivar full_image: an image of this product
-    @ivar consignment:
-    @ivar is_composed:
-    @ivar production_time:
-    @ivar quality_tests:
-    @ivar location: physical location of this product, like a drawer
+    :attribute sellable: sellable of this product
+    :attribute suppliers: list of suppliers that sells this product
+    :attribute consignment:
+    :attribute is_composed:
+    :attribute production_time:
+    :attribute quality_tests: Used for composed products only
+    :attribute location: physical location of this product, like a drawer
       or shelf number
-    @ivar manufacturer: name of the manufacturer for this product
-    @ivar part_number: a number representing this part
-    @ivar width: physical width of this product, unit not enforced
-    @ivar height: physical height of this product, unit not enforced
-    @ivar depth: depth of this product, unit not enforced
-    @ivar ncm: NFE: nomenclature comon do mercuosol
-    @ivar ex_tipi: NFE: see ncm
-    @ivar genero: NFE: see ncm
-    @ivar icms_template: ICMS tax template, brazil specific
-    @ivar ipi_template: IPI tax template, brazil specific
+    :attribute manufacturer: name of the manufacturer for this product
+    :attribute part_number: a number representing this part
+    :attribute width: physical width of this product, unit not enforced
+    :attribute height: physical height of this product, unit not enforced
+    :attribute depth: depth of this product, unit not enforced
+    :attribute ncm: NFE: nomenclature comon do mercuosol
+    :attribute ex_tipi: NFE: see ncm
+    :attribute genero: NFE: see ncm
+    :attribute icms_template: ICMS tax template, brazil specific
+    :attribute ipi_template: IPI tax template, brazil specific
     """
 
     sellable = ForeignKey('Sellable')
     suppliers = MultipleJoin('ProductSupplierInfo')
-    image = BLOBCol(default='')
-    full_image = BLOBCol(default='')
     consignment = BoolCol(default=False)
 
     # Production
@@ -167,21 +160,17 @@ class Product(Domain):
     height = DecimalCol(default=0)
     depth = DecimalCol(default=0)
     weight = DecimalCol(default=0)
-    quality_tests = MultipleJoin('ProductQualityTest')   # Used for composed products only
+    quality_tests = MultipleJoin('ProductQualityTest')
     production_time = IntCol(default=1)
 
     # Tax details
     icms_template = ForeignKey('ProductIcmsTemplate', default=None)
     ipi_template = ForeignKey('ProductIpiTemplate', default=None)
 
-    # Nomenclatura Comum do Mercosul related details
     ncm = UnicodeCol(default=None)
     ex_tipi = UnicodeCol(default=None)
     genero = UnicodeCol(default=None)
 
-    def facet_IStorable_add(self, **kwargs):
-        return ProductAdaptToStorable(self, **kwargs)
-
     #
     # General Methods
     #
@@ -189,18 +178,19 @@ class Product(Domain):
     def has_quality_tests(self):
         return bool(self.quality_tests)
 
-    @property
-    def has_image(self):
-        return self.image != ''
-
     @property
     def description(self):
         return self.sellable.description
 
+    @property
+    def storable(self):
+        return Storable.selectOneBy(product=self,
+                                    connection=self.get_connection())
+
     def remove(self):
         """Deletes this product from the database.
         """
-        storable = IStorable(self, None)
+        storable = self.storable
         if storable:
             storable.delete(storable.id, self.get_connection())
         for i in self.get_suppliers_info():
@@ -219,7 +209,7 @@ class Product(Domain):
         from stoqlib.domain.production import ProductionItem
         if self.get_history().count():
             return False
-        storable = IStorable(self, None)
+        storable = self.storable
         if storable and storable.get_stock_items().count():
             return False
         # Return False if the product is component of other.
@@ -248,9 +238,9 @@ class Product(Domain):
         # Components maximum lead time
         comp_max_time = 0
         for i in self.get_components():
-            storable = IStorable(i.component)
+            storable = i.component.storable
             needed = quantity * i.quantity
-            stock = storable.get_full_balance(branch)
+            stock = storable.get_balance_for_branch(branch)
             # We have enought of this component items to produce.
             if  stock >= needed:
                 continue
@@ -276,7 +266,7 @@ class Product(Domain):
             return self.suppliers.max('lead_time') or 0
 
     def get_history(self):
-        """Returns the list of L{ProductHistory} for this product.
+        """Returns the list of :class:`ProductHistory` for this product.
         """
         return ProductHistory.selectBy(sellable=self.sellable,
                                        connection=self.get_connection())
@@ -289,8 +279,8 @@ class Product(Domain):
         """Gets a list of main suppliers for a Product, the main supplier
         is the most recently selected supplier.
 
-        @returns: main supplier info
-        @rtype: ProductSupplierInfo or None if a product lacks
+        :returns: main supplier info
+        :rtype: ProductSupplierInfo or None if a product lacks
            a main suppliers
         """
         return ProductSupplierInfo.selectOneBy(
@@ -301,8 +291,8 @@ class Product(Domain):
     def get_suppliers_info(self):
         """Returns a list of suppliers for this product
 
-        @returns: a list of suppliers
-        @rtype: list of ProductSupplierInfo
+        :returns: a list of suppliers
+        :rtype: list of ProductSupplierInfo
         """
         return ProductSupplierInfo.selectBy(
             product=self, connection=self.get_connection())
@@ -310,7 +300,7 @@ class Product(Domain):
     def get_components(self):
         """Returns the products which are our components.
 
-        @returns: a sequence of ProductComponent instances
+        :returns: a sequence of ProductComponent instances
         """
         return ProductComponent.selectBy(product=self,
                                          connection=self.get_connection())
@@ -318,13 +308,13 @@ class Product(Domain):
     def has_components(self):
         """Returns if this product has components or not.
 
-        @returns: True if this product has components, False otherwise.
+        :returns: True if this product has components, False otherwise.
         """
         return self.get_components().count() > 0
 
     def get_production_cost(self):
         """ Return the production cost of one unit of the Product.
-        @returns: the production cost
+        :returns: the production cost
         """
         return self.sellable.cost
 
@@ -339,8 +329,8 @@ class Product(Domain):
     def is_composed_by(self, product):
         """Returns if we are composed by a given product or not.
 
-        @param product: a possible component of this product
-        @returns: True if the given product is one of our component or a
+        :param product: a possible component of this product
+        :returns: True if the given product is one of our component or a
         component of our components, otherwise False.
         """
         for component in self.get_components():
@@ -351,7 +341,7 @@ class Product(Domain):
         return False
 
     #
-    # AbstractModel Hooks
+    # Domain
     #
 
     def on_create(self):
@@ -391,7 +381,7 @@ class ProductHistory(Domain):
     sold_date = DateTimeCol(default=None)
     received_date = DateTimeCol(default=None)
     decreased_date = DateTimeCol(default=None)
-    branch = ForeignKey("PersonAdaptToBranch")
+    branch = ForeignKey("Branch")
     sellable = ForeignKey("Sellable")
 
     @classmethod
@@ -399,9 +389,9 @@ class ProductHistory(Domain):
         """Adds a sold item, populates the ProductHistory table using a
         product_sellable_item created during a sale.
 
-        @param conn: a database connection
-        @param branch: the branch
-        @param product_sellable_item: the sellable item for the sold
+        :param conn: a database connection
+        :param branch: the branch
+        :param product_sellable_item: the sellable item for the sold
         """
         cls(branch=branch,
             sellable=product_sellable_item.sellable,
@@ -415,9 +405,9 @@ class ProductHistory(Domain):
         Adds a received_item, populates the ProductHistory table using a
         receiving_order_item created during a purchase
 
-        @param conn: a database connection
-        @param branch: the branch
-        @param receiving_order_item: the item received for puchase
+        :param conn: a database connection
+        :param branch: the branch
+        :param receiving_order_item: the item received for puchase
         """
         cls(branch=branch, sellable=receiving_order_item.sellable,
             quantity_received=receiving_order_item.quantity,
@@ -430,9 +420,9 @@ class ProductHistory(Domain):
         Adds a transfered_item, populates the ProductHistory table using a
         transfered_order_item created during a transfer order
 
-        @param conn: a database connection
-        @param branch: the source branch
-        @param transfer_order_item: the item transfered from source branch
+        :param conn: a database connection
+        :param branch: the source branch
+        :param transfer_order_item: the item transfered from source branch
         """
         cls(branch=branch, sellable=transfer_order_item.sellable,
             quantity_transfered=transfer_order_item.quantity,
@@ -445,9 +435,9 @@ class ProductHistory(Domain):
         Adds a consumed_item, populates the ProductHistory table using a
         production_material item that was used in a production order.
 
-        @param conn: a database connection
-        @param branch: the source branch
-        @param retained_item: a ProductionMaterial instance
+        :param conn: a database connection
+        :param branch: the source branch
+        :param retained_item: a ProductionMaterial instance
         """
         cls(branch=branch, sellable=consumed_item.product.sellable,
             quantity_consumed=consumed_item.consumed,
@@ -460,9 +450,9 @@ class ProductHistory(Domain):
         Adds a produced_item, populates the ProductHistory table using a
         production_item that was produced in a production order.
 
-        @param conn: a database connection
-        @param branch: the source branch
-        @param retained_item: a ProductionItem instance
+        :param conn: a database connection
+        :param branch: the source branch
+        :param retained_item: a ProductionItem instance
         """
         cls(branch=branch, sellable=produced_item.product.sellable,
             quantity_produced=produced_item.produced,
@@ -474,9 +464,9 @@ class ProductHistory(Domain):
         Adds a lost_item, populates the ProductHistory table using a
         production_item/product_material that was lost in a production order.
 
-        @param conn: a database connection
-        @param branch: the source branch
-        @param lost_item: a ProductionItem or ProductionMaterial instance
+        :param conn: a database connection
+        :param branch: the source branch
+        :param lost_item: a ProductionItem or ProductionMaterial instance
         """
         cls(branch=branch, sellable=lost_item.product.sellable,
             quantity_lost=lost_item.lost,
@@ -488,9 +478,9 @@ class ProductHistory(Domain):
         Adds a decreased item, populates the ProductHistory table informing
         how many items wore manually decreased from stock.
 
-        @param conn: a database connection
-        @param branch: the source branch
-        @param item: a StockDecreaseItem instance
+        :param conn: a database connection
+        :param branch: the source branch
+        :param item: a StockDecreaseItem instance
         """
         cls(branch=branch, sellable=item.sellable,
             quantity_decreased=item.quantity,
@@ -501,24 +491,22 @@ class ProductStockItem(Domain):
     """Class that makes a reference to the product stock of a
     certain branch company.
 
-    @ivar stock_cost: the average stock price, will be updated as
+    :attribute stock_cost: the average stock price, will be updated as
       new stock items are received.
-    @ivar quantity: number of storables in the stock item
-    @ivar logic_quantity: ???
-    @ivar branch: the branch this stock item belongs to
-    @ivar storable: the storable the stock item refers to
+    :attribute quantity: number of storables in the stock item
+    :attribute branch: the branch this stock item belongs to
+    :attribute storable: the storable the stock item refers to
     """
 
     stock_cost = PriceCol(default=0)
     quantity = QuantityCol(default=0)
-    logic_quantity = QuantityCol(default=0)
-    branch = ForeignKey('PersonAdaptToBranch')
-    storable = ForeignKey('ProductAdaptToStorable')
+    branch = ForeignKey('Branch')
+    storable = ForeignKey('Storable')
 
     def update_cost(self, new_quantity, new_cost):
         """Update the stock_item according to new quantity and cost.
-        @param new_quantity: The new quantity added to stock.
-        @param new_cost: The cost of one unit of the added stock.
+        :param new_quantity: The new quantity added to stock.
+        :param new_cost: The cost of one unit of the added stock.
         """
         total_cost = self.quantity * self.stock_cost
         total_cost += new_quantity * new_cost
@@ -526,204 +514,122 @@ class ProductStockItem(Domain):
         self.stock_cost = total_cost / total_items
 
 
-#
-# Adapters
-#
+class Storable(Domain):
+    '''Storable represents the stock of a Product.
 
+    The actual stock of an item is in ProductStockItem.
 
-class ProductAdaptToStorable(ModelAdapter):
-    """A product implementation as a storable facet."""
-
-    implements(IStorable)
-
+    :ivar product: the product the stock represents
+    :ivar maximum_quantity: maximum quantity of stock items allowed
+    :ivar minimum_quantity: minimum quantity of stock items allowed
+    '''
+    product = ForeignKey('Product')
     minimum_quantity = QuantityCol(default=0)
     maximum_quantity = QuantityCol(default=0)
 
-    #
-    # Private
-    #
-
-    def _check_logic_quantity(self):
-        if sysparam(self.get_connection()).USE_LOGIC_QUANTITY:
-            return
-        raise StockError(
-            _("This company doesn't allow logic quantity operations"))
-
-    def _check_rejected_stocks(self, stocks, quantity, check_logic=False):
-        for stock_item in stocks:
-            if check_logic:
-                base_qty = stock_item.logic_quantity
-            else:
-                base_qty = stock_item.quantity
-            if base_qty < quantity:
-                raise StockError(
-                    _('Quantity to decrease is greater than available stock.'))
-
-    def _has_qty_available(self, quantity, branch):
-        logic_qty = self.get_logic_balance(branch)
-        balance = self.get_full_balance(branch) - logic_qty
-        qty_ok = quantity <= balance
-        logic_qty_ok = quantity <= self.get_full_balance(branch)
-        has_logic_qty = sysparam(self.get_connection()).USE_LOGIC_QUANTITY
-        if not qty_ok and not (has_logic_qty and logic_qty_ok):
-            raise StockError(
-                _('Quantity to sell is greater than the available stock.'))
-        return qty_ok
-
-    @argcheck(Person.getAdapterClass(IBranch))
-    def _get_stocks(self, branch=None):
-        # FIXME: Get rid of this after fixing all call sites.
-        query_args = {}
-        if branch:
-            query_args['branch'] = branch.id
-        return ProductStockItem.selectBy(storable=self,
-                                         connection=self.get_connection(),
-                                         **query_args)
-
     #
     # Properties
     #
 
-    @property
-    def product(self):
-        return self.get_adapted()
-
-    #
-    # IStorable implementation
-    #
-
     def increase_stock(self, quantity, branch, unit_cost=None):
+        """When receiving a product, update the stock reference for this new
+        item on a specific branch company.
+        :param quantity: amount to increase
+        :param branch: a branch
+        :param cost: optional parameter indicating the unit cost of the new
+                     stock items
+        """
         if quantity <= 0:
             raise ValueError(_("quantity must be a positive number"))
-
+        if branch is None:
+            raise ValueError("branch cannot be None")
         stock_item = self.get_stock_item(branch)
+        # If the stock_item is missing create a new one
         if stock_item is None:
-            # If the stock_item is missing create a new one
             stock_item = ProductStockItem(
                 storable=self,
                 branch=branch,
                 connection=self.get_connection())
 
-        # If previously lacked quantity change the status of the sellable
-        if not stock_item.quantity:
-            sellable = self.product.sellable
-            if sellable:
-                # Rename see bug 2669
-                sellable.can_sell()
-
+        # Unit cost must be updated here as
+        # 1) we need the stock item which might not exist
+        # 2) it needs to be updated before we change the quantity of the
+        #    stock item
         if unit_cost is not None:
             stock_item.update_cost(quantity, unit_cost)
 
         old_quantity = stock_item.quantity
         stock_item.quantity += quantity
 
+        # If previously lacked quantity change the status of the sellable
+        if not old_quantity:
+            sellable = self.product.sellable
+            if sellable:
+                sellable.can_sell()
+
         ProductStockUpdateEvent.emit(self.product, branch, old_quantity,
                                      stock_item.quantity)
 
     def decrease_stock(self, quantity, branch):
-        # The function get_full_balance returns the current amount of items
-        # in the stock. If get_full_balance == 0 we have no more stock for
-        # this product and we need to set it as sold.
-
-        if not self._has_qty_available(quantity, branch):
-            # Of course that here we must use the logic quantity balance
-            # as an addition to our main stock
-            logic_qty = self.get_logic_balance(branch)
-            balance = self.get_full_balance(branch) - logic_qty
-            logic_sold_qty = quantity - balance
-            quantity -= logic_sold_qty
-            self.decrease_logic_stock(logic_sold_qty, branch)
+        """When receiving a product, update the stock reference for the sold item
+        this on a specific branch company. Returns the stock item that was
+        decreased.
+        :param quantity: amount to decrease
+        :param branch: a branch
+        """
+        if quantity <= 0:
+            raise ValueError(_("quantity must be a positive number"))
+        if branch is None:
+            raise ValueError("branch cannot be None")
 
         stock_item = self.get_stock_item(branch)
-        self._check_rejected_stocks([stock_item], quantity)
+        if stock_item is None or quantity > stock_item.quantity:
+            raise StockError(
+                _('Quantity to sell is greater than the available stock.'))
 
         old_quantity = stock_item.quantity
         stock_item.quantity -= quantity
-        if stock_item.quantity < 0:
-            raise ValueError(_("Quantity cannot be negative"))
 
-        # We emptied the entire stock, we need to change the status of the
-        # sellable, but only if there is no stock in any other branch.
-        has_stock = any([s.quantity > 0 for s in self.get_stock_items()])
-        if not has_stock:
+        # We emptied the entire stock in all branches, we need to change
+        # the status of the sellable to unavailable as we cannot sell
+        # it anymore
+        if not ProductStockItem.selectBy(
+            storable=self,
+            connection=self.get_connection()).sum(ProductStockItem.q.quantity):
             sellable = self.product.sellable
             if sellable:
-                # FIXME: rename sell() to something more useful which is not
-                #        confusing a sale and a sellable, Bug 2669
                 sellable.set_unavailable()
 
         ProductStockUpdateEvent.emit(self.product, branch, old_quantity,
                                      stock_item.quantity)
-
         return stock_item
 
-    def increase_logic_stock(self, quantity, branch=None):
-        self._check_logic_quantity()
-        stocks = self._get_stocks(branch)
-        for stock_item in stocks:
-            stock_item.logic_quantity += quantity
-
-    def decrease_logic_stock(self, quantity, branch=None):
-        self._check_logic_quantity()
-
-        stocks = self._get_stocks(branch)
-        self._check_rejected_stocks(stocks, quantity, check_logic=True)
-        for stock_item in stocks:
-            stock_item.logic_quantity -= quantity
-
-    def get_full_balance(self, branch=None):
-        """ Get the stock balance and the logic balance."""
-        stocks = self._get_stocks(branch)
-        value = Decimal(0)
-        if not stocks:
-            return value
-        has_logic_qty = sysparam(self.get_connection()).USE_LOGIC_QUANTITY
-        for stock_item in stocks:
-            value += stock_item.quantity
-            if has_logic_qty:
-                value += stock_item.logic_quantity
-        return value
-
-    def get_logic_balance(self, branch=None):
-        stocks = self._get_stocks(branch)
-        assert stocks.count() >= 1
-        values = [stock_item.logic_quantity for stock_item in stocks]
-        return sum(values, Decimal(0))
-
-    def get_average_stock_price(self):
-        total_cost = Decimal(0)
-        total_qty = Decimal(0)
-        for stock_item in self.get_stock_items():
-            total_cost += stock_item.stock_cost
-            total_qty += stock_item.quantity
-
-        if not total_qty:
-            return currency(0)
-        return currency(total_cost / total_qty)
-
-    def has_stock_by_branch(self, branch):
-        stock = self._get_stocks(branch)
-        qty = stock.count()
-        if not qty:
-            return False
-        elif qty > 1:
-            raise DatabaseInconsistency(
-                _("You should have only one stock item for this branch, "
-                  "got %d") % qty)
-        stock = stock[0]
-        return stock.quantity + stock.logic_quantity > 0
+    def get_balance_for_branch(self, branch):
+        """Return the stock balance for the product in a branch.
+        :param branch: the branch to get the stock balance for
+        :returns: the amount of stock available in the branch
+        """
+        conn = self.get_connection()
+        stock_items = ProductStockItem.selectBy(storable=self,
+                                                connection=conn,
+                                                branch=branch)
+        return stock_items.sum(ProductStockItem.q.quantity) or Decimal(0)
 
     def get_stock_items(self):
+        """Fetches the stock items available for all branches.
+        :returns: a sequence of stock items
+        """
         return ProductStockItem.selectBy(storable=self,
                                          connection=self.get_connection())
 
     def get_stock_item(self, branch):
+        """Fetch a stock item for a specific branch
+        :returns: a stock item
+        """
         return ProductStockItem.selectOneBy(branch=branch,
                                             storable=self,
                                             connection=self.get_connection())
 
-Product.registerFacet(ProductAdaptToStorable, IStorable)
-
 
 class ProductComponent(Domain):
     """A product and it's related component eg other product
