@@ -33,7 +33,7 @@ from stoqlib.database.orm import (UnicodeCol, ForeignKey, DateTimeCol, IntCol,
 from stoqlib.database.orm import AND
 from stoqlib.domain.base import Domain
 from stoqlib.domain.product import ProductHistory
-from stoqlib.domain.interfaces import IContainer, IDescribable, IStorable
+from stoqlib.domain.interfaces import IContainer, IDescribable
 from stoqlib.lib.translation import stoqlib_gettext
 
 
@@ -43,18 +43,18 @@ _ = stoqlib_gettext
 class ProductionOrder(Domain):
     """Production Order object implementation.
 
-    @cvar ORDER_OPENED: The production order is opened, production items might
+    :cvar ORDER_OPENED: The production order is opened, production items might
                         have been added.
-    @cvar ORDER_WAITING: The production order is waiting some conditions to
+    :cvar ORDER_WAITING: The production order is waiting some conditions to
                          start the manufacturing process.
-    @cvar ORDER_PRODUCTION: The production order have already started.
-    @cvar ORDER_CLOSED: The production have finished.
+    :cvar ORDER_PRODUCTION: The production order have already started.
+    :cvar ORDER_CLOSED: The production have finished.
 
-    @ivar status: the production order status
-    @ivar open_date: the date when the production order was created
-    @ivar close_date: the date when the production order have been closed
-    @ivar description: the production order description
-    @ivar responsible: the person responsible for the production order
+    :attribute status: the production order status
+    :attribute open_date: the date when the production order was created
+    :attribute close_date: the date when the production order have been closed
+    :attribute description: the production order description
+    :attribute responsible: the person responsible for the production order
     """
     implements(IContainer, IDescribable)
 
@@ -77,8 +77,8 @@ class ProductionOrder(Domain):
     start_date = DateTimeCol(default=None)
     close_date = DateTimeCol(default=None)
     description = UnicodeCol(default='')
-    responsible = ForeignKey('PersonAdaptToEmployee', default=None)
-    branch = ForeignKey('PersonAdaptToBranch')
+    responsible = ForeignKey('Employee', default=None)
+    branch = ForeignKey('Branch')
 
     produced_items = MultipleJoin('ProductionProducedItem',
                                   joinColumn='order_id', orderBy='id')
@@ -111,7 +111,7 @@ class ProductionOrder(Domain):
     def get_service_items(self):
         """Returns all the services needed by this production.
 
-        @returns: a sequence of L{ProductionService} instances.
+        :returns: a sequence of :class:`ProductionService` instances.
         """
         return ProductionService.selectBy(order=self,
                                           connection=self.get_connection())
@@ -127,7 +127,7 @@ class ProductionOrder(Domain):
     def get_material_items(self):
         """Returns all the material needed by this production.
 
-        @returns: a sequence of L{ProductionMaterial} instances.
+        :returns: a sequence of :class:`ProductionMaterial` instances.
         """
         return ProductionMaterial.selectBy(order=self,
                                            connection=self.get_connection())
@@ -218,11 +218,11 @@ class ProductionOrder(Domain):
 class ProductionItem(Domain):
     """Production Item object implementation.
 
-    @ivar order: The L{ProductionOrder} of this item.
-    @ivar product: The product that will be manufactured.
-    @ivar quantity: The product's quantity that will be manufactured.
-    @ivar produced: The product's quantity that was manufactured.
-    @ivar lost: The product's quantity that was lost.
+    :attribute order: The :class:`ProductionOrder` of this item.
+    :attribute product: The product that will be manufactured.
+    :attribute quantity: The product's quantity that will be manufactured.
+    :attribute produced: The product's quantity that was manufactured.
+    :attribute lost: The product's quantity that was lost.
     """
     implements(IDescribable)
 
@@ -259,7 +259,7 @@ class ProductionItem(Domain):
         quantity items until we reach the total quantity that will be
         manufactured minus the quantity that was lost.
 
-        @param quantity: the quantity that will be produced.
+        :param quantity: the quantity that will be produced.
         """
         assert quantity > 0
         if self.order.status != ProductionOrder.ORDER_PRODUCING:
@@ -275,7 +275,7 @@ class ProductionItem(Domain):
         produced only if there are enough materials allocated, otherwise a
         ValueError exception will be raised.
 
-        @param quantity: the quantity that will be produced.
+        :param quantity: the quantity that will be produced.
         """
         assert self.can_produce(quantity)
 
@@ -310,7 +310,7 @@ class ProductionItem(Domain):
         else:
             # There are no quality tests for this product. Increase stock
             # right now.
-            storable = IStorable(self.product, None)
+            storable = self.product.storable
             storable.increase_stock(quantity, self.order.branch)
 
         self.produced += quantity
@@ -321,7 +321,7 @@ class ProductionItem(Domain):
         """Adds a quantity that was lost. The maximum quantity that can be
         lost is the total quantity minus the quantity already produced.
 
-        @param quantity: the quantity that was lost.
+        :param quantity: the quantity that was lost.
         """
         if self.lost + quantity > self.quantity - self.produced:
             raise ValueError(
@@ -346,13 +346,13 @@ class ProductionItem(Domain):
 class ProductionMaterial(Domain):
     """Production Material object implementation.
 
-    @ivar product: The L{Product} that will be consumed.
-    @ivar order: The L{ProductionOrder} that will consume this material.
-    @ivar needed: The quantity needed of this material.
-    @ivar consumed: The quantity already used of this material.
-    @ivar lost: The quantity lost of this material.
-    @ivar to_purchase: The quantity to purchase of this material.
-    @ivar to_make: The quantity to manufacture of this material.
+    :attribute product: The :class:`Product` that will be consumed.
+    :attribute order: The :class:`ProductionOrder` that will consume this material.
+    :attribute needed: The quantity needed of this material.
+    :attribute consumed: The quantity already used of this material.
+    :attribute lost: The quantity lost of this material.
+    :attribute to_purchase: The quantity to purchase of this material.
+    :attribute to_make: The quantity to manufacture of this material.
     """
     implements(IDescribable)
 
@@ -373,7 +373,7 @@ class ProductionMaterial(Domain):
     def can_add_lost(self, quantity):
         """Returns if we can loose a certain quantity of this material.
 
-        @param quantity: the quantity that will be lost.
+        :param quantity: the quantity that will be lost.
         """
         return self.can_consume(quantity)
 
@@ -391,11 +391,11 @@ class ProductionMaterial(Domain):
         quantity specified or raise a ValueError exception, if the quantity is
         not available.
 
-        @param quantity: the quantity to be allocated or None to allocate the
+        :param quantity: the quantity to be allocated or None to allocate the
                          maximum quantity possible.
         """
         stock = self.get_stock_quantity()
-        storable = IStorable(self.product, None)
+        storable = self.product.storable
         assert storable is not None
 
         if quantity is None:
@@ -422,7 +422,7 @@ class ProductionMaterial(Domain):
         assert remaining >= 0
         if not remaining:
             return
-        storable = IStorable(self.product)
+        storable = self.product.storable
         storable.increase_stock(remaining, self.order.branch)
         self.allocated -= remaining
 
@@ -431,7 +431,7 @@ class ProductionMaterial(Domain):
         can be lost is given by the formula:
             - max_lost(quantity) = needed - consumed - lost - quantity
 
-        @param quantity: the quantity that was lost.
+        :param quantity: the quantity that was lost.
         """
         assert quantity > 0
 
@@ -452,7 +452,7 @@ class ProductionMaterial(Domain):
 
             - max_consumed(quantity) = needed - consumed - lost - quantity
 
-        @param quantity: the quantity to be consumed.
+        :param quantity: the quantity to be consumed.
         """
         assert quantity > 0
 
@@ -481,17 +481,17 @@ class ProductionMaterial(Domain):
         return self.product.sellable.get_unit_description()
 
     def get_stock_quantity(self):
-        storable = IStorable(self.product, None)
+        storable = self.product.storable
         assert storable is not None
-        return storable.get_full_balance(self.order.branch)
+        return storable.get_balance_for_branch(self.order.branch)
 
 
 class ProductionService(Domain):
     """Production Service object implementation.
 
-    @ivar order: The L{ProductionOrder} of this service.
-    @ivar service: The service that will be used by the production.
-    @ivar quantity: The service's quantity.
+    :attribute order: The :class:`ProductionOrder` of this service.
+    :attribute service: The service that will be used by the production.
+    :attribute quantity: The service's quantity.
     """
     implements(IDescribable)
 
@@ -522,7 +522,7 @@ class ProductionProducedItem(Domain):
     # ProductionItem already has a reference to Product, but we need it for
     # constraint checks UNIQUE(product_id, serial_number)
     product = ForeignKey('Product')
-    produced_by = ForeignKey('PersonAdaptToUser')
+    produced_by = ForeignKey('LoginUser')
     produced_date = DateTimeCol()
     serial_number = IntCol()
     entered_stock = BoolCol(default=False)
@@ -553,7 +553,7 @@ class ProductionProducedItem(Domain):
         if self.entered_stock:
             return
 
-        storable = IStorable(self.product, None)
+        storable = self.product.storable
         storable.increase_stock(1, self.order.branch)
         self.entered_stock = True
 
@@ -604,7 +604,7 @@ class ProductionItemQualityResult(Domain):
 
     produced_item = ForeignKey('ProductionProducedItem')
     quality_test = ForeignKey('ProductQualityTest')
-    tested_by = ForeignKey('PersonAdaptToUser')
+    tested_by = ForeignKey('LoginUser')
     tested_date = DateTimeCol(default=None)
     result_value = UnicodeCol()
     test_passed = BoolCol(default=False)
