@@ -38,15 +38,15 @@ from stoqlib.database.runtime import get_current_user
 from stoqlib.domain.base import Domain
 from stoqlib.domain.event import Event
 from stoqlib.domain.payment.method import PaymentMethod
-from stoqlib.domain.payment.payment import Payment
 from stoqlib.domain.interfaces import (IPaymentTransaction, IContainer,
                                        IDescribable)
-from stoqlib.domain.person import (Person, PersonAdaptToBranch,
-                                   PersonAdaptToSupplier,
-                                   PersonAdaptToTransporter,
-                                   PersonAdaptToUser)
+from stoqlib.domain.person import (Person, Branch,
+                                   Supplier,
+                                   Transporter,
+                                   LoginUser)
 from stoqlib.domain.sellable import Sellable, SellableUnit
 from stoqlib.exceptions import DatabaseInconsistency, StoqlibError
+from stoqlib.lib.component import Adaptable
 from stoqlib.lib.defaults import quantize
 from stoqlib.lib.translation import stoqlib_gettext
 from stoqlib.lib.formatters import format_quantity, get_formatted_price
@@ -123,9 +123,9 @@ class PurchaseItem(Domain):
     @classmethod
     def get_ordered_quantity(cls, conn, sellable):
         """Returns the quantity already ordered of a given sellable.
-        @param conn: a database connection
-        @param sellable: the sellable we want to know the quantity ordered.
-        @returns: the quantity already ordered of a given sellable or zero if
+        :param conn: a database connection
+        :param sellable: the sellable we want to know the quantity ordered.
+        :returns: the quantity already ordered of a given sellable or zero if
         no quantity have been ordered.
         """
         query = AND(PurchaseItem.q.sellableID == sellable.id,
@@ -135,7 +135,7 @@ class PurchaseItem(Domain):
         return ordered_items.sum('quantity') or Decimal(0)
 
 
-class PurchaseOrder(Domain):
+class PurchaseOrder(Domain, Adaptable):
     """Purchase and order definition."""
 
     implements(IContainer)
@@ -174,12 +174,16 @@ class PurchaseOrder(Domain):
     surcharge_value = PriceCol(default=0)
     discount_value = PriceCol(default=0)
     consigned = BoolCol(default=False)
-    supplier = ForeignKey('PersonAdaptToSupplier')
-    branch = ForeignKey('PersonAdaptToBranch')
-    transporter = ForeignKey('PersonAdaptToTransporter', default=None)
-    responsible = ForeignKey('PersonAdaptToUser')
+    supplier = ForeignKey('Supplier')
+    branch = ForeignKey('Branch')
+    transporter = ForeignKey('Transporter', default=None)
+    responsible = ForeignKey('LoginUser')
     group = ForeignKey('PaymentGroup')
 
+    def __init__(self, *args, **kwargs):
+        self.addFacet(IPaymentTransaction)
+        Domain.__init__(self, *args, **kwargs)
+
     #
     # IContainer Implementation
     #
@@ -253,8 +257,15 @@ class PurchaseOrder(Domain):
 
     @property
     def payments(self):
-        return Payment.selectBy(group=self.group,
-                                connection=self.get_connection())
+        """Returns all valid payments for this purchase
+
+        This will return a list of valid payments for this purchase, that
+        is, all payments on the payment group that were not cancelled.
+        If you need to get the cancelled too, use self.group.payments.
+
+        :returns: a list of :class:`stoqlib.domain.payment.payment.Payment`
+        """
+        return self.group.get_valid_payments()
 
     #
     # Private
@@ -272,14 +283,14 @@ class PurchaseOrder(Domain):
     #
 
     def is_paid(self):
-        for payment in self.group.get_items():
+        for payment in self.payments:
             if not payment.is_paid():
                 return False
         return True
 
     def can_cancel(self):
         """Find out if it's possible to cancel the order
-        @returns: True if it's possible to cancel the order, otherwise False
+        :returns: True if it's possible to cancel the order, otherwise False
         """
         # FIXME: Canceling partial orders disabled until we fix bug 3282
         for item in self.get_items():
@@ -291,7 +302,7 @@ class PurchaseOrder(Domain):
 
     def can_close(self):
         """Find out if it's possible to close the order
-        @returns: True if it's possible to close the order, otherwise False
+        :returns: True if it's possible to close the order, otherwise False
         """
 
         # Consigned orders can be closed only after being confirmed
@@ -306,7 +317,7 @@ class PurchaseOrder(Domain):
     def confirm(self, confirm_date=None):
         """Confirms the purchase order
 
-        @param confirm_data: optional, datetime
+        :param confirm_data: optional, datetime
         """
         if confirm_date is None:
             confirm_date = const.NOW()
@@ -513,7 +524,7 @@ class Quotation(Domain):
     def is_closed(self):
         """Returns if the quotation is closed or not.
 
-        @returns: True if the quotation is closed, False otherwise.
+        :returns: True if the quotation is closed, False otherwise.
         """
         return self.purchase.status == PurchaseOrder.ORDER_CANCELLED
 
@@ -609,11 +620,10 @@ class PurchaseOrderAdaptToPaymentTransaction(object):
             return
 
         money = PaymentMethod.get_by_name(self.purchase.get_connection(), 'money')
-        in_payment = money.create_inpayment(
+        payment = money.create_inpayment(
             self.purchase.group, paid_value,
             description=_('%s Money Returned for Purchase %d') % (
             '1/1', self.purchase.id))
-        payment = in_payment.get_adapted()
         payment.set_pending()
         payment.pay()
 
@@ -626,16 +636,16 @@ class PurchaseItemView(Viewable):
     a specific purchase. It's used by the PurchaseDetails dialog
     to display all the purchase items within a purchase
 
-    @param id: id of the purchase item
-    @param purchase_id: id of the purchase order the item belongs to
-    @param sellable: sellable of the item
-    @param cost: cost of the item
-    @param quantity: quantity ordered
-    @param quantity_received: quantity received
-    @param total: total value of the items purchased
-    @param total_received: total value of the items received
-    @param description: description of the sellable
-    @param unit: unit as a string or None if the product has no unit
+    :param id: id of the purchase item
+    :param purchase_id: id of the purchase order the item belongs to
+    :param sellable: sellable of the item
+    :param cost: cost of the item
+    :param quantity: quantity ordered
+    :param quantity_received: quantity received
+    :param total: total value of the items purchased
+    :param total_received: total value of the items received
+    :param description: description of the sellable
+    :param unit: unit as a string or None if the product has no unit
     """
     columns = dict(
         id=PurchaseItem.q.id,
@@ -691,25 +701,25 @@ class PurchaseItemView(Viewable):
 class PurchaseOrderView(Viewable):
     """General information about purchase orders
 
-    @cvar id: the id of purchase_order table
-    @cvar status: the purchase order status
-    @cvar open_date: the date when the order was started
-    @cvar quote_deadline: the date when the quotation expires
-    @cvar expected_receival_date: expected date to receive products
-    @cvar expected_pay_date: expected date to pay the products
-    @cvar receival_date: the date when the products were received
-    @cvar confirm_date: the date when the order was confirmed
-    @cvar salesperson_name: the name of supplier's salesperson
-    @cvar expected_freight: the expected freight value
-    @cvar surcharge_value: the surcharge value for the order total
-    @cvar discount_value: the discount_value for the order total
-    @cvar supplier_name: the supplier name
-    @cvar transporter_name: the transporter name
-    @cvar branch_name: the branch company name
-    @cvar ordered_quantity: the total quantity ordered
-    @cvar received_quantity: the total quantity received
-    @cvar subtotal: the order subtotal (sum of product values)
-    @cvar total: subtotal - discount_value + surcharge_value
+    :cvar id: the id of purchase_order table
+    :cvar status: the purchase order status
+    :cvar open_date: the date when the order was started
+    :cvar quote_deadline: the date when the quotation expires
+    :cvar expected_receival_date: expected date to receive products
+    :cvar expected_pay_date: expected date to pay the products
+    :cvar receival_date: the date when the products were received
+    :cvar confirm_date: the date when the order was confirmed
+    :cvar salesperson_name: the name of supplier's salesperson
+    :cvar expected_freight: the expected freight value
+    :cvar surcharge_value: the surcharge value for the order total
+    :cvar discount_value: the discount_value for the order total
+    :cvar supplier_name: the supplier name
+    :cvar transporter_name: the transporter name
+    :cvar branch_name: the branch company name
+    :cvar ordered_quantity: the total quantity ordered
+    :cvar received_quantity: the total quantity received
+    :cvar subtotal: the order subtotal (sum of product values)
+    :cvar total: subtotal - discount_value + surcharge_value
     """
 
     Person_Supplier = Alias(Person, 'person_supplier')
@@ -747,23 +757,23 @@ class PurchaseOrderView(Viewable):
         INNERJOINOn(None, PurchaseItem,
                     PurchaseOrder.q.id == PurchaseItem.q.orderID),
 
-        LEFTJOINOn(None, PersonAdaptToSupplier,
-                   PurchaseOrder.q.supplierID == PersonAdaptToSupplier.q.id),
-        LEFTJOINOn(None, PersonAdaptToTransporter,
-                   PurchaseOrder.q.transporterID == PersonAdaptToTransporter.q.id),
-        LEFTJOINOn(None, PersonAdaptToBranch,
-                   PurchaseOrder.q.branchID == PersonAdaptToBranch.q.id),
-        LEFTJOINOn(None, PersonAdaptToUser,
-                   PurchaseOrder.q.responsibleID == PersonAdaptToUser.q.id),
+        LEFTJOINOn(None, Supplier,
+                   PurchaseOrder.q.supplierID == Supplier.q.id),
+        LEFTJOINOn(None, Transporter,
+                   PurchaseOrder.q.transporterID == Transporter.q.id),
+        LEFTJOINOn(None, Branch,
+                   PurchaseOrder.q.branchID == Branch.q.id),
+        LEFTJOINOn(None, LoginUser,
+                   PurchaseOrder.q.responsibleID == LoginUser.q.id),
 
         LEFTJOINOn(None, Person_Supplier,
-                   PersonAdaptToSupplier.q.originalID == Person_Supplier.q.id),
+                   Supplier.q.personID == Person_Supplier.q.id),
         LEFTJOINOn(None, Person_Transporter,
-                   PersonAdaptToTransporter.q.originalID == Person_Transporter.q.id),
+                   Transporter.q.personID == Person_Transporter.q.id),
         LEFTJOINOn(None, Person_Branch,
-                   PersonAdaptToBranch.q.originalID == Person_Branch.q.id),
+                   Branch.q.personID == Person_Branch.q.id),
        LEFTJOINOn(None, Person_Responsible,
-                   PersonAdaptToUser.q.originalID == Person_Responsible.q.id),
+                   LoginUser.q.personID == Person_Responsible.q.id),
     ]
 
     #
