@@ -32,23 +32,22 @@ from kiwi.python import Settable
 from stoqdrivers.enum import TaxType
 from zope.interface import implements
 
-from stoqlib.database.orm import ForeignKey, UnicodeCol, DateTimeCol, IntCol
+from stoqlib.database.orm import (ForeignKey, UnicodeCol, DateTimeCol, IntCol,
+                                  PriceCol, QuantityCol, MultipleJoin)
 from stoqlib.database.orm import AND, const
-from stoqlib.database.orm import PriceCol, QuantityCol
 from stoqlib.database.orm import Viewable, Alias, LEFTJOINOn, INNERJOINOn
 from stoqlib.database.runtime import (get_current_user,
                                       get_current_branch)
-from stoqlib.domain.base import Domain, ModelAdapter
+from stoqlib.domain.base import Domain
 from stoqlib.domain.event import Event
-from stoqlib.domain.events import SaleStatusChangedEvent, ECFIsLastSaleEvent
+from stoqlib.domain.events import (SaleStatusChangedEvent, ECFIsLastSaleEvent,
+                                   DeliveryStatusChangedEvent)
 from stoqlib.domain.fiscal import FiscalBookEntry
-from stoqlib.domain.interfaces import (IContainer,
-                                       IPaymentTransaction,
-                                       IDelivery, IStorable)
+from stoqlib.domain.interfaces import IContainer, IPaymentTransaction
 from stoqlib.domain.payment.method import PaymentMethod
 from stoqlib.domain.payment.payment import Payment
-from stoqlib.domain.person import (Person, PersonAdaptToClient,
-                                   PersonAdaptToSalesPerson)
+from stoqlib.domain.person import (Person, Client,
+                                   SalesPerson)
 from stoqlib.domain.product import Product, ProductHistory
 from stoqlib.domain.renegotiation import RenegotiationData
 from stoqlib.domain.sellable import Sellable
@@ -57,6 +56,7 @@ from stoqlib.domain.taxes import SaleItemIcms, SaleItemIpi
 from stoqlib.domain.till import Till
 from stoqlib.exceptions import (SellError, DatabaseInconsistency,
                                 StoqlibError)
+from stoqlib.lib.component import Adaptable
 from stoqlib.lib.defaults import quantize
 from stoqlib.lib.parameters import sysparam
 from stoqlib.lib.translation import stoqlib_gettext
@@ -72,15 +72,15 @@ _ = stoqlib_gettext
 class SaleItem(Domain):
     """An item in a sale.
 
-    @param sellable: the kind of item
-    @param sale: the same
-    @param quantity: the quantity of the of sold item in this sale
-    @param price: the price of each individual item
-    @param base_price: original value the *product* had when adding the
+    :param sellable: the kind of item
+    :param sale: the same
+    :param quantity: the quantity of the of sold item in this sale
+    :param price: the price of each individual item
+    :param base_price: original value the *product* had when adding the
                        sale item
-    @param notes:
-    @param estimated_fix_date:
-    @param completion_date:
+    :param notes:
+    :param estimated_fix_date:
+    :param completion_date:
     """
     quantity = QuantityCol()
     base_price = PriceCol()
@@ -88,6 +88,7 @@ class SaleItem(Domain):
     price = PriceCol()
     sale = ForeignKey('Sale')
     sellable = ForeignKey('Sellable')
+    delivery = ForeignKey('Delivery', default=None)
     cfop = ForeignKey('CfopData', default=None)
 
     # This is currently only used by services
@@ -132,13 +133,13 @@ class SaleItem(Domain):
             raise SellError(_(u"%r does not have enough stock to be sold.")
                               % self.sellable.get_description())
 
-        storable = IStorable(self.sellable.product, None)
+        storable = self.sellable.product_storable
         if storable:
             item = storable.decrease_stock(self.quantity, branch)
             self.average_cost = item.stock_cost
 
     def cancel(self, branch):
-        storable = IStorable(self.sellable.product, None)
+        storable = self.sellable.product_storable
         if storable:
             storable.increase_stock(self.quantity, branch)
 
@@ -157,22 +158,6 @@ class SaleItem(Domain):
     def get_quantity_unit_string(self):
         return "%s %s" % (self.quantity, self.sellable.get_unit_description())
 
-    def get_quantity_delivered(self):
-        delivered = Decimal(0)
-        for service in self.sale.services:
-            delivery = IDelivery(service, None)
-            if not delivery:
-                continue
-            item = delivery.get_item_by_sellable(self.sellable)
-            if not item:
-                continue
-            delivered += item.quantity
-
-        return delivered
-
-    def has_been_totally_delivered(self):
-        return self.get_quantity_delivered() == self.quantity
-
     def get_description(self):
         return self.sellable.get_description()
 
@@ -225,113 +210,156 @@ class SaleItem(Domain):
         return self.sale.cfop.code.replace('.', '')
 
 
-class DeliveryItem(Domain):
-    """Class responsible to store all the products for a certain delivery"""
+class Delivery(Domain):
+    """Delivery implementation
 
-    quantity = QuantityCol()
-    sellable = ForeignKey('Sellable')
-    delivery = ForeignKey('SaleItem', default=None)
+    :cvar STATUS_INITIAL: The delivery was created
+    :cvar STATUS_SENT: The delivery was sent to deliver
+    :cvar STATUS_RECEIVED: The delivery was received by the client
+
+    :attribute status: the delivery status
+    :attribute open_date: the date which the delivery was created
+    :attribute deliver_date: the date which the delivery sent to deliver
+    :attribute receive_date: the date which the delivery received by
+        the client
+    :attribute tracking_code: the delivery tracking code
+    :attribute address: the delivery address
+    :attribute transporter: the delivery
+        :class:`stoqlib.domain.person.PersonAdaptToTransporter`
+    :attrribute delivery_items: list of :class:`SaleItem` which will
+        be delivered
+    """
+
+    implements(IContainer)
+
+    (STATUS_INITIAL,
+     STATUS_SENT,
+     STATUS_RECEIVED) = range(3)
+
+    statuses = {STATUS_INITIAL: _("Waiting"),
+                STATUS_SENT: _("Sent"),
+                STATUS_RECEIVED: _("Received")}
+
+    status = IntCol(default=STATUS_INITIAL)
+    open_date = DateTimeCol(default=None)
+    deliver_date = DateTimeCol(default=None)
+    receive_date = DateTimeCol(default=None)
+    tracking_code = UnicodeCol(default='')
+    address = ForeignKey('Address', default=None)
+    transporter = ForeignKey('Transporter', default=None)
+    service_item = ForeignKey('SaleItem', default=None)
+
+    delivery_items = MultipleJoin('SaleItem', joinColumn='delivery_id')
 
     #
-    # Accessors
+    #  Properties
     #
 
-    def get_price(self):
-        return self.sellable.price
+    @property
+    def status_str(self):
+        return self.statuses[self.status]
 
-    def get_total(self):
-        return currency(self.get_price() * self.quantity)
+    @property
+    def address_str(self):
+        if self.address:
+            return self.address.get_address_string()
+        return ''
 
-    @classmethod
-    def create_from_sellable_item(cls, sale_item):
-        if not sale_item.sellable.product:
-            # FIXME: Maybe we should allow delivering services as well.
-            raise SellError(
-                _("It's only possible to deliver products, not %r") % (
-                type(sale_item), ))
-
-        quantity = sale_item.quantity - sale_item.get_quantity_delivered()
-        return cls(connection=sale_item.get_connection(),
-                   sellable=sale_item.sellable,
-                   quantity=quantity)
-
-
-class SaleItemAdaptToDelivery(ModelAdapter):
-    """A service implementation as a delivery facet."""
-
-    implements(IDelivery, IContainer)
-
-    address = UnicodeCol(default='')
+    @property
+    def client_str(self):
+        client = self.service_item.sale.client
+        if client:
+            return client.get_description()
+        return ''
 
     #
-    # IContainer implementation
+    #  Public API
     #
 
-    @argcheck(DeliveryItem)
+    def set_initial(self):
+        self._set_delivery_status(self.STATUS_INITIAL)
+
+    def set_sent(self):
+        self._set_delivery_status(self.STATUS_SENT)
+
+    def set_received(self):
+        self._set_delivery_status(self.STATUS_RECEIVED)
+
+    #
+    #  ORMObject hooks
+    #
+
+    def _create(self, id, **kwargs):
+        if not 'open_date' in kwargs:
+            kwargs['open_date'] = const.NOW()
+
+        super(Delivery, self)._create(id, **kwargs)
+
+    #
+    #  IContainer implementation
+    #
+
+    @argcheck(SaleItem)
     def add_item(self, item):
         item.delivery = self
 
     def get_items(self):
-        return DeliveryItem.selectBy(connection=self.get_connection(),
-                                     delivery=self)
+        return list(self.delivery_items)
 
-    @argcheck(DeliveryItem)
+    @argcheck(SaleItem)
     def remove_item(self, item):
-        DeliveryItem.delete(item.id, connection=item.get_connection())
+        item.delivery = None
 
     #
-    # General methods
+    #  Private
     #
 
-    @argcheck(Sellable)
-    def get_item_by_sellable(self, sellable):
-        return DeliveryItem.selectOneBy(connection=self.get_connection(),
-                                        delivery=self,
-                                        sellable=sellable)
-
-SaleItem.registerFacet(SaleItemAdaptToDelivery, IDelivery)
+    def _set_delivery_status(self, status):
+        old_status = self.status
+        DeliveryStatusChangedEvent.emit(self, old_status)
+        self.status = status
 
 
-class Sale(Domain):
+class Sale(Domain, Adaptable):
     """Sale object implementation.
 
-    @cvar STATUS_INITIAL: The sale is opened, products or other sellable items
+    :cvar STATUS_INITIAL: The sale is opened, products or other sellable items
       might have been added.
-    @cvar STATUS_ORDERED: The sale is orded, it has sellable items but not any
+    :cvar STATUS_ORDERED: The sale is orded, it has sellable items but not any
       payments yet. This state is mainly used when the parameter
       CONFIRM_SALES_AT_TILL is enabled.
-    @cvar STATUS_CONFIRMED: The sale has been confirmed and all payments
+    :cvar STATUS_CONFIRMED: The sale has been confirmed and all payments
       have been registered, but not necessarily paid.
-    @cvar STATUS_CLOSED: All the payments of the sale has been confirmed
+    :cvar STATUS_CLOSED: All the payments of the sale has been confirmed
       and the client does not owe anything to us.
-    @cvar STATUS_CANCELLED: The sale has been canceled, this can only happen
+    :cvar STATUS_CANCELLED: The sale has been canceled, this can only happen
       to an sale which has not yet reached the SALE_CONFIRMED status.
-    @cvar STATUS_RETURNED: The sale has been returned, all the payments made
+    :cvar STATUS_RETURNED: The sale has been returned, all the payments made
       have been canceled and the client has been compensated for
       everything already paid.
-    @cvar CLIENT_INDIVIDUAL: The sale was done by an individual
-    @cvar CLIENT_COMPANY: The sale was done by a company
-    @ivar status: status of the sale
-    @ivar client: who we sold the sale to
-    @ivar salesperson: who sold the sale
-    @ivar branch: branch where the sale was done
-    @ivar till: The Till operation where this sale lives. Note that every
+    :cvar CLIENT_INDIVIDUAL: The sale was done by an individual
+    :cvar CLIENT_COMPANY: The sale was done by a company
+    :attribute status: status of the sale
+    :attribute client: who we sold the sale to
+    :attribute salesperson: who sold the sale
+    :attribute branch: branch where the sale was done
+    :attribute till: The Till operation where this sale lives. Note that every
        sale and payment generated are always in a till operation
        which defines a financial history of a store.
-    @ivar open_date: the date sale was created
-    @ivar close_date: the date sale was closed
-    @ivar confirm_date: the date sale was confirmed
-    @ivar cancel_date: the date sale was cancelled
-    @ivar return_date: the date sale was returned
-    @ivar discount_value:
-    @ivar surcharge_value:
-    @ivar total_amount: the total value of all the items in the same
-    @ivar notes: Some optional additional information related to this sale.
-    @ivar coupon_id: the id of the coupon printed by the ECF.
-    @ivar service_invoice_number:
-    @ivar cfop:
-    @ivar invoice_number: the sale invoice number.
-    @ivar client_category: The L{ClientCategory} that was used for price
+    :attribute open_date: the date sale was created
+    :attribute close_date: the date sale was closed
+    :attribute confirm_date: the date sale was confirmed
+    :attribute cancel_date: the date sale was cancelled
+    :attribute return_date: the date sale was returned
+    :attribute discount_value:
+    :attribute surcharge_value:
+    :attribute total_amount: the total value of all the items in the same
+    :attribute notes: Some optional additional information related to this sale.
+    :attribute coupon_id: the id of the coupon printed by the ECF.
+    :attribute service_invoice_number:
+    :attribute cfop:
+    :attribute invoice_number: the sale invoice number.
+    :attribute client_category: The :class:`ClientCategory` that was used for price
         determination.
     """
 
@@ -371,13 +399,17 @@ class Sale(Domain):
     invoice_number = IntCol(default=None)
     operation_nature = UnicodeCol(default='')
     cfop = ForeignKey("CfopData")
-    client = ForeignKey('PersonAdaptToClient', default=None)
-    salesperson = ForeignKey('PersonAdaptToSalesPerson')
-    branch = ForeignKey('PersonAdaptToBranch', default=None)
-    transporter = ForeignKey('PersonAdaptToTransporter', default=None)
+    client = ForeignKey('Client', default=None)
+    salesperson = ForeignKey('SalesPerson')
+    branch = ForeignKey('Branch', default=None)
+    # FIXME: transporter should only be used on Delivery.
+    transporter = ForeignKey('Transporter', default=None)
     group = ForeignKey('PaymentGroup')
     client_category = ForeignKey('ClientCategory', default=None)
 
+    def __init__(self, *args, **kwargs):
+        self.addFacet(IPaymentTransaction)
+        Domain.__init__(self, *args, **kwargs)
     #
     # ORMObject hooks
     #
@@ -401,7 +433,7 @@ class Sale(Domain):
     @classmethod
     def get_last_confirmed(cls, conn):
         """Fetch the last confirmed sale
-        @param conn: a database connection
+        :param conn: a database connection
         """
         results = cls.select(AND(cls.q.status == cls.STATUS_CONFIRMED,
                                  cls.q.confirm_date != None),
@@ -415,8 +447,8 @@ class Sale(Domain):
         """Returns the last sale invoice number. If there is not an invoice
         number used, the returned value will be zero.
 
-        @param conn: a database connection
-        @returns: an integer representing the last sale invoice number
+        :param conn: a database connection
+        :returns: an integer representing the last sale invoice number
         """
         return cls.select(connection=conn).max('invoice_number') or 0
 
@@ -442,50 +474,50 @@ class Sale(Domain):
 
     def can_order(self):
         """Only newly created sales can be ordered
-        @returns: True if the sale can be ordered, otherwise False
+        :returns: True if the sale can be ordered, otherwise False
         """
         return (self.status == Sale.STATUS_INITIAL or
                 self.status == Sale.STATUS_QUOTE)
 
     def can_confirm(self):
         """Only ordered sales can be confirmed
-        @returns: True if the sale can be confirmed, otherwise False
+        :returns: True if the sale can be confirmed, otherwise False
         """
         return (self.status == Sale.STATUS_ORDERED or
                 self.status == Sale.STATUS_QUOTE)
 
     def can_set_paid(self):
         """Only confirmed sales can be paid
-        @returns: True if the sale can be set as paid, otherwise False
+        :returns: True if the sale can be set as paid, otherwise False
         """
         return self.status == Sale.STATUS_CONFIRMED
 
     def can_set_not_paid(self):
         """Only confirmed sales can be paid
-        @returns: True if the sale can be set as paid, otherwise False
+        :returns: True if the sale can be set as paid, otherwise False
         """
         return self.status == Sale.STATUS_PAID
 
     def can_set_renegotiated(self):
         """Only sales with status confirmed can be renegotiated.
-        @returns: True if the sale can be renegotiated, False otherwise.
+        :returns: True if the sale can be renegotiated, False otherwise.
         """
         # This should be as simple as:
         # return self.status == Sale.STATUS_CONFIRMED
         # But due to bug 3890 we have to check every payment.
-        return any([payment.status == Payment.STATUS_PENDING
-                    for payment in self.payments])
+        return self.payments.filterBy(
+            status=Payment.STATUS_PENDING).count() > 0
 
     def can_cancel(self):
         """Only ordered, confirmed, paid and quoting sales can be cancelled.
-        @returns: True if the sale can be cancelled, otherwise False
+        :returns: True if the sale can be cancelled, otherwise False
         """
         return self.status in (Sale.STATUS_CONFIRMED, Sale.STATUS_PAID,
                                Sale.STATUS_ORDERED, Sale.STATUS_QUOTE)
 
     def can_return(self):
         """Only confirmed or paid sales can be returned
-        @returns: True if the sale can be returned, otherwise False
+        :returns: True if the sale can be returned, otherwise False
         """
         return (self.status == Sale.STATUS_CONFIRMED or
                 self.status == Sale.STATUS_PAID)
@@ -537,8 +569,7 @@ class Sale(Domain):
         self._set_sale_status(Sale.STATUS_CONFIRMED)
 
         # do not log money payments twice
-        if not all(payment.method.method_name == 'money'
-                   for payment in self.group.payments):
+        if not self.only_paid_with_money():
             if self.client:
                 msg = _("Sale {sale_number} to client {client_name} was "
                         "confirmed with value {total_value:.2f}.").format(
@@ -558,7 +589,7 @@ class Sale(Domain):
         """
         assert self.can_set_paid()
 
-        for payment in self.group.payments:
+        for payment in self.payments:
             if not payment.is_paid():
                 raise StoqlibError(
                     _("You cannot close a sale without paying all the payment. "
@@ -570,8 +601,7 @@ class Sale(Domain):
         self.close_date = const.NOW()
         self._set_sale_status(Sale.STATUS_PAID)
 
-        if all(payment.method.method_name == 'money'
-                for payment in self.group.payments):
+        if self.only_paid_with_money():
             # Money payments are confirmed and paid, so lof them that way
             if self.client:
                 msg = _("Sale {sale_number} to client {client_name} was paid "
@@ -641,8 +671,8 @@ class Sale(Domain):
         A renegotiation object needs to be supplied which
         contains the invoice number and the eventual penalty
 
-        @param renegotiation: renegotiation information
-        @type renegotiation: L{RenegotiationData}
+        :param renegotiation: renegotiation information
+        :type renegotiation: :class:`RenegotiationData`
         """
         assert self.can_return()
 
@@ -679,7 +709,7 @@ class Sale(Domain):
             Sale total = Sum(product and service prices) + surcharge +
                              interest - discount
 
-        @returns: the total value
+        :returns: the total value
         """
         surcharge_value = self.surcharge_value or Decimal(0)
         discount_value = self.discount_value or Decimal(0)
@@ -690,7 +720,7 @@ class Sale(Domain):
     def get_sale_subtotal(self):
         """Fetch the subtotal for the sale, eg the sum of the
         prices for of all items
-        @returns: subtotal
+        :returns: subtotal
         """
         total = 0
         for i in self.get_items():
@@ -700,7 +730,7 @@ class Sale(Domain):
 
     def get_items_total_quantity(self):
         """Fetches the total number of items in the sale
-        @returns: number of items
+        :returns: number of items
         """
         return self.get_items().sum('quantity') or Decimal(0)
 
@@ -708,7 +738,7 @@ class Sale(Domain):
         """Returns the sale details. The details are composed by the sale
         notes, the items notes, the delivery address and the estimated fix
         date.
-        @returns: the sale details string.
+        :returns: the sale details string.
         """
         details = []
         if self.notes:
@@ -716,9 +746,13 @@ class Sale(Domain):
         delivery_added = False
         for sale_item in self.get_items():
             if delivery_added is False:
-                delivery = IDelivery(sale_item, None)
+                # FIXME: Add the delivery info just once can lead to an error.
+                #        It's possible that some item went to delivery X while
+                #        some went to delivery Y.
+                delivery = sale_item.delivery
             if delivery is not None:
-                details.append(_('Delivery Address: %s') % delivery.address)
+                details.append(_('Delivery Address: %s') %
+                               delivery.address.get_address_string())
                 # At the moment, we just support only one delivery per sale.
                 delivery_added = True
                 delivery = None
@@ -746,8 +780,8 @@ class Sale(Domain):
     def get_client_role(self):
         """Fetches the client role
 
-        @returns: the client role (a PersonAdaptToIndividual or a
-        PersonAdaptToCompany) instance or None if the sale haven't a client.
+        :returns: the client role (a Individual or a
+        Company) instance or None if the sale haven't a client.
         """
         if not self.client:
             return None
@@ -763,24 +797,23 @@ class Sale(Domain):
 
     def only_paid_with_money(self):
         """Find out if the sale is paid using money
-        @returns: True if the sale was paid with money, otherwise False
-        @rtype: bool
+        :returns: True if the sale was paid with money, otherwise False
+        :rtype: bool
         """
-        for payment in self.group.payments:
-            if payment.method.method_name != 'money':
-                return False
-        return True
+        if not self.payments:
+            return False
+        return all(payment.is_money() for payment in self.payments)
 
     def pay_money_payments(self):
-        for payment in self.group.payments:
-            if payment.method.method_name == 'money':
+        for payment in self.payments:
+            if payment.is_money():
                 payment.pay()
 
     def add_sellable(self, sellable, quantity=1, price=None):
         """Adds a new sellable item to a sale
-        @param sellable: the sellable
-        @param quantity: quantity to add, defaults to 1
-        @param price: optional, the price, it not set the price
+        :param sellable: the sellable
+        :param quantity: quantity to add, defaults to 1
+        :param price: optional, the price, it not set the price
           from the sellable will be used
         """
         price = price or sellable.price
@@ -825,8 +858,15 @@ class Sale(Domain):
 
     @property
     def payments(self):
-        return Payment.selectBy(group=self.group,
-                                connection=self.get_connection())
+        """Returns all valid payments for this sale
+
+        This will return a list of valid payments for this sale, that
+        is, all payments on the payment group that were not cancelled.
+        If you need to get the cancelled too, use self.group.payments.
+
+        :returns: a list of :class:`stoqlib.domain.payment.payment.Payment`
+        """
+        return self.group.get_valid_payments()
 
     def _get_discount_by_percentage(self):
         discount_value = self.discount_value
@@ -982,7 +1022,7 @@ class SaleAdaptToPaymentTransaction(object):
             till.add_entry(payment)
 
         # FIXME: Move this to a payment method specific hook
-        if payments.count() == 1 and payment.method.method_name == 'money':
+        if payments.count() == 1 and payment.is_money():
             self.sale.group.pay()
             self.pay()
 
@@ -994,7 +1034,7 @@ class SaleAdaptToPaymentTransaction(object):
         from stoqlib.domain.commission import Commission
 
         nitems = 0
-        for item in self.sale.group.payments:
+        for item in self.sale.payments:
             if not item.is_outpayment():
                 nitems += 1
 
@@ -1040,11 +1080,10 @@ class SaleAdaptToPaymentTransaction(object):
             return
 
         money = PaymentMethod.get_by_name(conn, 'money')
-        out_payment = money.create_outpayment(
+        payment = money.create_outpayment(
             self.sale.group, paid_value,
             description=_('%s Money Returned for Sale %d') % (
             '1/1', self.sale.id), till=till)
-        payment = out_payment.get_adapted()
         payment.set_pending()
         payment.pay()
         self._restore_commission(payment)
@@ -1068,7 +1107,7 @@ class SaleAdaptToPaymentTransaction(object):
         """A Brazil-specific method
         Calculates the icms total value
 
-        @param av_difference: the average difference for the sale items.
+        :param av_difference: the average difference for the sale items.
                               it means the average discount or surcharge
                               applied over all sale items
         """
@@ -1088,7 +1127,7 @@ class SaleAdaptToPaymentTransaction(object):
         """A Brazil-specific method
         Calculates the iss total value
 
-        @param av_difference: the average difference for the sale items.
+        :param av_difference: the average difference for the sale items.
                               it means the average discount or surcharge
                               applied over all sale items
         """
@@ -1157,23 +1196,23 @@ Sale.registerFacet(SaleAdaptToPaymentTransaction, IPaymentTransaction)
 class SaleView(Viewable):
     """Stores general informatios about sales
 
-    @cvar id: the id of the sale table
-    @cvar coupon_id: the id generated by the fiscal printer
-    @cvar open_date: the date when the sale was started
-    @cvar confirm_date: the date when the sale was confirmed
-    @cvar close_date: the date when the sale was closed
-    @cvar cancel_date: the date when the sale was cancelled
-    @cvar notes: sale order general notes
-    @cvar status: the sale status
-    @cvar salesperson_name: the salesperson name
-    @cvar client_name: the sale client name
-    @cvar client_id: the if of the client table
-    @cvar subtotal: the sum of all items in the sale
-    @cvar surcharge_value: the sale surcharge value
-    @cvar discount_value: the sale discount value
-    @cvar total: the subtotal - discount + charge
-    @cvar total_quantity: the items total quantity for the sale
-    @cvar invoice_number: the sale invoice number
+    :cvar id: the id of the sale table
+    :cvar coupon_id: the id generated by the fiscal printer
+    :cvar open_date: the date when the sale was started
+    :cvar confirm_date: the date when the sale was confirmed
+    :cvar close_date: the date when the sale was closed
+    :cvar cancel_date: the date when the sale was cancelled
+    :cvar notes: sale order general notes
+    :cvar status: the sale status
+    :cvar salesperson_name: the salesperson name
+    :cvar client_name: the sale client name
+    :cvar client_id: the if of the client table
+    :cvar subtotal: the sum of all items in the sale
+    :cvar surcharge_value: the sale surcharge value
+    :cvar discount_value: the sale discount value
+    :cvar total: the subtotal - discount + charge
+    :cvar total_quantity: the items total quantity for the sale
+    :cvar invoice_number: the sale invoice number
     """
 
     Person_Client = Alias(Person, 'person_client')
@@ -1193,7 +1232,7 @@ class SaleView(Viewable):
         notes=Sale.q.notes,
         surcharge_value=Sale.q.surcharge_value,
         discount_value=Sale.q.discount_value,
-        client_id=Sale.q.clientID,
+        client_id=Client.q.id,
         salesperson_name=Person_SalesPerson.q.name,
         client_name=Person_Client.q.name,
         v_ipi=const.SUM(SaleItemIpi.q.v_ipi),
@@ -1207,15 +1246,15 @@ class SaleView(Viewable):
         INNERJOINOn(None, SaleItem,
                     Sale.q.id == SaleItem.q.saleID),
 
-        LEFTJOINOn(None, PersonAdaptToClient,
-                   Sale.q.clientID == PersonAdaptToClient.q.id),
-        LEFTJOINOn(None, PersonAdaptToSalesPerson,
-                   Sale.q.salespersonID == PersonAdaptToSalesPerson.q.id),
+        LEFTJOINOn(None, Client,
+                   Sale.q.clientID == Client.q.id),
+        LEFTJOINOn(None, SalesPerson,
+                   Sale.q.salespersonID == SalesPerson.q.id),
 
         LEFTJOINOn(None, Person_Client,
-                   PersonAdaptToClient.q.originalID == Person_Client.q.id),
+                   Client.q.personID == Person_Client.q.id),
         LEFTJOINOn(None, Person_SalesPerson,
-                   PersonAdaptToSalesPerson.q.originalID == Person_SalesPerson.q.id),
+                   SalesPerson.q.personID == Person_SalesPerson.q.id),
 
         LEFTJOINOn(None, SaleItemIpi,
                    SaleItemIpi.q.id == SaleItem.q.ipi_infoID),
@@ -1245,6 +1284,12 @@ class SaleView(Viewable):
         return self.status in (Sale.STATUS_CONFIRMED, Sale.STATUS_PAID,
                                Sale.STATUS_ORDERED, Sale.STATUS_QUOTE)
 
+    def get_surcharge_value(self):
+        return currency(self.surcharge_value or 0)
+
+    def get_discount_value(self):
+        return currency(self.discount_value or 0)
+
     def get_subtotal(self):
         if self.v_ipi is not None:
             return currency(self.subtotal + self.v_ipi)
@@ -1273,49 +1318,6 @@ class SaleView(Viewable):
         return Sale.get_status_name(self.status)
 
 
-class DeliveryView(Viewable):
-    """Stores general informatios items that will be delivered.
-
-    @cvar id: the id of the sale item
-    @cvar sale_id: the id of the sale
-    @cvar quantity: the quantity of items that will be delivered
-    @cvar price: the sale item price
-    @cvar notes: sale item notes
-    @cvar estimated_fix_date: the estimated delivery date
-    @cvar completion_date: the real delivery date
-    @cvar address: the address where the item should be delivered
-    @cvar description: the sale item description
-    @cvar client_name: the sale client name
-    """
-
-    columns = dict(
-        id=SaleItem.q.id,
-        sale_id=SaleItem.q.saleID,
-        quantity=SaleItem.q.quantity,
-        price=SaleItem.q.price,
-        notes=SaleItem.q.notes,
-        estimated_fix_date=SaleItem.q.estimated_fix_date,
-        completion_date=SaleItem.q.completion_date,
-        address=SaleItemAdaptToDelivery.q.address,
-        description=Sellable.q.description,
-        client_name=Person.q.name,
-    )
-
-    joins = [LEFTJOINOn(None, Sellable,
-                        SaleItem.q.sellableID == Sellable.q.id),
-             LEFTJOINOn(None, DeliveryItem,
-                        Sellable.q.id == DeliveryItem.q.sellableID),
-             LEFTJOINOn(None, Sale, SaleItem.q.saleID == Sale.q.id),
-             LEFTJOINOn(None, PersonAdaptToClient,
-                        Sale.q.clientID == PersonAdaptToClient.q.id),
-             LEFTJOINOn(None, Person,
-                        PersonAdaptToClient.q.originalID == Person.q.id),
-    ]
-
-    clause = AND(SaleItemAdaptToDelivery.q.originalID == SaleItem.q.id,
-                 SaleItemAdaptToDelivery.q.id == DeliveryItem.q.deliveryID, )
-
-
 class SoldSellableView(Viewable):
     Person_Client = Alias(Person, 'person_client')
     Person_SalesPerson = Alias(Person, 'person_sales_person')
@@ -1336,15 +1338,15 @@ class SoldSellableView(Viewable):
                     SaleItem.q.sellableID == Sellable.q.id),
         LEFTJOINOn(None, Sale,
                     Sale.q.id == SaleItem.q.saleID),
-        LEFTJOINOn(None, PersonAdaptToClient,
-                   Sale.q.clientID == PersonAdaptToClient.q.id),
-        LEFTJOINOn(None, PersonAdaptToSalesPerson,
-                   Sale.q.salespersonID == PersonAdaptToSalesPerson.q.id),
+        LEFTJOINOn(None, Client,
+                   Sale.q.clientID == Client.q.id),
+        LEFTJOINOn(None, SalesPerson,
+                   Sale.q.salespersonID == SalesPerson.q.id),
 
         LEFTJOINOn(None, Person_Client,
-                   PersonAdaptToClient.q.originalID == Person_Client.q.id),
+                   Client.q.personID == Person_Client.q.id),
         LEFTJOINOn(None, Person_SalesPerson,
-                   PersonAdaptToSalesPerson.q.originalID == Person_SalesPerson.q.id),
+                   SalesPerson.q.personID == Person_SalesPerson.q.id),
 
         LEFTJOINOn(None, SaleItemIpi,
                    SaleItemIpi.q.id == SaleItem.q.ipi_infoID),
