@@ -25,11 +25,12 @@
 
 from zope.interface import implements
 
-from stoqlib.database.orm import BLOBCol
 from stoqlib.database.orm import ForeignKey
 from stoqlib.database.orm import INNERJOINOn, LEFTJOINOn
 from stoqlib.database.orm import Viewable
 from stoqlib.domain.base import Domain
+from stoqlib.domain.events import (ServiceCreateEvent, ServiceEditEvent,
+                                   ServiceRemoveEvent)
 from stoqlib.domain.interfaces import IDescribable
 from stoqlib.domain.sellable import (Sellable,
                                      SellableUnit, SellableCategory)
@@ -49,7 +50,6 @@ class Service(Domain):
 
     implements(IDescribable)
 
-    image = BLOBCol(default='')
     sellable = ForeignKey('Sellable')
 
     def remove(self):
@@ -85,6 +85,28 @@ class Service(Domain):
     def get_description(self):
         return self.sellable.get_description()
 
+    #
+    # Domain hooks
+    #
+
+    def on_create(self):
+        ServiceCreateEvent.emit(self)
+
+    def on_delete(self):
+        ServiceRemoveEvent.emit(self)
+
+    def on_update(self):
+        trans = self.get_connection()
+        emitted_trans_list = getattr(self, '_emitted_trans_list', set())
+
+        # Since other classes can propagate this event (like Sellable),
+        # emit the event only once for each transaction.
+        if not trans in emitted_trans_list:
+            ServiceEditEvent.emit(self)
+            emitted_trans_list.add(trans)
+
+        self._emitted_trans_list = emitted_trans_list
+
 
 #
 # Views
