@@ -29,10 +29,11 @@ from decimal import Decimal
 import os
 import sys
 
+import stoqlib
 from stoqlib.database.runtime import get_current_branch
 from stoqlib.domain.address import Address, CityLocation
-from stoqlib.domain.interfaces import IStorable, ICompany
 from stoqlib.domain.payment.method import PaymentMethod
+from stoqlib.domain.product import Storable
 from stoqlib.domain.test.domaintest import DomainTest
 from stoqlib.exceptions import ModelDataError
 from stoqlib.lib import test
@@ -40,7 +41,8 @@ from stoqlib.lib.diffutils import diff_files
 from stoqlib.lib.pluginmanager import get_plugin_manager
 
 # This test should be inside plugins/nfe, but it's not reachable there
-sys.path.append('plugins/nfe')
+sys.path.append(os.path.join(os.path.dirname(stoqlib.__file__), '..',
+    'plugins', 'nfe'))
 from nfegenerator import NFeGenerator, remove_accentuation, NFeIdentification
 
 
@@ -89,7 +91,7 @@ class TestNfeGenerator(DomainTest):
 
     def test_invalid_cnpj(self):
         sale = self._create_sale(2666, 2345, 5432)
-        company = ICompany(sale.branch.person)
+        company = sale.branch.person.company
         company.cnpj = '123.321.678/4567-90'
 
         generator = NFeGenerator(sale, self.trans)
@@ -105,14 +107,14 @@ class TestNfeGenerator(DomainTest):
         # [2] - Price
         # [3] - Quantity
         for data in [("Laranja", "1", Decimal(1), Decimal(10)),
-                     ("Limão", "2", Decimal(0.5), Decimal(15)),
+                     ("Limão", "2", Decimal('0.5'), Decimal(15)),
                      ("Abacaxi", "3", Decimal(3), Decimal(1)),
-                     ("Cenoura", "4", Decimal(1.5), Decimal(6)),
-                     ("Pêssego", "5", Decimal(3.5), Decimal(3))]:
+                     ("Cenoura", "4", Decimal('1.5'), Decimal(6)),
+                     ("Pêssego", "5", Decimal('3.5'), Decimal(3))]:
             sellable = self._create_sellable(data[0], data[1], data[2])
 
-            storable = sellable.product.addFacet(IStorable,
-                                                 connection=self.trans)
+            storable = Storable(product=sellable.product,
+                                connection=self.trans)
             storable.increase_stock(data[3], get_current_branch(self.trans))
 
             sale.add_sellable(sellable, data[3])
@@ -125,12 +127,12 @@ class TestNfeGenerator(DomainTest):
         sale.order()
 
         method = PaymentMethod.get_by_name(self.trans, 'money')
-        ipayment = method.create_inpayment(sale.group,
+        payment = method.create_inpayment(sale.group,
                                            sale.get_sale_subtotal(),
                                            due_date=due_date)
         sale.confirm()
         # Workaround to avoid differences on nfe because of id
-        ipayment.payment.id = payment_id
+        payment.id = payment_id
 
         return sale
 
