@@ -27,31 +27,19 @@ import datetime
 
 from kiwi.datatypes import currency
 
-from stoqlib.database.orm import ORMObjectMoreThanOneResultError, AND
-from stoqlib.domain.account import BankAccount
+from stoqlib.database.orm import ORMObjectIntegrityError, AND
 from stoqlib.domain.person import Calls, Liaison
 from stoqlib.domain.address import Address, CityLocation
 from stoqlib.domain.exampledata import ExampleCreator
 from stoqlib.domain.fiscal import CfopData
-from stoqlib.domain.interfaces import (IIndividual, ICompany, IClient,
-                                       ITransporter, ISupplier,
-                                       ICreditProvider, IEmployee,
-                                       IUser, IBranch, ISalesPerson)
-from stoqlib.domain.person import (Person,
-                                   EmployeeRole, WorkPermitData,
-                                   MilitaryData, VoterData,
-                                   PersonAdaptToClient,
-                                   PersonAdaptToBranch,
-                                   PersonAdaptToSalesPerson,
-                                   PersonAdaptToSupplier,
-                                   PersonAdaptToEmployee,
-                                   PersonAdaptToUser,
-                                   EmployeeRoleHistory,
-                                   PersonAdaptToCreditProvider,
-                                   PersonAdaptToTransporter)
+from stoqlib.domain.person import (Branch, Client, ClientCategory, Company,
+                                   CreditProvider, Employee, EmployeeRole,
+                                   EmployeeRoleHistory, Individual,
+                                   LoginUser, Person, SalesPerson, Supplier,
+                                   Transporter)
 from stoqlib.domain.product import Product
-from stoqlib.domain.profile import UserProfile
 from stoqlib.domain.purchase import PurchaseOrder
+from stoqlib.domain.sellable import ClientCategoryPrice
 from stoqlib.domain.test.domaintest import DomainTest
 from stoqlib.lib.translation import stoqlib_gettext
 
@@ -119,137 +107,6 @@ class TestPerson(DomainTest):
         self.assertEquals(person.get_address_string(), _(u'%s %s, %s') % (
             address.street, address.streetnumber, address.district))
 
-    #This method is used by test_check_individual_or_company_facets() method
-    def _check_has_individual_or_company_facets(self, person):
-        try:
-            person._check_individual_or_company_facets()
-        # yuck.
-        except TypeError:
-            return False
-        else:
-            return True
-
-    def testCheckIndividualOrCompanyFacets(self):
-        #First Person testcase without facets
-        person = self.create_person()
-        assert not self._check_has_individual_or_company_facets(person)
-
-        #Second Person testcase with an individual facet
-        person = self.create_person()
-        assert not self._check_has_individual_or_company_facets(person)
-        person.addFacet(IIndividual, connection=self.trans)
-        assert self._check_has_individual_or_company_facets(person)
-
-        #Third Person testcase with 2 primordial facets
-        person.addFacet(ICompany, connection=self.trans)
-        assert self._check_has_individual_or_company_facets(person)
-
-        #Fourth Person testcase with company facet
-        company = self.create_person()
-        assert not self._check_has_individual_or_company_facets(company)
-        company.addFacet(ICompany, connection=self.trans)
-        assert self._check_has_individual_or_company_facets(company)
-
-    def _check_create_facet_fails(self, person, iface, **kwargs):
-        try:
-            person.addFacet(iface, connection=self.trans, **kwargs)
-        # yuck.
-        except (TypeError, ValueError):
-            # Ok, it should actually fail since we did not create an
-            # individual or company facets
-            return True
-        else:
-            return False
-
-    def testFacetIClientAdd(self):
-        person = self.create_person()
-        assert self._check_create_facet_fails(person, IClient)
-        assert not self._check_create_facet_fails(person, IIndividual)
-        assert not self._check_create_facet_fails(person, IClient)
-        assert not self._check_create_facet_fails(person, ICompany)
-
-    def testFacetITransporterAdd(self):
-        person = self.create_person()
-        assert self._check_create_facet_fails(person, ITransporter)
-        assert not self._check_create_facet_fails(person, ICompany)
-        assert not self._check_create_facet_fails(person, ITransporter)
-        assert not self._check_create_facet_fails(person, IIndividual)
-
-    def testFacetISupplierAdd(self):
-        person = self.create_person()
-        assert self._check_create_facet_fails(person, ISupplier)
-        assert not self._check_create_facet_fails(person, IIndividual)
-        assert not self._check_create_facet_fails(person, ISupplier)
-        assert not self._check_create_facet_fails(person, ICompany)
-
-    def testFacetICreditProviderAdd(self):
-        person = self.create_person()
-        short_name = 'Credicard'
-        date = datetime.date(2006, 06, 01)
-        assert self._check_create_facet_fails(person, ICreditProvider,
-                                              short_name=short_name,
-                                              open_contract_date=date)
-        assert not self._check_create_facet_fails(person, ICompany)
-        assert not self._check_create_facet_fails(person, ICreditProvider,
-                                                  short_name=short_name,
-                                                  open_contract_date=date)
-        assert not self._check_create_facet_fails(person, IIndividual)
-
-    def testFacetIEmployeeAdd(self, **kwargs):
-        person = self.create_person()
-        assert self._check_create_facet_fails(person, IEmployee)
-        assert not self._check_create_facet_fails(person, IIndividual)
-        role = EmployeeRole(connection=self.trans, name='Escriba')
-        workpermit_data = WorkPermitData(connection=self.trans)
-        military_data = MilitaryData(connection=self.trans)
-        voter_data = VoterData(connection=self.trans)
-        bank_account = BankAccount(connection=self.trans, bank_number=1,
-                bank_account=' ', bank_branch=' ')
-        assert not self._check_create_facet_fails(person, IEmployee,
-                                                  role=role,
-                                                  workpermit_data=workpermit_data,
-                                                  military_data=military_data,
-                                                  voter_data=voter_data,
-                                                  bank_account=bank_account)
-        assert not self._check_create_facet_fails(person, ICompany)
-
-    def testFacetIUserAdd(self, **kwargs):
-        person = self.create_person()
-        assert self._check_create_facet_fails(person, IUser)
-        assert not self._check_create_facet_fails(person, IIndividual)
-        profile = UserProfile(name='profile', connection=self.trans)
-        assert not self._check_create_facet_fails(person, IUser,
-                                                  username='User',
-                                                  password='pass',
-                                                  profile=profile)
-        assert not self._check_create_facet_fails(person, ICompany)
-
-    def testFacetIBranchAdd(self, **kwargs):
-        person = self.create_person()
-        assert self._check_create_facet_fails(person, IBranch)
-        assert not self._check_create_facet_fails(person, ICompany)
-        assert not self._check_create_facet_fails(person, IBranch)
-        assert not self._check_create_facet_fails(person, IIndividual)
-
-    def testFacetISalesPersonAdd(self, **kwargs):
-        person = self.create_person()
-        assert self._check_create_facet_fails(person, ISalesPerson)
-        assert not self._check_create_facet_fails(person, IIndividual)
-        assert self._check_create_facet_fails(person, ISalesPerson)
-        role = EmployeeRole(connection=self.trans, name='Escrivaum')
-        workpermit_data = WorkPermitData(connection=self.trans)
-        military_data = MilitaryData(connection=self.trans)
-        voter_data = VoterData(connection=self.trans)
-        bank_account = BankAccount(connection=self.trans, bank_number=1,
-                bank_account=' ', bank_branch=' ')
-        assert not self._check_create_facet_fails(person, IEmployee,
-                                                  role=role,
-                                                  workpermit_data=workpermit_data,
-                                                  military_data=military_data,
-                                                  voter_data=voter_data,
-                                                  bank_account=bank_account)
-        assert not self._check_create_facet_fails(person, ICompany)
-
     def testGetPhoneNumberNumber(self):
         person = self.create_person()
         person.phone_number = '0321-12345'
@@ -310,11 +167,11 @@ class _PersonFacetTest(object):
 
 
 class TestIndividual(_PersonFacetTest, DomainTest):
-    facet = Person.getAdapterClass(IIndividual)
+    facet = Individual
 
     def testIndividual(self):
         person = self.create_person()
-        individual = person.addFacet(IIndividual, connection=self.trans)
+        individual = Individual(person=person, connection=self.trans)
 
         statuses = individual.get_marital_statuses()
         self.assertEqual(type(statuses), list)
@@ -332,7 +189,7 @@ class TestIndividual(_PersonFacetTest, DomainTest):
 
 
 class TestCompany(_PersonFacetTest, DomainTest):
-    facet = Person.getAdapterClass(ICompany)
+    facet = Company
 
     def testGetCnpjNumberNumber(self):
         company = self.create_company()
@@ -341,7 +198,7 @@ class TestCompany(_PersonFacetTest, DomainTest):
 
 
 class TestClient(_PersonFacetTest, DomainTest):
-    facet = PersonAdaptToClient
+    facet = Client
 
     def testGetname(self):
         client = self.create_client()
@@ -355,7 +212,7 @@ class TestClient(_PersonFacetTest, DomainTest):
         self.assertEquals(client.get_status_string(), status)
 
     def testGetactiveClients(self):
-        table = PersonAdaptToClient
+        table = Client
         active_clients = table.get_active_clients(self.trans).count()
         client = self.create_client()
         client.status = table.STATUS_SOLVENT
@@ -363,13 +220,13 @@ class TestClient(_PersonFacetTest, DomainTest):
         self.assertEquals(active_clients + 1, one_more_active_client)
 
     def testGetclient_sales(self):
-        client = PersonAdaptToClient.select(connection=self.trans)
+        client = Client.select(connection=self.trans)
         assert client
         client = client[0]
         CfopData(code='123', description='bla', connection=self.trans)
-        branches = PersonAdaptToBranch.select(connection=self.trans)
+        branches = Branch.select(connection=self.trans)
         assert branches
-        people = PersonAdaptToSalesPerson.select(connection=self.trans)
+        people = SalesPerson.select(connection=self.trans)
         assert people
         count_sales = client.get_client_sales().count()
         sale = self.create_sale()
@@ -381,18 +238,38 @@ class TestClient(_PersonFacetTest, DomainTest):
         one_more_sale = client.get_client_sales().count()
         self.assertEquals(count_sales + 1, one_more_sale)
 
+    def testClientCategory(self):
+        categories = ClientCategory.selectBy(name='Category',
+                                             connection=self.trans)
+        self.assertEquals(categories.count(), 0)
+
+        category = self.create_client_category('Category')
+        self.assertEquals(categories.count(), 1)
+
+        self.assertTrue(category.can_remove())
+        category.remove()
+        self.assertEquals(categories.count(), 0)
+
+        sellable = self.create_sellable(price=50)
+        category = self.create_client_category('Category')
+        ClientCategoryPrice(sellable=sellable,
+                            category=category,
+                            price=75,
+                            connection=self.trans)
+        self.assertFalse(category.can_remove())
+
 
 class TestSupplier(_PersonFacetTest, DomainTest):
-    facet = PersonAdaptToSupplier
+    facet = Supplier
 
     def testGetActiveSuppliers(self):
-        for supplier in PersonAdaptToSupplier.get_active_suppliers(self.trans):
+        for supplier in Supplier.get_active_suppliers(self.trans):
             self.assertEquals(supplier.status,
-                              PersonAdaptToSupplier.STATUS_ACTIVE)
+                              Supplier.STATUS_ACTIVE)
 
     def testGetAllSuppliers(self):
         query = AND(Person.q.name == "test",
-                    PersonAdaptToSupplier.q.originalID == Person.q.id)
+                    Supplier.q.personID == Person.q.id)
 
         suppliers = Person.select(query, connection=self.trans)
         self.assertEqual(suppliers.count(), 0)
@@ -419,7 +296,7 @@ class TestSupplier(_PersonFacetTest, DomainTest):
 
 
 class TestEmployee(_PersonFacetTest, DomainTest):
-    facet = PersonAdaptToEmployee
+    facet = Employee
 
     def testRoleHistory(self):
         #this test depends bug 2457
@@ -449,7 +326,8 @@ class TestEmployee(_PersonFacetTest, DomainTest):
                             employee=employee,
                             connection=self.trans,
                             salary=currency(320))
-        self.assertRaises(ORMObjectMoreThanOneResultError, employee.get_active_role_history)
+        self.assertRaises(ORMObjectIntegrityError,
+                          employee.get_active_role_history)
 
         #now with one employeerolehistory
         #FIXME: this breaks in buildbot, figure out why.
@@ -458,10 +336,10 @@ class TestEmployee(_PersonFacetTest, DomainTest):
 
 
 class TestUser(_PersonFacetTest, DomainTest):
-    facet = PersonAdaptToUser
+    facet = LoginUser
 
     def testGetstatusStr(self):
-        users = PersonAdaptToUser.select(connection=self.trans)
+        users = LoginUser.select(connection=self.trans)
         assert users
         user = users[0]
         user.is_active = False
@@ -470,10 +348,10 @@ class TestUser(_PersonFacetTest, DomainTest):
 
 
 class TestBranch(_PersonFacetTest, DomainTest):
-    facet = PersonAdaptToBranch
+    facet = Branch
 
     def testGetstatusStr(self):
-        branches = PersonAdaptToBranch.select(connection=self.trans)
+        branches = Branch.select(connection=self.trans)
         assert branches
         branch = branches[0]
         branch.is_active = False
@@ -482,19 +360,19 @@ class TestBranch(_PersonFacetTest, DomainTest):
 
     def testGetactiveBranches(self):
         person = self.create_person()
-        person.addFacet(ICompany, connection=self.trans)
-        count = PersonAdaptToBranch.get_active_branches(self.trans).count()
+        Company(person=person, connection=self.trans)
+        count = Branch.get_active_branches(self.trans).count()
         manager = self.create_employee()
-        branch = person.addFacet(IBranch, connection=self.trans,
-                                 manager=manager, is_active=True)
+        branch = Branch(person=person, connection=self.trans,
+                        manager=manager, is_active=True)
         assert branch.get_active_branches(self.trans).count() == count + 1
 
 
 class TestCreditProvider(_PersonFacetTest, DomainTest):
-    facet = PersonAdaptToCreditProvider
+    facet = CreditProvider
 
     def testGetCardProviders(self):
-        count = PersonAdaptToCreditProvider.get_card_providers(self.trans).count()
+        count = CreditProvider.get_card_providers(self.trans).count()
         facet = self._create_person_facet()
         self.assertEqual(facet.get_card_providers(self.trans).count(),
                          count + 1)
@@ -502,10 +380,10 @@ class TestCreditProvider(_PersonFacetTest, DomainTest):
 
 class SalesPersonTest(_PersonFacetTest, DomainTest):
 
-    facet = PersonAdaptToSalesPerson
+    facet = SalesPerson
 
     def testGetactiveSalespersons(self):
-        count = PersonAdaptToSalesPerson.get_active_salespersons(self.trans).count()
+        count = SalesPerson.get_active_salespersons(self.trans).count()
         salesperson = self.create_sales_person()
         one_more = salesperson.get_active_salespersons(self.trans).count()
         assert count + 1 == one_more
@@ -518,7 +396,7 @@ class SalesPersonTest(_PersonFacetTest, DomainTest):
 
 class TransporterTest(_PersonFacetTest, DomainTest):
 
-    facet = PersonAdaptToTransporter
+    facet = Transporter
 
     def testGetStatusString(self):
         transporter = self.create_transporter()
@@ -526,7 +404,7 @@ class TransporterTest(_PersonFacetTest, DomainTest):
         self.assertEquals(string, _(u'Active'))
 
     def testGetActiveTransporters(self):
-        count = PersonAdaptToTransporter.get_active_transporters(self.trans).count()
+        count = Transporter.get_active_transporters(self.trans).count()
         transporter = self.create_transporter()
         one_more = transporter.get_active_transporters(self.trans).count()
         self.assertEqual(count + 1, one_more)
