@@ -27,9 +27,9 @@ from decimal import Decimal
 from kiwi.datatypes import currency
 
 from stoqlib.database.runtime import get_current_branch
+from stoqlib.domain.product import Storable
 from stoqlib.domain.sellable import (Sellable,
                                      SellableCategory, ClientCategoryPrice)
-from stoqlib.domain.interfaces import IStorable
 from stoqlib.domain.sale import Sale
 from stoqlib.domain.test.domaintest import DomainTest
 from stoqlib.domain.views import (ProductFullStockView,
@@ -41,22 +41,26 @@ from stoqlib.lib.parameters import sysparam
 class TestSellableCategory(DomainTest):
     def setUp(self):
         DomainTest.setUp(self)
-        base_category = SellableCategory(description="Monitor",
-                                         connection=self.trans)
-        self._category = SellableCategory(description="LCD",
-                                          category=base_category,
-                                          connection=self.trans)
+        self._base_category = self._create_category('Monitor')
 
     def testGetDescription(self):
-        self.failUnless(self._category.get_description() == "LCD")
-        self.failUnless(self._category.get_full_description() == "Monitor LCD")
+        category = self._create_category('LCD', parent=self._base_category)
+        self.failUnless(category.get_description() == "LCD")
+        self.failUnless(category.full_description == "Monitor:LCD")
 
     def testMarkup(self):
-        self._category.suggested_markup = currency(10)
-        self._category.category.suggested_markup = currency(20)
-        self.failUnless(self._category.get_markup() == currency(10))
-        self._category.suggested_markup = None
-        self.failUnless(self._category.get_markup() == currency(20))
+        self._base_category.suggested_markup = currency('10')
+        category1 = self._create_category('LCD', parent=self._base_category)
+        category2 = self._create_category('LCD', parent=self._base_category)
+        category3 = self._create_category('LCD', parent=self._base_category)
+
+        category1.suggested_markup = None
+        category2.suggested_markup = currency(0)
+        category3.suggested_markup = currency(5)
+
+        self.assertEqual(category1.get_markup(), 10)
+        self.assertEqual(category2.get_markup(), 0)
+        self.assertEqual(category3.get_markup(), 5)
 
     def testGetBaseCategories(self):
         categories = SellableCategory.get_base_categories(self.trans)
@@ -72,22 +76,23 @@ class TestSellableCategory(DomainTest):
         self.assertEqual(categories.count(), count + 1)
 
     def testGetTaxConstant(self):
-        base_category = SellableCategory(description="Monitor",
-                                         connection=self.trans)
-        category = SellableCategory(description="LCD Monitor",
-                                    category=base_category,
-                                    connection=self.trans)
+        category = self._create_category('LCD', parent=self._base_category)
 
         self.assertEquals(category.get_tax_constant(), None)
 
         constant = self.create_sellable_tax_constant()
-        base_category.tax_constant = constant
+        self._base_category.tax_constant = constant
         self.assertEquals(category.get_tax_constant(), constant)
 
         constant2 = self.create_sellable_tax_constant()
         category.tax_constant = constant2
         self.assertEquals(category.get_tax_constant(), constant2)
 
+    def _create_category(self, description, parent=None):
+        return SellableCategory(description=description,
+                                category=parent,
+                                connection=self.trans)
+
 
 class TestSellable(DomainTest):
     def setUp(self):
@@ -231,13 +236,13 @@ class TestSellable(DomainTest):
         # Now with a category, max_discount = 0
         self.assertFalse(sellable.is_valid_price(0, cat))
         self.assertFalse(sellable.is_valid_price(-10, cat))
-        self.assertFalse(sellable.is_valid_price(149.99, cat))
+        self.assertFalse(sellable.is_valid_price(Decimal('149.99'), cat))
         self.assertTrue(sellable.is_valid_price(150, cat))
         self.assertTrue(sellable.is_valid_price(151, cat))
 
         # Now with a category, max_discount = 10%
         cat_price.max_discount = 10
-        self.assertTrue(sellable.is_valid_price(149.99, cat))
+        self.assertTrue(sellable.is_valid_price(Decimal('149.99'), cat))
         self.assertTrue(sellable.is_valid_price(135, cat))
         self.assertFalse(sellable.is_valid_price(134, cat))
 
@@ -318,7 +323,7 @@ class TestSellable(DomainTest):
         sellable = self.create_sellable()
         self.failUnless(sellable.can_close())
 
-        storable = sellable.product.addFacet(IStorable, connection=self.trans)
+        storable = Storable(product=sellable.product, connection=self.trans)
         storable.increase_stock(1, branch=get_current_branch(self.trans))
         self.failIf(sellable.can_close())
 
@@ -329,7 +334,7 @@ class TestSellable(DomainTest):
     def testCanRemove(self):
         branch = get_current_branch(self.trans)
         sellable = self.create_sellable()
-        storable = sellable.product.addFacet(IStorable, connection=self.trans)
+        storable = Storable(product=sellable.product, connection=self.trans)
         self.failUnless(sellable.can_remove())
 
         storable.increase_stock(1, branch=branch)
@@ -342,7 +347,7 @@ class TestSellable(DomainTest):
         # Can't remove the sellable if it's in a purchase.
         from stoqlib.domain.purchase import PurchaseItem
         sellable = self.create_sellable()
-        sellable.product.addFacet(IStorable, connection=self.trans)
+        Storable(product=sellable.product, connection=self.trans)
         self.assertTrue(sellable.can_remove())
         PurchaseItem(connection=self.trans,
                      quantity=8, quantity_received=0,
@@ -358,7 +363,7 @@ class TestSellable(DomainTest):
     def testRemove(self):
         # Remove category price and sellable
         sellable = self.create_sellable()
-        sellable.product.addFacet(IStorable, connection=self.trans)
+        Storable(product=sellable.product, connection=self.trans)
 
         ClientCategoryPrice(sellable=sellable,
                             category=self.create_client_category(),
