@@ -1,4 +1,4 @@
-# -*- Mode: Python; coding: iso-8859-1 -*-
+# -*- Mode: Python; coding: utf-8 -*-
 # vi:si:et:sw=4:sts=4:ts=4
 
 ##
@@ -27,14 +27,14 @@ from stoqlib.database.orm import Viewable, Field, Alias
 from stoqlib.domain.account import Account, AccountTransaction
 from stoqlib.domain.commission import CommissionSource
 from stoqlib.domain.loan import Loan, LoanItem
-from stoqlib.domain.person import (Person, PersonAdaptToSupplier,
-                                   PersonAdaptToUser, PersonAdaptToBranch,
-                                   PersonAdaptToClient, PersonAdaptToEmployee)
+from stoqlib.domain.person import (Person, Supplier,
+                                   LoginUser, Branch,
+                                   Client, Employee)
 from stoqlib.domain.product import (Product,
-                                    ProductAdaptToStorable,
                                     ProductStockItem,
                                     ProductHistory,
-                                    ProductComponent)
+                                    ProductComponent,
+                                    Storable)
 from stoqlib.domain.production import ProductionOrder, ProductionItem
 from stoqlib.domain.purchase import (Quotation, QuoteGroup, PurchaseOrder,
                                      PurchaseItem)
@@ -45,22 +45,24 @@ from stoqlib.domain.sellable import (Sellable, SellableUnit,
                                      SellableTaxConstant)
 from stoqlib.domain.stockdecrease import (StockDecrease, StockDecreaseItem)
 
+from stoqlib.lib.decorators import cached_property
+
 
 class ProductFullStockView(Viewable):
     """Stores information about products.
     This view is used to query stock information on a certain branch.
 
-    @cvar id: the id of the asellable table
-    @cvar barcode: the sellable barcode
-    @cvar status: the sellable status
-    @cvar cost: the sellable cost
-    @cvar price: the sellable price
-    @cvar description: the sellable description
-    @cvar unit: the unit of the product
-    @cvar product_id: the id of the product table
-    @cvar location: the location of the product
-    @cvar branch_id: the id of person_adapt_to_branch table
-    @cvar stock: the stock of the product
+    :cvar id: the id of the asellable table
+    :cvar barcode: the sellable barcode
+    :cvar status: the sellable status
+    :cvar cost: the sellable cost
+    :cvar price: the sellable price
+    :cvar description: the sellable description
+    :cvar unit: the unit of the product
+    :cvar product_id: the id of the product table
+    :cvar location: the location of the product
+    :cvar branch_id: the id of branch table
+    :cvar stock: the stock of the product
      """
 
     columns = dict(
@@ -70,14 +72,14 @@ class ProductFullStockView(Viewable):
         status=Sellable.q.status,
         cost=Sellable.q.cost,
         description=Sellable.q.description,
+        image_id=Sellable.q.imageID,
         product_id=Product.q.id,
         location=Product.q.location,
         tax_description=SellableTaxConstant.q.description,
         category_description=SellableCategory.q.description,
         total_stock_cost=const.SUM(
                 ProductStockItem.q.stock_cost * ProductStockItem.q.quantity),
-        stock=const.COALESCE(const.SUM(ProductStockItem.q.quantity +
-                                       ProductStockItem.q.logic_quantity), 0),
+        stock=const.COALESCE(const.SUM(ProductStockItem.q.quantity), 0),
         unit=SellableUnit.q.description,
         )
 
@@ -95,11 +97,10 @@ class ProductFullStockView(Viewable):
         INNERJOINOn(None, Product,
                     Product.q.sellableID == Sellable.q.id),
         # Product Stock Item
-        LEFTJOINOn(None, ProductAdaptToStorable,
-                   ProductAdaptToStorable.q.originalID == Product.q.id),
+        LEFTJOINOn(None, Storable,
+                   Storable.q.productID == Product.q.id),
         LEFTJOINOn(None, ProductStockItem,
-                   ProductStockItem.q.storableID ==
-                   ProductAdaptToStorable.q.id),
+                   ProductStockItem.q.storableID == Storable.q.id),
         ]
 
     clause = Sellable.q.status != Sellable.STATUS_CLOSED
@@ -158,6 +159,10 @@ class ProductFullStockView(Viewable):
         sellable = Sellable.get(self.id, connection=self.get_connection())
         return sellable.price
 
+    @property
+    def has_image(self):
+        return self.image_id is not None
+
 
 class ProductFullWithClosedStockView(ProductFullStockView):
     """Stores information about products, showing the closed ones too.
@@ -174,38 +179,41 @@ class ProductClosedStockView(ProductFullWithClosedStockView):
 
 
 class ProductComponentView(ProductFullStockView):
-    columns = ProductFullStockView.columns
-    clause = AND(ProductFullStockView.clause,
-                 ProductComponent.q.productID == Product.q.id, )
+    """Stores information about production products"""
 
-    @property
-    def sellable(self):
-        return Sellable.get(self.id, connection=self.get_connection())
+    joins = ProductFullStockView.joins[:]
+    joins.extend([
+        INNERJOINOn(None, ProductComponent,
+                    ProductComponent.q.productID == Product.q.id),
+        ])
+
+
+class ProductComponentWithClosedView(ProductComponentView):
+    """Stores information about production products, including closed ones"""
+
+    clause = None
 
 
 class ProductWithStockView(ProductFullStockView):
     """Stores information about products, since product has a purchase or sale.
     This view is used to query stock information on a certain branch.
 
-    @cvar id: the id of the asellable table
-    @cvar barcode: the sellable barcode
-    @cvar status: the sellable status
-    @cvar cost: the sellable cost
-    @cvar price: the sellable price
-    @cvar description: the sellable description
-    @cvar unit: the unit of the product
-    @cvar product_id: the id of the product table
-    @cvar branch_id: the id of person_adapt_to_branch table
-    @cvar stock: the stock of the product
+    :cvar id: the id of the asellable table
+    :cvar barcode: the sellable barcode
+    :cvar status: the sellable status
+    :cvar cost: the sellable cost
+    :cvar price: the sellable price
+    :cvar description: the sellable description
+    :cvar unit: the unit of the product
+    :cvar product_id: the id of the product table
+    :cvar branch_id: the id of branch table
+    :cvar stock: the stock of the product
      """
 
-    columns = ProductFullStockView.columns
     clause = AND(
         ProductFullStockView.clause,
         ProductStockItem.q.quantity >= 0,
-        ProductStockItem.q.logic_quantity >= 0,
         )
-    ProductFullStockView.joins
 
 
 class _PurchaseItemTotal(Viewable):
@@ -233,12 +241,11 @@ class ProductFullStockItemView(ProductFullStockView):
 
     columns = ProductFullStockView.columns.copy()
     columns.update(dict(
-        minimum_quantity=ProductAdaptToStorable.q.minimum_quantity,
-        maximum_quantity=ProductAdaptToStorable.q.maximum_quantity,
+        minimum_quantity=Storable.q.minimum_quantity,
+        maximum_quantity=Storable.q.maximum_quantity,
         to_receive_quantity=Field('_purchase_total', 'to_receive'),
-        difference=(const.SUM(
-            ProductStockItem.q.quantity + ProductStockItem.q.logic_quantity) -
-            ProductAdaptToStorable.q.minimum_quantity)))
+        difference=(const.SUM(ProductStockItem.q.quantity) -
+                    Storable.q.minimum_quantity)))
 
     joins = ProductFullStockView.joins[:]
     joins.append(LEFTJOINOn(None, _purchase_total,
@@ -248,15 +255,15 @@ class ProductFullStockItemView(ProductFullStockView):
 class ProductQuantityView(Viewable):
     """Stores information about products solded and received.
 
-    @cvar id: the id of the sellable_id of products_quantity table
-    @cvar description: the product description
-    @cvar branch_id: the id of person_adapt_to_branch table
-    @cvar quantity_sold: the quantity solded of product
-    @cvar quantity_transfered: the quantity transfered of product
-    @cvar quantity_received: the quantity received of product
-    @cvar branch: the id of the branch_id of producst_quantity table
-    @cvar date_sale: the date of product's sale
-    @cvar date_received: the date of product's received
+    :cvar id: the id of the sellable_id of products_quantity table
+    :cvar description: the product description
+    :cvar branch_id: the id of branch table
+    :cvar quantity_sold: the quantity solded of product
+    :cvar quantity_transfered: the quantity transfered of product
+    :cvar quantity_received: the quantity received of product
+    :cvar branch: the id of the branch_id of producst_quantity table
+    :cvar date_sale: the date of product's sale
+    :cvar date_received: the date of product's received
      """
 
     columns = dict(
@@ -290,16 +297,16 @@ class SellableFullStockView(Viewable):
     """Stores information about products.
     This view is used to query stock information on a certain branch.
 
-    @cvar id: the id of the asellable table
-    @cvar barcode: the sellable barcode
-    @cvar status: the sellable status
-    @cvar cost: the sellable cost
-    @cvar price: the sellable price
-    @cvar description: the sellable description
-    @cvar unit: the unit of the product or None
-    @cvar product_id: the id of the product table or None
-    @cvar branch_id: the id of person_adapt_to_branch table or None
-    @cvar stock: the stock of the product or None
+    :cvar id: the id of the asellable table
+    :cvar barcode: the sellable barcode
+    :cvar status: the sellable status
+    :cvar cost: the sellable cost
+    :cvar price: the sellable price
+    :cvar description: the sellable description
+    :cvar unit: the unit of the product or None
+    :cvar product_id: the id of the product table or None
+    :cvar branch_id: the id of branch table or None
+    :cvar stock: the stock of the product or None
      """
 
     columns = dict(
@@ -314,8 +321,7 @@ class SellableFullStockView(Viewable):
         category_description=SellableCategory.q.description,
         base_price=Sellable.q.base_price,
         max_discount=Sellable.q.max_discount,
-        stock=const.COALESCE(const.SUM(ProductStockItem.q.quantity +
-                                       ProductStockItem.q.logic_quantity), 0),
+        stock=const.COALESCE(const.SUM(ProductStockItem.q.quantity), 0),
         )
 
     joins = [
@@ -329,11 +335,10 @@ class SellableFullStockView(Viewable):
         LEFTJOINOn(None, Product,
                    Product.q.sellableID == Sellable.q.id),
         # Product Stock Item
-        LEFTJOINOn(None, ProductAdaptToStorable,
-                   ProductAdaptToStorable.q.originalID == Product.q.id),
+        LEFTJOINOn(None, Storable,
+                   Storable.q.productID == Product.q.id),
         LEFTJOINOn(None, ProductStockItem,
-                   ProductStockItem.q.storableID ==
-                   ProductAdaptToStorable.q.id),
+                   ProductStockItem.q.storableID == Storable.q.id),
         ]
 
     @classmethod
@@ -372,7 +377,7 @@ class SellableCategoryView(Viewable):
         id=SellableCategory.q.id,
         commission=CommissionSource.q.direct_value,
         installments_commission=CommissionSource.q.installments_value,
-        category_id=SellableCategory.q.id,
+        parent_id=SellableCategory.q.categoryID,
         description=SellableCategory.q.description,
         suggested_markup=SellableCategory.q.suggested_markup,
     )
@@ -386,32 +391,59 @@ class SellableCategoryView(Viewable):
 
     @property
     def category(self):
-        return SellableCategory.get(self.category_id,
+        return SellableCategory.get(self.id,
                                     connection=self.get_connection())
 
+    def get_parent(self):
+        if not self.parent_id:
+            return None
+
+        category_views = SellableCategoryView.select(
+            connection=self.get_connection(),
+            clause=SellableCategoryView.q.id == self.parent_id)
+        return category_views[0]
+
+    def get_suggested_markup(self):
+        return self._suggested_markup
+
+    @cached_property(ttl=0)
+    def _suggested_markup(self):
+        category = self
+        while category:
+            # Compare to None as suggested_markup can be 0
+            if category.suggested_markup is not None:
+                return category.suggested_markup
+
+            category = category.get_parent()
+
     def get_commission(self):
-        if self.commission:
+        # Compare to None as commission can be 0
+        if self.commission is not None:
             return self.commission
 
-        source = self._get_base_source_commission()
+        source = self._parent_source_commission
         if source:
             return source.direct_value
 
     def get_installments_commission(self):
-        if self.commission:
+        # Compare to None as commission can be 0
+        if self.commission is not None:
             return self.installments_commission
 
-        source = self._get_base_source_commission()
+        source = self._parent_source_commission
         if source:
             return source.installments_value
 
-    def _get_base_source_commission(self):
-        base_category = self.category.category
-        if not base_category:
-            return
+    @cached_property(ttl=0)
+    def _parent_source_commission(self):
+        parent = self.get_parent()
+        while parent:
+            source = CommissionSource.selectOneBy(
+                category=parent.category, connection=self.get_connection())
+            if source:
+                return source
 
-        return CommissionSource.selectOneBy(category=base_category,
-                                            connection=self.get_connection())
+            parent = parent.get_parent()
 
 
 class QuotationView(Viewable):
@@ -430,10 +462,10 @@ class QuotationView(Viewable):
     joins = [
         LEFTJOINOn(None, PurchaseOrder,
                    PurchaseOrder.q.id == Quotation.q.purchaseID),
-        LEFTJOINOn(None, PersonAdaptToSupplier,
-                   PersonAdaptToSupplier.q.id == PurchaseOrder.q.supplierID),
+        LEFTJOINOn(None, Supplier,
+                   Supplier.q.id == PurchaseOrder.q.supplierID),
         LEFTJOINOn(None, Person, Person.q.id ==
-                   PersonAdaptToSupplier.q.originalID),
+                   Supplier.q.personID),
     ]
 
     clause = QuoteGroup.q.id == Quotation.q.groupID
@@ -528,10 +560,10 @@ class StockDecreaseItemsView(Viewable):
                    StockDecreaseItem.q.sellableID == Sellable.q.id),
         LEFTJOINOn(None, SellableUnit,
                    Sellable.q.unitID == SellableUnit.q.id),
-        INNERJOINOn(None, PersonAdaptToEmployee,
-                   StockDecrease.q.removed_byID == PersonAdaptToEmployee.q.id),
+        INNERJOINOn(None, Employee,
+                   StockDecrease.q.removed_byID == Employee.q.id),
         INNERJOINOn(None, Person,
-                   PersonAdaptToEmployee.q.originalID == Person.q.id),
+                   Employee.q.personID == Person.q.id),
     ]
 
 
@@ -545,10 +577,10 @@ class SoldItemsByBranchView(SoldItemView):
     ))
 
     joins = SoldItemView.joins[:]
-    joins.append(LEFTJOINOn(None, PersonAdaptToBranch,
-                   PersonAdaptToBranch.q.id == Sale.q.branchID))
+    joins.append(LEFTJOINOn(None, Branch,
+                            Branch.q.id == Sale.q.branchID))
     joins.append(LEFTJOINOn(None, Person,
-                   PersonAdaptToBranch.q.originalID == Person.q.id))
+                            Branch.q.personID == Person.q.id))
 
     clause = OR(SoldItemView.clause,
                 Sale.q.status == Sale.STATUS_RENEGOTIATED)
@@ -560,14 +592,14 @@ class PurchasedItemAndStockView(Viewable):
     This view is used to query which products are going to be delivered and if
     they are on time or not.
 
-    @cvar id: the id of the purchased item
-    @cvar product_id: the id of the product
-    @cvar purchased: the quantity purchased
-    @cvar received: the quantity already received
-    @cvar stocked: the quantity in stock
-    @cvar expected_receival_date: the date that the item might be deliverd
-    @cvar purchase_date: the date when the item was purchased
-    @cvar branch: the branch where the purchase was done
+    :cvar id: the id of the purchased item
+    :cvar product_id: the id of the product
+    :cvar purchased: the quantity purchased
+    :cvar received: the quantity already received
+    :cvar stocked: the quantity in stock
+    :cvar expected_receival_date: the date that the item might be deliverd
+    :cvar purchase_date: the date when the item was purchased
+    :cvar branch: the branch where the purchase was done
     """
 
     columns = dict(
@@ -576,8 +608,7 @@ class PurchasedItemAndStockView(Viewable):
         description=Sellable.q.description,
         purchased=PurchaseItem.q.quantity,
         received=PurchaseItem.q.quantity_received,
-        stocked=const.SUM(ProductStockItem.q.quantity +
-                          ProductStockItem.q.logic_quantity),
+        stocked=const.SUM(ProductStockItem.q.quantity),
         expected_receival_date=PurchaseItem.q.expected_receival_date,
         order_id=PurchaseOrder.q.id,
         purchased_date=PurchaseOrder.q.open_date,
@@ -591,10 +622,10 @@ class PurchasedItemAndStockView(Viewable):
                     Sellable.q.id == PurchaseItem.q.sellableID),
         LEFTJOINOn(None, Product,
                    Product.q.sellableID == PurchaseItem.q.sellableID),
-        LEFTJOINOn(None, ProductAdaptToStorable,
-                   ProductAdaptToStorable.q.originalID == Product.q.id),
+        LEFTJOINOn(None, Storable,
+                   Storable.q.productID == Product.q.id),
         LEFTJOINOn(None, ProductStockItem,
-                   ProductStockItem.q.storableID == ProductAdaptToStorable.q.id),
+                   ProductStockItem.q.storableID == Storable.q.id),
     ]
 
     clause = AND(PurchaseOrder.q.status == PurchaseOrder.ORDER_CONFIRMED,
@@ -612,7 +643,6 @@ class ConsignedItemAndStockView(PurchasedItemAndStockView):
         sold=PurchaseItem.q.quantity_sold,
         returned=PurchaseItem.q.quantity_returned,
     ))
-    joins = PurchasedItemAndStockView.joins[:]
     clause = AND(PurchaseOrder.q.consigned == True,
                  PurchaseOrder.q.branchID == ProductStockItem.q.branchID)
 
@@ -620,19 +650,19 @@ class ConsignedItemAndStockView(PurchasedItemAndStockView):
 class PurchaseReceivingView(Viewable):
     """Stores information about received orders.
 
-    @cvar id: the id of the receiving order
-    @cvar receival_date: the date when the receiving order was closed
-    @cvar invoice_number: the number of the order that was received
-    @cvar invoice_total: the total value of the received order
-    @cvar purchase_id: the id of the received order
-    @cvar branch_id: the id branch where the order was received
-    @cvar purchase_responsible_name: the one who have confirmed the purchase
-    @cvar responsible_name: the one who has received the order
-    @cvar supplier_name: the supplier name
+    :cvar id: the id of the receiving order
+    :cvar receival_date: the date when the receiving order was closed
+    :cvar invoice_number: the number of the order that was received
+    :cvar invoice_total: the total value of the received order
+    :cvar purchase_id: the id of the received order
+    :cvar branch_id: the id branch where the order was received
+    :cvar purchase_responsible_name: the one who have confirmed the purchase
+    :cvar responsible_name: the one who has received the order
+    :cvar supplier_name: the supplier name
     """
     _Responsible = Alias(Person, "responsible")
-    _Supplier = Alias(Person, "supplier")
-    _PurchaseUser = Alias(PersonAdaptToUser, "purchase_user")
+    _Supplier = Alias(Person, "supplier_person")
+    _PurchaseUser = Alias(LoginUser, "purchase_user")
     _PurchaseResponsible = Alias(Person, "purchase_responsible")
 
     columns = dict(
@@ -653,15 +683,15 @@ class PurchaseReceivingView(Viewable):
         LEFTJOINOn(None, _PurchaseUser,
                    PurchaseOrder.q.responsibleID == _PurchaseUser.q.id),
         LEFTJOINOn(None, _PurchaseResponsible,
-                   _PurchaseUser.q.originalID == _PurchaseResponsible.q.id),
-        LEFTJOINOn(None, PersonAdaptToSupplier,
-                   ReceivingOrder.q.supplierID == PersonAdaptToSupplier.q.id),
+                   _PurchaseUser.q.personID == _PurchaseResponsible.q.id),
+        LEFTJOINOn(None, Supplier,
+                   ReceivingOrder.q.supplierID == Supplier.q.id),
         LEFTJOINOn(None, _Supplier,
-                   PersonAdaptToSupplier.q.originalID == _Supplier.q.id),
-        LEFTJOINOn(None, PersonAdaptToUser,
-                   ReceivingOrder.q.responsibleID == PersonAdaptToUser.q.id),
+                   Supplier.q.personID == _Supplier.q.id),
+        LEFTJOINOn(None, LoginUser,
+                   ReceivingOrder.q.responsibleID == LoginUser.q.id),
         LEFTJOINOn(None, _Responsible,
-                   PersonAdaptToUser.q.originalID == _Responsible.q.id),
+                   LoginUser.q.personID == _Responsible.q.id),
     ]
 
 
@@ -690,10 +720,10 @@ class SaleItemsView(Viewable):
                    SaleItem.q.saleID == Sale.q.id),
         LEFTJOINOn(None, SellableUnit,
                    Sellable.q.unitID == SellableUnit.q.id),
-        LEFTJOINOn(None, PersonAdaptToClient,
-                   Sale.q.clientID == PersonAdaptToClient.q.id),
+        LEFTJOINOn(None, Client,
+                   Sale.q.clientID == Client.q.id),
         LEFTJOINOn(None, Person,
-                   PersonAdaptToClient.q.originalID == Person.q.id),
+                   Client.q.personID == Person.q.id),
     ]
 
     clause = OR(Sale.q.status == Sale.STATUS_CONFIRMED,
@@ -707,17 +737,17 @@ class ReceivingItemView(Viewable):
     This view is used to query products that are going to be received or was
     already received and the information related to that process.
 
-    @cvar id: the id of the receiving item
-    @cvar order_id: the id of the receiving order
-    @cvar purchase_id: the id of the purchase order
-    @cvar purchase_item_id: the id of the purchase item
-    @cvar sellable_id: the id of the sellable related to the received item
-    @cvar invoice_number: the invoice number of the receiving order
-    @cvar receival_date: the date when the item was received
-    @cvar quantity: the received quantity
-    @cvar cost: the product cost
-    @cvar unit_description: the product unit description
-    @cvar supplier_name: the product supplier name
+    :cvar id: the id of the receiving item
+    :cvar order_id: the id of the receiving order
+    :cvar purchase_id: the id of the purchase order
+    :cvar purchase_item_id: the id of the purchase item
+    :cvar sellable_id: the id of the sellable related to the received item
+    :cvar invoice_number: the invoice number of the receiving order
+    :cvar receival_date: the date when the item was received
+    :cvar quantity: the received quantity
+    :cvar cost: the product cost
+    :cvar unit_description: the product unit description
+    :cvar supplier_name: the product supplier name
     """
     columns = dict(
         id=ReceivingOrderItem.q.id,
@@ -740,10 +770,10 @@ class ReceivingItemView(Viewable):
                    ReceivingOrderItem.q.sellableID == Sellable.q.id),
         LEFTJOINOn(None, SellableUnit,
                    Sellable.q.unitID == SellableUnit.q.id),
-        LEFTJOINOn(None, PersonAdaptToSupplier,
-                   ReceivingOrder.q.supplierID == PersonAdaptToSupplier.q.id),
+        LEFTJOINOn(None, Supplier,
+                   ReceivingOrder.q.supplierID == Supplier.q.id),
         LEFTJOINOn(None, Person,
-                   PersonAdaptToSupplier.q.originalID == Person.q.id),
+                   Supplier.q.personID == Person.q.id),
     ]
 
 
@@ -795,19 +825,19 @@ class LoanView(Viewable):
                     total=const.SUM(LoanItem.q.quantity * LoanItem.q.price), )
     joins = [
         INNERJOINOn(None, LoanItem, Loan.q.id == LoanItem.q.loanID),
-        LEFTJOINOn(None, PersonAdaptToBranch,
-                   Loan.q.branchID == PersonAdaptToBranch.q.id),
-        LEFTJOINOn(None, PersonAdaptToUser,
-                   Loan.q.responsibleID == PersonAdaptToUser.q.id),
-        LEFTJOINOn(None, PersonAdaptToClient,
-                   Loan.q.clientID == PersonAdaptToClient.q.id),
+        LEFTJOINOn(None, Branch,
+                   Loan.q.branchID == Branch.q.id),
+        LEFTJOINOn(None, LoginUser,
+                   Loan.q.responsibleID == LoginUser.q.id),
+        LEFTJOINOn(None, Client,
+                   Loan.q.clientID == Client.q.id),
 
         LEFTJOINOn(None, PersonBranch,
-                   PersonAdaptToBranch.q.originalID == PersonBranch.q.id),
+                   Branch.q.personID == PersonBranch.q.id),
         LEFTJOINOn(None, PersonResponsible,
-                   PersonAdaptToUser.q.originalID == PersonResponsible.q.id),
+                   LoginUser.q.personID == PersonResponsible.q.id),
         LEFTJOINOn(None, PersonClient,
-                   PersonAdaptToClient.q.originalID == PersonClient.q.id),
+                   Client.q.personID == PersonClient.q.id),
     ]
 
 
@@ -843,19 +873,15 @@ class AccountView(Viewable):
 
     class _SourceSum(Viewable):
         columns = dict(
-             id=AccountTransaction.q.source_accountID,
-             value=const.SUM(AccountTransaction.q.value),
-             )
-
-        joins = []
+            id=AccountTransaction.q.source_accountID,
+            value=const.SUM(AccountTransaction.q.value),
+            )
 
     class _DestSum(Viewable):
         columns = dict(
-             id=AccountTransaction.q.accountID,
-             value=const.SUM(AccountTransaction.q.value),
-              )
-
-        joins = []
+            id=AccountTransaction.q.accountID,
+            value=const.SUM(AccountTransaction.q.value),
+            )
 
     columns = dict(
         id=Account.q.id,
@@ -865,7 +891,7 @@ class AccountView(Viewable):
         description=Account.q.description,
         code=Account.q.code,
         source_value=Field('source_sum', 'value'),
-        dest_value=Field('dest_sum', 'value')
+        dest_value=Field('dest_sum', 'value'),
         )
 
     joins = [
@@ -896,11 +922,11 @@ class AccountView(Viewable):
     def get_combined_value(self):
         """Returns the combined value of incoming and outgoing
         transactions"""
-        if self.dest_value is None and self.source_value is None:
+        if not self.dest_value and not self.source_value:
             return 0
-        elif self.dest_value is None:
+        elif not self.dest_value:
             return -self.source_value
-        elif self.source_value is None:
+        elif not self.source_value:
             return self.dest_value
         else:
             return self.dest_value - self.source_value
