@@ -32,13 +32,13 @@ from kiwi.ui.dialogs import error, warning, info, yesno
 from kiwi.ui.delegates import GladeSlaveDelegate, GladeDelegate
 from kiwi.ui.views import BaseView
 from kiwi.utils import gsignal
-from kiwi.argcheck import argcheck
 from zope.interface import implements
 
 from stoqlib.exceptions import ModelDataError
 from stoqlib.lib.translation import stoqlib_gettext
 from stoqlib.lib.interfaces import ISystemNotifier
 from stoqlib.gui.base.gtkadds import change_button_appearance
+from stoqlib.gui.events import DialogCreateEvent
 
 _ = stoqlib_gettext
 _toplevel_stack = []
@@ -183,6 +183,8 @@ class BasicDialog(AbstractDialog):
             self.hide_footer()
         self.ok_button.set_use_underline(True)
 
+        DialogCreateEvent.emit(self)
+
     def _try_confirm(self, *args):
         """Only confirm if ok button is actually enabled.
 
@@ -228,7 +230,7 @@ class BasicDialog(AbstractDialog):
     def set_confirm_widget(self, widget):
         """Enables widget as a confirm widget, the dialog will be closed as
         confirmed if the widget is activated.
-        @param widget: a widget
+        :param widget: a widget
         """
         dialog = self.get_toplevel()
         if not widget.is_ancestor(dialog):
@@ -239,7 +241,7 @@ class BasicDialog(AbstractDialog):
     def set_cancel_widget(self, widget):
         """Enables widget as a cancel widget, the dialog will be closed as
         canceled if the widget is activated.
-        @param widget: a widget
+        :param widget: a widget
         """
         dialog = self.get_toplevel()
         if not widget.is_ancestor(dialog):
@@ -403,7 +405,6 @@ def get_current_toplevel():
         return _toplevel_stack[-1]
 
 
-@argcheck(gtk.Window)
 def add_current_toplevel(toplevel):
     _toplevel_stack.append(toplevel)
 
@@ -436,10 +437,10 @@ def run_dialog(dialog, parent=None, *args, **kwargs):
     """Runs a dialog and return the return value of it.
     If dialog is a class it will be instantiated before running the dialog.
 
-    @param dialog: the dialog, could be a class or instance
-    @param parent: parent of the dialog
-    @param args: custom positional argument
-    @param kwargs: custom keyword arguments
+    :param dialog: the dialog, could be a class or instance
+    :param parent: parent of the dialog
+    :param args: custom positional argument
+    :param kwargs: custom keyword arguments
     """
 
     if dialog is None:
