@@ -38,14 +38,14 @@ def change_button_appearance(button, icon=None, text=None):
 
 def button_set_image_with_label(button, stock_id, text):
     """Sets an image above the text
-    @param button:
-    @param stock_id:
-    @param text:
+    :param button:
+    :param stock_id:
+    :param text:
     """
 
     # Base on code in gazpacho by Lorenzo Gil Sanchez.
-    if button.child:
-        button.remove(button.child)
+    if button.get_child():
+        button.remove(button.get_child())
 
     align = gtk.Alignment(0.5, 0.5, 1.0, 1.0)
     box = gtk.VBox()
