@@ -43,7 +43,6 @@ from stoqlib.gui.base.dialogs import BasicDialog, run_dialog
 from stoqlib.gui.base.gtkadds import button_set_image_with_label
 from stoqlib.gui.base.messagebar import MessageBar
 from stoqlib.gui.editors.baseeditor import BaseEditor
-from stoqlib.lib.component import Adapter
 from stoqlib.lib.defaults import get_weekday_start
 from stoqlib.lib.osutils import get_application_dir
 from stoqlib.lib.parameters import sysparam
@@ -75,14 +74,14 @@ class _SearchDialogDetailsSlave(GladeSlaveDelegate):
 
 
 class StoqlibSearchSlaveDelegate(SearchSlaveDelegate):
-    def __init__(self, columns, restore_name=None):
+    def __init__(self, columns, tree=False, restore_name=None):
         self._columns = columns
         self._restore_name = restore_name
         self._settings_key = 'search-columns-%s' % (
             api.get_current_user(api.get_connection()).username, )
         self.restore_columns()
 
-        SearchSlaveDelegate.__init__(self, self._columns)
+        SearchSlaveDelegate.__init__(self, self._columns, tree=tree)
         self.search.connect("search-completed",
                             self._on_search__search_completed)
 
@@ -112,6 +111,9 @@ class StoqlibSearchSlaveDelegate(SearchSlaveDelegate):
             saved = self._migrate_from_pickle()
 
         for col in self._columns:
+            # Expanded columns should not have a width set.
+            if col.expand:
+                continue
             props = saved.get(col.title)
             if props:
                 col.visible = props[0]
@@ -186,11 +188,11 @@ class SearchDialog(BasicDialog):
     >>> def __init__(self, *args):
     ...     SearchDialog.__init__(self)
 
-    @cvar table: the table type which we will query on to get the objects.
-    @cvar searchbar_labels: labels for SearchBar entry and date fields
-    @cvar searchbar_result_strings: a tuple where each item has a singular
+    :cvar table: the table type which we will query on to get the objects.
+    :cvar searchbar_labels: labels for SearchBar entry and date fields
+    :cvar searchbar_result_strings: a tuple where each item has a singular
       and a plural form for searchbar results label
-    @cvar advanced_search: If the advanced search is enabled or disabled
+    :cvar advanced_search: If the advanced search is enabled or disabled
     """
     main_label_text = ''
     title = ''
@@ -200,6 +202,7 @@ class SearchDialog(BasicDialog):
     selection_mode = gtk.SELECTION_BROWSE
     size = ()
     advanced_search = True
+    tree = False
 
     @argcheck(object, object, object, bool, basestring, int, bool)
     def __init__(self, conn, table=None, search_table=None, hide_footer=True,
@@ -207,13 +210,13 @@ class SearchDialog(BasicDialog):
         """
         A base class for search dialog inheritance
 
-        @param conn:
-        @param table:
-        @param search_table:
-        @param hide_footer:
-        @param title:
-        @param selection_mode:
-        @param double_click_confirm: If double click a item in the list should
+        :param conn:
+        :param table:
+        :param search_table:
+        :param hide_footer:
+        :param title:
+        :param selection_mode:
+        :param double_click_confirm: If double click a item in the list should
           automatically confirm
         """
 
@@ -262,8 +265,11 @@ class SearchDialog(BasicDialog):
         return selection_mode
 
     def _setup_search(self):
-        self.search = StoqlibSearchSlaveDelegate(self.get_columns(),
-                                         restore_name=self.__class__.__name__)
+        self.search = StoqlibSearchSlaveDelegate(
+            self.get_columns(),
+            tree=self.tree,
+            restore_name=self.__class__.__name__,
+            )
         self.search.set_query_executer(self.executer)
         if self.advanced_search:
             self.search.enable_advanced_search()
@@ -308,9 +314,9 @@ class SearchDialog(BasicDialog):
     def add_button(self, label, stock=None, image=None):
         """Adds a button in the bottom of the dialog.
 
-        @param label: the text that will be displayed by the button.
-        @param stock: the gtk stock id to be used in the button.
-        @param image: the image filename.
+        :param label: the text that will be displayed by the button.
+        :param stock: the gtk stock id to be used in the button.
+        :param image: the image filename.
         """
         button = gtk.Button(label=label)
         if image:
@@ -341,7 +347,7 @@ class SearchDialog(BasicDialog):
 
     def confirm(self, retval=None):
         """Confirms the dialog
-        @retval: optional parameter which will be selected when the
+        :param retval: optional parameter which will be selected when the
           dialog is closed
         """
         if retval is None:
@@ -379,25 +385,25 @@ class SearchDialog(BasicDialog):
         pass
 
     def set_text_field_columns(self, columns):
-        """See L{SearchSlaveDelegate.set_text_field_columns}
+        """See :class:`SearchSlaveDelegate.set_text_field_columns`
         """
         self.search.set_text_field_columns(columns)
 
     def disable_search_entry(self):
-        """See L{SearchSlaveDelegate.disable_search_entry}
+        """See :class:`SearchSlaveDelegate.disable_search_entry`
         """
         self.search.disable_search_entry()
 
     def add_filter(self, search_filter, position=SearchFilterPosition.BOTTOM,
                    columns=None, callback=None):
-        """See L{SearchSlaveDelegate.add_filter}
+        """See :class:`SearchSlaveDelegate.add_filter`
         """
         self.search.add_filter(search_filter, position, columns, callback)
 
     def row_activate(self, obj):
         """This is called when an item in the results list is double clicked.
 
-        @param obj: the item that was double clicked.
+        :param obj: the item that was double clicked.
         """
         if self.double_click_confirm:
             # But only if its also confirmable with ok_button
@@ -409,8 +415,8 @@ class SearchDialog(BasicDialog):
     #
 
     def create_branch_filter(self, label=None):
-        from stoqlib.domain.person import PersonAdaptToBranch
-        branches = PersonAdaptToBranch.get_active_branches(self.conn)
+        from stoqlib.domain.person import Branch
+        branches = Branch.get_active_branches(self.conn)
         items = [(b.person.name, b.id) for b in branches]
         #if not items:
         #    raise ValueError('You should have at least one branch at '
@@ -427,8 +433,8 @@ class SearchDialog(BasicDialog):
         return branch_filter
 
     def create_provider_filter(self, label=None):
-        from stoqlib.domain.person import PersonAdaptToCreditProvider
-        providers = PersonAdaptToCreditProvider.get_active_providers(self.conn)
+        from stoqlib.domain.person import CreditProvider
+        providers = CreditProvider.get_active_providers(self.conn)
         items = [(p.person.name, p) for p in providers]
         items.insert(0, (_("Any"), None))
 
@@ -554,17 +560,17 @@ class SearchEditor(SearchDialog):
                  hide_toolbar=False, double_click_confirm=False):
         """
         Create a new SearchEditor object.
-        @param conn:
-        @param table:
-        @param editor_class:
-        @param interface: The interface which we need to apply to the objects in
+        :param conn:
+        :param table:
+        :param editor_class:
+        :param interface: The interface which we need to apply to the objects in
           kiwi list to get adapter for the editor.
-        @param search_table:
-        @param hide_footer:
-        @param title:
-        @param selection_mode:
-        @param hide_toolbar:
-        @param double_click_confirm: If double click a item in the list should
+        :param search_table:
+        :param hide_footer:
+        :param title:
+        :param selection_mode:
+        :param hide_toolbar:
+        :param double_click_confirm: If double click a item in the list should
           automatically confirm. Double click confirms takes precedence over
           editor_class (ie, if double_click_confirmis is True, it will
           confirm the dialog, instead of opening the editor).
@@ -615,8 +621,8 @@ class SearchEditor(SearchDialog):
 
     def add_message_bar(self, message, message_type=gtk.MESSAGE_INFO):
         """Adds a message bar to the top of the search results
-        @message: message to add
-        @message_type: type of message to add
+        :param message: message to add
+        :param message_type: type of message to add
         """
         self._message_bar = MessageBar(message, message_type)
         self.main_vbox.pack_start(self._message_bar, False, False)
@@ -670,22 +676,15 @@ class SearchEditor(SearchDialog):
         if obj:
             obj = self.get_editor_model(obj)
         if obj and self.interface:
-            if isinstance(obj, Adapter):
-                adapted = obj.get_adapted()
-            else:
-                adapted = obj
-            obj = self.interface(adapted)
+            obj = self.interface(obj)
 
         rv = self.run_editor(obj)
         if rv:
-            if self.editor_class.model_iface:
-                rv = rv.get_adapted()
-
             self.search.refresh()
             self.enable_ok()
 
-    def run_dialog(self, editor_class, parent, *args):
-        return run_dialog(editor_class, parent, *args)
+    def run_dialog(self, editor_class, parent, *args, **kwargs):
+        return run_dialog(editor_class, parent, *args, **kwargs)
 
     def run_editor(self, obj):
         trans = api.new_transaction()
@@ -700,7 +699,7 @@ class SearchEditor(SearchDialog):
         return retval
 
     def row_activate(self, obj):
-        """See L{SearchDialog.row_activate}
+        """See :class:`SearchDialog.row_activate`
         """
         if self.double_click_confirm:
             SearchDialog.row_activate(self, obj)
