@@ -34,7 +34,7 @@ from kiwi.ui.objectlist import Column
 from kiwi.ui.listdialog import ListSlave
 
 from stoqlib.api import api
-from stoqlib.domain.product import ProductAdaptToStorable
+from stoqlib.domain.product import Storable
 from stoqlib.gui.editors.baseeditor import BaseEditor
 from stoqlib.lib.message import yesno
 from stoqlib.lib.translation import stoqlib_gettext
@@ -69,13 +69,12 @@ class InitialStockDialog(BaseEditor):
         self._setup_widgets()
 
     def _setup_widgets(self):
-        # XXX: the branch should be in bold font
-        self.branch_label.set_text(
-            _(u"Registering initial stock for products in %s") %
+        self.branch_label.set_markup(
+            _(u"Registering initial stock for products in <b>%s</b>") %
                                             self._branch.person.name)
 
         self._storables = [_TemporaryStorableItem(s)
-            for s in ProductAdaptToStorable.select(connection=self.conn)
+            for s in Storable.select(connection=self.conn)
                 if s.get_stock_item(self._branch) is None]
 
         self.slave.listcontainer.add_items(self._storables)
