@@ -37,6 +37,13 @@ from stoqlib.lib.translation import stoqlib_gettext
 _ = stoqlib_gettext
 
 
+def format_category_type(value):
+    if value == PaymentCategory.TYPE_PAYABLE:
+        return _('Payable')
+    elif value == PaymentCategory.TYPE_RECEIVABLE:
+        return _('Receivable')
+
+
 class PaymentCategoryDialog(ModelListDialog):
 
     # ModelListDialog
@@ -49,14 +56,36 @@ class PaymentCategoryDialog(ModelListDialog):
     columns = [
         Column('name', title=_('Category'),
                data_type=str, expand=True, sorted=True),
+        Column('category_type', title=_('Type'), data_type=int,
+               format_func=format_category_type),
         Column('color', title=_('Color'), width=20,
                data_type=gtk.gdk.Pixbuf, format_func=render_pixbuf),
         Column('color', data_type=str, width=120,
                column='color')
         ]
 
+    def __init__(self, conn, category_type=None):
+        self.category_type = category_type
+
+        ModelListDialog.__init__(self, conn)
+
+        column = self.listcontainer.list.get_column_by_name('category_type')
+        column.treeview_column.set_visible(category_type is None)
+
+    def populate(self):
+        results = super(PaymentCategoryDialog, self).populate()
+
+        if self.category_type is not None:
+            results = results.filterBy(category_type=self.category_type)
+
+        return results
+
     def delete_model(self, model, trans):
         for payment in Payment.selectBy(category=model,
                                         connection=trans):
             payment.category = None
         PaymentCategory.delete(model.id, connection=trans)
+
+    def run_editor(self, trans, model):
+        return self.run_dialog(self._editor_class, conn=trans,
+                               model=model, category_type=self.category_type)
