@@ -34,7 +34,6 @@ from kiwi.ui.delegates import GladeSlaveDelegate
 from kiwi.ui.objectlist import Column, ColoredColumn
 
 from stoqlib.api import api
-from stoqlib.domain.interfaces import IStorable
 from stoqlib.domain.product import Product
 from stoqlib.domain.payment.group import PaymentGroup
 from stoqlib.domain.purchase import PurchaseOrder, PurchaseItem
@@ -42,7 +41,7 @@ from stoqlib.domain.views import (ProductFullStockView,
                                   PurchasedItemAndStockView)
 from stoqlib.exceptions import StockError
 from stoqlib.gui.base.dialogs import BasicWrappingDialog, run_dialog
-from stoqlib.gui.dialogs.csvexporterdialog import CSVExporterDialog
+from stoqlib.gui.dialogs.spreadsheetexporterdialog import SpreadSheetExporterDialog
 from stoqlib.gui.wizards.purchasewizard import PurchaseWizard
 from stoqlib.lib.message import warning, yesno
 from stoqlib.lib.parameters import sysparam
@@ -98,9 +97,9 @@ class _TemporaryProductionItemComponent(object):
         self.stock_quantity = self._get_stock_quantity()
         self.purchase_quantity = self._get_purchase_quantity()
         self.make_quantity = self._get_make_quantity()
-
-        #XXX: workaround!
         conn = api.get_connection()
+        self.branch = api.get_current_branch(conn)
+        #XXX: workaround!
         items = PurchasedItemAndStockView.select(
             Product.q.id == self.product.id, connection=conn)
         self.to_receive = sum(
@@ -109,12 +108,12 @@ class _TemporaryProductionItemComponent(object):
     def _get_stock_quantity(self):
         """Returns the quantity we have in stock of this component
         """
-        storable = IStorable(self.product, None)
+        storable = self.product.storable
         if storable is None:
             return Decimal(0)
 
         try:
-            quantity = storable.get_full_balance()
+            quantity = storable.get_balance_for_branch(self.branch)
         except StockError:
             quantity = Decimal(0)
 
@@ -385,8 +384,10 @@ class ProductionComponentSlave(GladeSlaveDelegate):
                 self.component_list.remove(c)
 
     def _run_csv_exporter_dialog(self):
-        run_dialog(CSVExporterDialog, self, None,
-                   _TemporaryProductionItemComponent, self.component_list)
+        run_dialog(SpreadSheetExporterDialog, self,
+                   object_list=self.component_list,
+                   name=_('Production components'),
+                   filename_prefix=_('production-components'))
 
     #
     # Public API
