@@ -31,8 +31,7 @@ import gtk
 from kiwi.datatypes import currency
 from kiwi.ui.widgets.list import Column, ColoredColumn
 
-from stoqlib.domain.interfaces import IClient
-from stoqlib.domain.person import Person
+from stoqlib.domain.person import Client
 from stoqlib.domain.sale import SaleView, Sale
 from stoqlib.domain.payment.views import PaymentChangeHistoryView
 from stoqlib.domain.renegotiation import RenegotiationData
@@ -92,8 +91,8 @@ class SaleDetailsDialog(BaseEditor):
     def __init__(self, conn, model=None, visual_mode=False):
         """ Creates a new SaleDetailsDialog object
 
-        @param conn: a database connection
-        @param model: a L{stoqlib.domain.sale.Sale} object
+        :param conn: a database connection
+        :param model: a :class:`stoqlib.domain.sale.Sale` object
         """
         BaseEditor.__init__(self, conn, model,
                             visual_mode=visual_mode)
@@ -104,7 +103,7 @@ class SaleDetailsDialog(BaseEditor):
         self.payments_info_list.set_columns(self._get_payments_info_columns())
 
     def _get_payments(self, sale):
-        for payment in sale.payments:
+        for payment in sale.group.payments:
             if payment.is_outpayment():
                 yield _TemporaryOutPayment(payment)
             else:
@@ -216,8 +215,8 @@ class SaleDetailsDialog(BaseEditor):
         if not self.model.client_id:
             raise StoqlibError("You should never call ClientDetailsDialog "
                                "for sales which clients were not specified")
-        client = Person.iget(IClient, self.model.client_id,
-                             connection=self.conn)
+        client = Client.get(self.model.client_id,
+                            connection=self.conn)
         run_dialog(ClientDetailsDialog, self, self.conn, client)
 
     def on_status_details_button__clicked(self, button):
