@@ -29,10 +29,11 @@ from kiwi.datatypes import  ValidationError
 from kiwi.ui.widgets.combo import ProxyComboBox
 from kiwi.ui.widgets.entry import ProxyEntry
 
+from stoqlib.api import api
 from stoqlib.domain.account import (Account, BankAccount,
                                     BillOption)
-from stoqlib.domain.payment.operation import register_payment_operations
 from stoqlib.gui.accounttree import AccountTree
+from stoqlib.gui.base.dialogs import run_dialog
 from stoqlib.gui.editors.baseeditor import BaseEditor
 from stoqlib.gui.printing import print_report
 from stoqlib.lib.boleto import (get_all_banks,
@@ -261,10 +262,13 @@ class AccountEditor(BaseEditor):
                 entry = ProxyEntry()
                 entry.model_attribute = name
                 setattr(self, name, entry)
+                # Set the model attr too so it can be validated
+                setattr(self.bank_model, name, '')
                 entry.props.data_type = 'str'
                 entry.connect('validate', self._on_bank_option__validate,
                               bank_info, option)
-                self._add_widget("<i>%s</i>:" % (option, ), entry, options=True)
+                self._add_widget("<i>%s</i>:" % (option.capitalize(), ),
+                                 entry, options=True)
                 entry.show()
                 self._option_fields[option] = entry
                 attributes.append(entry.model_attribute)
@@ -273,6 +277,7 @@ class AccountEditor(BaseEditor):
 
         self.bank_proxy = self.add_proxy(
             self.bank_model, attributes)
+        self._fill_bank_account()
 
     def _fill_bank_account(self):
         if not self.model.bank:
@@ -323,22 +328,20 @@ class AccountEditor(BaseEditor):
 
     def _remove_bank_widgets(self):
         for widget in self._bank_widgets:
-            widget.parent.remove(widget)
+            widget.get_parent().remove(widget)
             widget.destroy()
         self.table.resize(5, 2)
         self._bank_widgets = []
 
     def _remove_bank_option_widgets(self):
         for widget in self._bank_option_widgets:
-            widget.parent.remove(widget)
+            widget.get_parent().remove(widget)
             widget.destroy()
         self.table.resize(5 + len(self._bank_widgets) / 2, 2)
         self._bank_option_widgets = []
         self._option_fields = {}
 
     def _print_test_bill(self):
-        register_payment_operations()
-
         try:
             bank_info = get_bank_info_by_number(self.bank_model.bank_number)
         except NotImplementedError:
@@ -388,7 +391,6 @@ class AccountEditor(BaseEditor):
         if self._bank_number == bank_number:
             return
         self._update_bank_type()
-        self._fill_bank_account()
 
         self._bank_number = bank_number
 
@@ -415,3 +417,14 @@ class AccountEditor(BaseEditor):
 
     def _on_test_button__clicked(self, button):
         self._print_test_bill()
+
+
+def test():
+    creator = api.prepare_test()
+    retval = run_dialog(AccountEditor, None, creator.trans, None,
+                        parent_account=None)
+    api.finish_transaction(creator.trans, retval)
+
+
+if __name__ == '__main__':
+    test()
