@@ -32,10 +32,10 @@ from kiwi.ui.listdialog import ListContainer
 from kiwi.ui.widgets.label import ProxyLabel
 
 from stoqlib.database.runtime import StoqlibTransaction
-from stoqlib.lib.component import Adapter
 from stoqlib.lib.translation import stoqlib_gettext
 from stoqlib.gui.base.dialogs import BasicWrappingDialog, run_dialog
 from stoqlib.gui.base.messagebar import MessageBar
+from stoqlib.gui.events import EditorSlaveCreateEvent
 from stoqlib.gui.help import show_section
 
 log = Logger('stoqlib.gui.editors')
@@ -47,21 +47,19 @@ class BaseEditorSlave(GladeSlaveDelegate):
     """ Base class for editor slaves inheritance. It offers methods for
     setting up focus sequence, required attributes and validated attrs.
 
-    @cvar gladefile:
-    @cvar model_type:
-    @cvar model_iface:
+    :cvar gladefile:
+    :cvar model_type:
     """
     gladefile = None
     model_type = None
-    model_iface = None
     proxy_widgets = ()
 
     def __init__(self, conn, model=None, visual_mode=False):
         """ A base class for editor slaves inheritance
 
-        @param conn: a connection
-        @param model: the object model tied with the proxy widgets
-        @param visual_mode: does this slave must be opened in visual mode?
+        :param conn: a connection
+        :param model: the object model tied with the proxy widgets
+        :param visual_mode: does this slave must be opened in visual mode?
                             if so, all the proxy widgets will be disable
         """
         self.conn = self.trans = conn
@@ -82,25 +80,15 @@ class BaseEditorSlave(GladeSlaveDelegate):
         log.info("%s editor using a %smodel %s" % (
             self.__class__.__name__, created, type(model).__name__))
 
-        if self.model_iface:
-            if not isinstance(model, Adapter):
-                model = self.model_iface(model)
-            elif not self.model_iface.providedBy(model):
-                raise TypeError(
-                    "%s editor requires a model implementing %s, got a %r" % (
-                    self.__class__.__name__, self.model_iface.__name__,
-                    model))
-            self.model_type = self.model_type or type(model)
-
-        elif self.model_type:
+        if self.model_type:
             if not isinstance(model, self.model_type):
                 raise TypeError(
                     '%s editor requires a model of type %s, got a %r' % (
                     self.__class__.__name__, self.model_type.__name__,
                     model))
         else:
-            raise ValueError("Editor %s must define a model_type or "
-                             "model_iface attributes" % (
+            raise ValueError("Editor %s must define a model_type "
+                             "attribute" % (
                 self.__class__.__name__, ))
         self.model = model
 
@@ -110,6 +98,8 @@ class BaseEditorSlave(GladeSlaveDelegate):
         self.setup_proxies()
         self.setup_slaves()
 
+        EditorSlaveCreateEvent.emit(self, model, conn, visual_mode)
+
     def _setup_visual_mode(self):
         widgets = self.__class__.proxy_widgets
         for widget_name in widgets:
@@ -124,7 +114,7 @@ class BaseEditorSlave(GladeSlaveDelegate):
         After this method is called, the model can be accessed as self.model.
         The default behavior is to raise a TypeError, which can
         be overridden in a subclass.
-        @param trans: a database transaction
+        :param trans: a database transaction
         """
         raise TypeError(
                 "%r needs a model, got None. Perhaps you want to "
@@ -169,12 +159,12 @@ class BaseEditor(BaseEditorSlave):
     """ Base class for editor dialogs. It offers methods of
     BaseEditorSlave, a windows title and OK/Cancel buttons.
 
-    @cvar model_name: the model type name of the model we are editing.
+    :cvar model_name: the model type name of the model we are editing.
        This value will be showed in the title of the editor and can not
        be merely the attribute __name__ of the object for usability reasons.
        Call sites will decide what could be the best name applicable in each
        situation.
-    @cvar confirm_widgets: a list of widget names that when activated will
+    :cvar confirm_widgets: a list of widget names that when activated will
         confirm the dialog
     """
 
@@ -251,13 +241,13 @@ class BaseEditor(BaseEditorSlave):
 
     def enable_window_controls(self):
         """Enables the window controls
-        See L{kiwi.ui.views.BaseView.enable_window_controls}.
+        See :class:`kiwi.ui.views.BaseView.enable_window_controls`.
         """
         self.main_dialog.enable_window_controls()
 
     def set_description(self, description):
         """Sets the description of the model object which is used by the editor
-        @param description:
+        :param description:
         """
         format = self._get_title_format()
         self.main_dialog.set_title(format % description)
@@ -273,10 +263,10 @@ class BaseEditor(BaseEditorSlave):
         """
         Adds a button to editor. The added button is returned which you
         can use to connect signals on.
-        @param label: label of the button
-        @param stock: stock label of the button
-        @param returns: the button added
-        @rtype: gtk.Button
+        :param label: label of the button
+        :param stock: stock label of the button
+        :param returns: the button added
+        :rtype: gtk.Button
         """
 
         if label is None and stock is None:
@@ -332,14 +322,14 @@ class BaseEditor(BaseEditorSlave):
         """
         Make a widget confirmable, eg activating that widget would
         close the dialog.
-        @param widget_name: name of the widget to be confirmable
+        :param widget_name: name of the widget to be confirmable
         """
         self.main_dialog.set_confirm_widget(widget_name)
 
     def add_message_bar(self, message, message_type=gtk.MESSAGE_INFO):
         """Adds a message bar to the top of the search results
-        @message: message to add
-        @message_type: type of message to add
+        :param message: message to add
+        :param message_type: type of message to add
         """
         self._message_bar = MessageBar(message, message_type)
         toplevel = self.main_dialog.get_toplevel()
@@ -460,7 +450,7 @@ class BaseRelationshipEditorSlave(GladeSlaveDelegate):
         if not self.editor:
             return model
 
-        res = run_dialog(self.editor, self, self.conn, model)
+        res = run_dialog(self.editor, self._parent, self.conn, model)
 
         if not res:
             self.model_type.delete(id=model.id, connection=self.conn)
@@ -468,7 +458,7 @@ class BaseRelationshipEditorSlave(GladeSlaveDelegate):
         return res
 
     def edit(self, model):
-        return run_dialog(self.editor, self, self.conn, model)
+        return run_dialog(self.editor, self._parent, self.conn, model)
 
     def remove(self, model):
         self.model_type.delete(model.id, connection=self.conn)
