@@ -25,8 +25,7 @@
 import datetime
 
 from stoqlib.api import api
-from stoqlib.domain.interfaces import IUser, IClient
-from stoqlib.domain.person import Calls, Person
+from stoqlib.domain.person import Calls, LoginUser, Person
 from stoqlib.gui.base.dialogs import run_dialog
 from stoqlib.gui.editors.baseeditor import BaseEditor
 from stoqlib.lib.translation import stoqlib_gettext
@@ -46,15 +45,16 @@ class CallsEditor(BaseEditor):
                      'attendant')
     size = (400, 300)
 
-    def __init__(self, conn, model, person, person_iface):
+    def __init__(self, conn, model, person, person_type):
         self.person = person
-        self.person_iface = person_iface
+        self.person_type = person_type
         BaseEditor.__init__(self, conn, model)
         # If person is not None, this means we already are in this person
         # details dialog. No need for this option
         if person:
-            self.details_button.set_sensitive(False)
+            self.details_button.hide()
 
+        self.details_button.set_sensitive(self.model.person is not None)
         if self.model.person:
             self.set_description(_('Call to %s') % self.model.person.name)
         else:
@@ -79,19 +79,20 @@ class CallsEditor(BaseEditor):
                                         self.model.person)])
             self.person_combo.set_sensitive(False)
         else:
-            persons = [(p.person.name, p.person)
-                         for p in Person.iselect(self.person_iface,
-                                                 connection=self.conn)]
-            self.person_combo.prefill(sorted(persons))
+            # Get only persons of person_type by joining with the table
+            query = (self.person_type.q.personID == Person.q.id)
+            persons = Person.select(query, connection=self.conn)
+            self.person_combo.prefill(api.for_combo(persons, attr='name'))
 
     def _fill_attendant_combo(self):
-        attendants = [(a.person.name, a)
-                     for a in Person.iselect(IUser,
-                                             connection=self.conn)]
-        self.attendant.prefill(sorted(attendants))
+        login_users = LoginUser.select(connection=self.conn)
+        self.attendant.prefill(api.for_combo(login_users))
 
     def on_details_button__clicked(self, button):
         from stoqlib.gui.dialogs.clientdetails import ClientDetailsDialog
-        client = IClient(self.model.person, None)
+        client = self.model.person.client
         if client:
             run_dialog(ClientDetailsDialog, self, self.conn, client)
+
+    def on_person_combo__changed(self, combo):
+        self.details_button.set_sensitive(combo.read() is not None)
