@@ -31,10 +31,11 @@ from kiwi.ui.widgets.spinbutton import ProxySpinButton
 from kiwi.ui.widgets.textview import ProxyTextView
 from kiwi.ui.widgets.combo import ProxyComboEntry, ProxyComboBox
 
-from stoqlib.domain.base import AbstractModel
+from stoqlib.domain.base import Domain
+from stoqlib.domain.image import Image
 from stoqlib.domain.parameter import ParameterData
+from stoqlib.gui.slaves.imageslaveslave import ImageSlave
 from stoqlib.gui.editors.baseeditor import BaseEditor
-from stoqlib.lib.imageutils import ImageHelper
 from stoqlib.lib.parameters import (sysparam, get_parameter_details,
                                     DirectoryParameter)
 from stoqlib.lib.translation import stoqlib_gettext
@@ -52,6 +53,10 @@ class SystemParameterEditor(BaseEditor):
     def __init__(self, conn, model):
         if not model:
             raise ValueError("This editor can't be called without a model")
+        # By default, if the user sets a value to None (e.g. selecting nothing
+        # on a comboentry) we block it's update. Change this to False if the
+        # param itself can accept None.
+        self._block_none_value = True
         self.sensitive = True
         if model.field_name in ['DEMO_MODE']:
             self.sensitive = False
@@ -86,13 +91,16 @@ class SystemParameterEditor(BaseEditor):
         self._entry = widget
 
     def _setup_spin_entry_slave(self, box=None):
-        widget = ProxySpinButton()
+        data_type = self.constant.get_parameter_type()
+        widget = ProxySpinButton(data_type=data_type)
         widget.props.sensitive = self.sensitive
-        widget.data_type = int
         widget.set_range(self.constant.range[0], self.constant.range[1])
-        widget.set_value(int(self.model.field_value))
+        widget.set_value(data_type(self.model.field_value))
         widget.set_increments(1, 10)
-        widget.connect('changed', self._on_spin_changed)
+        if issubclass(data_type, Decimal):
+            widget.props.digits = 2
+
+        widget.connect('value-changed', self._on_spin__value_changed)
         if box is None:
             self.container.add(widget)
         else:
@@ -140,6 +148,24 @@ class SystemParameterEditor(BaseEditor):
         self.container.add(hbox)
         hbox.show()
 
+    def _setup_image_slave(self):
+        event_box = gtk.EventBox()
+        event_box.show()
+
+        field_name = self.model.field_name
+        model = sysparam(self.conn).get_parameter_by_field(field_name,
+                                                           Image)
+
+        self.container.add(event_box)
+        self._image_slave = ImageSlave(self.conn, model)
+        self._image_slave.connect('image-changed',
+                                  self._on_image_slave__image_changed)
+        self._image_slave.show()
+        self.attach_slave('image_slave', self._image_slave, event_box)
+
+        # Images can have field_value as None
+        self._block_none_value = False
+
     def _setup_comboboxentry_slave(self):
         widget = ProxyComboEntry()
         widget.props.sensitive = self.sensitive
@@ -205,15 +231,15 @@ class SystemParameterEditor(BaseEditor):
         sparam = sysparam(self.conn)
         self.constant = sparam.get_parameter_constant(self.model.field_name)
         field_type = self.constant.get_parameter_type()
-        if issubclass(field_type, AbstractModel):
+        if issubclass(field_type, Image):
+            self._setup_image_slave()
+        elif issubclass(field_type, Domain):
             self._setup_comboboxentry_slave()
-        elif issubclass(field_type, ImageHelper):
-            self._setup_entry_with_filechooser_button_slave()
         elif issubclass(field_type, DirectoryParameter):
             self._setup_entry_with_filechooser_button_slave(dir_only=True)
         elif issubclass(field_type, bool):
             self._setup_radio_slave()
-        elif issubclass(field_type, (int, float)):
+        elif issubclass(field_type, (int, float, Decimal)):
             if self.constant.options:
                 self._setup_options_combo_slave()
             elif self.constant.range:
@@ -225,15 +251,13 @@ class SystemParameterEditor(BaseEditor):
                 self._setup_text_view_slave()
             else:
                 self._setup_entry_slave()
-        elif issubclass(field_type, Decimal):
-            self._setup_entry_slave()
         else:
             raise TypeError("ParameterData for `%s' has an invalid "
                             "type: %r" % (self.model.field_name,
                                           field_type))
 
     def on_confirm(self):
-        if self.model.field_value is None:
+        if self._block_none_value and self.model.field_value is None:
             return False
         return self.model
 
@@ -241,6 +265,9 @@ class SystemParameterEditor(BaseEditor):
     # Callbacks
     #
 
+    def _on_image_slave__image_changed(self, slave, image):
+        self.model.field_value = image and str(image.id)
+
     def _on_entry__validate(self, widget, value):
         validate_func = self.constant.get_parameter_validator()
         if validate_func and callable(validate_func):
@@ -256,8 +283,15 @@ class SystemParameterEditor(BaseEditor):
     def _on_yes_radio__toggled(self, widget):
         self.model.field_value = str(int(widget.get_active()))
 
-    def _on_spin_changed(self, widget):
-        self.model.field_value = str(widget.get_value_as_int())
+    def _on_spin__value_changed(self, widget):
+        data_type = self.constant.get_parameter_type()
+        if data_type is int:
+            # float and Decimal are subclasses of int
+            value = widget.get_value_as_int()
+        else:
+            value = widget.read()
+
+        self.model.field_value = str(value)
 
     def _on_filechooser_button__selection_changed(self, widget):
         filename = widget.get_filename()
