@@ -2,7 +2,7 @@
 # vi:si:et:sw=4:sts=4:ts=4
 
 ##
-## Copyright (C) 2007-2011 Async Open Source <http://www.async.com.br>
+## Copyright (C) 2007-2012 Async Open Source <http://www.async.com.br>
 ## All rights reserved
 ##
 ## This program is free software; you can redistribute it and/or modify
@@ -26,6 +26,7 @@
 
 
 import datetime
+import operator
 
 from dateutil.relativedelta import relativedelta
 import gtk
@@ -34,14 +35,12 @@ from kiwi.datatypes import currency, ValidationError, ValueUnset
 from kiwi.ui.widgets.list import Column
 
 from stoqlib.api import api
-from stoqlib.domain.interfaces import (IInPayment, IOutPayment, IClient,
-                                       ISupplier)
 from stoqlib.domain.payment.category import PaymentCategory
 from stoqlib.domain.payment.group import PaymentGroup
 from stoqlib.domain.payment.method import PaymentMethod
 from stoqlib.domain.payment.payment import Payment
 from stoqlib.domain.payment.views import PaymentChangeHistoryView
-from stoqlib.domain.person import PersonAdaptToClient, PersonAdaptToSupplier
+from stoqlib.domain.person import Client, Supplier
 from stoqlib.domain.sale import SaleView
 from stoqlib.gui.base.dialogs import run_dialog
 from stoqlib.gui.dialogs.purchasedetails import PurchaseDetailsDialog
@@ -53,7 +52,7 @@ from stoqlib.gui.editors.personeditor import ClientEditor, SupplierEditor
 from stoqlib.gui.wizards.personwizard import run_person_role_dialog
 from stoqlib.lib.defaults import (INTERVALTYPE_WEEK,
                                   INTERVALTYPE_MONTH)
-from stoqlib.lib.translation import stoqlib_gettext
+from stoqlib.lib.translation import locale_sorted, stoqlib_gettext
 
 _ = stoqlib_gettext
 INTERVALTYPE_ONCE = -1
@@ -62,27 +61,37 @@ INTERVALTYPE_QUARTERLY = 11
 
 
 class PaymentEditor(BaseEditor):
-    gladefile = "PaymentEditor"
-    model_type = Payment
-    person_editor = None
-    person_class = None
-    person_iface = None
     title = _("Payment")
-    confirm_widgets = ['due_date']
+    gladefile = "PaymentEditor"
     proxy_widgets = ['value',
                      'description',
                      'due_date',
                      ]
+    # FIXME: Person should really be a proxy_widget attribute,
+    # but it breaks when displaying an existing payment
 
-    def __init__(self, conn, model=None):
+    confirm_widgets = ['due_date']
+
+    model_type = Payment
+
+    # Override in subclass
+    payment_type = None
+    person_editor = None
+    person_class = None
+
+    def __init__(self, conn, model=None, category=None):
         """ A base class for additional payments
 
-        @param conn: a database connection
-        @param model: a L{stoqlib.domain.payment.payment.Payment} object or None
+        :param conn: a database connection
+        :param model: a :class:`stoqlib.domain.payment.payment.Payment` object or None
 
         """
+        self._is_new_model = not model
         BaseEditor.__init__(self, conn, model)
         self._setup_widgets()
+        if category:
+            self.category.select_item_by_label(category)
+        self.description.grab_focus()
 
     #
     # BaseEditor hooks
@@ -103,6 +112,7 @@ class PaymentEditor(BaseEditor):
                        group=group,
                        till=None,
                        category=None,
+                       payment_type=self.payment_type,
                        connection=trans)
 
     def setup_proxies(self):
@@ -117,7 +127,7 @@ class PaymentEditor(BaseEditor):
             (_('Quarterly'), INTERVALTYPE_QUARTERLY)])
         self.add_category.set_tooltip_text(_("Add a new payment category"))
         self.edit_category.set_tooltip_text(_("Edit the selected payment category"))
-        if self.person_iface == ISupplier:
+        if self.person_type == Supplier:
             self.add_person.set_tooltip_text(_("Add a new supplier"))
             self.edit_person.set_tooltip_text(_("Edit the selected supplier"))
         else:
@@ -162,25 +172,27 @@ class PaymentEditor(BaseEditor):
     # Private
 
     def _populate_person(self):
-        if self.person_class == PersonAdaptToSupplier:
+        if self.person_class == Supplier:
             facets = self.person_class.get_active_suppliers(self.trans)
         else:
             facets = self.person_class.get_active_clients(self.trans)
 
         if facets:
-            self.person.prefill(sorted([(f.person.name, f)
-                                        for f in facets]))
+            items = [(f.person.name, f) for f in facets]
+            self.person.prefill(items)
         self.person.set_sensitive(bool(facets))
 
         person = getattr(self.model.group, self.person_attribute)
         if person:
-            facet = self.person_iface(person)
+            facet = self.person_type.selectOneBy(person=person,
+                                        connection=person.get_connection())
             self.person.select(facet)
 
     def _run_payment_category_editor(self, category=None):
         trans = api.new_transaction()
         category = trans.get(category)
-        model = run_dialog(PaymentCategoryEditor, self, trans, category)
+        model = run_dialog(PaymentCategoryEditor, self, trans, category,
+                           self.category_type)
         rv = api.finish_transaction(trans, model)
         trans.close()
         if rv:
@@ -198,21 +210,28 @@ class PaymentEditor(BaseEditor):
             self.person.select(model)
 
     def _fill_category_combo(self):
-        categories = PaymentCategory.select(
-            connection=self.trans).orderBy('name')
+        categories = PaymentCategory.selectBy(
+            connection=self.trans,
+            category_type=self.category_type).orderBy('name')
         self.category.set_sensitive(bool(categories))
-        categories = [(c.name, c) for c in categories]
-        categories.insert(0, (_('No category'), None))
-        self.category.prefill(categories)
+        self.category.prefill(api.for_combo(categories,
+                                            empty=_('No category'),
+                                            attr='name'))
         self.category.select(self.model.category)
         self.edit_category.set_sensitive(False)
 
     def _fill_method_combo(self):
-        methods = PaymentMethod.select(
-            connection=self.trans).orderBy('description')
+        methods = set()
+        if self._is_new_model:
+            methods.update(set(PaymentMethod.get_creatable_methods(
+                self.trans,
+                self.payment_type,
+                separate=True)))
+        methods.add(self.model.method)
         self.method.set_sensitive(False)
-        self.method.prefill([(m.description, m) for m in methods
-                             if m.is_active and m.method_name != 'multiple'])
+        self.method.prefill(locale_sorted(
+            [(m.description, m) for m in methods],
+            key=operator.itemgetter(0)))
         self.method.select(self.model.method)
 
     def _setup_widgets(self):
@@ -292,7 +311,7 @@ class PaymentEditor(BaseEditor):
 
         next_date = start_date + delta
         dates = []
-        while next_date < end_date:
+        while next_date <= end_date:
             dates.append(next_date)
             next_date = next_date + delta
         if not dates:
@@ -301,22 +320,19 @@ class PaymentEditor(BaseEditor):
         description = self.model.description
         self.model.description = '1/%d %s' % (n_dates, description)
         for i, date in enumerate(dates):
-            p = Payment(open_date=self.model.open_date,
-                        status=self.model.status,
-                        description='%d/%d %s' % (i + 2, n_dates,
-                                                  description),
-                        value=self.model.value,
-                        base_value=self.model.base_value,
-                        due_date=date,
-                        method=self.model.method,
-                        group=self.model.group,
-                        till=self.model.till,
-                        category=self.model.category,
-                        connection=self.conn)
-            if self.model.is_inpayment():
-                p.addFacet(IInPayment, connection=self.conn)
-            elif self.model.is_outpayment():
-                p.addFacet(IOutPayment, connection=self.conn)
+            Payment(open_date=self.model.open_date,
+                    payment_type=self.model.payment_type,
+                    status=self.model.status,
+                    description='%d/%d %s' % (i + 2, n_dates,
+                                              description),
+                    value=self.model.value,
+                    base_value=self.model.base_value,
+                    due_date=date,
+                    method=self.model.method,
+                    group=self.model.group,
+                    till=self.model.till,
+                    category=self.model.category,
+                    connection=self.conn)
 
     #
     # Kiwi Callbacks
@@ -359,46 +375,42 @@ class PaymentEditor(BaseEditor):
 
 
 class InPaymentEditor(PaymentEditor):
+    payment_type = Payment.TYPE_IN
     person_attribute = 'payer'
     person_editor = ClientEditor
-    person_class = PersonAdaptToClient
-    person_iface = IClient
+    person_class = Client
+    person_type = Client
     _person_label = _("Payer:")
     help_section = 'account-receivable'
+    category_type = PaymentCategory.TYPE_RECEIVABLE
 
-    def __init__(self, conn, model=None):
-        """ This dialog is responsible to create additional payments with
-        IInPayment facet.
-
-        @param conn: a database connection
-        @param model: a L{stoqlib.domain.payment.payment.Payment} object
-                      or None
+    def __init__(self, conn, model=None, category=None):
+        """Edit or display incoming payments
+        :param conn: a database connection
+        :param model: a :class:`Payment` object or None
         """
-        PaymentEditor.__init__(self, conn, model)
+        PaymentEditor.__init__(self, conn, model, category=category)
         if model is None or not model.is_inpayment():
-            self.model.addFacet(IInPayment, connection=self.conn)
             self.can_edit_details()
 
 
 class OutPaymentEditor(PaymentEditor):
+    payment_type = Payment.TYPE_OUT
     person_attribute = 'recipient'
     person_editor = SupplierEditor
-    person_class = PersonAdaptToSupplier
-    person_iface = ISupplier
+    person_class = Supplier
+    person_type = Supplier
     _person_label = _("Recipient:")
     help_section = 'account-payable'
+    category_type = PaymentCategory.TYPE_PAYABLE
 
-    def __init__(self, conn, model=None):
-        """ This dialog is responsible to create additional payments with
-        IOutPayment facet.
-
-        @param conn: a database connection
-        @param model: a L{stoqlib.domain.payment.payment.Payment} object
-                      or None
+    def __init__(self, conn, model=None, category=None):
+        """Edit or display outgoing payments
+        :param conn: a database connection
+        :param model: a :class:`Payment` object or None
         """
-        PaymentEditor.__init__(self, conn, model)
+        PaymentEditor.__init__(self, conn, model, category=category)
         if model is None or not model.is_outpayment():
-            self.model.addFacet(IOutPayment, connection=self.conn)
             self.can_edit_details()
 
 
@@ -486,3 +498,13 @@ def get_dialog_for_payment(payment):
         return OutPaymentEditor
 
     raise TypeError(payment)
+
+
+def test():
+    creator = api.prepare_test()
+    retval = run_dialog(InPaymentEditor, None, creator.trans, None)
+    api.finish_transaction(creator.trans, retval)
+
+
+if __name__ == '__main__':
+    test()
