@@ -26,6 +26,7 @@
 
 from kiwi.datatypes import ValidationError
 
+from stoqlib.api import api
 from stoqlib.domain.account import Account
 from stoqlib.domain.payment.method import PaymentMethod
 from stoqlib.gui.base.dialogs import run_dialog
@@ -48,8 +49,8 @@ class PaymentMethodEditor(BaseEditor):
     def __init__(self, conn, model):
         """
         Create a new PaymentMethodEditor object.
-        @param conn: an orm Transaction instance
-        @param model: an adapter of PaymentMethod which means a subclass of
+        :param conn: an orm Transaction instance
+        :param model: an adapter of PaymentMethod which means a subclass of
                       PaymentMethod
         """
         self.model_type = PaymentMethod
@@ -57,9 +58,9 @@ class PaymentMethodEditor(BaseEditor):
         self.set_description(model.description)
 
     def _setup_widgets(self):
-        destinations = Account.select(connection=self.conn)
-        items = [(a.long_description, a) for a in destinations]
-        self.account.prefill(sorted(items))
+        accounts = Account.select(connection=self.conn)
+        self.account.prefill(api.for_combo(
+            accounts, attr='long_description'))
         self.account.select(self.model.destination_account)
 
     #
@@ -107,3 +108,14 @@ class MoneyPaymentMethodEditor(PaymentMethodEditor):
     def __init__(self, conn, model):
         PaymentMethodEditor.__init__(self, conn, model)
         self.slave_holder.hide()
+
+
+def test():
+    creator = api.prepare_test()
+    money = PaymentMethod.get_by_name(creator.trans, 'bill')
+    retval = run_dialog(PaymentMethodEditor, None, creator.trans, money)
+    api.finish_transaction(creator.trans, retval)
+
+
+if __name__ == '__main__':
+    test()
