@@ -2,7 +2,7 @@
 # vi:si:et:sw=4:sts=4:ts=4
 
 ##
-## Copyright (C) 2005-2008 Async Open Source <http://www.async.com.br>
+## Copyright (C) 2005-2012 Async Open Source <http://www.async.com.br>
 ## All rights reserved
 ##
 ## This program is free software; you can redistribute it and/or modify
@@ -27,6 +27,7 @@ import datetime
 
 from kiwi.datatypes import ValidationError
 
+from stoqlib.api import api
 from stoqlib.lib.translation import stoqlib_gettext
 from stoqlib.gui.editors.simpleeditor import SimpleEntryEditor
 from stoqlib.gui.templates.persontemplate import BasePersonRoleEditor
@@ -41,10 +42,9 @@ from stoqlib.gui.slaves.userslave import UserDetailsSlave, UserStatusSlave
 from stoqlib.gui.slaves.supplierslave import SupplierDetailsSlave
 from stoqlib.gui.slaves.transporterslave import TransporterDataSlave
 from stoqlib.gui.slaves.branchslave import BranchDetailsSlave
-from stoqlib.domain.person import EmployeeRole, PersonAdaptToCreditProvider
-from stoqlib.domain.interfaces import (IClient, ICreditProvider, IEmployee,
-                                       ISupplier, ITransporter, IUser,
-                                       IIndividual, IBranch)
+from stoqlib.domain.person import (Client, Branch, Employee, EmployeeRole,
+                                   CreditProvider, Individual, LoginUser,
+                                   Supplier, Transporter)
 
 _ = stoqlib_gettext
 
@@ -52,7 +52,7 @@ _ = stoqlib_gettext
 class ClientEditor(BasePersonRoleEditor):
     model_name = _('Client')
     title = _('New Client')
-    model_iface = IClient
+    model_type = Client
     gladefile = 'BaseTemplate'
 
     help_section = 'client'
@@ -64,9 +64,9 @@ class ClientEditor(BasePersonRoleEditor):
 
     def create_model(self, conn):
         person = BasePersonRoleEditor.create_model(self, conn)
-        client = IClient(person, None)
+        client = person.client
         if client is None:
-            client = person.addFacet(IClient, connection=conn)
+            client = Client(person=person, connection=conn)
         return client
 
     def setup_slaves(self):
@@ -79,7 +79,7 @@ class ClientEditor(BasePersonRoleEditor):
 class UserEditor(BasePersonRoleEditor):
     model_name = _('User')
     title = _('New User')
-    model_iface = IUser
+    model_type = LoginUser
     gladefile = 'BaseTemplate'
     USER_TAB_POSITION = 0
 
@@ -93,13 +93,14 @@ class UserEditor(BasePersonRoleEditor):
 
     def create_model(self, conn):
         person = BasePersonRoleEditor.create_model(self, conn)
-        user = IUser(person, None)
-        return user or person.addFacet(IUser, connection=conn, username="",
-                                       password="", profile=None)
+        return person.login_user or LoginUser(person=person,
+                                              connection=conn, username="",
+                                              password="", profile=None)
 
     def setup_slaves(self):
         BasePersonRoleEditor.setup_slaves(self)
-        user_status = UserStatusSlave(self.conn, self.model)
+        user_status = UserStatusSlave(self.conn, self.model,
+                            visual_mode=self.visual_mode)
         self.main_slave.attach_person_slave(user_status)
         passwd_fields = not self.edit_mode
         self.user_details = UserDetailsSlave(self.conn, self.model,
@@ -125,7 +126,7 @@ class UserEditor(BasePersonRoleEditor):
 class CreditProviderEditor(BasePersonRoleEditor):
     model_name = _('Credit Provider')
     title = _('New Credit Provider')
-    model_iface = ICreditProvider
+    model_type = CreditProvider
     gladefile = 'BaseTemplate'
     provtype = None
 
@@ -135,16 +136,16 @@ class CreditProviderEditor(BasePersonRoleEditor):
 
     def create_model(self, conn):
         person = BasePersonRoleEditor.create_model(self, conn)
-        credprovider = ICreditProvider(person, None)
-        if credprovider:
-            return credprovider
+        if person.credit_provider:
+            return person.credi_provider
         if self.provtype is None:
-            raise ValueError('Subclasses of CreditProviderEditor must '
+            raise ValueError('subclasses of CreditProviderEditor must '
                              'define a provtype attribute')
-        return person.addFacet(ICreditProvider, short_name='',
-                               provider_type=self.provtype,
-                               open_contract_date=datetime.datetime.today(),
-                               connection=conn)
+        return CreditProvider(person=person,
+                              short_name='',
+                              provider_type=self.provtype,
+                              open_contract_date=datetime.datetime.today(),
+                              connection=conn)
 
     def setup_slaves(self):
         BasePersonRoleEditor.setup_slaves(self)
@@ -158,13 +159,13 @@ class CreditProviderEditor(BasePersonRoleEditor):
 class CardProviderEditor(CreditProviderEditor):
     model_name = _('Card Provider')
     title = _('New Card Provider')
-    provtype = PersonAdaptToCreditProvider.PROVIDER_CARD
+    provtype = CreditProvider.PROVIDER_CARD
 
 
 class EmployeeEditor(BasePersonRoleEditor):
     model_name = _('Employee')
     title = _('New Employee')
-    model_iface = IEmployee
+    model_type = Employee
     gladefile = 'BaseTemplate'
 
     ui_form_name = 'employee'
@@ -175,11 +176,11 @@ class EmployeeEditor(BasePersonRoleEditor):
 
     def create_model(self, conn):
         person = BasePersonRoleEditor.create_model(self, conn)
-        if not IIndividual(person, None):
-            person.addFacet(IIndividual, connection=self.conn)
-        employee = IEmployee(person, None)
+        if not person.individual:
+            Individual(person=person, connection=self.conn)
+        employee = person.employee
         if not employee:
-            employee = person.addFacet(IEmployee, connection=conn, role=None)
+            employee = Employee(person=person, connection=conn, role=None)
         return employee
 
     def setup_slaves(self):
@@ -254,7 +255,7 @@ class EmployeeRoleEditor(SimpleEntryEditor):
 class SupplierEditor(BasePersonRoleEditor):
     model_name = _('Supplier')
     title = _('New Supplier')
-    model_iface = ISupplier
+    model_type = Supplier
     gladefile = 'BaseTemplate'
 
     help_section = 'supplier'
@@ -266,9 +267,9 @@ class SupplierEditor(BasePersonRoleEditor):
 
     def create_model(self, conn):
         person = BasePersonRoleEditor.create_model(self, conn)
-        supplier = ISupplier(person, None)
+        supplier = person.supplier
         if supplier is None:
-            supplier = person.addFacet(ISupplier, connection=conn)
+            supplier = Supplier(person=person, connection=conn)
         return supplier
 
     def setup_slaves(self):
@@ -282,7 +283,7 @@ class SupplierEditor(BasePersonRoleEditor):
 class TransporterEditor(BasePersonRoleEditor):
     model_name = _('Transporter')
     title = _('New Transporter')
-    model_iface = ITransporter
+    model_type = Transporter
     gladefile = 'BaseTemplate'
 
     help_section = 'transporter'
@@ -294,9 +295,10 @@ class TransporterEditor(BasePersonRoleEditor):
 
     def create_model(self, conn):
         person = BasePersonRoleEditor.create_model(self, conn)
-        transporter = ITransporter(person, None)
+        transporter = person.transporter
         if transporter is None:
-            transporter = person.addFacet(ITransporter, connection=conn)
+            transporter = Transporter(person=person,
+                                      connection=conn)
         return transporter
 
     def setup_slaves(self):
@@ -311,7 +313,7 @@ class TransporterEditor(BasePersonRoleEditor):
 class BranchEditor(BasePersonRoleEditor):
     model_name = _('Branch')
     title = _('New Branch')
-    model_iface = IBranch
+    model_type = Branch
     gladefile = 'BaseTemplate'
 
     help_section = 'branch'
@@ -323,9 +325,9 @@ class BranchEditor(BasePersonRoleEditor):
 
     def create_model(self, conn):
         person = BasePersonRoleEditor.create_model(self, conn)
-        branch = IBranch(person, None)
+        branch = person.branch
         if branch is None:
-            branch = person.addFacet(IBranch, connection=conn)
+            branch = Branch(person=person, connection=conn)
 
         return branch
 
@@ -334,3 +336,14 @@ class BranchEditor(BasePersonRoleEditor):
         self.status_slave = BranchDetailsSlave(self.conn, self.model,
                                                visual_mode=self.visual_mode)
         self.main_slave.attach_person_slave(self.status_slave)
+
+
+def test():
+    from stoqlib.gui.wizards.personwizard import run_person_role_dialog
+    creator = api.prepare_test()
+    retval = run_person_role_dialog(ClientEditor, None, creator.trans, None)
+    api.finish_transaction(creator.trans, retval)
+
+
+if __name__ == '__main__':
+    test()
