@@ -27,18 +27,14 @@ from decimal import Decimal
 import sys
 
 import gtk
-
 from kiwi.datatypes import ValidationError, currency
 from kiwi.ui.widgets.list import Column, SummaryLabel
-
 from stoqdrivers.enum import TaxType
 
-
-from stoqlib.domain.interfaces import IStorable
-from stoqlib.domain.person import PersonAdaptToSupplier
+from stoqlib.domain.person import Supplier
 from stoqlib.domain.product import (ProductSupplierInfo, Product,
                                     ProductComponent,
-                                    ProductQualityTest)
+                                    ProductQualityTest, Storable)
 from stoqlib.domain.sellable import (Sellable,
                                      SellableTaxConstant)
 from stoqlib.domain.views import ProductFullStockView
@@ -49,11 +45,11 @@ from stoqlib.gui.editors.baseeditor import (BaseEditor, BaseEditorSlave,
 from stoqlib.gui.editors.sellableeditor import SellableEditor
 from stoqlib.gui.slaves.productslave import (ProductDetailsSlave,
                                              ProductTaxSlave)
+from stoqlib.lib.defaults import quantize
 from stoqlib.lib.message import info, yesno
 from stoqlib.lib.parameters import sysparam
 from stoqlib.lib.translation import stoqlib_gettext
 from stoqlib.lib.formatters import get_formatted_cost
-from stoqlib.lib.pluginmanager import get_plugin_manager
 
 _ = stoqlib_gettext
 
@@ -90,7 +86,7 @@ class _TemporaryProductComponent(object):
     #
 
     def get_total_production_cost(self):
-        return self.production_cost * self.quantity
+        return quantize(self.production_cost * self.quantity)
 
     def delete_product_component(self, connection):
         component = self._get_product_component(connection)
@@ -308,12 +304,12 @@ class ProductComponentSlave(BaseEditorSlave):
         return len(self.component_tree) > 0
 
     def get_component_cost(self):
-        value = 0
+        value = Decimal('0')
         for component in self.component_tree:
             if self.component_tree.get_parent(component):
                 continue
             value += component.get_total_production_cost()
-        return value
+        return quantize(value)
 
     #
     # Kiwi Callbacks
@@ -506,7 +502,7 @@ class ProductSupplierSlave(BaseRelationshipEditorSlave):
             self.target_combo.select(suggested)
 
     def get_targets(self):
-        suppliers = PersonAdaptToSupplier.get_active_suppliers(self.conn)
+        suppliers = Supplier.get_active_suppliers(self.conn)
         return [(s.person.name, s) for s in suppliers]
 
     def get_relations(self):
@@ -527,8 +523,8 @@ class ProductSupplierSlave(BaseRelationshipEditorSlave):
 
         if product.is_supplied_by(supplier):
             product_desc = self._product.sellable.get_description()
-            info(_(u'%s is already supplied by %s' % (product_desc,
-                                                      supplier.person.name)))
+            info(_(u'%s is already supplied by %s') % (product_desc,
+                                                      supplier.person.name))
             return
 
         model = ProductSupplierInfo(product=product,
@@ -590,9 +586,10 @@ class ProductEditor(SellableEditor):
     _model_created = False
 
     def get_taxes(self):
-        constants = SellableTaxConstant.select(connection=self.conn)
-        return [(c.description, c) for c in constants
-                                   if c.tax_type != TaxType.SERVICE]
+        query = (SellableTaxConstant.q.tax_type != int(TaxType.SERVICE))
+        constants = SellableTaxConstant.select(query,
+                                        connection=self.conn).orderBy('id')
+        return [(c.description, c) for c in constants]
 
     def update_status_unavailable_label(self):
         text = ''
@@ -603,19 +600,6 @@ class ProductEditor(SellableEditor):
 
         self.status_unavailable_label.set_text(text)
 
-    def _get_plugin_tabs(self):
-        manager = get_plugin_manager()
-        tab_list = []
-
-        for plugin_name in manager.active_plugins_names:
-            plugin = manager.get_plugin(plugin_name)
-            if plugin.has_product_slave:
-                slave_class = plugin.get_product_slave_class()
-                plugin_product_slave = slave_class(self.conn, self.model)
-                tab_list.append((slave_class.title, plugin_product_slave))
-
-        return tab_list
-
     #
     # BaseEditor
     #
@@ -630,7 +614,6 @@ class ProductEditor(SellableEditor):
 
     def get_extra_tabs(self):
         extra_tabs = []
-        extra_tabs.extend(self._get_plugin_tabs())
 
         suppliers_slave = ProductSupplierSlave(self.conn, self.model)
         extra_tabs.append((_(u'Suppliers'), suppliers_slave))
@@ -654,7 +637,7 @@ class ProductEditor(SellableEditor):
                             connection=conn)
         sellable.unit = sysparam(self.conn).SUGGESTED_UNIT
         model = Product(connection=conn, sellable=sellable)
-        model.addFacet(IStorable, connection=conn)
+        Storable(product=model, connection=conn)
         return model
 
     def on_consignment_yes_button__toggled(self, widget):
