@@ -25,19 +25,19 @@
 
 This file contains several editors used in the production process:
 
-L{ProductionItemEditor}: A base class with some information about the product or
+:class:`ProductionItemEditor`: A base class with some information about the product or
                          material (description, location, unit). See subclasses
                          for specifc usage.
 
-L{ProducedItemSlave}: A slave for serial number input.
+:class:`ProducedItemSlave`: A slave for serial number input.
 
-L{ProductionItemProducedEditor}: A dialog to enter the number of itens produced.
-                                 This uses the L{ProducedItemSlave} slave for
+:class:`ProductionItemProducedEditor`: A dialog to enter the number of itens produced.
+                                 This uses the :class:`ProducedItemSlave` slave for
                                  serial number input
-L{ProductionItemLostEditor}: A dialog to input the number of items lost.
+:class:`ProductionItemLostEditor`: A dialog to input the number of items lost.
 
-L{ProductionServiceEditor}: Editor for an service item in the production order
-L{ProductionMaterialEditor}: Item for an production material in the production
+:class:`ProductionServiceEditor`: Editor for an service item in the production order
+:class:`ProductionMaterialEditor`: Item for an production material in the production
                              order
 """
 
@@ -53,7 +53,7 @@ from stoqlib.domain.production import ProductionProducedItem
 from stoqlib.domain.production import (ProductionItem, ProductionMaterial,
                                        ProductionService)
 from stoqlib.gui.editors.baseeditor import BaseEditor, BaseEditorSlave
-from stoqlib.lib.defaults import DECIMAL_PRECISION
+from stoqlib.lib.defaults import QUANTITY_PRECISION
 from stoqlib.lib.message import info
 from stoqlib.lib.translation import stoqlib_gettext
 
@@ -88,7 +88,7 @@ class ProductionItemEditor(BaseEditor):
         self.order_number.set_text("%04d" % self.model.order.id)
         self.quantity.set_adjustment(
             gtk.Adjustment(lower=0, upper=self.get_max_quantity(), step_incr=1))
-        self.quantity.set_digits(DECIMAL_PRECISION)
+        self.quantity.set_digits(QUANTITY_PRECISION)
 
     def get_max_quantity(self):
         """Returns the maximum quantity allowed in the quantity spinbutton.
