@@ -30,6 +30,7 @@ from kiwi.datatypes import ValidationError, currency
 from kiwi.ui.objectlist import Column
 from stoqdrivers.enum import TaxType, UnitType
 
+from stoqlib.api import api
 from stoqlib.database.exceptions import IntegrityError
 from stoqlib.domain.fiscal import CfopData
 from stoqlib.domain.person import ClientCategory
@@ -42,6 +43,7 @@ from stoqlib.gui.base.lists import ModelListDialog
 from stoqlib.gui.databaseform import DatabaseForm
 from stoqlib.gui.editors.baseeditor import (BaseEditor,
                                             BaseRelationshipEditorSlave)
+from stoqlib.gui.editors.categoryeditor import SellableCategoryEditor
 from stoqlib.gui.slaves.commissionslave import CommissionSlave
 from stoqlib.gui.slaves.sellableslave import OnSaleInfoSlave
 from stoqlib.lib.message import info, yesno, warning
@@ -426,39 +428,36 @@ class SellableEditor(BaseEditor):
         """Subclasses may override this method to provide a custom
         tax selection.
 
-        @returns: a list of tuples containing the tax description and a
-            L{stoqlib.domain.sellable.SellableTaxConstant} object.
+        :returns: a list of tuples containing the tax description and a
+            :class:`stoqlib.domain.sellable.SellableTaxConstant` object.
         """
         return []
 
+    def _fill_categories(self):
+        categories = SellableCategory.select(connection=self.conn)
+        self.category_combo.prefill(api.for_combo(categories,
+                                                  attr='full_description'))
+
     #
     # BaseEditor hooks
     #
 
     def setup_sellable_combos(self):
-        category_list = SellableCategory.select(
-            SellableCategory.q.categoryID != None,
-            connection=self.conn).orderBy('description')
-
-        items = [(cat.get_description(), cat) for cat in category_list]
-        self.category_combo.prefill(items)
+        self._fill_categories()
+        self.edit_category.set_sensitive(False)
 
         self.statuses_combo.prefill(
                     [(v, k) for k, v in Sellable.statuses.items()])
         self.statuses_combo.set_sensitive(False)
 
-        cfop_items = [(item.get_description(), item)
-                        for item in CfopData.select(connection=self.conn)]
-        cfop_items.insert(0, ('', None))
-        self.default_sale_cfop.prefill(cfop_items)
+        cfops = CfopData.select(connection=self.conn)
+        self.default_sale_cfop.prefill(api.for_combo(cfops, empty=''))
 
         self.setup_unit_combo()
 
     def setup_unit_combo(self):
         units = SellableUnit.select(connection=self.conn)
-        items = [(_("No unit"), None)]
-        items.extend([(unit.description, unit) for unit in units])
-        self.unit_combo.prefill(items)
+        self.unit_combo.prefill(api.for_combo(units, empty=_('No units')))
 
     def setup_tax_constants(self):
         taxes = self.get_taxes()
@@ -468,6 +467,8 @@ class SellableEditor(BaseEditor):
         self.set_widget_formats()
         self._sellable = self.model.sellable
 
+        self.add_category.set_tooltip_text(_("Add a new category"))
+        self.edit_category.set_tooltip_text(_("Edit the selected category"))
         self.setup_sellable_combos()
         self.setup_tax_constants()
         self.tax_proxy = self.add_proxy(self._sellable,
@@ -478,6 +479,12 @@ class SellableEditor(BaseEditor):
 
         self.update_requires_weighing_label()
 
+    def _run_category_editor(self, category=None):
+        # Editing this in a new transaction is causing a deadlock
+        model = run_dialog(SellableCategoryEditor, self, self.conn, category)
+        if model:
+            self._fill_categories()
+            self.category_combo.select(model)
     #
     # Kiwi handlers
     #
@@ -524,6 +531,9 @@ class SellableEditor(BaseEditor):
         self._sellable.set_unavailable()
         self.confirm()
 
+    def on_category_combo__content_changed(self, category):
+        self.edit_category.set_sensitive(bool(category.get_selected()))
+
     def on_tax_constant__changed(self, combo):
         self._update_tax_value()
 
@@ -533,6 +543,12 @@ class SellableEditor(BaseEditor):
     def on_sale_price_button__clicked(self, button):
         self.edit_sale_price()
 
+    def on_add_category__clicked(self, widget):
+        self._run_category_editor()
+
+    def on_edit_category__clicked(self, widget):
+        self._run_category_editor(self.category_combo.get_selected())
+
     def on_code__validate(self, widget, value):
         if not value:
             return ValidationError(_(u'The code can not be empty.'))
