@@ -25,12 +25,13 @@
 
 from kiwi.datatypes import  ValidationError
 
+from stoqlib.api import api
+
 from stoqlib.database.runtime import get_current_station
-from stoqlib.lib.translation import stoqlib_gettext
 from stoqlib.domain.station import BranchStation
-from stoqlib.domain.interfaces import IBranch
-from stoqlib.domain.person import Person
+from stoqlib.domain.person import Branch
 from stoqlib.gui.editors.baseeditor import BaseEditor
+from stoqlib.lib.translation import stoqlib_gettext
 
 _ = stoqlib_gettext
 
@@ -60,11 +61,8 @@ class StationEditor(BaseEditor):
                              connection=conn)
 
     def setup_proxies(self):
-        statuses = []
-        # FIXME: Implement and use IDescribable on PersonAdaptToBranch
-        for branch in Person.iselect(IBranch, connection=self.conn):
-            statuses.append((branch.person.name, branch))
-        self.branch.prefill(sorted(statuses))
+        branches = Branch.select(connection=self.conn)
+        self.branch.prefill(api.for_combo(branches))
 
         self.add_proxy(self.model, StationEditor.proxy_widgets)
         if not self.edit_mode:
