@@ -25,18 +25,25 @@
 import inspect
 import gc
 
+from kiwi.component import provide_utility
 from kiwi.python import Settable
-from kiwi.ui.wizard import WizardStep
 from twisted.trial.unittest import SkipTest
 
 from stoqlib.api import api
 from stoqlib.lib.introspection import get_all_classes
+from stoqlib.gui.domainslavemapper import DefaultDomainSlaveMapper
 from stoqlib.gui.editors.baseeditor import BaseEditor, BaseEditorSlave
+from stoqlib.gui.interfaces import IDomainSlaveMapper
+from stoqlib.gui.base.wizards import WizardStep
 from stoqlib.domain.person import Person
 
 from stoqlib.domain.test.domaintest import DomainTest
 
 
+provide_utility(IDomainSlaveMapper, DefaultDomainSlaveMapper(),
+                replace=True)
+
+
 def get_all_slaves():
     slaves = []
     for klass in get_all_classes('stoqlib/gui'):
@@ -71,10 +78,7 @@ def _test_slave(self, slave):
         if arg in ['conn', 'trans']:
             value = self.trans
         elif arg == 'model':
-            if slave.model_type is None:
-                model_type = slave.model_iface
-            else:
-                model_type = slave.model_type
+            model_type = slave.model_type
 
             if slave.create_model == BaseEditor.create_model:
                 needs_model = True
@@ -136,9 +140,11 @@ def _create_slave_test():
     TODO = {}
     SKIP = {
         'PaymentEditor': 'Base Class for other editors',
+        'OutPaymentEditor': 'missing method',
         'BranchDialog': 'cannot provide ICurrentBranch twice',
         'BranchEditor': ' ',
         'CreditProviderEditor': ' ',
+        'DeliveryEditor': 'need implement create_model',
         'ICMSTemplateSlave': 'Unkown type',
         'IPITemplateSlave': 'Unkown type',
         'InConsignmentItemEditor': ' ',
@@ -152,6 +158,7 @@ def _create_slave_test():
         'AccountTransactionEditor': 'needs to set a value',
         'PurchaseInstallmentConfirmationSlave': 'pending payment',
         'SaleInstallmentConfirmationSlave': 'pending payment',
+        'SellableCategoryEditor': 'Needs a parent category',
         'EmployeeEditor': 'bank account',
         'EmployeeDetailsSlave': 'bank account',
         }
@@ -161,7 +168,7 @@ def _create_slave_test():
         args = inspect.getargspec(slave.__init__)[0]
         if 'wizard' in args or 'model_type' in args:
             continue
-        if slave.model_iface is None and slave.model_type is None:
+        if slave.model_type is None:
             continue
         if slave.model_type is Settable:
             continue
