@@ -24,6 +24,7 @@
 """ Editors implementation for open/close operation on till operation"""
 
 import datetime
+from datetime import timedelta
 
 from kiwi.datatypes import ValidationError, currency
 from kiwi.python import Settable
@@ -37,8 +38,7 @@ from stoqlib.domain.account import AccountTransaction
 from stoqlib.domain.events import (TillOpenEvent, TillCloseEvent,
                                    TillAddTillEntryEvent,
                                    TillAddCashEvent, TillRemoveCashEvent)
-from stoqlib.domain.interfaces import IEmployee
-from stoqlib.domain.person import Person
+from stoqlib.domain.person import Employee
 from stoqlib.domain.till import Till
 from stoqlib.exceptions import DeviceError, TillError
 from stoqlib.gui.editors.baseeditor import BaseEditor, BaseEditorSlave
@@ -75,12 +75,22 @@ class _TillClosingModel(object):
         self.value = value
 
     def get_opening_date(self):
+        # self.till is None only in the special case that the user added the ECF
+        # to Stoq with a pending reduce Z, so we need to close the till on the
+        # ECF, but not on Stoq.
+        # Return a date in the past
+        if not self.till:
+            return datetime.datetime.now() - timedelta(1)
         return self.till.opening_date
 
     def get_cash_amount(self):
+        if not self.till:
+            return currency(0)
         return currency(self.till.get_cash_amount() - self.value)
 
     def get_balance(self):
+        if not self.till:
+            return currency(0)
         return currency(self.till.get_balance() - self.value)
 
 
@@ -164,11 +174,12 @@ class TillClosingEditor(BaseEditor):
                  close_ecf=True):
         """
         Create a new TillClosingEditor object.
-        @param previous_day: If the till wasn't closed previously
+        :param previous_day: If the till wasn't closed previously
         """
         self._previous_day = previous_day
         self.till = Till.get_last(conn)
-        assert self.till
+        if close_db:
+            assert self.till
         self._close_db = close_db
         self._close_ecf = close_ecf
         BaseEditor.__init__(self, conn, model)
@@ -194,6 +205,10 @@ class TillClosingEditor(BaseEditor):
         self.day_history_box.pack_start(summary_day_history, False)
 
     def _get_day_history(self):
+        if not self.till:
+            assert self._close_ecf and not self._close_db
+            return
+
         day_history = {}
         day_history[_(u'Initial Amount')] = self.till.initial_cash_amount
 
@@ -229,7 +244,7 @@ class TillClosingEditor(BaseEditor):
         return _TillClosingModel(till=self.till, value=currency(0))
 
     def setup_proxies(self):
-        if not self.till.get_balance():
+        if self.till and not self.till.get_balance():
             self.value.set_sensitive(False)
         self.proxy = self.add_proxy(self.model,
                                     TillClosingEditor.proxy_widgets)
@@ -358,9 +373,9 @@ class CashAdvanceEditor(BaseEditor):
         return self.employee_combo.get_selected_label()
 
     def _setup_widgets(self):
-        # FIXME: Implement and use IDescribable on PersonAdaptToEmployee
+        # FIXME: Implement and use IDescribable on Employee
         employees = [(e.person.name, e)
-                     for e in Person.iselect(IEmployee, connection=self.conn)]
+                     for e in Employee.select(connection=self.conn)]
         self.employee_combo.prefill(employees)
         self.employee_combo.set_active(0)
 
