@@ -39,8 +39,8 @@ from stoqlib.domain.events import (CardPaymentReceiptPrepareEvent,
                                    GerencialReportPrintEvent,
                                    GerencialReportCancelEvent,
                                    CancelPendingPaymentsEvent,
-                                   HasPendingReduceZ)
-from stoqlib.domain.interfaces import ICompany, IContainer
+                                   HasPendingReduceZ, HasOpenCouponEvent)
+from stoqlib.domain.interfaces import IContainer
 from stoqlib.domain.till import Till
 from stoqlib.drivers.cheque import print_cheques_for_payment_group
 from stoqlib.exceptions import DeviceError, TillError
@@ -96,8 +96,8 @@ class FiscalPrinterHelper(gobject.GObject):
 
     def __init__(self, conn, parent):
         """ Creates a new FiscalPrinterHelper object
-        @param conn:
-        @param parent: a gtk.Window subclass or None
+        :param conn:
+        :param parent: a gtk.Window subclass or None
         """
         gobject.GObject.__init__(self)
         self.conn = conn
@@ -131,9 +131,9 @@ class FiscalPrinterHelper(gobject.GObject):
         fixing an conflicting status: If the DB is open but the ECF is
         closed, or the other way around.
 
-        @param close_db: If the till in the DB should be closed
-        @param close_ecf: If the till in the ECF should be closed
-        @returns: True if the till was closed, otherwise False
+        :param close_db: If the till in the DB should be closed
+        :param close_ecf: If the till in the ECF should be closed
+        :returns: True if the till was closed, otherwise False
         """
 
         if not self._previous_day:
@@ -171,7 +171,7 @@ class FiscalPrinterHelper(gobject.GObject):
         """Checks if the last opened till was closed and asks the
         user if he wants to close it
 
-        @returns:
+        :returns:
             - CLOSE_TILL_BOTH if both DB and ECF needs closing.
             - CLOSE_TILL_DB if only DB needs closing.
             - CLOSE_TILL_ECF if only ECF needs closing.
@@ -197,12 +197,12 @@ class FiscalPrinterHelper(gobject.GObject):
 
     def create_coupon(self):
         """ Creates a new fiscal coupon
-        @returns: a new coupon
+        :returns: a new coupon
         """
 
         if sysparam(self.conn).DEMO_MODE:
             branch = api.get_current_branch(self.conn)
-            company = ICompany(branch.person, None)
+            company = branch.person.company
             if company and company.cnpj not in ['24.198.774/7322-35',
                                                 '66.873.574/0001-82']:
                 # FIXME: Find a better description for the warning bellow.
@@ -279,6 +279,15 @@ class FiscalPrinterHelper(gobject.GObject):
 
         return False
 
+    def check_open_coupon(self):
+        try:
+            HasOpenCouponEvent.emit()
+            return True
+        except (DeviceError, DriverError), e:
+            warning(e)
+            self.emit('ecf-changed', False)
+            return False
+
     def check_till(self):
         try:
             self._check_needs_closing()
@@ -287,6 +296,18 @@ class FiscalPrinterHelper(gobject.GObject):
             warning(e)
             self.emit('ecf-changed', False)
 
+    def run_initial_checks(self):
+        """This will check:
+
+        1) If printer has open coupon, cancel it
+        2) If printer has pending reduce Z, offer to close the till
+
+        If the first check fails, the second one will not happen
+        """
+        if not self.check_open_coupon():
+            return
+        self.check_till()
+
 
 class FiscalCoupon(gobject.GObject):
     """ This class is used just to allow us cancel an item with base in a
@@ -343,8 +364,8 @@ class FiscalCoupon(gobject.GObject):
     def add_item(self, sale_item):
         """ Adds an item to fiscal coupon
 
-        @param sale_item: a sale item
-        @returns: id of the sale_item.:
+        :param sale_item: a sale item
+        :returns: id of the sale_item.:
           0 >= if it was added successfully
           -1 if an error happend
           0 if added but not printed (free deliveries)
