@@ -1,4 +1,4 @@
-# -*- Mode: Python; coding: iso-8859-1 -*-
+# -*- Mode: Python; coding: utf-8 -*-
 # vi:si:et:sw=4:sts=4:ts=4
 
 ##
@@ -22,76 +22,85 @@
 ## Author(s): Stoq Team <stoq-devel@async.com.br>
 ##
 
+import platform
+
+import gtk
 from kiwi.component import get_utility
 
 from stoqlib.lib.interfaces import IApplicationDescriptions
 from stoqlib.lib.translation import stoqlib_gettext
 
 _ = stoqlib_gettext
-
 _user_bindings = {}
 
+if platform.system() == 'Darwin':
+    default_pref_shortcut = '<Primary>comma'
+else:
+    default_pref_shortcut = ''
+
 _bindings = [
     # Common application shortcuts
-    ('app.common.toggle_fullscreen', '<Control>F11',
+    ('app.common.toggle_fullscreen', '<Primary>F11',
      _('Toggle fullscreen')),
     ('app.common.toggle_statusbar', '',
      _('Toggle statusbar')),
     ('app.common.toggle_toolbar', '',
      _('Toggle toolbar')),
-    ('app.common.new_window', '<Control>n',
+    ('app.common.new_window', '<Primary>n',
      _('Create a new Window')),
     ('app.common.change_password', '',
      _('Change password')),
     ('app.common.sign_out', '',
      _('Sign out')),
-    ('app.common.close_window', '<Control>w',
+    ('app.common.close_window', '<Primary>w',
      _('Close window')),
-    ('app.common.print', '<Control>p',
+    ('app.common.print', '<Primary>p',
      _("Print"),),
-    ('app.common.quit', '<Control>q',
+    ('app.common.preferences', default_pref_shortcut,
+     _("Show preferences")),
+    ('app.common.quit', '<Primary>q',
      _("Quit the application")),
     ('app.common.help', 'F1',
      _('Show help')),
-    ('app.common.help_contents', '<Control>F1',
+    ('app.common.help_contents', '<Primary>F1',
      _('Show help contents')),
 
     # Admin application
-    ('app.admin.search_roles', '<Control><Alt>o',
+    ('app.admin.search_roles', '<Primary><Alt>o',
      _("Search for employee roles")),
-    ('app.admin.search_employees', '<Control><Alt>e',
+    ('app.admin.search_employees', '<Primary><Alt>e',
      _("Search for employees")),
     ('app.admin.search_events', '',
      _("Search for events")),
-    ('app.admin.search_cfop', '<Control>o',
+    ('app.admin.search_cfop', '<Primary>o',
      _("Search for C.F.O.Ps")),
-    ('app.admin.search_fiscalbook', '<Control><alt>f',
+    ('app.admin.search_fiscalbook', '<Primary><alt>f',
      _("Search for fiscal books")),
-    ('app.admin.search_profile', '<Control><Alt>u',
+    ('app.admin.search_profile', '<Primary><Alt>u',
      _("Search for user profiles")),
-    ('app.admin.search_users', '<Control>u',
+    ('app.admin.search_users', '<Primary>u',
      _("Search for users")),
-    ('app.admin.search_branches', '<Control>b',
+    ('app.admin.search_branches', '<Primary>b',
      _("Search for company branches")),
-    ('app.admin.search_computers', '<Control><alt>h',
+    ('app.admin.search_computers', '<Primary><alt>h',
      _("Search for computers")),
-    ('app.admin.config_devices', '<Control>d',
+    ('app.admin.config_devices', '<Primary>d',
      _("Configure devices")),
-    ('app.admin.config_payment_methods', '<Control>m',
+    ('app.admin.config_payment_methods', '<Primary>m',
      _("Configure payment methods")),
-    ('app.admin.config_payment_categories', '<Control>a',
+    ('app.admin.config_payment_categories', '<Primary>a',
      _("Configure payment categories")),
-    ('app.admin.config_client_categories', '<Control>x',
+    ('app.admin.config_client_categories', '<Primary>x',
      _("Configure client categories")),
-    ('app.admin.config_invoices', '<Control>n',
+    ('app.admin.config_invoices', '<Primary>n',
      _("Configure invoices")),
-    ('app.admin.config_invoice_printers', '<Control>f',
+    ('app.admin.config_invoice_printers', '<Primary>f',
      _("Configure invoice printers")),
-    ('app.admin.config_sintegra', '<Control>w',
+    ('app.admin.config_sintegra', '',
      _("Configure sintegra")),
-    ('app.admin.config_taxes', '<Control>l',
+    ('app.admin.config_taxes', '<Primary>l',
      _("Configure tax classes")),
-    ('app.admin.config_parameters', '<Control>y',
+    ('app.admin.config_parameters', '<Primary>y',
      _("Configure parameters")),
 
     # Calendar application
@@ -109,15 +118,17 @@ _bindings = [
      _("Show today")),
 
     # Financial application
-    ('app.financial.import', '<Control>i',
+    ('app.financial.configure_payment_methods', '',
+     _("Configure payment methods")),
+    ('app.financial.import', '<Primary>i',
      _("Import transactions")),
     ('app.financial.delete_account', '',
      _("Delete account")),
     ('app.financial.delete_transaction', '',
      _("Delete account transaction")),
-    ('app.financial.new_account', '<Control>a',
+    ('app.financial.new_account', '<Primary>a',
      _("Create a new account")),
-    ('app.financial.new_transaction', '<Control>t',
+    ('app.financial.new_transaction', '<Primary>t',
      _("Create a new account transaction")),
     ('app.financial.edit', '',
      _("Edit an account or account transaction")),
@@ -125,9 +136,9 @@ _bindings = [
     # Inventory application
     ('app.inventory.new_inventory', '',
      _("Open a new inventory")),
-    ('app.inventory.inventory_count', '<Control>c',
+    ('app.inventory.inventory_count', '<Primary>c',
      _("Count the selected inventory")),
-    ('app.inventory.inventory_adjust', '<Control>a',
+    ('app.inventory.inventory_adjust', '<Primary>a',
      _("Adjust the selected inventory")),
     ('app.inventory.inventory_cancel', '',
      _("Cancel the selected inventory")),
@@ -135,16 +146,16 @@ _bindings = [
      _('Print the product listing for the selected inventory')),
 
     # Payable application
-    ('app.payable.add_payable', '<Control>p',
+    ('app.payable.add_payable', '<Primary>p',
      _("Create a new account payable")),
-    ('app.payable.payment_flow_history', '<Control>f',
+    ('app.payable.payment_flow_history', '<Primary>f',
      _('Show a report of payment expected to receive grouped by day')),
     ('app.payable.payment_details', '',
      _("Show details for the selected payment")),
     ('app.payable.payment_pay', '',
      _("Pay the selected payment")),
     ('app.payable.payment_edit', '',
-     _("Edit the selected payment")),
+     _("Edit the selected payment installments")),
     ('app.payable.payment_cancel', '',
      _("Cancel the selected payment")),
     ('app.payable.payment_set_not_paid', '',
@@ -153,57 +164,59 @@ _bindings = [
      _("Change the selected payment due date")),
     ('app.payable.payment_comments', '',
      _("Add comments to the selected payment")),
-    ('app.payable.payment_print_receipt', '<Control>r',
+    ('app.payable.payment_print_receipt', '<Primary>r',
      _("Print a receipt for the selected payment")),
+    ('app.payable.search_payment_categories', '',
+     _("Search for payment categories")),
     ('app.payable.search_bills', '',
      _("Search for paid bills")),
 
     # Pos application
-    ('app.pos.till_open', '<Control>F6',
+    ('app.pos.till_open', '<Primary>F6',
      _("Open the till")),
-    ('app.pos.till_close', '<Control>F7',
+    ('app.pos.till_close', '<Primary>F7',
      _("Close the till")),
-    ('app.pos.order_confirm', '<Control>F10',
+    ('app.pos.order_confirm', '<Primary>F10',
      _("Confirm the current order")),
-    ('app.pos.order_cancel', '<Control><Alt>o',
+    ('app.pos.order_cancel', '<Primary><Alt>o',
      _("Cancel the current order")),
-    ('app.pos.order_create_delivery', '<Control>F5',
+    ('app.pos.order_create_delivery', '<Primary>F5',
      _("Create a delivery for the current order")),
-    ('app.pos.search_sales', '<Control><Alt>a',
+    ('app.pos.search_sales', '<Primary><Alt>a',
      _("Search for sales ")),
-    ('app.pos.search_sold_items', '<Contrl><Alt>a',
+    ('app.pos.search_sold_items', '<Primary><Alt>a',
      _("Search for sold items")),
-    ('app.pos.search_clients', '<Control><Alt>c',
+    ('app.pos.search_clients', '<Primary><Alt>c',
      _("Search for clients")),
-    ('app.pos.search_products', '<Control><Alt>p',
+    ('app.pos.search_products', '<Primary><Alt>p',
      _("Search for products")),
-    ('app.pos.search_services', '<Contro><Alt>s',
+    ('app.pos.search_services', '<Primary><Alt>s',
      _("Search for services")),
-    ('app.pos.search_deliveries', '<Control><Alt>e',
+    ('app.pos.search_deliveries', '<Primary><Alt>e',
      _("Search for deliveries")),
-    # ecf till read memory: <Control>F9
-    # ecf till summarize: <Control>F11
-    # books search books: <Control><Alt>B
-    # books search publishers: <Control><Alt>P
+    # ecf till read memory: <Primary>F9
+    # ecf till summarize: <Primary>F11
+    # books search books: <Primary><Alt>B
+    # books search publishers: <Primary><Alt>P
 
     # Production application
-    ('app.production.new_production_order', '<Control>o',
+    ('app.production.new_production_order', '<Primary>o',
      _("Create a new production order")),
-    ('app.production.new_production_quote', '<Control>p',
+    ('app.production.new_production_quote', '<Primary>p',
      _("Create a new production quote")),
     ('app.production.production_details', '',
      _("Show details for the selected production")),
-    ('app.production.production_start', '<Control>t',
+    ('app.production.production_start', '<Primary>t',
      _("Start the selected production")),
     ('app.production.production_edit', '',
      _("Edit the selected production")),
-    ('app.production.search_production_products', '<Control>d',
+    ('app.production.search_production_products', '<Primary>d',
      _("Search for production products")),
-    ('app.production.search_services', '<Control>s',
+    ('app.production.search_services', '<Primary>s',
      _("Search for services")),
-    ('app.production.search_production_items', '<Control>r',
+    ('app.production.search_production_items', '<Primary>r',
      _("Search for production items")),
-    ('app.production.search_production_history', '<Control>h',
+    ('app.production.search_production_history', '<Primary>h',
      _("Search for production history")),
 
     # Purchase application
@@ -215,27 +228,25 @@ _bindings = [
      _("Create a new consignment")),
     ('app.purchase.new_product', '',
      _("Create a new product")),
-    ('app.purchase.search_base_categories', '<Control>b',
-     _("Search for base categories")),
-    ('app.purchase.search_categories', '<Control>c',
+    ('app.purchase.search_categories', '<Primary>c',
      _("Search for categories")),
-    ('app.purchase.search_products', '<Control>d',
+    ('app.purchase.search_products', '<Primary>d',
      _("Search for products")),
-    ('app.purchase.search_product_units', '<Control>u',
+    ('app.purchase.search_product_units', '<Primary>u',
      _("Search for product units")),
-    ('app.purchase.search_services', '<Control>s',
+    ('app.purchase.search_services', '<Primary>s',
      _("Search for services")),
-    ('app.purchase.search_stock_items', '<Control>i',
+    ('app.purchase.search_stock_items', '<Primary>i',
      _("Search for stock items")),
-    ('app.purchase.search_closed_stock_items', '<Control><Alt>c',
+    ('app.purchase.search_closed_stock_items', '<Primary><Alt>c',
      _("Search for closed stock items")),
-    ('app.purchase.search_suppliers', '<Control>u',
+    ('app.purchase.search_suppliers', '<Primary>u',
      _("Search for suppliers")),
-    ('app.purchase.search_transporters', '<Control>t',
+    ('app.purchase.search_transporters', '<Primary>t',
      _("Search for transporters")),
-    ('app.purchase.search_quotes', '<Control>e',
+    ('app.purchase.search_quotes', '<Primary>e',
      _("Search for quotes")),
-    ('app.purchase.search_purchased_items', '<Control>p',
+    ('app.purchase.search_purchased_items', '<Primary>p',
      _("Search for purchased items")),
     ('app.purchase.search_products_sold', '',
      _("Search for sold products")),
@@ -253,13 +264,13 @@ _bindings = [
      _("Show details for the selected purchase order")),
     ('app.purchase.order_finish', '',
      _("Finish the selected purchase order")),
-    # books search books: <Control><Alt>B
-    # books search publishers: <Control><Alt>P
+    # books search books: <Primary><Alt>B
+    # books search publishers: <Primary><Alt>P
 
     # Receivable application
-    ('app.receivable.add_receiving', '<Control>p',
+    ('app.receivable.add_receiving', '<Primary>p',
      _("Create a new account receivable")),
-    ('app.receivable.payment_flow_history', '<Control>f',
+    ('app.receivable.payment_flow_history', '<Primary>f',
      _('Show a report of payment expected to receive grouped by day')),
     ('app.receivable.payment_details', '',
      _("Show details for the selected payment")),
@@ -273,29 +284,33 @@ _bindings = [
      _("Change the selected payment due date")),
     ('app.receivable.payment_renegotiate', '',
      _("Renegotiate the selected payment")),
+    ('app.receivable.payment_edit_installments', '',
+     _("Edit the selected payment installments")),
     ('app.receivable.payment_comments', '',
      _("Add comments to the selected payment")),
     ('app.receivable.payment_print_bill', '',
      _("Print a bill for the selected payment")),
-    ('app.receivable.payment_print_receipt', '<Control>r',
+    ('app.receivable.payment_print_receipt', '<Primary>r',
      _("Print a receipt for the selected payment")),
+    ('app.receivable.search_payment_categories', '',
+     _("Search for payment categories")),
     ('app.receivable.search_bills', '',
      _("Search for bills")),
     ('app.receivable.search_card_payments', '',
      _("Search for card payments")),
 
     # Sales application
-    ('app.sales.search_sold_items_by_branch', '<Control><Alt>a',
+    ('app.sales.search_sold_items_by_branch', '<Primary><Alt>a',
      _("Search for sold items by branch")),
-    ('app.sales.search_products', '<Control><Alt>p',
+    ('app.sales.search_products', '<Primary><Alt>p',
      _("Search for products")),
-    ('app.sales.search_services', '<Control><Alt>s',
+    ('app.sales.search_services', '<Primary><Alt>s',
      _("Search for services")),
-    ('app.sales.search_deliveries', '<Control><Alt>e',
+    ('app.sales.search_deliveries', '<Primary><Alt>e',
      _("Search for deliveries")),
-    ('app.sales.search_clients', '<Control><Alt>c',
+    ('app.sales.search_clients', '<Primary><Alt>c',
      _("Search for clients")),
-    ('app.sales.search_commissions', '<Control><Alt>o',
+    ('app.sales.search_commissions', '<Primary><Alt>o',
      _("Search for commissions")),
     ('app.sales.search_loans', '',
      _("Search for loans")),
@@ -313,47 +328,47 @@ _bindings = [
      _("Show details for the selected sale")),
     ('app.sales.search_client_calls', '',
      _("Search for client calls")),
-    # books search books: <Control><Alt>B
-    # books search publishers: <Control><Alt>P
+    # books search books: <Primary><Alt>B
+    # books search publishers: <Primary><Alt>P
 
     # Stock application
-    ('app.stock.new_receiving', '<Control>r',
+    ('app.stock.new_receiving', '<Primary>r',
      _("Create a new receiving")),
-    ('app.stock.transfer_product', '<Control>t',
+    ('app.stock.transfer_product', '<Primary>t',
      _("Create a new product transfer")),
-    ('app.stock.search_receiving', '<Control><Alt>u',
+    ('app.stock.search_receiving', '<Primary><Alt>u',
      _("Search for receivings")),
-    ('app.stock.search_product_history', "<Control><Alt>p",
+    ('app.stock.search_product_history', "<Primary><Alt>p",
      _("Search for product history")),
     ('app.stock.search_purchased_stock_items', '',
      _("Search for purchased stock items")),
-    ('app.stock.search_stock_items', "<Control><Alt>s",
+    ('app.stock.search_stock_items', "<Primary><Alt>s",
      _("Search for stock items")),
-    ('app.stock.search_transfers', "<Control><Alt>t",
+    ('app.stock.search_transfers', "<Primary><Alt>t",
      _("Search for transfers")),
-    ('app.stock.search_closed_stock_items', "<Control><Alt>c",
+    ('app.stock.search_closed_stock_items', "<Primary><Alt>c",
      _("Search for closed stock items")),
     ('app.stock.edit_product', '',
      _("Edit the selected product")),
     ('app.stock.history', '',
      _("Show the selected product history")),
-    ('app.stock.toggle_picture_viewer', '<Control><Alt>v',
+    ('app.stock.toggle_picture_viewer', '<Primary><Alt>v',
      _("Toggle the picture viewer")),
 
     # Till application
-    ('app.till.open_till', '<Control>F6',
+    ('app.till.open_till', '<Primary>F6',
      _("Open the till")),
-    ('app.till.close_till', '<Control>F7',
+    ('app.till.close_till', '<Primary>F7',
      _("Close the till")),
-    ('app.till.search_clients', '<Control><Alt>c',
+    ('app.till.search_clients', '<Primary><Alt>c',
      _("Search for clients")),
-    ('app.till.search_sale', '<Control><Alt>a',
+    ('app.till.search_sale', '<Primary><Alt>a',
      _("Search for sales")),
-    ('app.till.search_sold_items_by_branch', '<Contrl><Alt>d',
+    ('app.till.search_sold_items_by_branch', '<Primary><Alt>d',
      _("Search for sold items by branch")),
-    ('app.till.search_till_history', '<Control><Alt>t',
+    ('app.till.search_till_history', '<Primary><Alt>t',
      _("Search for till history")),
-    ('app.till.search_fiscal_till_operations', '<Contro><Alt>f',
+    ('app.till.search_fiscal_till_operations', '<Primary><Alt>f',
      _("Search for fiscal till operations")),
     ('app.till.confirm_sale', '',
      _("Confirm the sale")),
@@ -361,8 +376,8 @@ _bindings = [
      _("Return the sale")),
     ('app.till.sale_details', '',
      _("Show details of the sale")),
-    # ecf till read memory: <Control>F9
-    # ecf till summarize: <Control>F11
+    # ecf till read memory: <Primary>F9
+    # ecf till summarize: <Primary>F11
 ]
 
 
@@ -388,6 +403,9 @@ class KeyBindingCategory(object):
         self.label = label
 
 
+_pre_gtk_2_24_9 = gtk.gtk_version < (2, 24, 9)
+
+
 class KeyBindingGroup(object):
     def __init__(self, bindings):
         self._bindings = bindings
@@ -395,7 +413,12 @@ class KeyBindingGroup(object):
     def get(self, name):
         if not name in self._bindings:
             raise AttributeError(name)
-        return self._bindings[name]
+        binding = self._bindings[name]
+        if _pre_gtk_2_24_9:
+            binding = binding.replace('<Primary>', '<Control>')
+        if platform.system() == 'Darwin':
+            binding = binding.replace('<Alt>', '<Control>')
+        return binding
 
 
 def add_bindings(bindings):
