@@ -31,11 +31,10 @@ from kiwi.ui.search import DateSearchFilter
 from kiwi.ui.objectlist import SearchColumn, Column
 
 from stoqlib.api import api
-from stoqlib.domain.interfaces import IClient
-from stoqlib.domain.person import CallsView, ClientCallsView
+from stoqlib.domain.person import CallsView, Client, ClientCallsView
 from stoqlib.gui.base.dialogs import run_dialog
 from stoqlib.gui.base.search import SearchEditor
-from stoqlib.gui.dialogs.csvexporterdialog import CSVExporterDialog
+from stoqlib.gui.dialogs.spreadsheetexporterdialog import SpreadSheetExporterDialog
 from stoqlib.gui.editors.callseditor import CallsEditor
 from stoqlib.gui.printing import print_report
 from stoqlib.lib.translation import stoqlib_gettext
@@ -48,7 +47,7 @@ class CallsSearch(SearchEditor):
     """This search can be used directly, to show calls to any kind of person in
     the system.
 
-    Subclasses can also override I{person_interface} to set the person type that
+    Subclasses can also override I{person_type} to set the person type that
     will be available when creating a new call, and I{person_name}, that will be
     the column title in this search.
     """
@@ -56,17 +55,17 @@ class CallsSearch(SearchEditor):
     search_table = CallsView
     editor_class = CallsEditor
     searching_by_date = True
-    person_interface = None
+    person_type = None
     person_name = _('Person')
     size = (700, 450)
 
     def __init__(self, conn, person=None, date=None, reuse_transaction=False):
         """
-        @param person: If not None, the search will show only call made to
+        :param person: If not None, the search will show only call made to
             this person.
-        @param date: If not None, the search will be filtered using this date by
+        :param date: If not None, the search will be filtered using this date by
             default
-        @param reuse_transaction: When False, a new transaction will be
+        :param reuse_transaction: When False, a new transaction will be
             created/commited when creating a new call. When True, no transaction
             will be created. In this case, I{conn} will be utilized.
         """
@@ -84,7 +83,7 @@ class CallsSearch(SearchEditor):
         return calls.call
 
     def setup_widgets(self):
-        self.csv_button = self.add_button(label=_("Export CSV..."))
+        self.csv_button = self.add_button(label=_("Export to spreadsheet..."))
         self.csv_button.connect('clicked', self._on_export_csv_button__clicked)
         self.csv_button.show()
         self.csv_button.set_sensitive(False)
@@ -122,7 +121,7 @@ class CallsSearch(SearchEditor):
                              data_type=str, width=100, expand=True)]
         if not self.person:
             columns.insert(1,
-                SearchColumn('person', title=self.person_name,
+                SearchColumn('name', title=self.person_name,
                              data_type=str, width=150, expand=True))
         return columns
 
@@ -146,17 +145,17 @@ class CallsSearch(SearchEditor):
 
     def run_editor(self, obj):
         if self._reuse_transaction:
-            self.conn.savepoint('before_run_editor')
+            self.conn.savepoint('before_run_editor_calls')
             retval = run_dialog(self.editor_class, self, self.conn,
                                 self.conn.get(obj), self.person,
-                                self.person_interface)
+                                self.person_type)
             if not retval:
-                self.conn.rollback_to_savepoint('before_run_editor')
+                self.conn.rollback_to_savepoint('before_run_editor_calls')
         else:
             trans = api.new_transaction()
             retval = run_dialog(self.editor_class, self, trans,
                                 trans.get(obj), self.person,
-                                self.person_interface)
+                                self.person_type)
             api.finish_transaction(trans, retval)
             trans.close()
         return retval
@@ -166,8 +165,10 @@ class CallsSearch(SearchEditor):
     #
 
     def _on_export_csv_button__clicked(self, widget):
-        run_dialog(CSVExporterDialog, self, self.conn, self.search_table,
-                   self.results)
+        run_dialog(SpreadSheetExporterDialog, self,
+                   object_list=self.results,
+                   name=_('Calls'),
+                   filename_prefix=_('calls'))
 
     def _on_results__has_rows(self, widget, has_rows):
         self.print_button.set_sensitive(has_rows)
@@ -182,5 +183,5 @@ class CallsSearch(SearchEditor):
 class ClientCallsSearch(CallsSearch):
     title = _("Calls Search")
     search_table = ClientCallsView
-    person_interface = IClient
+    person_type = Client
     person_name = _('Client')
