@@ -32,8 +32,7 @@ from kiwi.ui.search import ComboSearchFilter
 from kiwi.ui.objectlist import SearchColumn, ColoredColumn, Column
 
 from stoqlib.domain.commission import CommissionView
-from stoqlib.domain.interfaces import ISalesPerson
-from stoqlib.domain.person import Person
+from stoqlib.domain.person import SalesPerson
 from stoqlib.reporting.sale import SalesPersonReport
 from stoqlib.gui.base.search import SearchDialog
 from stoqlib.gui.printing import print_report
@@ -57,7 +56,7 @@ class CommissionSearch(SearchDialog):
         self.set_searchbar_labels(_('matching:'))
 
         persons = [p.person.name for p in
-                   Person.iselect(ISalesPerson, connection=self.conn)]
+                   SalesPerson.select(connection=self.conn)]
         persons = zip(persons, persons)
         persons.insert(0, (_('Anyone'), None))
         salesperson_filter = ComboSearchFilter(_('Sold by:'), persons)
