@@ -34,7 +34,7 @@ from kiwi.ui.objectlist import Column, ColoredColumn, SearchColumn
 
 from stoqlib.api import api
 from stoqlib.database.orm import AND
-from stoqlib.domain.person import PersonAdaptToBranch
+from stoqlib.domain.person import Branch
 from stoqlib.domain.product import Product
 from stoqlib.domain.sellable import Sellable
 from stoqlib.domain.views import (ProductQuantityView,
@@ -45,7 +45,7 @@ from stoqlib.gui.base.dialogs import run_dialog
 from stoqlib.gui.base.gtkadds import change_button_appearance
 from stoqlib.gui.base.search import (SearchDialog, SearchEditor,
                                      SearchDialogPrintSlave)
-from stoqlib.gui.dialogs.csvexporterdialog import CSVExporterDialog
+from stoqlib.gui.dialogs.spreadsheetexporterdialog import SpreadSheetExporterDialog
 from stoqlib.gui.editors.producteditor import (ProductEditor,
                                                ProductStockEditor)
 from stoqlib.gui.printing import print_report
@@ -75,16 +75,16 @@ class ProductSearch(SearchEditor):
                  hide_price_column=False):
         """
         Create a new ProductSearch object.
-        @param conn: a orm Transaction instance
-        @param hide_footer: do I have to hide the dialog footer?
-        @param hide_toolbar: do I have to hide the dialog toolbar?
-        @param selection_mode: the kiwi list selection mode
-        @param hide_cost_column: if it's True, no need to show the
+        :param conn: a orm Transaction instance
+        :param hide_footer: do I have to hide the dialog footer?
+        :param hide_toolbar: do I have to hide the dialog toolbar?
+        :param selection_mode: the kiwi list selection mode
+        :param hide_cost_column: if it's True, no need to show the
                                  column 'cost'
-        @param use_product_statuses: a list instance that, if provided, will
+        :param use_product_statuses: a list instance that, if provided, will
                                      overwrite the statuses list defined in
                                      get_filter_slave method
-        @param hide_price_column: if it's True no need to show the
+        :param hide_price_column: if it's True no need to show the
                                   column 'price'
         """
         self.use_product_statuses = use_product_statuses
@@ -124,7 +124,7 @@ class ProductSearch(SearchEditor):
     #
 
     def setup_widgets(self):
-        self.csv_button = self.add_button(label=_(u'Export CSV...'))
+        self.csv_button = self.add_button(label=_('Export to spreadsheet...'))
         self.csv_button.connect('clicked', self._on_export_csv_button__clicked)
         self.csv_button.show()
         self.csv_button.set_sensitive(False)
@@ -187,7 +187,7 @@ class ProductSearch(SearchEditor):
     def executer_query(self, query, having, conn):
         branch = self.branch_filter.get_state().value
         if branch is not None:
-            branch = PersonAdaptToBranch.get(branch, connection=conn)
+            branch = Branch.get(branch, connection=conn)
 
         composed_query = Product.q.is_composed == False
         if query:
@@ -203,8 +203,10 @@ class ProductSearch(SearchEditor):
     #
 
     def _on_export_csv_button__clicked(self, widget):
-        run_dialog(CSVExporterDialog, self, self.conn, self.search_table,
-                   self.results)
+        run_dialog(SpreadSheetExporterDialog, self,
+                   object_list=self.results,
+                   name=_('Product'),
+                   filename_prefix=_('product'))
 
     def _on_results__has_rows(self, widget, has_rows):
         self.csv_button.set_sensitive(has_rows)
@@ -319,7 +321,7 @@ class ProductsSoldSearch(SearchDialog):
         # duplicate values in the results.
         branch = self.branch_filter.get_state().value
         if branch is not None:
-            branch = PersonAdaptToBranch.get(branch, connection=conn)
+            branch = Branch.get(branch, connection=conn)
 
         date = self.date_filter.get_state()
         if isinstance(date, DateQueryState):
@@ -412,7 +414,7 @@ class ProductStockSearch(SearchEditor):
     def executer_query(self, query, having, conn):
         branch = self.branch_filter.get_state().value
         if branch is not None:
-            branch = PersonAdaptToBranch.get(branch, connection=conn)
+            branch = Branch.get(branch, connection=conn)
         return self.table.select_by_branch(query, branch, connection=conn)
 
 
