@@ -32,7 +32,6 @@ from kiwi.ui.objectlist import SearchColumn
 
 from stoqlib.api import api
 from stoqlib.database.orm import AND
-from stoqlib.domain.interfaces import IStorable
 from stoqlib.domain.sellable import Sellable
 from stoqlib.domain.views import SellableFullStockView
 from stoqlib.gui.base.columns import AccessorColumn
@@ -60,16 +59,16 @@ class SellableSearch(SearchEditor):
                  info_message=None):
         """
         Create a new SellableSearch object.
-        @param conn: a orm Transaction instance
-        @param hide_footer: do I have to hide the dialog footer?
-        @param hide_toolbar: do I have to hide the dialog toolbar?
-        @param selection_mode: the kiwi list selection mode
-        @param search_str: FIXME
-        @param sale_items: optionally, a list of sellables which will be
+        :param conn: a orm Transaction instance
+        :param hide_footer: do I have to hide the dialog footer?
+        :param hide_toolbar: do I have to hide the dialog toolbar?
+        :param selection_mode: the kiwi list selection mode
+        :param search_str: FIXME
+        :param sale_items: optionally, a list of sellables which will be
             used to deduct stock values
-        @param quantity: the quantity of stock to add to the order,
+        :param quantity: the quantity of stock to add to the order,
             is necessary to supply if you supply an order.
-        @param double_click_confirm: If double click a item in the list should
+        :param double_click_confirm: If double click a item in the list should
             automatically confirm
         """
         self._first_search = True
@@ -88,7 +87,7 @@ class SellableSearch(SearchEditor):
                 raise TypeError("You need to specify a quantity "
                                 "when supplying an order")
             for item in sale_items:
-                if IStorable(item.sellable.product, None):
+                if item.sellable.product_storable:
                     quantity = self.current_sale_stock.get(item.sellable.id, 0)
                     quantity += item.quantity
                     self.current_sale_stock[item.sellable.id] = quantity
@@ -158,7 +157,7 @@ class SellableSearch(SearchEditor):
         if not sellable_view:
             return
         sellable = Sellable.get(sellable_view.id, self.conn)
-        if (IStorable(sellable.product, None) and
+        if (sellable.product_storable and
             self.quantity > self._get_available_stock(sellable_view)):
             self.ok_button.set_sensitive(False)
         else:
