@@ -30,16 +30,16 @@ from kiwi.datatypes import currency, ValidationError
 from kiwi.ui.objectlist import Column
 from kiwi import ValueUnset
 
+from stoqlib.api import api
+from stoqlib.domain.account import Account
+from stoqlib.domain.purchase import PurchaseOrder
+from stoqlib.domain.sale import Sale, SaleView
 from stoqlib.gui.base.dialogs import run_dialog
 from stoqlib.gui.dialogs.purchasedetails import PurchaseDetailsDialog
 from stoqlib.gui.dialogs.saledetails import SaleDetailsDialog
 from stoqlib.gui.editors.baseeditor import BaseEditor
-from stoqlib.lib.translation import stoqlib_gettext
 from stoqlib.lib.parameters import sysparam
-from stoqlib.domain.account import Account
-from stoqlib.domain.payment.operation import register_payment_operations
-from stoqlib.domain.purchase import PurchaseOrder
-from stoqlib.domain.sale import Sale, SaleView
+from stoqlib.lib.translation import stoqlib_gettext
 
 _ = stoqlib_gettext
 
@@ -139,7 +139,7 @@ class _SaleConfirmationModel(_ConfirmationModel):
             return self._sale.client.person.name
 
     def confirm(self):
-        paid = [p.is_paid() for p in self._sale.group.get_items()]
+        paid = [p.is_paid() for p in self._sale.payments]
         if all(paid):
             self._sale.set_paid()
 
@@ -218,8 +218,8 @@ class _InstallmentConfirmationSlave(BaseEditor):
 
     def __init__(self, conn, payments):
         """ Creates a new _InstallmentConfirmationSlave
-        @param conn: a database connection
-        @param payments: a list of payments
+        :param conn: a database connection
+        :param payments: a list of payments
         """
         self._payments = payments
         self._proxy = None
@@ -291,7 +291,6 @@ class _InstallmentConfirmationSlave(BaseEditor):
     def _update_accounts(self):
         if len(self._payments) != 1:
             return
-        register_payment_operations()
 
         payment = self._payments[0]
         create_transaction = payment.method.operation.create_transaction()
@@ -300,8 +299,9 @@ class _InstallmentConfirmationSlave(BaseEditor):
             return
 
         destinations = Account.select(connection=self.conn)
-        items = [(a.long_description, a) for a in destinations]
-        self.account.prefill(sorted(items))
+        self.account.prefill(api.for_combo(
+            destinations,
+            attr='long_description'))
         self.account.select(payment.method.destination_account)
 
     #
@@ -359,7 +359,7 @@ class _InstallmentConfirmationSlave(BaseEditor):
         total = self.model.get_installment_value()
         if value >= total:
             return ValidationError(_("Discount can not be greater or "
-                                     "equal than %.2f" % (total, )))
+                                     "equal than %.2f") % (total, ))
         if value < 0:
             return ValidationError(_("Discount can not be less than zero"))
 
