@@ -24,14 +24,12 @@
 ##
 """ Slaves for payment management """
 
-import gtk
-
-
 from copy import deepcopy
 import datetime
 from dateutil.relativedelta import relativedelta
 from decimal import Decimal
 
+import gtk
 from kiwi import ValueUnset
 from kiwi.component import get_utility
 from kiwi.datatypes import format_price, currency, ValidationError
@@ -42,12 +40,11 @@ from kiwi.ui.objectlist import Column
 
 from stoqlib.api import api
 from stoqlib.domain.events import CreatePaymentEvent
-from stoqlib.domain.interfaces import IInPayment, IOutPayment
 from stoqlib.domain.payment.group import PaymentGroup
 from stoqlib.domain.payment.method import PaymentMethod, CreditCardData
 from stoqlib.domain.payment.payment import Payment, PaymentChangeHistory
 from stoqlib.domain.payment.renegotiation import PaymentRenegotiation
-from stoqlib.domain.person import PersonAdaptToCreditProvider
+from stoqlib.domain.person import CreditProvider
 from stoqlib.domain.purchase import PurchaseOrder
 from stoqlib.domain.sale import Sale
 from stoqlib.drivers.cheque import get_current_cheque_printer_settings
@@ -203,9 +200,10 @@ class PaymentListSlave(GladeSlaveDelegate):
     gladefile = 'PaymentListSlave'
     gsignal('payment-edited')
 
-    def __init__(self, iface, group, method, total_value, editor_class, parent):
+    def __init__(self, payment_type, group, method, total_value,
+                 editor_class, parent):
         self.parent = parent
-        self.iface = iface
+        self.payment_type = payment_type
         self.group = group
         self.total_value = total_value
         self.editor_class = editor_class
@@ -338,7 +336,7 @@ class PaymentListSlave(GladeSlaveDelegate):
             due_date = datetime.datetime(p.due_date.year,
                                          p.due_date.month,
                                          p.due_date.day)
-            payment = self.method.create_payment(iface=self.iface,
+            payment = self.method.create_payment(payment_type=self.payment_type,
                                                  payment_group=self.group,
                                                  value=p.value,
                                                  due_date=due_date,
@@ -346,8 +344,7 @@ class PaymentListSlave(GladeSlaveDelegate):
                                                  payment_number=p.payment_number)
             if p.bank_account:
                 # Add the bank_account into the payment, if any.
-                adapted = payment.get_adapted()
-                bank_account = adapted.check_data.bank_account
+                bank_account = payment.check_data.bank_account
                 bank_account.bank_number = p.bank_account.bank_number
                 bank_account.bank_branch = p.bank_account.bank_branch
                 bank_account.bank_account = p.bank_account.bank_account
@@ -424,7 +421,7 @@ class BasePaymentMethodSlave(BaseEditorSlave):
         # Note that 'order' may be a Sale or a PurchaseOrder object
         self.order = order_obj
         self.method = payment_method
-        self.method_iface = self._get_payment_method_iface()
+        self.payment_type = self._get_payment_type()
         self.total_value = outstanding_value or self._get_total_amount()
         self.payment_group = self.order.group
         self.payment_list = None
@@ -451,7 +448,7 @@ class BasePaymentMethodSlave(BaseEditorSlave):
         self.wizard.refresh_next(validation_ok)
 
     def _setup_payment_list(self):
-        self.payment_list = PaymentListSlave(self.method_iface,
+        self.payment_list = PaymentListSlave(self.payment_type,
                                              self.payment_group,
                                              self.method,
                                              self.total_value,
@@ -494,13 +491,13 @@ class BasePaymentMethodSlave(BaseEditorSlave):
         else:
             raise TypeError
 
-    def _get_payment_method_iface(self):
+    def _get_payment_type(self):
         if isinstance(self.order, Sale):
-            return IInPayment
+            return Payment.TYPE_IN
         elif isinstance(self.order, PurchaseOrder):
-            return IOutPayment
+            return Payment.TYPE_OUT
         elif isinstance(self.order, PaymentRenegotiation):
-            return IInPayment
+            return Payment.TYPE_IN
         else:
             raise TypeError
 
@@ -710,7 +707,6 @@ class CardMethodSlave(BaseEditorSlave):
         self._payment_group = self.model.group
         self.total_value = (outstanding_value or
                             self._get_total_amount())
-        self.providers = self._get_credit_providers()
         self._selected_type = CreditCardData.TYPE_CREDIT
         BaseEditorSlave.__init__(self, conn)
         self.register_validate_function(self._refresh_next)
@@ -745,7 +741,9 @@ class CardMethodSlave(BaseEditorSlave):
         self.credit_provider.select_item_by_position(0)
 
     def create_model(self, conn):
-        if not self.providers:
+        providers = CreditProvider.get_card_providers(
+            self.method.get_connection())
+        if providers.count() == 0:
             raise ValueError('You must have credit providers information '
                              'stored in the database before start doing '
                              'sales')
@@ -762,8 +760,9 @@ class CardMethodSlave(BaseEditorSlave):
             raise TypeError
 
     def _setup_widgets(self):
-        provider_items = [(p.short_name, p) for p in self.providers]
-        self.credit_provider.prefill(provider_items)
+        providers = CreditProvider.get_card_providers(
+            self.method.get_connection())
+        self.credit_provider.prefill(api.for_combo(providers))
 
         self._radio_group = None
 
@@ -828,16 +827,11 @@ class CardMethodSlave(BaseEditorSlave):
 
         operation = self.method.operation
         for payment in payments:
-            adapted = payment.get_adapted()
-            data = operation.get_card_data_by_payment(adapted)
+            data = operation.get_card_data_by_payment(payment)
             data.card_type = payment_type
             data.provider = provider
             data.fee = provider.get_fee_for_payment(provider, data)
-            data.fee_value = data.fee * adapted.value / 100
-
-    def _get_credit_providers(self):
-        return PersonAdaptToCreditProvider.get_card_providers(
-            self.method.get_connection())
+            data.fee_value = data.fee * payment.value / 100
 
     #
     #   Callbacks
@@ -909,7 +903,7 @@ class MultipleMethodSlave(BaseEditorSlave):
     def __init__(self, wizard, parent, conn, order, payment_method,
                  outstanding_value=currency(0), finish_on_total=True):
         """
-        @param finish_on_total: finalize the payment when the total value is
+        :param finish_on_total: finalize the payment when the total value is
                                 reached.
         """
         self.finish_on_total = finish_on_total
@@ -964,18 +958,25 @@ class MultipleMethodSlave(BaseEditorSlave):
             # payment group - witch should not be considered here.)
             return self.model.group.get_total_value()
         else:
-            raise TypeError
+            raise AssertionError
 
     def _setup_widgets(self):
         self.remove_button.hide()
-        self.cash_radio.connect('toggled', self._on_method__toggled)
-        self.cash_radio.set_data('method', self._method)
-        for method in ['bill', 'check', 'card', 'store_credit',
-                       'deposit']:
-            self._add_method(PaymentMethod.get_by_name(self.conn, method))
+        if isinstance(self.model, (PaymentRenegotiation, Sale)):
+            payment_type = Payment.TYPE_IN
+        elif isinstance(self.model, PurchaseOrder):
+            payment_type = Payment.TYPE_OUT
+        else:
+            raise AssertionError
+
+        for method in PaymentMethod.get_creatable_methods(
+            self.conn, payment_type, separate=False):
+            if method.method_name == 'multiple':
+                continue
+            self._add_method(method)
 
         self.payments.set_columns(self._get_columns())
-        self.payments.add_list(self.model.group.get_items())
+        self.payments.add_list(self.model.group.payments)
 
         self.total_value.set_bold(True)
         self.received_value.set_bold(True)
@@ -1052,8 +1053,13 @@ class MultipleMethodSlave(BaseEditorSlave):
                   payment_method.method_name == 'store_credit'):
                 return
 
-        radio = gtk.RadioButton(self.cash_radio,
-                                payment_method.get_description())
+        children = self.methods_box.get_children()
+        if children:
+            group = children[0]
+        else:
+            group = None
+
+        radio = gtk.RadioButton(group, payment_method.get_description())
         self.methods_box.pack_start(radio)
         radio.connect('toggled', self._on_method__toggled)
         radio.set_data('method', payment_method)
@@ -1147,10 +1153,10 @@ class MultipleMethodSlave(BaseEditorSlave):
 
         if isinstance(self.model, PurchaseOrder):
             payment = self._method.create_outpayment(
-                self.model.group, payment_value).get_adapted()
+                self.model.group, payment_value)
         else:
             payment = self._method.create_inpayment(
-                self.model.group, payment_value).get_adapted()
+                self.model.group, payment_value)
         # We have to modify the payment, so the fiscal printer can calculate
         # and print the change.
         payment.base_value = self._holder.value
@@ -1163,7 +1169,7 @@ class MultipleMethodSlave(BaseEditorSlave):
         # rename the payments at runtime.
         self.payments.clear()
         payment_group = self.model.group
-        payments = payment_group.get_items()
+        payments = payment_group.payments
         npayments = payments.count()
 
         for i, payment in enumerate(payments.orderBy('id')):
