@@ -31,7 +31,6 @@ from kiwi.datatypes import ValidationError
 
 from stoqlib.gui.editors.baseeditor import BaseEditorSlave
 from stoqlib.gui.slaves.sellableslave import SellableDetailsSlave
-from stoqlib.domain.interfaces import IStorable
 from stoqlib.domain.product import Product
 from stoqlib.domain.taxes import ProductTaxTemplate
 from stoqlib.lib.translation import stoqlib_gettext
@@ -106,7 +105,7 @@ class ProductInformationSlave(BaseEditorSlave):
         self.proxy = self.add_proxy(
             self.model, ProductInformationSlave.proxy_widgets)
 
-        storable = IStorable(self.model, None)
+        storable = self.model.storable
         if storable is not None:
             self.storable_proxy = self.add_proxy(
                 storable, ProductInformationSlave.storable_widgets)
@@ -155,7 +154,7 @@ class ProductInformationSlave(BaseEditorSlave):
 
     def on_genero__validate(self, widget, value):
         if len(value) not in (0, 2):
-            return ValidationError(_(u'NCM must have 2 digits.'))
+            return ValidationError(_(u'Gênero must have 2 digits.'))
 
     def on_minimum_quantity__validate(self, widget, value):
         if value and value < 0:
@@ -181,7 +180,6 @@ class ProductInformationSlave(BaseEditorSlave):
 class ProductDetailsSlave(SellableDetailsSlave):
 
     def setup_slaves(self):
-        self.setup_image_slave(self.model.product)
         self.info_slave = ProductInformationSlave(self.conn, self.model.product,
                                                   self.db_form)
         self.attach_slave('details_holder', self.info_slave)
