@@ -59,43 +59,6 @@ class OnSaleInfoSlave(BaseEditorSlave):
             return ValidationError(_("Sale price can not be 0"))
 
 
-class TributarySituationSlave(BaseEditorSlave):
-    """This is base slave for tributary taxes applied to product, service
-    and it's category if any.
-    """
-    gladefile = "TributarySituationSlave"
-    proxy_widgets = ("tax_constant", "tax_value")
-    model_type = None
-
-    def __init__(self, conn, model=None):
-        self.proxy = None
-        BaseEditorSlave.__init__(self, conn, model)
-
-    def setup_combos(self):
-        """The child class must fill the combo
-        """
-
-    def _update_tax_value(self):
-        constant = self.tax_constant.get_selected_data()
-        if constant:
-            self.model.tax_value = constant.tax_value
-            if self.proxy:
-                self.proxy.update('tax_value')
-
-    #
-    # BaseEditorSlave hooks
-    #
-
-    def setup_proxies(self):
-        self.setup_combos()
-        self.proxy = self.add_proxy(self.model,
-                                    TributarySituationSlave.proxy_widgets)
-        self._update_tax_value()
-
-    def on_tax_constant__changed(self, combo):
-        self._update_tax_value()
-
-
 class SellableDetailsSlave(BaseEditorSlave):
     """This is base slave for product or service details."""
     gladefile = 'SellableDetailsSlave'
@@ -106,11 +69,31 @@ class SellableDetailsSlave(BaseEditorSlave):
     def __init__(self, conn, model=None, db_form=None):
         self.db_form = db_form
         BaseEditorSlave.__init__(self, conn, model)
+        self._setup_image_slave(model and model.image)
+
+    #
+    #  BaseEditorSlave hooks
+    #
 
     def setup_proxies(self):
         self.proxy = self.add_proxy(self.model,
                                     SellableDetailsSlave.proxy_widgets)
 
-    def setup_image_slave(self, image_model):
+    #
+    #  Private
+    #
+
+    def _setup_image_slave(self, image_model):
         slave = ImageSlave(self.conn, image_model)
+        slave.connect('image-changed', self._on_image_slave__image_changed)
         self.attach_slave('sellable_image_holder', slave)
+
+    #
+    #  Callbacks
+    #
+
+    def _on_image_slave__image_changed(self, slave, image):
+        if image:
+            image.description = ('%s #%d' %
+                                 (self.model.get_description(), self.model.id))
+        self.model.image = image
