@@ -29,20 +29,18 @@ from kiwi.argcheck import argcheck
 from kiwi.datatypes import ValidationError
 from kiwi.python import AttributeForwarder
 
+from stoqlib.api import api
 from stoqlib.database.runtime import StoqlibTransaction
 from stoqlib.domain.address import CityLocation
-from stoqlib.domain.interfaces import IIndividual
-from stoqlib.domain.person import PersonAdaptToIndividual
+from stoqlib.domain.person import Individual
 from stoqlib.gui.editors.baseeditor import BaseEditorSlave
-from stoqlib.lib.defaults import get_country_states
 from stoqlib.lib.translation import stoqlib_gettext
-from stoqlib.lib.validators import validate_cpf
 
 _ = stoqlib_gettext
 
 
 class _IndividualDocuments(BaseEditorSlave):
-    model_iface = IIndividual
+    model_type = Individual
     gladefile = 'IndividualDocuments'
     proxy_widgets = ('cpf',
                      'rg_expedition_date',
@@ -50,6 +48,9 @@ class _IndividualDocuments(BaseEditorSlave):
                      'rg_number')
 
     def setup_proxies(self):
+        self.document_l10n = api.get_l10n_field(self.conn, 'person_document')
+        self.cpf_lbl.set_label(self.document_l10n.label + ':')
+        self.cpf.set_mask(self.document_l10n.entry_mask)
         self.proxy = self.add_proxy(self.model,
                                     _IndividualDocuments.proxy_widgets)
 
@@ -58,11 +59,13 @@ class _IndividualDocuments(BaseEditorSlave):
         if self.cpf.is_empty():
             return
 
-        if not validate_cpf(value):
-            return ValidationError(_(u'The CPF is not valid.'))
+        if not self.document_l10n.validate(value):
+            return ValidationError(_('%s is not valid.') % (
+                self.document_l10n.label,))
 
         if self.model.check_cpf_exists(value):
-            return ValidationError(_('A person with this CPF already exists'))
+            return ValidationError(_('A person with this %s already exists') % (
+                                                    self.document_l10n.label,))
 
 
 class _IndividualDetailsModel(AttributeForwarder):
@@ -78,7 +81,7 @@ class _IndividualDetailsModel(AttributeForwarder):
         'gender'
         ]
 
-    @argcheck(PersonAdaptToIndividual, StoqlibTransaction)
+    @argcheck(Individual, StoqlibTransaction)
     def __init__(self, target, conn):
         AttributeForwarder.__init__(self, target)
         self.conn = conn
@@ -91,13 +94,13 @@ class _IndividualDetailsModel(AttributeForwarder):
 
     def is_married(self):
         return (self.target.marital_statuses ==
-                PersonAdaptToIndividual.STATUS_MARRIED)
+                Individual.STATUS_MARRIED)
 
     def is_male(self):
-        return self.target.gender == PersonAdaptToIndividual.GENDER_MALE
+        return self.target.gender == Individual.GENDER_MALE
 
     def is_female(self):
-        return self.target.gender == PersonAdaptToIndividual.GENDER_FEMALE
+        return self.target.gender == Individual.GENDER_FEMALE
 
     def birth_location_changed(self):
         return (self.birth_city != self.target.birth_location.city or
@@ -131,13 +134,14 @@ class _IndividualDetailsSlave(BaseEditorSlave):
         ]
 
     def __init__(self, conn, model, visual_mode=False):
+        self.state_l10n = api.get_l10n_field(conn, 'state')
         BaseEditorSlave.__init__(self, conn, model, visual_mode=visual_mode)
 
     def _setup_widgets(self):
         self.male_check.set_active(self.model.is_male())
         self.female_check.set_active(self.model.is_female())
         self.marital_status.prefill(self.model.get_marital_statuses())
-        self.birth_state.prefill(get_country_states())
+        self.birth_state.prefill(self.state_l10n.state_list)
 
     def _update_marital_status(self):
         if self.model.is_married():
@@ -163,9 +167,9 @@ class _IndividualDetailsSlave(BaseEditorSlave):
 
     def on_confirm(self):
         if self.male_check.get_active():
-            self.model.gender = PersonAdaptToIndividual.GENDER_MALE
+            self.model.gender = Individual.GENDER_MALE
         else:
-            self.model.gender = PersonAdaptToIndividual.GENDER_FEMALE
+            self.model.gender = Individual.GENDER_FEMALE
 
         self.model.ensure_birth_location()
         return self.model
@@ -183,17 +187,17 @@ class _IndividualDetailsSlave(BaseEditorSlave):
 
 
 class IndividualEditorTemplate(BaseEditorSlave):
-    model_iface = IIndividual
+    model_type = Individual
     gladefile = 'BaseTemplate'
 
     def __init__(self, conn, model=None, person_slave=None,
                  visual_mode=False):
         """ Creates a new IndividualEditorTemplate object
 
-        @param conn: a database connnection
-        @param model: model
-        @param person_slave: the person slave
-        @param visual_model:
+        :param conn: a database connnection
+        :param model: model
+        :param person_slave: the person slave
+        :param visual_model:
         """
         self._person_slave = person_slave
         BaseEditorSlave.__init__(self, conn, model, visual_mode=visual_mode)
