@@ -31,9 +31,7 @@ from kiwi.python import Settable
 from kiwi.ui.widgets.list import Column
 
 from stoqlib.api import api
-from stoqlib.domain.interfaces import IStorable
 from stoqlib.domain.payment.method import PaymentMethod
-from stoqlib.domain.payment.operation import register_payment_operations
 from stoqlib.domain.purchase import PurchaseOrderView, PurchaseOrder
 from stoqlib.domain.receiving import (ReceivingOrder,
                                       get_receiving_items_by_purchase_order)
@@ -131,7 +129,7 @@ class ConsignmentItemSelectionStep(BaseWizardStep):
             self._validate_step(True)
 
     def _return_single_item(self, sellable, quantity):
-        storable = IStorable(sellable.product, None)
+        storable = sellable.product_storable
         assert storable
 
         branch = self.consignment.branch
@@ -268,7 +266,6 @@ class ConsignmentWizard(PurchaseWizard):
 
         # If we receive the order right after the purchase.
         self.receiving_model = None
-        register_payment_operations()
         first_step = StartConsignmentStep(self, conn, model)
         BaseWizard.__init__(self, conn, first_step, model)
 
@@ -283,7 +280,6 @@ class CloseInConsignmentWizard(BaseWizard):
     size = (790, 400)
 
     def __init__(self, conn):
-        register_payment_operations()
         register_payment_slaves()
         self.purchase_model = None
         first_step = ConsignmentSelectionStep(self, conn)
@@ -299,7 +295,7 @@ class CloseInConsignmentWizard(BaseWizard):
         can_close = all([i.quantity_received == i.quantity_sold +
                                                 i.quantity_returned
                          for i in purchase.get_items()])
-        for payment in purchase.group.get_items():
+        for payment in purchase.group.payments:
             if payment.is_preview():
                 payment.set_pending()
 
