@@ -24,11 +24,10 @@
 ##
 """ Loan wizard"""
 
-import gtk
-
 from decimal import Decimal
 import datetime
 
+import gtk
 from kiwi.datatypes import ValidationError, currency
 from kiwi.python import Settable
 from kiwi.ui.widgets.entry import ProxyEntry
@@ -36,8 +35,7 @@ from kiwi.ui.objectlist import Column, SearchColumn
 
 from stoqlib.api import api
 from stoqlib.database.orm import ORMObjectQueryExecuter
-from stoqlib.domain.interfaces import IStorable, ISalesPerson
-from stoqlib.domain.person import (ClientView, PersonAdaptToUser,
+from stoqlib.domain.person import (ClientView, LoginUser,
                                    ClientCategory)
 from stoqlib.domain.loan import Loan, LoanItem
 from stoqlib.domain.payment.group import PaymentGroup
@@ -85,16 +83,15 @@ class StartNewLoanStep(WizardEditorStep):
 
         # Responsible combo
         self.salesperson_lbl.set_text(_(u'Responsible:'))
-        self.salesperson.set_property('model-attribute', 'responsible')
-        users = PersonAdaptToUser.selectBy(is_active=True, connection=self.conn)
-        items = [(u.person.name, u) for u in users]
-        self.salesperson.prefill(items)
+        self.salesperson.model_attribute = 'responsible'
+        users = LoginUser.selectBy(is_active=True, connection=self.conn)
+        self.salesperson.prefill(api.for_combo(users))
         self.salesperson.set_sensitive(False)
 
         self._fill_clients_combo()
         self._fill_clients_category_combo()
 
-        self.expire_date.set_property('mandatory', True)
+        self.expire_date.mandatory = True
 
         # CFOP combo
         self.cfop_lbl.hide()
@@ -107,7 +104,7 @@ class StartNewLoanStep(WizardEditorStep):
 
         # removed_by widget
         self.removed_by = ProxyEntry(unicode)
-        self.removed_by.set_property('model-attribute', 'removed_by')
+        self.removed_by.model_attribute = 'removed_by'
         if 'removed_by' not in self.proxy_widgets:
             self.proxy_widgets.append('removed_by')
         self.removed_by.show()
@@ -118,18 +115,17 @@ class StartNewLoanStep(WizardEditorStep):
         self.nature_lbl.hide()
 
     def _fill_clients_combo(self):
+        # FIXME: This should not be using a normal ProxyComboEntry,
+        #        we need a specialized widget that does the searching
+        #        on demand.
         clients = ClientView.get_active_clients(self.conn)
-        max_results = sysparam(self.conn).MAX_SEARCH_RESULTS
-        clients = clients[:max_results]
-        items = [(c.name, c.client) for c in clients]
-        self.client.prefill(sorted(items))
-        self.client.set_property('mandatory', True)
+        clients = clients.orderBy('name')
+        self.client.prefill([(c.name, c.client) for c in clients])
+        self.client.mandatory = True
 
     def _fill_clients_category_combo(self):
-        cats = ClientCategory.select(connection=self.conn).orderBy('name')
-        items = [(c.get_description(), c) for c in cats]
-        items.insert(0, ['', None])
-        self.client_category.prefill(items)
+        categories = ClientCategory.select(connection=self.conn)
+        self.client_category.prefill(api.for_combo(categories, empty=''))
 
     def _replace_widget(self, old_widget, new_widget):
         # retrieve the position, since we will replace two widgets later.
@@ -214,9 +210,9 @@ class LoanItemStep(SaleQuoteItemStep):
         self.slave.set_editor(LoanItemEditor)
 
     def _has_stock(self, sellable, quantity):
-        storable = IStorable(sellable.product, None)
+        storable = sellable.product_storable
         if storable is not None:
-            balance = storable.get_full_balance(self.model.branch)
+            balance = storable.get_balance_for_branch(self.model.branch)
         else:
             balance = Decimal(0)
         return balance >= quantity
@@ -335,7 +331,7 @@ class LoanItemSelectionStep(BaseWizardStep):
         sale = Sale(connection=self.conn,
                     branch=self.loan.branch,
                     client=self.loan.client,
-                    salesperson=ISalesPerson(user.person),
+                    salesperson=user.person.salesperson,
                     cfop=sysparam(self.conn).DEFAULT_SALES_CFOP,
                     group=PaymentGroup(connection=self.conn),
                     coupon_id=None)
