@@ -24,11 +24,9 @@
 """ Purchase quote wizard definition """
 
 import datetime
-
 from decimal import Decimal
 
 import gtk
-
 from kiwi.datatypes import currency, ValidationError
 from kiwi.python import Settable
 from kiwi.ui.search import DateSearchFilter
@@ -37,10 +35,9 @@ from kiwi.ui.widgets.list import Column
 from stoqlib.api import api
 from stoqlib.database.orm import ORMObjectQueryExecuter
 from stoqlib.domain.payment.group import PaymentGroup
-from stoqlib.domain.person import Person
+from stoqlib.domain.person import Branch
 from stoqlib.domain.purchase import (PurchaseOrder, PurchaseItem, QuoteGroup,
                                      Quotation)
-from stoqlib.domain.interfaces import IBranch
 from stoqlib.domain.sellable import Sellable
 from stoqlib.domain.views import QuotationView
 from stoqlib.gui.base.dialogs import run_dialog
@@ -79,10 +76,8 @@ class StartQuoteStep(WizardEditorStep):
         quote_group = "%05d" % self.wizard.quote_group.id
         self.quote_group.set_text(quote_group)
 
-        table = Person.getAdapterClass(IBranch)
-        branches = table.get_active_branches(self.conn)
-        items = [(s.person.name, s) for s in branches]
-        self.branch_combo.prefill(sorted(items))
+        branches = Branch.get_active_branches(self.conn)
+        self.branch_combo.prefill(api.for_combo(branches))
         self.notes.set_accepts_tab(False)
 
     def post_init(self):
@@ -390,7 +385,7 @@ class QuoteGroupSelectionStep(BaseWizardStep):
 
     def _remove_quote(self):
         q = self.search.results.get_selected().quotation
-        msg = _('Are you sure you want to remove "%s" ?' % q.get_description())
+        msg = _('Are you sure you want to remove "%s" ?') % q.get_description()
         if not yesno(msg, gtk.RESPONSE_NO,
                      _("Remove quote"), _("Don't remove")):
             return
