@@ -2,7 +2,7 @@
 # vi:si:et:sw=4:sts=4:ts=4
 
 ##
-## Copyright (C) 2005-2011 Async Open Source <http://www.async.com.br>
+## Copyright (C) 2005-2012 Async Open Source <http://www.async.com.br>
 ## All rights reserved
 ##
 ## This program is free software; you can redistribute it and/or modify
@@ -29,33 +29,34 @@ import sys
 
 import gtk
 
+from kiwi.component import get_utility
 from kiwi.datatypes import currency, ValidationError
 from kiwi.ui.widgets.list import Column
 
 from stoqlib.api import api
-from stoqlib.domain.interfaces import IBranch, ITransporter, ISupplier
 from stoqlib.domain.inventory import Inventory
 from stoqlib.domain.payment.group import PaymentGroup
-from stoqlib.domain.payment.operation import register_payment_operations
-from stoqlib.domain.person import Person
+from stoqlib.domain.payment.payment import Payment
+from stoqlib.domain.person import Branch, Supplier, Transporter
 from stoqlib.domain.product import ProductSupplierInfo
 from stoqlib.domain.purchase import PurchaseOrder, PurchaseItem
 from stoqlib.domain.receiving import (ReceivingOrder, ReceivingOrderItem,
                                       get_receiving_items_by_purchase_order)
 from stoqlib.domain.sellable import Sellable
-from stoqlib.lib.translation import stoqlib_gettext
-from stoqlib.lib.parameters import sysparam
-from stoqlib.lib.formatters import format_quantity, get_formatted_cost
+from stoqlib.gui.base.dialogs import run_dialog
 from stoqlib.gui.base.wizards import WizardEditorStep, BaseWizard
 from stoqlib.gui.editors.purchaseeditor import PurchaseItemEditor
+from stoqlib.gui.editors.personeditor import SupplierEditor, TransporterEditor
+from stoqlib.gui.interfaces import IDomainSlaveMapper
 from stoqlib.gui.printing import print_report
 from stoqlib.gui.wizards.personwizard import run_person_role_dialog
 from stoqlib.gui.wizards.receivingwizard import ReceivingInvoiceStep
 from stoqlib.gui.wizards.abstractwizard import SellableItemStep
-from stoqlib.gui.editors.personeditor import SupplierEditor, TransporterEditor
 from stoqlib.gui.slaves.paymentmethodslave import SelectPaymentMethodSlave
-from stoqlib.gui.slaves.paymentslave import (CheckMethodSlave,
-                                             BillMethodSlave, MoneyMethodSlave)
+from stoqlib.gui.slaves.paymentslave import register_payment_slaves
+from stoqlib.lib.translation import stoqlib_gettext
+from stoqlib.lib.parameters import sysparam
+from stoqlib.lib.formatters import format_quantity, get_formatted_cost
 from stoqlib.reporting.purchase import PurchaseOrderReport
 
 _ = stoqlib_gettext
@@ -80,19 +81,12 @@ class StartPurchaseStep(WizardEditorStep):
         WizardEditorStep.__init__(self, conn, wizard, model)
 
     def _fill_supplier_combo(self):
-        # FIXME: Implement and use IDescribable on PersonAdaptToSupplier
-        table = Person.getAdapterClass(ISupplier)
-        suppliers = table.get_active_suppliers(self.conn)
-        items = [(s.person.name, s) for s in suppliers]
-        self.supplier.prefill(sorted(items))
-        self.edit_supplier.set_sensitive(len(items))
+        suppliers = Supplier.get_active_suppliers(self.conn)
+        self.supplier.prefill(api.for_combo(suppliers))
 
     def _fill_branch_combo(self):
-        # FIXME: Implement and use IDescribable on PersonAdaptToBranch
-        table = Person.getAdapterClass(IBranch)
-        branches = table.get_active_branches(self.conn)
-        items = [(s.person.name, s) for s in branches]
-        self.branch.prefill(sorted(items))
+        branches = Branch.get_active_branches(self.conn)
+        self.branch.prefill(api.for_combo(branches))
 
     def _setup_widgets(self):
         allow_outdated = sysparam(self.conn).ALLOW_OUTDATED_OPERATIONS
@@ -326,10 +320,6 @@ class PurchasePaymentStep(WizardEditorStep):
     gladefile = 'PurchasePaymentStep'
     model_type = PaymentGroup
 
-    slave_classes = {'bill': BillMethodSlave,
-                     'check': CheckMethodSlave,
-                     'money': MoneyMethodSlave}
-
     def __init__(self, wizard, previous, conn, model,
                  outstanding_value=currency(0)):
         self.order = model
@@ -355,9 +345,10 @@ class PurchasePaymentStep(WizardEditorStep):
         WizardEditorStep.__init__(self, conn, wizard, model.group, previous)
 
     def _setup_widgets(self):
-        methods = self.slave_classes.keys()
+        register_payment_slaves()
+
         self._ms = SelectPaymentMethodSlave(connection=self.conn,
-                                            available_methods=methods,
+                                            payment_type=Payment.TYPE_OUT,
                                             default_method=self._method)
         self._ms.connect_after('method-changed',
                                self._after_method_select__method_changed)
@@ -368,7 +359,10 @@ class PurchasePaymentStep(WizardEditorStep):
     def _set_method_slave(self):
         """Sets the payment method slave"""
         method = self._ms.get_selected_method()
-        slave_class = self.slave_classes.get(method.method_name)
+        if not method:
+            return
+        domain_mapper = get_utility(IDomainSlaveMapper)
+        slave_class = domain_mapper.get_slave_class(method)
         if slave_class:
             self.wizard.payment_group = self.model
             self.slave = slave_class(self.wizard, self,
@@ -439,10 +433,7 @@ class FinishPurchaseStep(WizardEditorStep):
         self.add_transporter.set_tooltip_text(_("Add a new transporter"))
         self.edit_transporter.set_tooltip_text(_("Edit the selected transporter"))
 
-        # FIXME: Implement and use IDescribable on PersonAdaptToTransporter
-        table = Person.getAdapterClass(ITransporter)
-        transporters = table.get_active_transporters(self.conn)
-        items = [(t.person.name, t) for t in transporters]
+        items = api.for_combo(Transporter.get_active_transporters(self.conn))
         self.transporter.prefill(items)
         self.transporter.set_sensitive(bool(items))
         self.edit_transporter.set_sensitive(bool(items))
@@ -571,7 +562,6 @@ class PurchaseWizard(BaseWizard):
         if model.status != PurchaseOrder.ORDER_PENDING:
             raise ValueError('Invalid order status. It should '
                              'be ORDER_PENDING')
-        register_payment_operations()
         first_step = StartPurchaseStep(self, conn, model)
         BaseWizard.__init__(self, conn, first_step, model, title=title,
                             edit_mode=edit_mode)
@@ -606,3 +596,13 @@ class PurchaseWizard(BaseWizard):
             self.receiving_model.confirm()
 
         self.close()
+
+
+def test():
+    creator = api.prepare_test()
+    retval = run_dialog(PurchaseWizard, None, creator.trans)
+    api.finish_transaction(creator.trans, retval)
+
+
+if __name__ == '__main__':
+    test()
