@@ -30,12 +30,11 @@ from kiwi.datatypes import currency, ValidationError
 from kiwi.ui.widgets.list import Column
 
 from stoqlib.api import api
-from stoqlib.domain.payment.operation import register_payment_operations
 from stoqlib.domain.payment.renegotiation import PaymentRenegotiation
 from stoqlib.domain.payment.group import PaymentGroup
-from stoqlib.lib.translation import stoqlib_gettext
 from stoqlib.gui.base.wizards import WizardEditorStep, BaseWizard
 from stoqlib.gui.wizards.salewizard import BaseMethodSelectionStep
+from stoqlib.lib.translation import stoqlib_gettext
 
 _ = stoqlib_gettext
 
@@ -154,7 +153,6 @@ class PaymentRenegotiationWizard(BaseWizard):
     title = _('Payments Renegotiation Wizard')
 
     def __init__(self, conn, groups):
-        register_payment_operations()
         self.groups = groups
         self._create_model(conn)
         first = PaymentRenegotiationPaymentListStep(conn, self, self.model, self.groups)
@@ -181,6 +179,6 @@ class PaymentRenegotiationWizard(BaseWizard):
 
     def finish(self):
         self.retval = True
-        for payment in self.model.group.get_items():
+        for payment in self.model.group.payments:
             payment.set_pending()
         self.close()
