@@ -24,22 +24,19 @@
 ##
 """ Sale quote wizard"""
 
-import gtk
-
 from decimal import Decimal
 import datetime
 
+import gtk
 from kiwi.datatypes import currency, ValidationError
 from kiwi.ui.widgets.list import Column
 from kiwi.python import Settable
 
 from stoqlib.api import api
 from stoqlib.database.orm import AND, OR
-from stoqlib.domain.interfaces import ISalesPerson, IStorable
 from stoqlib.domain.fiscal import CfopData
 from stoqlib.domain.payment.group import PaymentGroup
-from stoqlib.domain.payment.operation import register_payment_operations
-from stoqlib.domain.person import Person, ClientView, ClientCategory
+from stoqlib.domain.person import ClientView, ClientCategory, SalesPerson
 from stoqlib.domain.product import ProductStockItem
 from stoqlib.domain.sale import Sale, SaleItem
 from stoqlib.domain.sellable import Sellable
@@ -85,9 +82,8 @@ class StartSaleQuoteStep(WizardEditorStep):
         self.invoice_number.hide()
 
         # Salesperson combo
-        salespersons = Person.iselect(ISalesPerson, connection=self.conn)
-        items = [(s.person.name, s) for s in salespersons]
-        self.salesperson.prefill(items)
+        salespersons = SalesPerson.select(connection=self.conn)
+        self.salesperson.prefill(api.for_combo(salespersons))
         if not sysparam(self.conn).ACCEPT_CHANGE_SALESPERSON:
             self.salesperson.set_sensitive(False)
         else:
@@ -95,9 +91,8 @@ class StartSaleQuoteStep(WizardEditorStep):
 
         # CFOP combo
         if sysparam(self.conn).ASK_SALES_CFOP:
-            cfops = [(cfop.get_description(), cfop)
-                        for cfop in CfopData.select(connection=self.conn)]
-            self.cfop.prefill(cfops)
+            cfops = CfopData.select(connection=self.conn)
+            self.cfop.prefill(api.for_combo(cfops))
         else:
             self.cfop_lbl.hide()
             self.cfop.hide()
@@ -111,17 +106,16 @@ class StartSaleQuoteStep(WizardEditorStep):
         self._fill_clients_category_combo()
 
     def _fill_clients_combo(self):
+        # FIXME: This should not be using a normal ProxyComboEntry,
+        #        we need a specialized widget that does the searching
+        #        on demand.
         clients = ClientView.get_active_clients(self.conn)
-        max_results = sysparam(self.conn).MAX_SEARCH_RESULTS
-        clients = clients[:max_results]
-        items = [(c.get_description(), c.client) for c in clients]
-        self.client.prefill(items)
+        clients = clients.orderBy('name')
+        self.client.prefill([(c.name, c.client) for c in clients])
 
     def _fill_clients_category_combo(self):
-        cats = ClientCategory.select(connection=self.conn).orderBy('name')
-        items = [(c.get_description(), c) for c in cats]
-        items.insert(0, ['', None])
-        self.client_category.prefill(items)
+        categories = ClientCategory.select(connection=self.conn).orderBy('name')
+        self.client_category.prefill(api.for_combo(categories, empty=''))
 
     def post_init(self):
         self.toogle_client_details()
@@ -259,10 +253,10 @@ class SaleQuoteItemStep(SellableItemStep):
             product = i.sellable.product
             if not product:
                 continue
-            storable = IStorable(product, None)
+            storable = product.storable
             if not storable:
                 continue
-            stock = storable.get_full_balance(self.model.branch)
+            stock = storable.get_balance_for_branch(self.model.branch)
             i._stock_quantity = stock
 
         return list(items)
@@ -392,7 +386,6 @@ class SaleQuoteWizard(BaseWizard):
             raise ValueError('Invalid sale status. It should '
                              'be STATUS_QUOTE')
 
-        register_payment_operations()
         first_step = StartSaleQuoteStep(conn, self, model)
         BaseWizard.__init__(self, conn, first_step, model, title=title,
                             edit_mode=False)
@@ -404,7 +397,7 @@ class SaleQuoteWizard(BaseWizard):
 
     def _create_model(self, conn):
         user = api.get_current_user(conn)
-        salesperson = ISalesPerson(user.person)
+        salesperson = user.person.salesperson
 
         return Sale(coupon_id=None,
                     status=Sale.STATUS_QUOTE,
