@@ -2,7 +2,7 @@
 # vi:si:et:sw=4:sts=4:ts=4
 
 ##
-## Copyright (C) 2005-2008 Async Open Source <http://www.async.com.br>
+## Copyright (C) 2005-2012 Async Open Source <http://www.async.com.br>
 ## All rights reserved
 ##
 ## This program is free software; you can redistribute it and/or modify
@@ -24,9 +24,7 @@
 ##
 """ Sale wizard definition """
 
-
 import gtk
-
 from kiwi.component import get_utility
 from kiwi.datatypes import currency, ValidationError
 from kiwi.python import Settable
@@ -35,6 +33,13 @@ from stoqlib.api import api
 from stoqlib.database.exceptions import IntegrityError
 from stoqlib.database.orm import AND
 from stoqlib.domain.events import CreatePaymentEvent
+from stoqlib.domain.fiscal import CfopData
+from stoqlib.domain.person import (ClientView,
+                                   CreditProvider, SalesPerson, Transporter)
+from stoqlib.domain.payment.method import PaymentMethod
+from stoqlib.domain.payment.payment import Payment
+from stoqlib.domain.payment.renegotiation import PaymentRenegotiation
+from stoqlib.domain.sale import Sale
 from stoqlib.enums import CreatePaymentStatus
 from stoqlib.exceptions import StoqlibError
 from stoqlib.lib.message import warning, marker
@@ -53,14 +58,6 @@ from stoqlib.gui.slaves.paymentmethodslave import SelectPaymentMethodSlave
 from stoqlib.gui.slaves.paymentslave import register_payment_slaves
 from stoqlib.gui.slaves.saleslave import SaleDiscountSlave
 from stoqlib.gui.wizards.personwizard import run_person_role_dialog
-from stoqlib.domain.fiscal import CfopData
-from stoqlib.domain.person import (Person, ClientView,
-                                   PersonAdaptToCreditProvider)
-from stoqlib.domain.payment.method import PaymentMethod
-from stoqlib.domain.payment.operation import register_payment_operations
-from stoqlib.domain.payment.renegotiation import PaymentRenegotiation
-from stoqlib.domain.sale import Sale
-from stoqlib.domain.interfaces import ISalesPerson, ITransporter
 
 N_ = _ = stoqlib_gettext
 
@@ -127,11 +124,26 @@ class BaseMethodSelectionStep(object):
     and a cash_change_holder EventBox in the glade file
     """
 
+    def __init__(self, create_payment=True):
+        self._create_payment = create_payment
+
+        if not create_payment:
+            for widget in [
+                self.select_method_holder,
+                self.cash_change_holder,
+                self.subtotal_expander,
+                ]:
+                widget.hide()
+
     #
     #   Private API
     #
 
     def _update_next_step(self, method):
+        if not self._create_payment:
+            self.wizard.enable_finish()
+            return
+
         if method and method.method_name == 'money':
             self.wizard.enable_finish()
             self.cash_change_slave.enable_cash_change()
@@ -164,10 +176,9 @@ class BaseMethodSelectionStep(object):
     #
 
     def setup_slaves(self):
-        methods = SelectPaymentMethodSlave.AVAILABLE_METHODS
         marker('SelectPaymentMethodSlave')
         self.pm_slave = SelectPaymentMethodSlave(connection=self.conn,
-                                                 available_methods=methods)
+                                                 payment_type=Payment.TYPE_IN)
         self.pm_slave.connect('method-changed', self.on_payment_method_changed)
         self.attach_slave('select_method_holder', self.pm_slave)
 
@@ -178,6 +189,9 @@ class BaseMethodSelectionStep(object):
             'activate', lambda entry: self.wizard.go_to_next())
 
     def next_step(self):
+        if not self._create_payment:
+            return
+
         selected_method = self.get_selected_method()
         if selected_method.method_name == 'money':
             if not self.cash_change_slave.can_finish():
@@ -190,7 +204,7 @@ class BaseMethodSelectionStep(object):
 
             # We have to modify the payment, so the fiscal printer can
             # calculate and print the payback, if necessary.
-            payment = self.setup_cash_payment().get_adapted()
+            payment = self.setup_cash_payment()
             total = self.cash_change_slave.get_received_value()
             payment.base_value = total
 
@@ -209,8 +223,7 @@ class BaseMethodSelectionStep(object):
 
             step_class = PaymentMethodStep
         elif selected_method.method_name == 'card':
-            providers = PersonAdaptToCreditProvider.get_card_providers(
-                                                                     self.conn)
+            providers = CreditProvider.get_card_providers(self.conn)
             if not providers:
                 warning(_("You need active credit providers to use the "
                           "card payment method."))
@@ -263,8 +276,17 @@ class SalesPersonStep(BaseMethodSelectionStep, WizardEditorStep):
         self.payment_group = payment_group
         marker("WizardEditorStep.__init__")
         WizardEditorStep.__init__(self, conn, wizard, model)
+
+        # If the sale already have payments and they match its total amount,
+        # we cannot let the user create more, or even edit the existing ones.
+        if (payment_group.payments.count() and
+            payment_group.get_total_value() == model.get_total_sale_amount()):
+            create_payment = False
+        else:
+            create_payment = True
+
         marker("BaseMethodSelectionStep.__init__")
-        BaseMethodSelectionStep.__init__(self)
+        BaseMethodSelectionStep.__init__(self, create_payment)
         self.update_discount_and_surcharge()
 
     #
@@ -283,28 +305,28 @@ class SalesPersonStep(BaseMethodSelectionStep, WizardEditorStep):
 
     def _fill_clients_combo(self):
         marker('Filling clients')
+        # FIXME: This should not be using a normal ProxyComboEntry,
+        #        we need a specialized widget that does the searching
+        #        on demand.
         clients = ClientView.get_active_clients(self.conn)
-        max_results = sysparam(self.conn).MAX_SEARCH_RESULTS
-        clients = clients[:max_results]
+        clients = clients.orderBy('name')
         items = [(c.name, c.client) for c in clients]
-        self.client.prefill(sorted(items))
+        self.client.prefill(items)
         self.client.set_sensitive(len(items))
         marker('Filled clients')
 
     def _fill_transporter_combo(self):
         marker('Filling transporters')
-        table = Person.getAdapterClass(ITransporter)
-        transporters = table.get_active_transporters(self.conn)
-        items = [(t.person.name, t) for t in transporters]
+        transporters = Transporter.get_active_transporters(self.conn)
+        items = api.for_combo(transporters)
         self.transporter.prefill(items)
         self.transporter.set_sensitive(len(items))
         marker('Filled transporters')
 
     def _fill_cfop_combo(self):
         marker('Filling CFOPs')
-        cfops = [(cfop.get_description(), cfop)
-                    for cfop in CfopData.select(connection=self.conn)]
-        self.cfop.prefill(cfops)
+        cfops = CfopData.select(connection=self.conn)
+        self.cfop.prefill(api.for_combo(cfops))
         marker('Filled CFOPs')
 
     def _create_client(self):
@@ -371,9 +393,8 @@ class SalesPersonStep(BaseMethodSelectionStep, WizardEditorStep):
             self.client.set_property('mandatory', mandatory_client)
 
         marker('Filling sales persons')
-        salespersons = Person.iselect(ISalesPerson, connection=self.conn)
-        items = [(s.person.name, s) for s in salespersons]
-        self.salesperson.prefill(items)
+        salespersons = SalesPerson.select(connection=self.conn)
+        self.salesperson.prefill(api.for_combo(salespersons))
         marker('Finished filling sales persons')
 
         marker('Read parameter')
@@ -414,7 +435,8 @@ class SalesPersonStep(BaseMethodSelectionStep, WizardEditorStep):
     def post_init(self):
         marker('Entering post_init')
         self.toogle_client_details()
-        self.wizard.payment_group.clear_unused()
+        if self._create_payment:
+            self.wizard.payment_group.clear_unused()
         self.register_validate_function(self.wizard.refresh_next)
         self._update_next_step(self.get_selected_method())
 
@@ -480,7 +502,7 @@ class SalesPersonStep(BaseMethodSelectionStep, WizardEditorStep):
         trans = api.new_transaction()
         transporter = trans.get(self.model.transporter)
         model = run_person_role_dialog(TransporterEditor, self.wizard, trans,
-                                        transporter)
+                                       transporter)
         rv = api.finish_transaction(trans, model)
         trans.close()
         if rv:
@@ -533,7 +555,6 @@ class ConfirmSaleWizard(BaseWizard):
     def __init__(self, conn, model):
         marker('ConfirmSaleWizard')
         self._check_payment_group(model, conn)
-        register_payment_operations()
 
         # invoice_model is a Settable so avoid bug 4218, where more
         # than one checkout may try to use the same invoice number.
@@ -589,3 +610,15 @@ class ConfirmSaleWizard(BaseWizard):
             else:
                 break
         self.close()
+
+
+def test():
+    creator = api.prepare_test()
+    sale_item = creator.create_sale_item()
+    retval = run_dialog(ConfirmSaleWizard, None, creator.trans,
+                        sale_item.sale)
+    api.finish_transaction(creator.trans, retval)
+
+
+if __name__ == '__main__':
+    test()
