@@ -36,3 +36,27 @@ class CompanyDocument(object):
         return True
 
 company_document = CompanyDocument()
+
+
+class PersonDocument(object):
+    label = _('Document')
+    entry_mask = None
+
+    def validate(self, value):
+        return True
+
+person_document = PersonDocument()
+
+# This is not actually a state, it's more like a country subdivsion, see:
+# http://en.wikipedia.org/wiki/Country_subdivision
+
+
+class State(object):
+    label = _('State')
+
+    state_list = []
+
+    def validate(self, value):
+        return True
+
+state = State()
