@@ -25,7 +25,6 @@
 
 from kiwi.python import namedAny
 
-from stoqlib.lib.parameters import sysparam
 from stoqlib.l10n.generic import generic
 
 # This maps country lists in stoqlib.lib.countries to ISO 639-1
@@ -33,15 +32,18 @@ iso639_list = {
     # FIXME: We should use a combo in parameters instead.
     'brazil': 'br',
     'brasil': 'br',
+    'sverige': 'sv',
+    'sweden': 'sv',
 }
 
 
 def get_l10n_module(conn):
+    from stoqlib.lib.parameters import sysparam
     country = sysparam(conn).COUNTRY_SUGGESTED
 
     short = iso639_list.get(country.lower(), None)
     if short is None:
-        return generic
+        short = 'br'
 
     path = 'stoqlib.l10n.%s.%s' % (short, short)
     try:
