@@ -1,4 +1,4 @@
-# -*- Mode: Python; coding: iso-8859-1 -*-
+# -*- Mode: Python; coding: utf-8 -*-
 # vi:si:et:sw=4:sts=4:ts=4
 
 ##
@@ -35,15 +35,15 @@ class ICookieFile(Interface):
     def get():
         """Fetch the cookie or raise CookieError if a problem occurred
 
-        @returns: (username, password)
-        @rtype: tuple
+        :returns: (username, password)
+        :rtype: tuple
         """
 
     def store(username, password):
         """Stores a username and password
 
-        @param username: username
-        @param password: password
+        :param username: username
+        :param password: password
         """
 
     def clear():
@@ -58,7 +58,7 @@ class IApplicationDescriptions(Interface):
     def get_application_names():
         """
         Gets a list of application names.
-        @returns: a list of application names.
+        :returns: a list of application names.
         """
 
     def get_descriptions():
@@ -69,7 +69,7 @@ class IApplicationDescriptions(Interface):
         * Application full name
         * Application icon name
         * Application description
-        @returns: a list of tuples with Stoq application informations.
+        :returns: a list of tuples with Stoq application informations.
         """
 
 
@@ -97,20 +97,19 @@ class IPluginManager(Interface):
 class IPlugin(Interface):
 
     name = Attribute('name')
-    has_product_slave = Attribute('has_product_slave')
 
     def activate():
         """Called everytime the plugins gets activated
 
         This is where the init plugin logic should be, like events
-            connection and so on.
+        connection and so on.
         """
         pass
 
     def get_migration():
         """Get the database migration for the plugin
 
-        @returns: a L{stoqlib.database.migration.PluginSchemaMigration}
+        :returns: a :class:`stoqlib.database.migration.PluginSchemaMigration`
         """
         pass
 
@@ -118,22 +117,28 @@ class IPlugin(Interface):
         """Returns a C{list} of domain classes
 
         This should return a C{list} of tuples, each one containing the
-            domain path as the first item, and a list of classes as
-            the second. e.g. A 'from a.b import C, D' should be
-            translated into the C{tuple} ('a.b', ['C', 'D']).
+        domain path as the first item, and a list of classes as
+        the second. e.g. A 'from a.b import C, D' should be
+        translated into the C{tuple} ('a.b', ['C', 'D']).
         @note: this information is used for database synchronization
 
-        @returns: a C{list} of C{tuple} containing domain info
+        :returns: a C{list} of C{tuple} containing domain info
         """
         pass
 
-    def get_product_slave_class():
-        """Returns a slave that will be appended on product editor
+    def get_dbadmin_commands():
+        """Returns a list of available commands for dbadmin
 
-        If C{self.has_product_slave} is C{True}, this should return a
-            slave that will be used as an extra tab on product editor.
+        :returns: a C{list} of available commands
+        """
+        pass
 
-        @returns: a L{stoqlib.gui.editors.baseeditor.BaseEditorSlave}
+    def handle_dbadmin_command(command, options, args):
+        """Handle a dbadmin command
+
+        :param command: the command string
+        :param options: extra optparser options
+        :param args: a list of C{args}
         """
         pass
 
@@ -149,25 +154,68 @@ class IPaymentOperation(Interface):
 
     def payment_create(payment):
         """This is called when a payment is created
-        @param payment: the created payment
+        :param payment: the created payment
         """
 
     def payment_delete(payment):
         """This is called just before a payment is deleted
-        @param payment: the payment which is going to be deleted
+        :param payment: the payment which is going to be deleted
+        """
+
+    def create_transaction():
+        """If this payment method should create a transaction when
+          paid
+        :returns: True if an AccountTransaction should be created
         """
 
     def selectable(method):
         """This is called to find out if the method should
         be shown in the slave list of payment methods
-        @returns: True if it should be shown, otherwise
+        :returns: True if it should be shown
+        """
+
+    def creatable(method, payment_type, separate):
+        """If it's possible to create new payments of this payment method type
+        :param method: payment method
+        :param payment_type: kind of payment
+        :param separate: if it's created separately from a sale/purchase
+        :returns: True if you can create new methods of this type
+        """
+
+    def can_cancel(payment):
+        """
+        If it's possible to cancel a payment
+        :param payment: the payment to cancel
+        """
+
+    def can_change_due_date(payment):
+        """
+        If it's possible to change the due date of a payment
+        :param payment: the payment to change due date
+        """
+
+    def can_pay(payment):
+        """
+        If it's possible to pay a payable
+        :param payment: the payment to pay
+        """
+
+    def can_print(payment):
+        """
+        If it's possible to print this payment
+        :param payment: the payment to print
+        """
+
+    def print_(payment):
+        """Prints this payment
+        :param payment: the payment to print
         """
 
     def get_constant(payment):
         """This should return a stoqdriver payment method constant
-        @param payment: the payment whose method we shout return a stoqdrivers
+        :param payment: the payment whose method we shout return a stoqdrivers
                         constant
-        @returns: one L{PaymentMethodConstant}
+        :returns: one :class:`PaymentMethodConstant`
         """
 
 
@@ -177,21 +225,21 @@ class IPaymentOperationManager(Interface):
     """
     def get_operation_names():
         """Get the operation names registered in this manager
-        @returns: payment names
-        @rtype: list of strings
+        :returns: payment names
+        :rtype: list of strings
         """
 
     def register(name, operation):
         """Register a payment operation.
-        @param name: name of the payment operation
-        @param operation: the payment operation
-        @type operation: an object implementing L{IPaymentOperation}
+        :param name: name of the payment operation
+        :param operation: the payment operation
+        :type operation: an object implementing :class:`IPaymentOperation`
         """
     def get(name):
         """Get an operation given a name
-        @param name: name of the operation
-        @returns: the operation
-        @rtype operation: an object implementing L{IPaymentOperation}
+        :param name: name of the operation
+        :returns: the operation
+        :rtype operation: an object implementing :class:`IPaymentOperation`
         """
 
 
@@ -205,12 +253,12 @@ class IAppInfo(Interface):
     """
     def set(name, value):
         """Sets a variable to value
-        @param name: string, variable name
-        @param value: value of the key
+        :param name: string, variable name
+        :param value: value of the key
         """
 
     def get(name):
         """Gets a variable
-        @param name: name of the variable to fetch
-        @returns: the key for @name
+        :param name: name of the variable to fetch
+        :returns: the key for @name
         """
