@@ -25,6 +25,7 @@
 
 from decimal import Decimal
 import os
+import sys
 
 from kiwi.argcheck import argcheck
 from kiwi.datatypes import ValidationError
@@ -32,20 +33,19 @@ from kiwi.log import Logger
 from kiwi.python import namedAny, ClassInittableObject
 from stoqdrivers.enum import TaxType
 
-import stoqlib
-from stoqlib.database.runtime import new_transaction
+from stoqlib.database.orm import ORMObjectNotFound
+from stoqlib.database.runtime import new_transaction, get_connection
 from stoqlib.domain.parameter import ParameterData
-from stoqlib.domain.interfaces import ISupplier, IBranch
 from stoqlib.exceptions import DatabaseInconsistency
-from stoqlib.lib.imageutils import ImageHelper
+from stoqlib.l10n.l10n import get_l10n_field
+from stoqlib.lib.barcode import BarcodeInfo
+from stoqlib.lib.kiwilibrary import library
 from stoqlib.lib.translation import stoqlib_gettext
 from stoqlib.lib.validators import (validate_int,
                                     validate_decimal,
                                     validate_directory,
                                     validate_area_code,
-                                    validate_percentage,
-                                    validate_state)
-from stoqlib.lib.barcode import BarcodeInfo
+                                    validate_percentage)
 
 _ = stoqlib_gettext
 log = Logger('stoqlib.parameters')
@@ -122,10 +122,12 @@ class ParameterDetails(object):
                                    % value)
 
     @staticmethod
-    def validate_state(state):
-        if not validate_state(state):
-            return ValidationError(_("'%s' is not a valid state.")
-                                   % state)
+    def validate_state(value):
+        state_l10n = get_l10n_field(get_connection(), 'state')
+        if not state_l10n.validate(value):
+            return ValidationError(
+                _("'%s' is not a valid %s.")
+                % (value, state_l10n.label.lower(), ))
 
     #
     #  Private API
@@ -144,9 +146,9 @@ class ParameterDetails(object):
 _details = [
     ParameterDetails(
         'EDIT_CODE_PRODUCT',
-        ('Products'),
-        ('Disable edit code products'),
-        ('Disable edit code products on purchase application'),
+        _('Products'),
+        _('Disable edit code products'),
+        _('Disable edit code products on purchase application'),
         bool, initial=False),
 
     ParameterDetails(
@@ -155,16 +157,17 @@ _details = [
         _('Primary company'),
         _('The primary company which is the owner of all other '
           'branch companies'),
-        'person.PersonAdaptToBranch'),
+        'person.Branch'),
 
     ParameterDetails(
         'CUSTOM_LOGO_FOR_REPORTS',
         _('General'),
         _('Custom logotype for reports'),
         _('Defines a custom logo for all the reports generated by Stoq. '
-          'The recommended image dimension is 171x59 (pixels), if needed, '
+          'The recommended image dimension is 170x65 (pixels), if needed, '
           'the image will be resized. In order to use the default logotype '
-          'leave this field blank'), ImageHelper, initial=''),
+          'leave this field blank'),
+        'image.Image'),
 
     ParameterDetails(
         'DISABLE_COOKIES',
@@ -190,7 +193,7 @@ _details = [
         _('Suggested supplier'),
         _('The supplier suggested when we are adding a new product in the '
           'system'),
-        'person.PersonAdaptToSupplier'),
+        'person.Supplier'),
 
     ParameterDetails(
         'SUGGESTED_UNIT',
@@ -200,14 +203,6 @@ _details = [
           'system'),
         'sellable.SellableUnit'),
 
-    ParameterDetails(
-        'DEFAULT_BASE_CATEGORY',
-        _('Purchase'),
-        _('Default base sellable category'),
-        _('A default base sellable category which we always get as a '
-          'suggestion when adding a new Sellable on the system'),
-        'sellable.SellableCategory'),
-
     ParameterDetails(
         'ALLOW_OUTDATED_OPERATIONS',
         _('General'),
@@ -223,15 +218,6 @@ _details = [
         _('The default delivery service in the system.'),
         'service.Service'),
 
-    ParameterDetails(
-        'USE_LOGIC_QUANTITY',
-        _('Stock'),
-        _('Use logic quantity'),
-        _('An integer that defines if the company can work or not with '
-          'logic quantities during stock operations. See StockItem '
-          'documentation.'),
-          bool, initial=True),
-
     # XXX This parameter is POS-specific. How to deal with that
     # in a better way?
     ParameterDetails(
@@ -305,7 +291,7 @@ _details = [
         _('Max search results'),
         _('The maximum number of results we must show after searching '
           'in any dialog.'),
-        int, initial=600),
+        int, initial=600, range=(1, sys.maxint)),
 
     ParameterDetails(
         'CONFIRM_SALES_ON_TILL',
@@ -339,7 +325,7 @@ _details = [
         _('Sales'),
         _('Max discount for sales'),
         _('The max discount for salesperson in a sale'),
-        Decimal, initial=5,
+        Decimal, initial=5, range=(0, 100),
         validator=ParameterDetails.validate_percentage),
 
     ParameterDetails(
@@ -407,7 +393,7 @@ _details = [
         _('Default ICMS to be applied on all the products of a sale. ') + ' ' +
         _('This is a percentage value and must be between 0 and 100.') + ' ' +
         _('E.g: 18, which means 18% of tax.'),
-        Decimal, initial=18,
+        Decimal, initial=18, range=(0, 100),
         validator=ParameterDetails.validate_percentage),
 
     ParameterDetails(
@@ -417,7 +403,7 @@ _details = [
         _('Default ISS to be applied on all the services of a sale. ') + ' ' +
         _('This is a percentage value and must be between 0 and 100.') + ' ' +
         _('E.g: 12, which means 12% of tax.'),
-        Decimal, initial=18,
+        Decimal, initial=18, range=(0, 100),
         validator=ParameterDetails.validate_percentage),
 
     ParameterDetails(
@@ -428,7 +414,7 @@ _details = [
         ' ' +
         _('This is a percentage value and must be between 0 and 100.') + ' ' +
         _('E.g: 16, which means 16% of tax.'),
-        Decimal, initial=18,
+        Decimal, initial=18, range=(0, 100),
         validator=ParameterDetails.validate_percentage),
 
     ParameterDetails(
@@ -461,7 +447,7 @@ _details = [
         _('Number of digits to use for product cost'),
         _('Set this parameter accordingly to the number of digits of the '
           'products you purchase'),
-        int, initial=2, range=[2, 8]),
+        int, initial=2, range=(2, 8)),
 
     ParameterDetails(
         'SCALE_BARCODE_FORMAT',
@@ -628,22 +614,29 @@ class ParameterAccess(ClassInittableObject):
 
     def _create_default_values(self):
         # Create default values for parameters that take objects
+        self._create_default_image()
         self._create_default_sales_cfop()
         self._create_default_return_sales_cfop()
         self._create_default_receiving_cfop()
         self._create_default_stock_decrease_cfop()
         self._create_suggested_supplier()
         self._create_suggested_unit()
-        self._create_default_base_category()
         self._create_default_salesperson_role()
         self._create_main_company()
         self._create_delivery_service()
         self._create_product_tax_constant()
 
+    def _create_default_image(self):
+        key = "CUSTOM_LOGO_FOR_REPORTS"
+        from stoqlib.domain.image import Image
+        if self.get_parameter_by_field(key, Image):
+            return
+        self._set_schema(key, None)
+
     def _create_suggested_supplier(self):
+        from stoqlib.domain.person import Supplier
         key = "SUGGESTED_SUPPLIER"
-        from stoqlib.domain.person import Person
-        if self.get_parameter_by_field(key, Person.getAdapterClass(ISupplier)):
+        if self.get_parameter_by_field(key, Supplier):
             return
         self._set_schema(key, None)
 
@@ -654,15 +647,6 @@ class ParameterAccess(ClassInittableObject):
             return
         self._set_schema(key, None)
 
-    def _create_default_base_category(self):
-        from stoqlib.domain.sellable import SellableCategory
-        key = "DEFAULT_BASE_CATEGORY"
-        if self.get_parameter_by_field(key, SellableCategory):
-            return
-        base_category = SellableCategory(description=key,
-                                         connection=self.conn)
-        self._set_schema(key, base_category.id)
-
     def _create_default_salesperson_role(self):
         from stoqlib.domain.person import EmployeeRole
         key = "DEFAULT_SALESPERSON_ROLE"
@@ -673,9 +657,9 @@ class ParameterAccess(ClassInittableObject):
         self._set_schema(key, role.id, is_editable=False)
 
     def _create_main_company(self):
-        from stoqlib.domain.person import Person
+        from stoqlib.domain.person import Branch
         key = "MAIN_COMPANY"
-        if self.get_parameter_by_field(key, Person.getAdapterClass(IBranch)):
+        if self.get_parameter_by_field(key, Branch):
             return
         self._set_schema(key, None)
 
@@ -740,7 +724,7 @@ class ParameterAccess(ClassInittableObject):
         self.rebuild_cache_for(parameter_name)
 
     def rebuild_cache_for(self, param_name):
-        from stoqlib.domain.base import AbstractModel
+        from stoqlib.domain.base import Domain
         try:
             value = self._cache[param_name]
         except KeyError:
@@ -748,7 +732,7 @@ class ParameterAccess(ClassInittableObject):
 
         param = get_parameter_by_field(param_name, self.conn)
         value_type = type(value)
-        if not issubclass(value_type, AbstractModel):
+        if not issubclass(value_type, Domain):
             # XXX: workaround to works with boolean types:
             data = param.field_value
             if value_type is bool:
@@ -757,6 +741,10 @@ class ParameterAccess(ClassInittableObject):
             return
         table = value_type
         obj_id = param.field_value
+        if not obj_id:
+            del self._cache[param_name]
+            return
+
         self._cache[param_name] = table.get(obj_id, connection=self.conn)
 
     def clear_cache(self):
@@ -779,14 +767,14 @@ class ParameterAccess(ClassInittableObject):
             return detail.type
 
     def get_parameter_by_field(self, field_name, field_type):
-        from stoqlib.domain.base import AbstractModel
+        from stoqlib.domain.base import Domain
         if isinstance(field_type, basestring):
             field_type = namedAny('stoqlib.domain.' + field_type)
         if field_name in self._cache:
             param = self._cache[field_name]
-            if issubclass(field_type, AbstractModel):
+            if issubclass(field_type, Domain):
                 return field_type.get(param.id, connection=self.conn)
-            elif issubclass(field_type, (ImageHelper, DirectoryParameter)):
+            elif issubclass(field_type, DirectoryParameter):
                 return param
             else:
                 return field_type(param)
@@ -794,10 +782,13 @@ class ParameterAccess(ClassInittableObject):
                                           connection=self.conn)
         if value is None:
             return
-        if issubclass(field_type, AbstractModel):
+        if issubclass(field_type, Domain):
             if value.field_value == '' or value.field_value is None:
                 return
-            param = field_type.get(value.field_value, connection=self.conn)
+            try:
+                param = field_type.get(value.field_value, connection=self.conn)
+            except ORMObjectNotFound:
+                return None
         else:
             # XXX: workaround to works with boolean types:
             value = value.field_value
@@ -811,6 +802,12 @@ class ParameterAccess(ClassInittableObject):
                     return None
                 else:
                     param = bool(int(value))
+            elif field_type is str:
+                # This that happens during startup if we haven't set
+                # the default encoding to utf-8 which normally pango or gtk does.
+                # Just make sure the string is utf-8 encoded instead of passing it
+                # to str which is not (yet) expecting utf-8.
+                param = value.encode('utf-8')
             else:
                 param = field_type(value)
         self._cache[field_name] = param
@@ -892,7 +889,7 @@ def get_parameter_details(field_name):
 def check_parameter_presence(conn):
     """Check so the number of installed parameters are equal to
     the number of available ones
-    @returns: True if they're up to date, False otherwise
+    :returns: True if they're up to date, False otherwise
     """
 
     results = ParameterData.select(connection=conn)
@@ -916,4 +913,4 @@ def ensure_system_parameters(update=False):
 def is_developer_mode():
     if os.environ.get('STOQ_DEVELOPER_MODE') == '0':
         return
-    return stoqlib.library.uninstalled
+    return library.uninstalled
