@@ -1,8 +1,8 @@
-# -*- Mode: Python; coding: iso-8859-1 -*-
+# -*- Mode: Python; coding: utf-8 -*-
 # vi:si:et:sw=4:sts=4:ts=4
 
 ##
-## Copyright (C) 2011 Async Open Source <http://www.async.com.br>
+## Copyright (C) 2011-2012 Async Open Source <http://www.async.com.br>
 ## All rights reserved
 ##
 ## This program is free software; you can redistribute it and/or modify
@@ -39,9 +39,11 @@ from twisted.internet.protocol import Protocol
 from twisted.web.client import Agent
 from twisted.web.http_headers import Headers
 from twisted.web.iweb import IBodyProducer
+
 from stoqlib.database.runtime import get_connection
+from stoqlib.exceptions import StoqlibError
 from stoqlib.lib.interfaces import IAppInfo
-from stoqlib.lib.parameters import sysparam
+from stoqlib.lib.parameters import is_developer_mode, sysparam
 from stoqlib.lib.pluginmanager import InstalledPlugin
 
 log = Logger('stoqlib.webservice')
@@ -52,11 +54,28 @@ class JsonDownloader(Protocol):
         self.finished = finished
         self.data = ''
 
+    def _try_show_html(self, data):
+        if not data:
+            return
+        if not '<html>' in data:
+            return
+        if not is_developer_mode():
+            return
+
+        from stoqlib.gui.webview import show_html
+        show_html(data)
+
     def dataReceived(self, bytes):
         self.data += bytes
 
     def connectionLost(self, reason):
-        self.finished.callback(json.loads(self.data))
+        try:
+            data = json.loads(self.data)
+        except ValueError:
+            self._try_show_html(self.data)
+            log.info(self.data)
+            data = None
+        self.finished.callback(data)
 
 
 class StringProducer(object):
@@ -98,13 +117,16 @@ class WebService(object):
 
     def _do_request(self, method, document, **params):
         url = '%s/%s' % (self.API_SERVER, document)
-        log.info("Doing a %s on %r" % (method, document))
-
         headers = self._get_headers()
 
         if method == 'GET':
-            # FIXME: Remove q=
-            url += '?q=' + urllib.quote(json.dumps(params))
+            # FIXME: Get rid of this
+            if document in ['bugreport.json',
+                            'tefrequest.json',
+                            'version.json']:
+                url += '?q=' + urllib.quote(json.dumps(params))
+            else:
+                url += '?' + urllib.urlencode(params)
             producer = None
         elif method == 'POST':
             producer = StringProducer(urllib.urlencode(params))
@@ -112,6 +134,8 @@ class WebService(object):
         else:
             raise AssertionError(method)
 
+        log.info("Requsting %s %s %r" % (method, url, headers))
+
         agent = Agent(reactor)
         d = agent.request(method, url, Headers(headers), producer)
 
@@ -126,16 +150,16 @@ class WebService(object):
         # We avoid using SQLObject, otherwise crash-reporting will break
         # for errors that happens in patches modifying any of the
         # tables in the FROM clause below
-        conn = get_connection()
-        data = conn.queryOne("""SELECT person_adapt_to_company.cnpj
-          FROM parameter_data,
-               person_adapt_to_branch,
-               person_adapt_to_company,
-               person
+        try:
+            conn = get_connection()
+        except StoqlibError:
+            return ''
+        data = conn.queryOne("""SELECT company.cnpj
+          FROM parameter_data, branch, company, person
          WHERE field_name = 'MAIN_COMPANY' AND
-               person_adapt_to_branch.id = field_value::int AND
-               person_adapt_to_branch.original_id = person.id AND
-               person_adapt_to_company.original_id = person.id;""")
+               branch.id = field_value::int AND
+               branch.person_id = person.id AND
+               company.person_id = person.id;""")
         if data:
             return data[0]
         return ''
@@ -146,9 +170,9 @@ class WebService(object):
 
     def version(self, conn, app_version):
         """Fetches the latest version
-        @param conn: connection
-        @param app_version: application version
-        @returns: a deferred with the version_string as a parameter
+        :param conn: connection
+        :param app_version: application version
+        :returns: a deferred with the version_string as a parameter
         """
         params = {
             'dist': platform.dist(),
@@ -182,3 +206,24 @@ class WebService(object):
             'phone': phone,
         }
         return self._do_request('GET', 'tefrequest.json', **params)
+
+    def feedback(self, screen, email, feedback):
+        app_info = get_utility(IAppInfo, None)
+        if app_info:
+            app_version = app_info.get('version')
+        else:
+            app_version = 'Unknown'
+        conn = get_connection()
+        params = {
+            'cnpj': self._get_cnpj(),
+            'demo': sysparam(conn).DEMO_MODE,
+            'dist': platform.dist(),
+            'email': email,
+            'feedback': feedback,
+            'plugins': InstalledPlugin.get_plugin_names(conn),
+            'screen': screen,
+            'time': datetime.datetime.today().isoformat(),
+            'uname': platform.uname(),
+            'version': app_version,
+        }
+        return self._do_request('GET', 'feedback.json', **params)
