@@ -25,25 +25,26 @@
 """ Base class implementation for all Stoq reports """
 
 from decimal import Decimal
+import tempfile
 
 import gtk
 import pango
 
+from kiwi.datatypes import converter, ValidationError
 from kiwi.accessor import kgetattr
 from kiwi.environ import environ
 from kiwi.ui.objectlist import ObjectList
-from mako.lookup import TemplateLookup
 from reportlab.lib.units import mm
 from reportlab.lib.utils import ImageReader
 from trml2pdf.trml2pdf import parseString
 
 from stoqlib.database.runtime import (get_current_branch, get_connection,
                                       get_current_user)
-from stoqlib.domain.interfaces import ICompany
 from stoqlib.exceptions import DatabaseInconsistency
-from stoqlib.lib.parameters import sysparam
-from stoqlib.lib.translation import stoqlib_gettext, stoqlib_ngettext
 from stoqlib.lib.formatters import format_phone_number, format_quantity
+from stoqlib.lib.parameters import sysparam
+from stoqlib.lib.template import render_template
+from stoqlib.lib.translation import stoqlib_gettext, stoqlib_ngettext
 from stoqlib.reporting.base.printing import ReportTemplate
 from stoqlib.reporting.base.tables import ObjectTableColumn as OTC
 
@@ -51,22 +52,39 @@ _ = stoqlib_gettext
 
 
 FANCYNAME_FONT = ("Vera-B", 14)
-LOGO_SIZE = (171, 59)
+LOGO_SIZE = (170, 65)
 SMALL_FONT = ("Vera", 12)
 TEXT_HEIGHT = 13
 
 
 def _get_logotype_path(trans):
-    logofile = sysparam(trans).CUSTOM_LOGO_FOR_REPORTS
-    if logofile.is_valid():
-        logofile.resize(LOGO_SIZE)
-        return str(logofile.image_path)
-    else:
-        return environ.find_resource("pixmaps", "stoq_logo_bgwhite.png")
+    logo_domain = sysparam(trans).CUSTOM_LOGO_FOR_REPORTS
+    if logo_domain and logo_domain.image:
+        pixbuf_converter = converter.get_converter(gtk.gdk.Pixbuf)
+        try:
+            pixbuf = pixbuf_converter.from_string(logo_domain.image)
+        except ValidationError:
+            pixbuf = None
+
+        if pixbuf:
+            w, h = LOGO_SIZE
+            ow, oh = pixbuf.props.width, pixbuf.props.height
+            if ow > oh:
+                w = int(h * (ow / float(oh)))
+            else:
+                w = int(h * (oh / float(ow)))
+
+            pixbuf = pixbuf.scale_simple(w, h, gtk.gdk.INTERP_BILINEAR)
+            tmp_file = tempfile.NamedTemporaryFile(prefix='stoq-logo')
+            tmp_file.close()
+            pixbuf.save(tmp_file.name, 'png')
+            return tmp_file.name
+
+    return environ.find_resource("pixmaps", "stoq_logo_bgwhite.png")
 
 
 class BaseStoqReport(ReportTemplate):
-    logo_border = 5 * mm
+    logo_border = 4 * mm
     report_name_prefix = "Stoq - "
 
     def __init__(self, *args, **kwargs):
@@ -79,8 +97,7 @@ class BaseStoqReport(ReportTemplate):
         # vertical position where the document really must starts be
         # drawed (this is used to not override the space reserved to
         # the logotype)
-        self.header_height = (self._logotype.getSize()[1]
-                              + BaseStoqReport.logo_border)
+        self.header_height = LOGO_SIZE[1]
         title = self.get_title()
         if title:
             if not type(title) is tuple:
@@ -91,7 +108,7 @@ class BaseStoqReport(ReportTemplate):
         canvas.saveState()
         person = get_current_branch(get_connection()).person
         main_address = person.get_main_address()
-        company = ICompany(person, None)
+        company = person.company
 
         logo_width, logo_height = self._logotype.getSize()
         header_y = self._topMargin - logo_height - BaseStoqReport.logo_border
@@ -276,7 +293,7 @@ class ObjectListReport(SearchResultsReport):
     def get_columns(self):
         """Returns the report columns.
 
-        @returns: a list of ObjectTableColumns.
+        :returns: a list of ObjectTableColumns.
         """
         if not self._columns:
             self._columns = self._setup_columns_from_list()
@@ -285,15 +302,15 @@ class ObjectListReport(SearchResultsReport):
     def add_summary_by_column(self, column_name, value):
         """Includes the summary of a certain column in the summary row.
 
-        @param column_name: the name of the summarized column.
-        @param value: the summary value.
+        :param column_name: the name of the summarized column.
+        :param value: the summary value.
         """
         self._summary_row.update({column_name: value})
 
     def get_summary_row(self):
         """Returns the row used to summarize data.
 
-        @returns: the summary row.
+        :returns: the summary row.
         """
         row = []
         for column in self.get_columns():
@@ -338,8 +355,8 @@ class PriceReport(SearchResultsReport):
 class BaseRMLReport(object):
     """
     A base class for all rml reports
-    @cvar template_name: the name of the template to be used in report
-    @cvar title: the report title
+    :cvar template_name: the name of the template to be used in report
+    :cvar title: the report title
     """
     template_name = None
     title = _('Untitled')
@@ -347,12 +364,10 @@ class BaseRMLReport(object):
     def __init__(self, filename, template_name=None):
         """ Creates a new BaseRMLReport object
 
-        @param filename: filename to save report as
-        @param template_name: optional, name of the rml template to use
+        :param filename: filename to save report as
+        :param template_name: optional, name of the rml template to use
         """
-        template_name = template_name or self.template_name
-        lookup = TemplateLookup(directories=environ.get_resource_paths('template'))
-        self._template = lookup.get_template(template_name)
+        self.template_name = template_name or self.template_name
         self.filename = filename
 
     def save(self):
@@ -363,10 +378,10 @@ class BaseRMLReport(object):
                 "%s.get_namespace must return a dictionary, not $r" %
                 (self.__class__.__name__, ns))
         self._complete_namespace(ns)
-        template = self._template.render(**ns)
+        trml_data = render_template(self.template_name, **ns)
         pdf_file = open(self.filename, 'w')
         # create the pdf file
-        pdf_file.write(parseString(template))
+        pdf_file.write(parseString(trml_data))
         pdf_file.close()
 
     def _complete_namespace(self, ns):
