@@ -34,12 +34,12 @@ import stoqlib
 from stoqlib.database.runtime import get_current_station
 from stoqlib.database.runtime import get_current_branch
 from stoqlib.domain.commission import CommissionSource, CommissionView
-from stoqlib.domain.interfaces import IStorable
 from stoqlib.domain.payment.method import PaymentMethod
 from stoqlib.domain.payment.views import (InPaymentView, OutPaymentView,
                                           InCheckPaymentView,
                                           OutCheckPaymentView)
 from stoqlib.domain.person import CallsView
+from stoqlib.domain.product import Storable
 from stoqlib.domain.purchase import PurchaseOrder
 from stoqlib.domain.service import ServiceView
 from stoqlib.domain.test.domaintest import DomainTest
@@ -197,9 +197,7 @@ class TestReport(DomainTest):
 
         method = PaymentMethod.get_by_name(self.trans, 'money')
         group = self.create_payment_group()
-        inpayment = method.create_inpayment(group, Decimal(100))
-        payment = inpayment.get_adapted()
-
+        payment = method.create_inpayment(group, Decimal(100))
         payment.description = "Test receivable account"
         payment.group.payer = payer.person
         payment.set_pending()
@@ -216,9 +214,7 @@ class TestReport(DomainTest):
 
         method = PaymentMethod.get_by_name(self.trans, 'money')
         group = self.create_payment_group()
-        outpayment = method.create_outpayment(group, Decimal(100))
-        payment = outpayment.get_adapted()
-
+        payment = method.create_outpayment(group, Decimal(100))
         payment.description = "Test payable account"
         payment.group.recipient = drawee.person
         payment.set_pending()
@@ -264,8 +260,6 @@ class TestReport(DomainTest):
         sale.add_sellable(sellable, price=100)
         method = PaymentMethod.get_by_name(self.trans, 'bill')
         payment = method.create_inpayment(sale.group, Decimal(100))
-        inpayment = payment.get_adapted()
-
         TillEntry(value=25, id=20,
                   description="Cash In",
                   payment=None,
@@ -281,7 +275,7 @@ class TestReport(DomainTest):
 
         TillEntry(value=100, id=22,
                   description=sellable.get_description(),
-                  payment=inpayment,
+                  payment=payment,
                   till=till,
                   date=datetime.date(2007, 1, 1),
                   connection=self.trans)
@@ -308,7 +302,7 @@ class TestReport(DomainTest):
         sale.salesperson = salesperson
         sale.add_sellable(sellable, quantity=1)
 
-        storable = product.addFacet(IStorable, connection=self.trans)
+        storable = Storable(product=product, connection=self.trans)
         storable.increase_stock(100, get_current_branch(self.trans))
 
         CommissionSource(sellable=sellable,
@@ -341,7 +335,7 @@ class TestReport(DomainTest):
         sale.get_order_number_str = lambda: '9090'
 
         sale.add_sellable(sellable, quantity=1)
-        storable = product.addFacet(IStorable, connection=self.trans)
+        storable = Storable(product=product, connection=self.trans)
         storable.increase_stock(100, get_current_branch(self.trans))
         sale.order()
         self.checkPDF(SaleOrderReport, sale, date=default_date)
